
//
// @(#)btyaccpar, based on byacc 1.8 (Berkeley)
// Parser skeleton modified for use in the Firebird project by Nickolay Samofatov
//
#define YYBTYACC 1

#include "firebird.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "../dsql/Nodes.h"
#include "../dsql/AggNodes.h"
#include "../dsql/DdlNodes.h"
#include "../dsql/BoolNodes.h"
#include "../dsql/ExprNodes.h"
#include "../dsql/PackageNodes.h"
#include "../dsql/StmtNodes.h"
#include "../dsql/WinNodes.h"
#include "../jrd/RecordSourceNodes.h"
#include "../common/classes/Nullable.h"
#include "gen/parse.h"
#include "../dsql/Parser.h"

#define YYERROR_DETAILED

/*
*	PROGRAM:	Dynamic SQL runtime support
*	MODULE:		parse.y
*	DESCRIPTION:	Dynamic SQL parser
*
* The contents of this file are subject to the Interbase Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy
* of the License at http://www.Inprise.com/IPL.html
*
* Software distributed under the License is distributed on an
* "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
* or implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The Original Code was created by Inprise Corporation
* and its predecessors. Portions created by Inprise Corporation are
* Copyright (C) Inprise Corporation.
*
* All Rights Reserved.
* Contributor(s): ______________________________________.
*
* 2002-02-24 Sean Leyne - Code Cleanup of old Win 3.1 port (WINDOWS_ONLY)
* 2001.05.20 Neil McCalden: Allow a udf to be used in a 'group by' clause.
* 2001.05.30 Claudio Valderrama: DROP TABLE and DROP VIEW lead now to two
*   different node types so DDL can tell which is which.
* 2001.06.13 Claudio Valderrama: SUBSTRING is being surfaced.
* 2001.06.30 Claudio valderrama: Feed (line,column) for each node. See node.h.
* 2001.07.10 Claudio Valderrama: Better (line,column) report and "--" for comments.
* 2001.07.28 John Bellardo: Changes to support parsing LIMIT and FIRST
* 2001.08.03 John Bellardo: Finalized syntax for LIMIT, change LIMIT to SKIP
* 2001.08.05 Claudio Valderrama: closed Bug #448062 and other spaces that appear
*   in rdb$*_source fields when altering domains plus one unexpected null pointer.
* 2001.08.12 Claudio Valderrama: adjust SUBSTRING's starting pos argument here
*   and not in gen.c; this closes Bug #450301.
* 2001.10.01 Claudio Valderrama: enable explicit GRANT...to ROLE role_name.
* 2001.10.06 Claudio Valderrama: Honor explicit USER keyword in GRANTs and REVOKEs.
* 2002.07.05 Mark O'Donohue: change keyword DEBUG to KW_DEBUG to avoid
*			clashes with normal DEBUG macro.
* 2002.07.30 Arno Brinkman:
* 2002.07.30 	Let IN predicate handle value_expressions
* 2002.07.30 	tokens CASE, NULLIF, COALESCE added
* 2002.07.30 	See block < CASE expression > what is added to value as case_expression
* 2002.07.30 	function is split up into aggregate_function, numeric_value_function, string_value_function, generate_value_function
* 2002.07.30 	new group_by_function and added to grp_column_elem
* 2002.07.30 	cast removed from function and added as cast_specification to value
* 2002.08.04 Claudio Valderrama: allow declaring and defining variables at the same time
* 2002.08.04 Dmitry Yemanov: ALTER VIEW
* 2002.08.06 Arno Brinkman: ordinal added to grp_column_elem for using positions in group by
* 2002.08.07 Dmitry Yemanov: INT64/LARGEINT are replaced with BIGINT and available in dialect 3 only
* 2002.08.31 Dmitry Yemanov: allowed user-defined index names for PK/FK/UK constraints
* 2002.09.01 Dmitry Yemanov: RECREATE VIEW
* 2002.09.28 Dmitry Yemanov: Reworked internal_info stuff, enhanced
*							exception handling in SPs/triggers,
*							implemented ROWS_AFFECTED system variable
* 2002.10.21 Nickolay Samofatov: Added support for explicit pessimistic locks
* 2002.10.29 Nickolay Samofatov: Added support for savepoints
* 2002.12.03 Dmitry Yemanov: Implemented ORDER BY clause in subqueries.
* 2002.12.18 Dmitry Yemanov: Added support for SQL-compliant labels and LEAVE statement
* 2002.12.28 Dmitry Yemanov: Added support for parametrized events.
* 2003.01.14 Dmitry Yemanov: Fixed bug with cursors in triggers.
* 2003.01.15 Dmitry Yemanov: Added support for runtime trigger action checks.
* 2003.02.10 Mike Nordell  : Undefined Microsoft introduced macros to get a clean compile.
* 2003.05.24 Nickolay Samofatov: Make SKIP and FIRST non-reserved keywords
* 2003.06.13 Nickolay Samofatov: Make INSERTING/UPDATING/DELETING non-reserved keywords
* 2003.07.01 Blas Rodriguez Somoza: Change DEBUG and IN to avoid conflicts in win32 build/bison
* 2003.08.11 Arno Brinkman: Changed GROUP BY to support all expressions and added "AS" support
*						   with table alias. Also removed group_by_function and ordinal.
* 2003.08.14 Arno Brinkman: Added support for derived tables.
* 2003.10.05 Dmitry Yemanov: Added support for explicit cursors in PSQL.
* 2004.01.16 Vlad Horsun: added support for default parameters and
*   EXECUTE BLOCK statement
* Adriano dos Santos Fernandes
*/

#include "firebird.h"
#include "dyn_consts.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>

#include "gen/iberror.h"
#include "../dsql/dsql.h"
#include "../jrd/ibase.h"
#include "../jrd/flags.h"
#include "../jrd/jrd.h"
#include "../jrd/DataTypeUtil.h"
#include "../dsql/errd_proto.h"
#include "../dsql/make_proto.h"
#include "../yvalve/gds_proto.h"
#include "../jrd/err_proto.h"
#include "../common/intlobj_new.h"
#include "../jrd/Attachment.h"
#include "../common/StatusArg.h"

/* This is needed here to provide backward compatibility when working with SSPI plugin*/
#include "../auth/trusted/AuthSspi.h"

/* since UNIX isn't standard, we have to define*/
/* stuff which is in <limits.h> (which isn't available on all UNIXes...*/

const long SHRT_POS_MAX			= 32767;
const long SHRT_UNSIGNED_MAX	= 65535;
const long SHRT_NEG_MAX			= 32768;
const int POSITIVE	= 0;
const int NEGATIVE	= 1;
const int UNSIGNED	= 2;

/*const int MIN_CACHE_BUFFERS	= 250;*/
/*const int DEF_CACHE_BUFFERS	= 1000;*/

#define YYSTYPE YYSTYPE
#if defined(DEBUG) || defined(DEV_BUILD)
#define YYDEBUG		1
#endif

#define YYREDUCEPOSNFUNC yyReducePosn
#define YYREDUCEPOSNFUNCARG NULL


/* ASF: Inherited attributes (aka rule parameters) are executed even when in trial mode, but action*/
/* rules ({}) are executed only when in full parse mode. NOTRIAL should be used to avoid segfaults*/
/* due to accessing invalid pointers in parameters (not yet returned from action rules).*/
#define NOTRIAL(x) (yytrial ? NULL : (x))


inline unsigned trigger_type_suffix(const unsigned slot1, const unsigned slot2, const unsigned slot3)
{
	return ((slot1 << 1) | (slot2 << 3) | (slot3 << 5));
}


#include "../dsql/chars.h"

using namespace Jrd;
using namespace Firebird;

static int yylhs[] = {                                        -1,
    0,    0,    1,    1,    1,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    3,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    4,    4,    4,    4,  555,  556,
    5,  557,  559,    6,    6,    6,    6,    6,    6,    6,
  560,    6,    6,  561,  562,    6,    7,    7,    7,    7,
    7,    7,    7,    7,    7,    7,    7,    7,    7,  558,
  558,    8,    8,  563,    8,    9,  564,    9,   10,   11,
   12,   12,   12,   12,   12,   13,   13,  565,  565,   14,
   14,   15,   15,   15,   16,   16,   17,   17,   18,   18,
   18,   19,   19,   20,   20,   21,   21,  566,  566,   22,
   22,  567,   23,  568,  569,   24,   24,   24,   24,   24,
   24,   24,  570,   24,   24,  571,   24,   24,   25,   25,
   26,   26,  572,   27,   27,  573,   27,   27,   28,   28,
   28,   28,   28,   28,   29,   29,   29,   30,   30,   31,
   32,   32,   33,   34,   35,   35,  574,  575,  576,   36,
   37,   37,   37,   38,  577,   38,  578,   38,   39,  579,
   39,   40,   41,   41,   41,   41,  580,   42,  581,   42,
   43,   43,   44,   44,   44,   44,   44,   45,   46,   46,
   47,   48,  582,  583,   48,   48,   48,   48,   48,   48,
   48,   48,   48,   48,   48,   48,   48,   48,   48,   48,
   48,  584,   48,  585,   48,   49,   50,   50,   50,   50,
   50,   50,   50,   50,   50,   50,   50,   51,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   53,
   54,   55,   56,   56,   57,   57,   57,  587,  588,   58,
   59,   59,   59,   60,   60,   61,   61,   62,  591,   62,
   63,   63,  593,  594,   64,   65,   65,   66,  595,   66,
   67,   67,  592,  592,   68,   69,   69,  596,   70,   71,
   72,   72,   73,   74,   74,  597,  597,   75,   76,   76,
   77,   78,   78,   79,   79,   80,   81,   81,   81,   82,
  598,  599,  600,  601,   83,   84,   84,   84,   85,   85,
   86,  602,   86,   87,   87,   87,   88,   88,   89,   89,
   90,   90,   91,   91,   92,  603,  604,  605,   93,  589,
  589,   94,   95,   95,   96,  606,   96,   97,   97,   97,
   97,   97,   97,   97,   97,   98,   98,   99,   99,  100,
  100,  100,  100,  607,  608,  101,  102,  102,  103,  609,
  103,  104,  104,  610,  610,  610,  590,  590,  590,  611,
  612,  105,  613,  106,  107,  107,  107,  108,  108,  108,
  614,  109,  615,  109,  616,  110,  110,  617,  618,  111,
  619,  111,  111,  111,  112,  113,  113,  114,  620,  620,
  621,  586,  586,  115,  115,  116,  116,  117,  117,  117,
  117,  118,  118,  118,  118,  118,  118,  119,  622,  119,
  120,  623,  120,  121,  122,  122,  122,  122,  122,  624,
  123,  124,  124,  125,  125,  125,  125,  126,  126,  127,
  127,  127,  127,  127,  128,  129,  130,  130,  130,  130,
  131,  131,  132,  133,  625,  626,  627,  134,  135,  136,
  137,  137,  137,  138,  138,  139,  139,  140,  141,  141,
  142,  143,  144,  144,  144,  145,  145,  146,  147,  628,
  148,  149,  149,  149,  150,  150,  151,  151,  152,  153,
  154,  155,  155,  156,  156,  157,  157,  158,  159,  160,
  160,  161,  161,  162,  162,  163,  163,  163,  163,  164,
  164,  165,  165,  166,  630,  631,  632,  166,  633,  166,
  167,  167,  168,  629,  629,  169,  170,  170,  170,  171,
  171,  172,  173,  173,  173,  174,  174,  175,  175,  176,
  176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
  176,  176,  176,  176,  176,  176,  176,  176,  176,  177,
  177,  178,  178,  178,  178,  178,  179,  180,  180,  180,
  181,  634,  635,  182,  183,  183,  184,  184,  185,  636,
  637,  638,  186,  187,  188,  189,  639,  189,  189,  190,
  190,  191,  192,  192,  193,  194,  194,  640,  195,  195,
  196,  196,  196,  196,  196,  196,  196,  196,  197,  197,
  198,  199,  200,  201,  202,  202,  202,  202,  203,  204,
  204,  205,  205,  206,  207,  207,  208,  208,  209,  210,
  210,  641,  642,  211,  643,  212,  644,  212,  213,  213,
  213,  213,  213,  214,  214,  214,  215,  216,  645,  646,
  217,  217,  218,  218,  218,  218,  218,  218,  219,  219,
  220,  220,  220,  221,  221,  221,  647,  222,  223,  223,
  224,  224,  225,  226,  227,  228,  229,  229,  230,  230,
  230,  230,  230,  230,  231,  232,  232,  232,  233,  233,
  233,  234,  234,  234,  234,  234,  235,  235,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
  236,  236,  236,  237,  237,  238,  238,  238,  238,  238,
  238,  238,  238,  238,  238,  238,  238,  238,  238,  238,
  239,  239,  240,  240,  241,  648,  649,  241,  241,  241,
  241,  241,  650,  241,  241,  241,  241,  241,  241,  241,
  241,  241,  241,  241,  241,  241,  651,  652,  242,  243,
  653,  243,  244,  244,  244,  244,  244,  244,  244,  244,
  244,  245,  654,  245,  246,  246,  246,  246,  246,  246,
  246,  246,  246,  246,  246,  246,  246,  246,  247,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  655,  655,  249,  249,  250,  250,  250,  251,  251,
  252,  253,  253,  254,  254,  255,  256,  256,  257,  257,
  656,  258,  258,  258,  258,  258,  258,  657,  258,  258,
  258,  258,  259,  259,  260,  260,  260,  261,  261,  262,
  263,  263,  263,  263,  263,  263,  263,  263,  263,  263,
  263,  263,  263,  263,  263,  263,  263,  263,  263,  263,
  263,  264,  264,  264,  265,  265,  266,  266,  267,  267,
  268,  268,  268,  269,  269,  270,  270,  271,  271,  272,
  272,  273,  273,  274,  274,  274,  274,  274,  274,  274,
  274,  274,  274,  658,  658,  659,  660,  275,  275,  275,
  275,  276,  276,  277,  277,  277,  278,  278,  279,  279,
  279,  280,  280,  280,  663,  663,  663,  662,  662,  661,
  661,  661,  281,  281,  282,  282,  282,  664,  664,  283,
  283,  283,  283,  284,  284,  285,  285,  285,  286,  287,
  288,  288,  289,  666,  666,  290,  291,  665,  665,  292,
  292,  667,  667,  668,  669,  293,  294,  294,  295,  295,
  296,  670,  296,  297,  297,  297,  297,  297,  297,  297,
  297,  297,  671,  672,  297,  298,  298,  299,  299,  299,
  300,  300,  300,  301,  301,  301,  302,  302,  302,  303,
  303,  304,  304,  305,  306,  306,  307,  307,  308,  309,
  309,  309,  309,  309,  309,  673,  674,  310,  311,  311,
  312,  313,  313,  313,  313,  313,  313,  313,  313,  313,
  313,  313,  313,  313,  314,  315,  315,  315,  316,  316,
  316,  317,  318,  318,  319,  319,  320,  321,  321,  322,
  322,  323,  323,  324,  324,  325,  325,  325,  326,  326,
  327,  328,  329,  330,  330,  330,  331,  332,  333,  333,
  333,  333,  334,  334,  334,  335,  335,  335,  336,  336,
  337,  337,  338,  338,  339,  339,  340,  340,  677,  677,
  341,  342,  342,  343,  343,  344,  344,  344,  345,  346,
  346,  347,  347,  348,  348,  349,  349,  349,  350,  351,
  352,  352,  353,  354,  355,  355,  355,  355,  356,  356,
  357,  357,  358,  359,  359,  359,  359,  359,  678,  678,
  360,  360,  361,  361,  362,  363,  363,  364,  364,  365,
  365,  680,  681,  366,  679,  679,  679,  679,  679,  679,
  367,  367,  368,  368,  369,  369,  370,  682,  683,  370,
  684,  370,  371,  371,  372,  685,  372,  373,  373,  374,
  374,  375,  376,  376,  376,  377,  377,  378,  378,  379,
  379,  380,  380,  686,  686,  381,  381,  687,  687,  382,
  382,  382,  688,  383,  383,  383,  384,  689,  690,  385,
  386,  386,  691,  386,  386,  692,  693,  387,  694,  695,
  388,  389,  389,  389,  389,  696,  390,  697,  390,  391,
  391,  392,  393,  394,  394,  395,  396,  698,  699,  700,
  397,  398,  701,  398,  399,  399,  399,  400,  400,  401,
  402,  402,  403,  404,  404,  405,  405,  406,  407,  407,
  408,  702,  408,  409,  410,  410,  411,  411,  411,  412,
  413,  413,  414,  415,  415,  415,  415,  415,  415,  415,
  416,  416,  416,  416,  416,  416,  416,  416,  416,  416,
  416,  417,  418,  418,  418,  418,  418,  418,  418,  418,
  419,  420,  420,  420,  421,  421,  422,  422,  423,  423,
  424,  424,  425,  425,  425,  426,  426,  426,  426,  426,
  426,  426,  426,  427,  427,  428,  429,  430,  430,  430,
  431,  431,  431,  431,  432,  432,  433,  703,  704,  434,
  706,  435,  707,  436,  708,  437,  705,  705,  438,  438,
  439,  709,  439,  440,  440,  440,  440,  440,  440,  440,
  440,  440,  441,  442,  442,  443,  443,  444,  444,  710,
  711,  712,  445,  713,  714,  446,  715,  716,  447,  448,
  717,  718,  719,  449,  450,  451,  451,  452,  452,  452,
  453,  453,  454,  454,  454,  454,  454,  455,  455,  456,
  456,  457,  457,  458,  458,  459,  459,  460,  460,  460,
  461,  461,  461,  461,  461,  461,  461,  461,  461,  461,
  461,  461,  461,  461,  461,  461,  461,  461,  461,  461,
  461,  461,  461,  461,  461,  461,  461,  461,  462,  462,
  463,  463,  463,  463,  463,  464,  464,  465,  465,  466,
  467,  467,  468,  468,  469,  469,  469,  470,  470,  470,
  470,  471,  471,  471,  471,  471,  472,  472,  473,  474,
  474,  475,  476,  476,  476,  476,  476,  476,  477,  477,
  478,  479,  479,  480,  481,  482,  483,  484,  484,  485,
  486,  486,  486,  487,  487,  487,  488,  488,  488,  488,
  488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
  488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
  488,  488,  488,  488,  488,  489,  489,  489,  489,  489,
  489,  489,  489,  489,  489,  489,  489,  490,  490,  490,
  491,  491,  492,  493,  493,  494,  494,  495,  495,  496,
  497,  497,  497,  498,  499,  499,  500,  501,  501,  502,
  502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
  502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
  502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
  502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
  502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
  503,  503,  503,  503,  503,  503,  503,  503,  504,  504,
  504,  504,  505,  505,  506,  506,  507,  507,  507,  507,
  508,  508,  508,  509,  509,  509,  509,  510,  511,  511,
  512,  512,  512,  512,  512,  513,  513,  720,  721,  722,
  514,  515,  515,  516,  516,  517,  517,  518,  518,  519,
  520,  521,  522,  522,  523,  523,  524,  524,  524,  524,
  524,  524,  524,  524,  524,  524,  676,  676,  675,  675,
  525,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
  544,  545,  546,  547,  548,  549,  550,  551,  552,  553,
  553,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,  554,  554,  554,  554,  554,  554,  554,  554,  554,
  554,
};
static int yylen[] = {                                         2,
    1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    0,    0,
    4,    0,    0,   10,   10,   10,   10,   10,   10,   10,
    0,    8,    8,    0,    0,    7,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    2,    1,    1,    0,
    1,    1,    2,    0,    2,    2,    0,    4,    1,    1,
    1,    1,    1,    2,    2,    2,    2,    0,    1,    2,
    4,    1,    2,    2,    2,    2,    2,    4,    1,    1,
    1,    0,    3,    0,    3,    0,    2,    2,    1,    1,
    2,    0,    4,    0,    0,   10,   10,   10,   10,   10,
   10,   10,    0,    8,    8,    0,    7,    6,    0,    3,
    0,    3,    0,    2,    2,    0,    4,    4,    2,    2,
    2,    2,    2,    2,    1,    2,    2,    2,    4,    1,
    2,    4,    1,    2,    2,    3,    0,    0,    0,   11,
    1,    1,    5,    0,    0,    2,    0,    4,    2,    0,
    4,    2,    0,    2,    2,    1,    0,    2,    0,    4,
    2,    2,    0,    2,    2,    1,    3,    9,    1,    1,
    2,    2,    0,    0,    9,    2,    2,    2,    4,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    3,    0,    3,    0,    4,    2,    2,    2,    2,    4,
    2,    2,    2,    3,    2,    2,    2,    4,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    3,    4,    2,
    2,    2,    0,    1,    1,    1,    4,    0,    0,    8,
    0,    1,    1,    0,    1,    0,    4,    0,    0,    2,
    1,    2,    0,    0,    8,    0,    2,    2,    0,    3,
    1,    1,    0,    1,    2,    0,    1,    2,    4,    3,
    0,    1,    3,    0,    3,    0,    1,    3,    1,    3,
    3,    1,    3,    0,    1,    5,    1,    1,    2,    1,
    0,    0,    0,    0,   10,    0,    2,    5,    0,    2,
    2,    0,    3,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    0,    1,    5,    0,    0,    0,    6,    0,
    1,    1,    0,    2,    2,    0,    3,    3,    2,    2,
    2,    2,    2,    3,    4,    0,    2,    2,    3,    1,
    4,    6,    3,    0,    0,    5,    0,    2,    2,    0,
    3,    3,    4,    0,    1,    2,    0,    1,    1,    0,
    0,    7,    0,    7,    0,    4,    4,    0,    3,    2,
    0,    2,    0,    4,    0,    2,    2,    0,    0,    7,
    0,    7,    3,    2,    6,    0,    3,    4,    1,    1,
    3,    2,    1,    1,    1,    0,    2,    1,    3,    6,
    1,    1,    1,    1,    1,    1,    1,    0,    0,    2,
    2,    0,    3,    3,    1,    1,    5,    2,    3,    0,
    3,    0,    2,    3,    4,    8,    1,    0,    4,    0,
    1,    1,    2,    2,    3,    3,    1,    2,    2,    2,
    1,    1,    4,    3,    0,    0,    0,    6,    1,    1,
    0,    2,    4,    0,    5,    2,    4,    3,    1,    4,
    2,    2,    0,    2,    2,    1,    1,    4,    3,    0,
    8,    0,    2,    1,    5,    3,    0,    2,    1,    1,
    5,    1,    0,    1,    2,    3,    3,    1,    1,    6,
    5,    0,    1,    1,    2,    2,    3,    2,    3,    0,
    1,    1,    2,    4,    0,    0,    0,   11,    0,   13,
    1,    1,    3,    0,    1,    7,    0,    2,    1,    1,
    1,    3,    0,    1,    2,    1,    2,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
    2,    1,    1,    1,    1,    1,    5,    2,    3,    6,
    1,    0,    0,    8,    2,    2,    0,    1,    2,    0,
    0,    0,    7,    3,    5,    1,    0,    7,    7,    2,
    4,    3,    2,    4,    1,    0,    2,    0,    3,    2,
    5,    3,    3,    2,    2,    3,    3,    3,    8,    6,
    3,    0,    3,    2,    1,    1,    3,    3,    7,    0,
    2,    1,    2,    2,    0,    1,    0,    1,    3,    1,
    2,    0,    0,    6,    0,    2,    0,    4,    2,    2,
    2,    2,    1,    1,    1,    1,    2,    2,    0,    0,
    7,    3,    1,    1,    1,    1,    2,    2,    5,    7,
    0,    1,    3,    0,    2,    4,    0,   10,    0,    4,
    2,    4,    4,    5,    1,    1,    0,    3,    7,    6,
    9,    8,    9,    8,    1,    1,    1,    0,    2,    2,
    2,    1,    1,    2,    2,    2,    1,    3,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    3,    1,    1,    1,    1,    1,    3,    3,
    3,    3,    3,    3,    5,    5,    5,    5,    5,    5,
    0,    2,    2,    1,    2,    0,    0,    5,    2,    2,
    2,    2,    0,    4,    2,    2,    3,    2,    2,    2,
    3,    3,    2,    2,    3,    4,    0,    0,    4,    2,
    0,    3,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    0,    4,    3,    3,    3,    3,    4,    4,
    5,    5,    4,    5,    3,    4,    4,    3,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    2,    1,    1,    0,    1,    1,    2,    2,
    3,    0,    2,    0,    2,    5,    1,    1,    2,    3,
    0,    3,    4,    3,    2,    2,    5,    0,    5,    1,
    4,    2,    0,    2,    7,    6,    4,    2,    0,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    3,    2,
    3,    2,    2,    2,    2,    5,    2,    2,    3,    3,
    4,    0,    2,    2,    1,    1,    1,    3,    1,    1,
    3,    6,    1,    1,    1,    4,    5,    1,    3,    1,
    3,    1,    2,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    0,    0,    6,    4,    6,
    5,    0,    3,    0,    2,    2,    0,    3,    4,    1,
    5,    4,    1,    4,    1,    2,    2,    1,    1,    1,
    2,    2,    2,    2,    0,    3,    5,    1,    1,    2,
    3,    1,    2,    0,    3,    1,    1,    1,    2,    4,
    0,    1,    5,    0,    1,    3,    3,    0,    1,    0,
    2,    0,    1,    0,    0,    5,    3,    3,    0,    2,
    2,    0,    3,    2,    2,    1,    2,    1,    3,    2,
    2,    3,    0,    0,    4,    3,    1,    1,    3,    3,
    1,    2,    3,    0,    1,    2,    0,    1,    1,    1,
    1,    1,    3,    2,    0,    3,    1,    3,    4,    5,
    6,    7,    7,    6,    1,    0,    0,    9,    0,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    2,    1,    1,    1,    1,    2,    2,    1,    2,
    1,    2,    1,    3,    1,    1,    3,    0,    3,    0,
    2,    0,    2,    4,    5,    0,    3,    2,    1,    3,
    6,    1,    1,    1,    4,    4,    1,    9,    0,    2,
    1,    1,    2,    4,    2,    2,    4,    2,    1,    1,
    1,    1,    1,    3,    1,    3,    1,    3,    0,    1,
    2,    1,    3,    1,    1,    1,    1,    3,    6,    0,
    1,    0,    3,    1,    3,    1,    1,    1,    4,    5,
    5,    5,    2,    4,    4,    2,    6,    4,    0,    3,
    1,    3,    1,    0,    1,    2,    2,    2,    0,    1,
    0,    3,    1,    3,    1,    0,    2,    0,    2,    0,
    2,    0,    0,    6,    0,    1,    2,    1,    1,    1,
    1,    3,    2,    1,    1,    2,    1,    0,    0,    6,
    0,    5,    1,    3,    0,    0,    5,    0,    3,    1,
    3,    3,    0,    1,    1,    0,    2,    1,    1,    2,
    4,    0,    1,    1,    1,    0,    3,    1,    1,    0,
    5,    4,    0,    8,    5,    4,    3,    0,    0,   11,
    2,    2,    0,    3,    3,    0,    0,    5,    0,    0,
    6,    4,    6,    2,    4,    0,    8,    0,   10,    1,
    1,    8,    5,    1,    1,    9,    6,    0,    0,    0,
   15,    0,    0,    3,    0,    2,    4,    1,    3,    4,
    1,    3,    3,    1,    1,    0,    1,    3,    1,    3,
    0,    0,    2,    4,    1,    3,    1,    3,    4,    1,
    1,    3,    1,    1,    3,    3,    2,    3,    3,    4,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    3,    1,    1,    1,    1,    1,    1,    1,    1,
    6,    1,    1,    1,    5,    6,    5,    6,    1,    3,
    3,    4,    1,    1,    2,    3,    5,    4,    6,    4,
    6,    5,    7,    3,    4,    4,    4,    1,    1,    1,
    3,    3,    4,    4,    1,    3,    3,    0,    0,    6,
    0,    7,    0,    6,    0,    7,    0,    1,    0,    2,
    2,    0,    3,    2,    2,    2,    2,    3,    3,    1,
    1,    2,    3,    0,    5,    2,    4,    3,    2,    0,
    0,    0,    5,    0,    0,    5,    0,    0,    5,    1,
    0,    0,    0,    8,    1,    2,    2,    1,    1,    1,
    1,    1,    3,    3,    3,    2,    2,    0,    2,    3,
    2,    1,    1,    1,    1,    1,    3,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    2,    2,    3,    3,    3,    3,    3,    3,    3,
    1,    1,    1,    1,    3,    1,    1,    1,    1,    1,
    1,    2,    2,    2,    2,    0,    3,    0,    3,    4,
    0,    1,    1,    3,    1,    2,    1,    1,    1,    1,
    1,    1,    1,    2,    2,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
    1,    1,    2,    1,    1,    1,    1,    1,    2,    1,
    1,    1,    1,    1,    1,    1,    4,    5,    5,    5,
    5,    5,    5,    5,    5,    5,    5,    6,    6,    4,
    4,    4,    4,    6,    6,    6,    6,    6,    6,    6,
    6,    6,    6,    6,    6,    3,    3,    3,    4,    4,
    7,    8,    6,    4,    8,    6,    4,    0,    2,    2,
    1,    1,    6,    0,    3,    0,    2,    1,    1,    6,
    1,    1,    1,    4,    4,    4,    4,    4,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    7,    8,    8,    8,   10,    8,    6,    4,    1,    1,
    4,    4,    7,    8,    0,    2,    7,    6,    6,    4,
    1,    1,    1,    4,    3,    6,    5,    6,    1,    1,
    6,    8,    6,    6,    8,    1,    1,    0,    0,    0,
    8,    4,    5,    0,    2,    3,    5,    4,    5,    1,
    1,    1,    3,    5,    4,    6,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    0,    1,    0,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,
};
static int yydefred[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,   29,    0,    0,
  102,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    3,    4,    5,   21,   23,   19,   17,   22,   18,
  754,    9,   10,   15,   20,   11, 1026, 1027, 1028,   26,
   27,   25,   28,   24,   16, 1095,   12,    0,    0,    7,
    0,    8,    6, 1300, 1301,   13, 1304, 1305,   14,    0,
    0,  763,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  202,    0,  753, 1039,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  234,    0,    0,    0,    0,    0,    0,  202,    0,
  181,    0,    0,    0,  144,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  202,    0,  930,    0,  657,   30,    0,
    0,   30,    0,    0,    0, 1044,    0,    0, 1890, 1891,
 1892, 1893, 1894, 1895, 1896, 1897, 1898, 1899, 1900, 1901,
 1902, 1903, 1904, 1905, 1906, 1908, 1909, 1910, 1911, 1912,
 1913, 1914, 1907, 1915, 1916, 1917, 1918, 1919, 1920,    0,
 1921, 1922, 1923, 1924, 1925, 1926, 1927, 1928, 1929, 1930,
 1931, 1932, 1933, 1934, 1935, 1936, 1937, 1938, 1939, 1940,
 1941, 1942, 1943, 1944, 1945, 1946, 1947, 1948, 1780, 1782,
 1783, 1784, 1785, 1786, 1787, 1805, 1806, 1788, 1790, 1789,
 1798, 1799, 1795, 1791, 1796, 1792, 1794, 1797, 1793, 1801,
 1802, 1800, 1803, 1804, 1808, 1807, 1809, 1810, 1811, 1812,
 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822,
 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832,
 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842,
 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852,
 1853, 1854, 1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862,
 1863, 1864, 1865, 1866, 1867, 1868, 1869, 1870, 1871, 1872,
 1873, 1874, 1875, 1876, 1877, 1883, 1879, 1878, 1880, 1881,
 1882, 1884, 1885, 1886, 1887, 1888, 1889, 1953, 1954, 1955,
 1956, 1957, 1958, 1960, 1961, 1962, 1964, 1965, 1963, 1949,
 1966, 1950, 1951, 1952, 1959, 1967, 1968, 1969, 1970, 1971,
 1972, 1973, 1974, 1975, 1976, 1977, 1978, 1979, 1980, 1981,
    0, 1201,    0, 1773, 1781,    0,    0, 1139,    0, 1772,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  206, 1029, 1778,    0,    0,    2,    0,    0,    0,    0,
 1144, 1147,    0,    0,    0,    0,  317,  811,  812,  813,
  814,  815,  816,  817,  818,  819,  820,  821,  822,  823,
  824,  825,  826,  827,  828,  829,  830,  831,  839,  833,
  834,  832,  866,  887,  863,  835,  836,  837,  838,  840,
  842,  845,  841,  843,  844,  846,  847,  848,  849,  850,
  851,  852,  853,  854,  855,  856,  857,  858,  868,  881,
  878,  864,  882,  859,  865,  885,  886,  879,  880,  867,
  883,  884,  888,  889,  862,  861,  860,  869,  870,  871,
  872,  873,  874,  875,  876,  877,  890,  891,  765,  777,
  810,  755,    0, 1762,    0,  479,  466,  467,    0,  768,
  470, 1754,  773,    0, 1765,  766,    0, 1766,  449,  441,
  442,    0,  761,  445, 1770,  756, 1203,  760,    0, 1774,
  770,    0, 1775,  666,  759,    0,  769,    0, 1771,  774,
  204, 1444,  488,  762,    0, 1779,    0, 1036, 1549,    0,
  194,  316, 1551,  322,  195,    0, 1758,  182,    0,  186,
  192,    0,    0,  187, 1554,  196, 1556,    0,  188,    0,
  190,    0,  199, 1408,  191,  197,  290,  193,  198,    0,
 1757,    0,  204, 1440,    0,  200, 1254, 1255,    0,    0,
  145,    0, 1763,    0,  938, 1761,  931,    0,  937,  940,
  943,  932,  933,    0,  934,  935,    0,  936, 1777,  942,
  944,  945,  204,    0,    0,  948,    0,    0,    0,  506,
    0, 1277,    0,    0,    0, 1037,    0,    0, 1045, 1047,
 1048,    0,    0, 1170,    0,    0,    0,    0,    0,  215,
  208,  216,  207,  209,  212,  211,  217,    0,    0,  213,
    0,    0, 1101, 1102, 1107,    0, 1106,    0, 1108, 1110,
 1116,    0, 1103, 1105,    0, 1104, 1111, 1115, 1109, 1113,
 1114,    0,    0,    0,    0,    0,    0,    0, 1127,    0,
    0,    0,    0, 1152,    0,    0,    0,    0,    0,    0,
  772,    0, 1756, 1418,  771, 1413,  317,  778,  232,  767,
    0,    0,    0,    0,  148,    0,  285,    0,  899,  900,
    0,    0,  446,  757,  676,  677,    0, 1411,    0,    0,
 1327,  908,  907,    0, 1444,  775,    0,    0, 1043, 1041,
 1550,  317,  264,    0,  230,    0,    0,  272,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  202,    0,  218,
  243,  242,    0,    0,  360,    0,    0, 1097,    0,    0,
 1440,  203,    0,  201,    0,    0,  146,  147,    0,    0,
    0,    0,  939,    0,    0,  941,    0,    0,  950, 1450,
 1455,  949,    0,    0,    0,    0, 1509,    0, 1545,    0,
 1751,    0, 1506, 1655,    0,    0,    0,    0, 1670,    0,
 1546,    0, 1540, 1529,    0, 1528,    0,    0,    0, 1511,
    0,    0, 1530, 1531, 1541, 1542,    0, 1543, 1544,    0,
    0,    0, 1548, 1398, 1399, 1400,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1547, 1537, 1538, 1752,
 1510,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1539, 1487,    0,    0, 1337, 1475, 1344,
 1351, 1358, 1352, 1353, 1354, 1355, 1356, 1359, 1360, 1361,
 1357,    0,    0, 1476, 1504, 1507, 1482,    0, 1532, 1484,
 1485, 1486, 1501, 1502, 1503, 1533, 1483, 1562,    0, 1612,
    0, 1563, 1564, 1618, 1619, 1621, 1622, 1623, 1566,    0,
 1629, 1565, 1689, 1690, 1491, 1488, 1489, 1709, 1710, 1716,
 1717, 1490, 1508,    0, 1340,    0,    0,    0,    0,    0,
   31,    0,  123,    0,    0,    0,    0,  103,  104,  116,
 1035,    0,    0, 1089,    0,    0,    0, 1321, 1341,    0,
    0,    0, 1202, 1140,    0, 1184, 1767,    0,    0,  214,
 1032, 1030, 1112, 1120, 1118, 1117, 1096,    0,    0, 1769,
    0,    0,    0,    0,    0, 1129, 1133, 1560,    0, 1155,
 1153,    0, 1158, 1156, 1748, 1159,    0, 1160, 1150,    0,
    0, 1750,    0,    0,    0, 1134,    0,    0, 1276,    0,
    0, 1313, 1333,    0, 1097,    0,    0,  778,    0,    0,
    0,    0,    0,  502,    0,    0,    0,  469,    0,    0,
    0,  281,    0,  444,    0,  757,  735,  734,    0,    0,
 1097,    0, 1329,    0,    0,  776, 1445, 1451,    0,    0,
    0,    0,  980, 1018,  984,    0, 1019,    0,    0,  985,
    0,    0,    0, 1010, 1022,  979, 1005,  981,  982,  977,
  983,    0,  955,  956,  964,    0,  965,  974,    0,  975,
  976,  978,    0,    0,    0,    0,    0,  270,  224,    0,
  480,  220,  225,    0,  450,  219,  675,  221,  227,    0,
  665,  223,  226,  204, 1447,  489,  222,  245,    0,    0,
  370,    0,    0,    0,    0,    0,    0,  291,  189,  363,
  205, 1441,    0,    0,  148,    0,    0,  180, 1552,  179,
 1755,    0,    0, 1219,    0,    0,    0, 1303,  954,  953,
    0,  951,    0,    0,    0, 1534,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1535, 1536,    0, 1512,
    0, 1514,    0,    0,    0,    0, 1718,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1513, 1515,    0,    0,
    0, 1142, 1143,    0,    0,    0,    0,    0,  604,    0,
    0,  649,    0,    0,    0, 1383, 1366,    0,    0, 1367,
    0, 1370,    0, 1368, 1369,    0,    0,    0, 1363, 1364,
 1365,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  157,  507,    0,   69,
   70,    0,    0,    0,    0,    0,   64,    0,    0,    0,
    0, 1175, 1177, 1174, 1186, 1187, 1188, 1176,    0,    0,
    0,    0,    0,    0,  123, 1033,  288,    0,  286,  287,
 1558, 1046, 1045, 1308,    0,    0,    0,    0,    0,    0,
 1183,    0,  210, 1097, 1126, 1090, 1125,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1162,    0,    0, 1163,
 1165,    0,    0,    0, 1250,    0, 1146, 1145,    0,    0,
    0, 1479,    0, 1478, 1525, 1527, 1480,    0, 1135, 1318,
    0,    0, 1275,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  920,    0,  909,    0,    0,  903,    0,  901,
    0,    0,  515,    0,    0,  468,  503,  476,    0,  478,
    0,    0,  283,  277,    0,  443,  447,    0,    0,    0,
    0,    0,  928,    0,    0,    0,    0, 1328,    0,    0,
 1442,    0,    0,    0,    0,    0,  484,  318,  317,    0,
  987, 1006, 1007, 1023,    0, 1020,    0,    0, 1013, 1011,
 1012,    0,  267,  253,    0,    0,    0,  973,    0,    0,
    0,    0, 1014,  273,  231,  279,    0,    0, 1415, 1447,
  228,    0,    0,  369,  361,    0,    0,  682,  683,  680,
    0,    0,    0,    0,    0,    0,  687,  679, 1409, 1097,
  292,    0, 1442,    0,    0,    0, 1555, 1553,    0,    0,
    0, 1226, 1228,    0, 1229, 1221, 1222,    0,  946,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1737, 1738,
 1739, 1740, 1741, 1742, 1745, 1746, 1743, 1744,    0,    0,
    0,    0,    0,    0, 1726,    0, 1719,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1701, 1703, 1702,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1596,    0,    0,    0,    0,    0, 1597, 1598,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1500, 1348, 1477,
  653,    0,    0,  605,    0,  606,    0,    0,    0,    0,
    0,    0,    0, 1394, 1405,    0, 1401,    0, 1402, 1349,
    0,    0,    0,    0,    0,    0,    0, 1385,    0, 1372,
 1374, 1373,    0,    0,    0, 1496,    0,    0,    0,    0,
    0,    0,    0,    0, 1705,    0, 1505, 1338,    0,    0,
  155,    0,    0,    0,    0,    0,    0,    0,   54,   55,
   59,   50,   52,   49,   47,   48,   56,   53,   58,   51,
    0,    0,    0,    0,    0,    0,   45,  126,  138,  140,
    0,    0,    0,    0, 1205,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  120,  122,    0,    0,    0,
    0,    0,    0,  289, 1559,    0,    0, 1309, 1322,    0,
 1307,    0, 1342, 1185,    0,    0, 1091, 1122,    0,    0,
 1124, 1094, 1154, 1157,    0,    0,    0,    0,    0,    0,
    0,    0, 1526, 1776, 1265, 1264, 1267, 1268, 1269,    0,
    0,    0,    0,    0, 1335,    0, 1409,  910,    0,    0,
  915,    0,  922,  916,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  780,  905,  509,  505,    0,    0,  511,
  512,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  526,
  521,    0,    0,  520,    0,  530,  529,  552,  541,  542,
  555,    0,  539,  556,  553,  543,  536,  554,    0,  545,
  546,  544,  634,  636,  635,  537,    0,  531,  532,  535,
  533,  534,  550,  540, 1325, 1324,    0,    0,    0,  452,
  155,    0,    0,  275,    0,  793,  420,    0,    0,  792,
    0,    0,    0,    0,  752,    0,    0, 1409, 1330,    0,
  664,  906,    0, 1452,    0,    0,  481,  485,    0,    0,
    0, 1557,    0,    0,    0,    0, 1021,    0,  265,  407,
  402,  403,  404,  405,  406,  254,    0,  968,    0,    0,
    0,    0,    0,    0,    0,    0,  278, 1097,  229, 1448,
    0,  238,  371,    0,  685,  686,  684,    0,    0,    0,
    0,  708,  702,  696,  720,  693,  690,  699,  717,  705,
  711,  714,  731,  726,    0,  707,  701,  695,  719,  692,
  689,  698,  716,  704,  710,  713,  722,  730,    0,  709,
  703,  697,  721,  694,  691,  700,  718,  706,  712,  715,
  723,  732,    0,    0,    0,    0,    0,    0,  361,    0,
    0,    0,    0,    0,    0,  494,  183,  157,    0,  155,
    0, 1320, 1760, 1227,    0, 1263,    0,    0,    0,    0,
    0, 1567,    0, 1396,    0, 1691,    0,    0,    0,    0,
    0, 1688, 1397,    0,    0,    0, 1517, 1519,    0,    0,
    0,    0,    0,    0, 1720,    0,    0,    0, 1735, 1624,
 1625, 1626, 1692, 1627,    0, 1700,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1599,    0, 1600,    0,
 1604,    0, 1607, 1580, 1581, 1582, 1583,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1339,
    0,    0,    0, 1520,    0,    0,    0,    0,    0,    0,
 1403, 1404, 1350,    0,    0, 1395,    0,    0,    0,    0,
    0,    0,    0, 1628, 1704,    0,  650,    0,    0,    0,
    0,   61,    0,    0,    0,    0,    0,    0,    0,   57,
   41,   41,   67,   67,   67,    0,    0,   73,    0,   72,
    0,   71,    0,   66,   80,   87,  123,    0,    0, 1178,
 1210, 1208, 1206,    0, 1278, 1207,    0,    0,    0,    0,
    0,   41,    0,    0,    0,    0,    0,   41,    0,    0,
    0,    0, 1063,    0, 1056,    0,    0,    0, 1051, 1058,
 1067, 1068,    0,    0, 1141,    0,    0, 1092, 1093,    0,
    0,    0,    0, 1164, 1168, 1166, 1251,    0, 1252,    0,
    0,    0,    0, 1319,    0,    0, 1334,  315,    0,    0,
    0,    0,  251,  914,    0,    0,  918,  782,    0,    0,
  785,  787,  786,    0,    0,  783,  790,  791,  972,    0,
  506,  506,    0,    0,  504,    0,  462,    0,  960,  959,
  963,    0,  519,    0,    0,  570,    0,    0,    0,  613,
  616, 1768,  637,  638,    0,  640,  614,    0,  551,  522,
  622,  527,    0,  620,  528,    0,    0,    0,    0,  611,
  475,    0,    0,    0,  448,    0,    0,  893,    0,    0,
    0,  809,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  926,    0,    0,    0, 1446,    0,  486,  487,  319,
  317,    0,    0,    0,    0,    0,    0,    0,  325,    0,
    0,  989,    0,    0, 1025,    0, 1016,    0,    0,  966,
    0,  998,    0,    0,  999, 1002, 1004,  280,    0, 1442,
  321,    0,  239,    0,  375,    0,    0,    0,  670,  724,
  688,  728,  729,  733,    0, 1410,    0, 1430,    0, 1431,
    0,    0,    0,    0,    0, 1421,    0,    0,  293,  371,
 1443,  496,    0,    0,  498,    0,    0,    0,  491,    0,
    0,  495,  184,  155,  149,    0,    0,    0, 1223, 1302,
 1573, 1572,    0,    0,  398,  401, 1569, 1568,    0, 1577,
 1576, 1575, 1574,    0,    0, 1571, 1570,    0,    0,    0,
 1728, 1727,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  656,  608,  607, 1380, 1377,
 1407, 1406, 1375,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1707,    0,  160,  660,    0,  661,  160,    0,
    0,    0,    0,    0,    0,    0,    0,  123,  123,    0,
    0,    0,   83,   84,   75,   74,    0,    0,  139,    0,
    0, 1279, 1189,    0, 1200, 1195,    0,  123,    0,    0,
    0,    0,    0,    0,    0,  113,  113,  123, 1053,    0,
    0, 1057,    0, 1054,    0, 1055, 1064,    0,    0, 1061,
 1060,    0,    0,    0,    0, 1100,    0,    0,    0, 1258,
 1259, 1257,    0, 1272, 1274, 1336, 1414,  913,  344,  252,
    0,  921,    0,    0,  784,  788,  789,    0,    0,  397,
    0,    0,  513,    0,    0,  518,    0,    0,    0,  571,
    0,    0,  601,    0,  642,  568,    0,  623,  621,    0,
    0,    0,    0,  562,    0,    0,  160,  453,  456,    0,
    0,  794,    0,  797,  798,  420,    0,  796, 1759,  898,
  897,  795,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  808,  805,  389,    0,  390,    0,    0,    0,    0,
    0,    0,  925, 1412,  668, 1473, 1472,    0,    0,    0,
    0,    0,    0,    0,    0,  327,    0,    0,  333,    0,
  330,  329,  332,  331,  991,    0,  995,  996,    0,    0,
    0,    0,  254,  969,  971,  967, 1001, 1409,    0,    0,
    0,  373,  362,  372,    0,    0,    0,  669,    0,    0,
 1409, 1423,    0, 1427,    0, 1424, 1426, 1425, 1432,    0,
  297,    0,    0,  497,  499,  490,    0,    0,    0,  160,
  152,    0,    0,  159,  151,    0,    0,    0, 1708, 1736,
    0, 1687, 1620,    0,    0,    0, 1729,    0,    0, 1711,
 1713,    0, 1698, 1699,    0,    0,    0,    0,    0,    0,
    0, 1714,    0, 1579, 1578,    0,    0,    0, 1603,    0,
 1606, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592,
 1593, 1594, 1595, 1376, 1378,    0,    0,    0, 1371,    0,
 1613, 1706,    0,    0,    0,    0,   33,   33,   33,   33,
   33,   33,   33,    0,    0,    0,   68,    0,   82,    0,
   81,   90,   89,   91,   88,    0,  126,    0,    0,  143,
  141,  100,    0, 1181, 1190, 1279,    0,    0, 1191, 1192,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  123,
  123,    0,    0, 1066, 1059,    0, 1075, 1070, 1069,    0,
 1073, 1062,    0, 1306, 1098,    0,    0,    0,    0,    0,
 1271,  345,  917,    0,  919,    0,    0,  507,  464,  465,
    0,  961,  958,    0,    0,    0,    0,    0,    0,  643,
  644,  646,  645,    0,    0,    0,  625,    0,  563,    0,
    0,    0,    0,  474,  471,  423,    0,    0,    0,  384,
    0,  394,    0,  395,    0,  799,    0,  800,  392,  807,
  806,  803,    0,  895,    0,    0,  749,  750,  746,  745,
  748,  747, 1470,    0,    0, 1466,    0, 1467, 1453,    0,
    0,    0,  338,  340,    0,  328,  334,  990,    0,  988,
 1017,  255,    0,    0,    0, 1449,  358,  359,  247,  240,
    0,  375,  376,  377,    0,  674,    0,  672, 1097, 1428,
 1429,    0,  294,  292,    0,  185,  236,    0,    0,  158,
  169,    0,    0,    0,    0,    0,  166,  162,    0,    0,
    0, 1234,    0, 1231,    0, 1235,    0,  399,    0, 1693,
    0,    0,    0,    0,    0,    0,    0, 1697, 1681,    0,
    0,    0,    0,    0,    0,    0, 1601,    0,    0,    0,
  662,    0,    0,  459,    0,  658,  123,  123,  123,  123,
  123,  123,  123,    0,  126,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  124,  125,  135,    0,    0,    0,
   99,    0,   46,    0,  101, 1179,    0,    0, 1193,    0,
 1197,  105,  105,  105,  105,  105,  105,  105,    0,    0,
  117, 1076,    0, 1082,    0, 1087,    0, 1433,    0, 1213,
    0, 1217, 1148,    0,  924,  269,    0,    0,    0,    0,
    0,    0,  572,    0,    0,  557,    0,    0,    0,    0,
    0,  575,    0,    0,  457,  458,  473,    0,    0,    0,
  427,  421,    0,  378,  381,  383,  801,  802,  804,  391,
    0, 1465, 1464, 1469, 1463,    0,  339,    0,    0,  335,
  993,    0,    0,  258,  262,  261, 1416,    0,  374,  673,
  671,    0,    0,    0,    0,    0,  292,    0,  364,    0,
    0,    0,    0,    0,  168,  161,    0,  164,  165,  178,
    0, 1224, 1238, 1237, 1241, 1233, 1236,    0, 1694,    0,
 1725,    0, 1721, 1712, 1682, 1683, 1684,    0, 1715,    0,
 1686, 1609, 1610, 1602, 1605,  663,  160,  455,  461,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   42,  130,
  137,  129,  132,  136,  133,  134,  131,   43,   95,  142,
   98,   97, 1280,    0,    0, 1281, 1282,    0,  123,  123,
  123,  123,  123,  123,  123,  114,  115,    0,    0,    0,
 1084,    0,    0,  346,  345,    0,    0,    0,    0,  560,
    0,    0,    0,    0,    0,  627,  633,    0,    0,    0,
    0,  626,    0,    0,    0,    0,    0,    0,    0,    0,
  379,  379,  388,    0, 1460, 1459, 1454,    0, 1458,    0,
  343,  260,  268, 1409, 1435,    0, 1436,    0,  298,  295,
  314,  292,  301,    0,    0,    0,    0,    0,  172,    0,
  176,  171,    0, 1232,    0,    0,    0, 1722,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   93,
  127,  128, 1284, 1285,    0, 1286, 1194,    0,    0,    0,
    0,    0,    0,    0, 1083, 1079, 1078,    0, 1088, 1310,
 1214,    0,    0,    0,    0,  962,  516,    0,  573,  571,
    0,  641,  624,    0,  632,  631, 1764,  629,  630,    0,
    0,  566,  565,  618,  609,    0,    0,    0,  424,    0,
    0,    0, 1457, 1456, 1461, 1462,    0,    0, 1439,    0,
  303,    0,    0,    0,    0,  304,  305,  306,    0,    0,
  237,  170,    0,  174,    0,  153, 1239, 1239,  400, 1723,
 1685,  460,   34,   36,   35,   37,   38,   39,   40, 1289,
 1287,  106,  108,  107,  109,  110,  111,  112, 1080, 1081,
 1086,    0,    0,    0,    0,  349,    0,    0,  577,    0,
    0,  599,  628,  564,    0,    0,  425,    0,    0,    0,
  409,    0,    0, 1437, 1438,  307,  310,  309,  312,  311,
  308,  366,  367,  150,  177,    0,    0, 1290,    0, 1313,
    0,  351,    0,    0,    0,    0,  508,  571,    0,    0,
    0,    0,    0,    0,  590,  619,    0,    0,    0,  380,
    0,    0,  382,  342,    0, 1243,    0, 1242,    0,    0,
    0, 1288,    0, 1311,    0,  356,  352,    0,    0,    0,
    0,  589,    0,    0,    0,    0,    0,    0,    0,    0,
  429,    0,  385,    0,  411,  412,    0, 1240, 1246,    0,
    0, 1291,    0, 1294,    0, 1314,  353,  510,  572,  578,
  572,  579,  580,  583,    0,    0,    0,    0,    0,    0,
  596,  598,  597,    0,    0,    0,    0,    0,  413,    0,
 1244,    0,    0, 1296,    0,    0,    0,    0,    0,    0,
    0,    0,  426,    0,  434,    0,  433,  387,    0,    0,
    0,  416,  414,  415,    0,    0,    0, 1295,    0,    0,
  581,  584,    0,    0,    0,    0,  437,  436,  435,    0,
    0,  418, 1247, 1298,    0,    0,  440,  438,  439,  419,
    0,    0,    0,    0,    0,    0,    0,  417,    0,    0,
    0, 1297,    0, 1299,
};
static int yydgoto[] = {                                      20,
   21,   22,   23,   24,   25,  951, 1641, 1272, 1643, 1273,
 1274, 2064, 1275, 1644, 2065, 1276, 1645, 2066, 2886, 2678,
 2903, 2680,   26,  958,  959,  960, 2664, 2895, 2896, 1278,
 1649, 2397, 2681,   27,  105,  727, 2593, 1929, 2296, 2594,
 2838, 2832, 3005, 3142,  551, 1137,   28,  101,   29,  361,
   30,  710,  518, 1099,  462,  102, 2826,  526,  713, 1119,
 1862, 2810, 2132,  515, 2552, 2803, 2984, 1423, 1424, 2985,
  521,  697,  698, 1042, 1103, 1438,  473,  667,  668,   31,
 1299,  536,  539, 2279, 2823, 2996, 3133, 3226, 3227, 3228,
 3130,  651,  511,  512, 1408, 1830, 2229, 2220, 2534, 2793,
 2133, 3084, 3182, 3266,  529, 1129, 2999,  715, 2254, 2564,
 2494, 2965, 3353, 2513, 2761, 2154, 2304, 1839, 3280, 3321,
 3355, 3413, 2495, 2496, 2962, 3209, 3385, 3386, 3387, 3428,
  479,  480,  481,  482,  483, 1106, 1382, 2041, 2192, 2489,
 2873, 2874, 2377, 2463,  466,  467,  468,  469, 2755,  664,
 1038,  470, 1102,  503, 1405, 1406, 1407,  504, 1117,  724,
 1924, 1925, 1926, 1032, 1033, 1034, 1739, 1740, 1741, 2164,
 1760, 1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769,
 1770, 1771, 3103, 2475, 2476, 1772, 1773, 1774, 2943, 3339,
 3373, 3340, 3374, 3189, 3270, 3315, 1775, 1776, 2473, 1777,
  885, 1575, 1778, 1779, 1780, 1781, 2170, 3203, 3202, 2183,
 2184, 2950, 3102, 1782, 1783, 1784, 1785, 2746, 1786,  886,
 1232,   33, 1268, 2038, 2378,  494, 1112,  495, 1821,  531,
 1108,  677, 1125, 1450, 1456, 1457, 1126, 1393, 1395,   34,
   79,  459, 1366, 1734, 1388, 1810, 2201,  460, 2772, 2502,
  476,  660, 1030, 1370,  497,  684, 1026, 1365, 2725,  488,
 1050,   35,  126,  736, 1082, 2157, 2158, 2159, 2160, 1084,
 1847, 1848, 1085, 2149, 1087, 2550, 2234, 1428, 1088, 2150,
 1090, 1419, 1091, 1416,   36,   37,   38,  982,   39,   40,
   41,  508,   42,   43, 1302, 1676, 2099, 2100, 2101, 2102,
 2708, 3178, 3261, 2923, 2924, 3081, 2925,   44,   45,   46,
 2106,  632,  633,  634,  635,  636, 1320,  992, 1316, 1787,
  368,  996,  639,   48,   49,  347,  348, 1223, 1224,  370,
  371,  372,  642,  643,  644, 1007, 1328, 1329, 1330, 1331,
 1696, 2110, 1281, 1282, 1283, 2683,  599,  975, 1284, 1285,
 1286, 1287, 2689, 2690, 1288, 1663,  341,  496, 1661, 2439,
 2929, 2930, 2720,  731, 1147, 2842, 2843, 2844, 2845, 3016,
 3325, 3328,  647, 1334, 1335,  549, 2119, 2442, 1936, 1937,
 1017, 1349, 1788,   51, 1789, 2907, 3066, 3067, 3332, 3362,
 1790,   54,   55, 1791,   57,   58, 1792, 3301, 1019, 1351,
  732,  967, 1793, 1794,  680,  681, 1052,  649, 1023, 1714,
  887,  888,  970, 1144,  889,  890,  891, 1252,  892, 1603,
  893,  894, 1581,  895, 1253,  896,  897,  898,  899,  900,
  901, 1584, 1585,  533,  491,  655, 1109, 1459, 1916, 2276,
 2436, 2266, 2992, 3127,  722,  686, 1441,  739, 1057, 1058,
 3117, 3118, 3214, 2533, 2786, 2216, 2528,  902,  903, 1343,
  904,  905,  906, 1170, 1172,  907, 1494,  908, 1841,  909,
  910,  911,  912,  913,  914,  915,  916, 1317, 1138,  527,
 1468,  528, 1834, 1300, 1301,  917,  918,  919,  920, 2867,
  921,  922, 2033, 2338,  923,  924,  925,  926,  927,  928,
  929,  930,  931,  932,  933, 2605,  934, 1531,  935,  936,
  937,  938,  939,  940, 2609, 2856,  941, 1176, 2853, 1177,
 1963, 2336,  942, 1509,  943,  944,  471, 1140,  652,  540,
  945, 2498, 1743,  555,  519,  552, 3196,  522, 3326,  976,
 1797,  993,  484, 1650,  946,  487,  532, 2682, 1229,  568,
  362,  947,  948,  345,  129,  581,  952, 2043, 2877, 2388,
  953, 2067, 1277, 2390, 1624, 2904,  132, 1294, 3069, 2700,
 1295, 2665, 2068, 1135, 1039, 2589, 2297, 1621, 2653, 2833,
 3001, 2293, 2587,  502,  685, 2514, 2253, 2561, 2252, 2809,
 2811,  694, 1846, 2238, 2982, 2986, 1385, 1461, 3134, 2582,
 2995, 3132,  692,  657, 1829, 1357, 2722, 2934, 3263, 3305,
 1122, 1863, 1462, 2255, 2812, 2565, 3111, 3211, 3112, 2515,
 2516, 3281, 3354, 2197,  673, 1045, 1805,  665, 1374, 2152,
  950, 1622, 2151, 2749, 2953, 2470, 2736, 3092, 3308, 3309,
 2478, 2747, 2951, 3194, 2176, 2477,  580,  674, 1046,  377,
  658, 1028, 1728, 2196, 1811, 1720, 2453, 1092, 1411, 1835,
 1093, 1094, 1095, 1096,   81,  962,  690,  589,  965, 2089,
 2427, 2710, 1314, 1460, 1013, 1008,  595, 2072, 1477, 1935,
 2597, 3145, 3296, 3146, 3392, 1707, 1710,  374, 2402, 2686,
 3064, 3251, 3299, 3298, 3329, 3417, 3442, 1678, 2103, 3262,
 1354,  650,  718, 1915,  656, 1051, 1025, 1858, 2267,  723,
 1463, 1823,  687, 1401, 1442, 2250, 1402, 2217, 2976, 1517,
 1965, 2324,
};
static int yysindex[] = {                                   8686,
37561,  -43,38780, 1814,  100,30798,  -20,    0,  551,  708,
    0,  -43,  588,95704,96097, 2360,99241,  677,  831,    0,
 1190,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1010,  973,    0,
 1125,    0,    0,    0,    0,    0,    0,    0,    0, 1052,
 1077,    0,89376,99241, 1157,99241,99241,99241,99241,99241,
99241,99241,99241,99241,99241,  996,    0,99241,    0,    0,
 1220, 1697,99241,99241,99241,99241, 1382,99241, 1210,99241,
99241,    0,99241,99241,99241,99241,99241,  942,    0,99634,
    0,  120, 1378,99241,    0,99241,99241,99241, 1398,99241,
99241,99241,99241,99241, 1210,99241,99241,99241,99241,99241,
99241,99241, 1131,    0,100027,    0,99241,    0,    0,99241,
99241,    0,  928,99241, 1460,    0,99241, 1355,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1481,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1438,    0, 1608,    0,    0,99241, 1836,    0, 1805,    0,
99241,99241,99241,99241,99241,99241,99241,99241, 1330,100420,
    0,    0,    0,99241,38182,    0, 1505, 1487,    0,   12,
    0,    0, 1530,    0,99241, 1561,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1697,    0,99241,    0,    0,    0,  736,    0,
    0,    0,    0, 1467,    0,    0,  644,    0,    0,    0,
    0,  800,    0,    0,    0,    0,    0,    0,  676,    0,
    0, 1561,    0,    0,    0, 1952,    0,  595,    0,    0,
    0,    0,    0,    0, 1740,    0, 1605,    0,    0, 1573,
    0,    0,    0,    0,    0, 1760,    0,    0, 1697,    0,
    0, 1474, 3220,    0,    0,    0,    0,  951,    0, 1783,
    0, 1134,    0,    0,    0,    0,    0,    0,    0, 1803,
    0, 1715,    0,    0,99241,    0,    0,    0, 1824,99241,
    0, 1818,    0, 1675,    0,    0,    0,99241,    0,    0,
    0,    0,    0,   23,    0,    0, 1659,    0,    0,    0,
    0,    0,    0,99241,99241,    0,77761, 2113,    0,    0,
    0,    0, 1680,  617, 1685,    0, 1759,99241,    0,    0,
    0, 1860,99241,    0,99241, 1836,99241,99241, 1936,    0,
    0,    0,    0,    0,    0,    0,    0, 1807,99241,    0,
 1846, 1816,    0,    0,    0, 1914,    0, 1870,    0,    0,
    0, 1874,    0,    0,99241,    0,    0,    0,    0,    0,
    0, 1906,99241,99241,99241,99241, 1876, 1786,    0,  232,
  342,  134,    0,    0, 2009,  979, -153, 1775,  -15, 2264,
    0, 1919,    0,    0,    0,    0,    0,    0,    0,    0,
 2005, 2032, 1539, 2071,    0, 1904,    0, 1704,    0,    0,
 2032, 2071,    0,    0,    0,    0,  776,    0,99241, 2081,
    0,    0,    0, 2086,    0,    0,99241, 2091,    0,    0,
    0,    0,    0,21682,    0, 1926, 1704,    0,99241,99241,
99241,99241,99241,99241,99241,99241, 1777,    0,99241,    0,
    0,    0, 2083, 1023,    0,99241, 1217,    0,99241,99241,
    0,    0,99241,    0, 2118,99241,    0,    0,86604,70831,
 2022, 1775,    0, 2050, 2082,    0, 1765,99241,    0,    0,
    0,    0, 2398, 2419, 2423, 2024,    0, 2432,    0, 2433,
    0, 2445,    0,    0, 2449, 2458,78391, 2464,    0, 2465,
    0, 2470,    0,    0,    0,    0, 2481, 2056, 2066,    0,
 2491, 2492,    0,    0,    0,    0, 2500,    0,    0,71461,
 2512, 2514,    0,    0,    0,    0, 2518, 2200, 2522, 2524,
 2529, 2534, 2547, 2557,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2565, 2575, 2582,    0,    0,    0,    0, 2584,    0,    0,
    0,    0,    0,    0,    0, 2598,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2604, 2608,
 2614, 2619, 2629, 2635, 2640, 2644,    0,    0,    0,    0,
    0, 2649, 2652, 2660, 2663, 2667, 2668, 2669, 2671, 2673,
 2675, 2676, 2678, 2680, 2682, 2685, 2686, 2491, 2492,82801,
82801,72091,99241,    0,    0, 2222, 2537,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,25938, 1506,    0,    0,    0,    0, 2683,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2114,    0,    0,    0,    0,    0,    0,    0,    0, 2691,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2693,    0, 2606, 2695,    0,99241, 2702,
    0,  -29,    0,85422, 2377, 2383, 2384,    0,    0,    0,
    0,99241,  176,    0,    0,99241,  181,    0,    0, 2689,
 2711,    0,    0,    0, 1516,    0,    0, 2719,99241,    0,
    0,    0,    0,    0,    0,    0,    0,   20, 2428,    0,
 2717, 2717,    0, 2435,99241,    0,    0,    0,78391,    0,
    0,78391,    0,    0,    0,    0,72721,    0,    0,78391,
  973,    0,  973,78391,  189,    0, 2267,78391,    0, 2732,
 1775,    0,    0, 2479,    0,    0, 1286,    0, 1697, 2421,
  838, 2516, 2032,    0,99241, 1697, 1697,    0, 2742,  176,
 2517,    0, 2516,    0, 2742,    0,    0,    0,  993, 2403,
    0, 1998,    0, 2352, 2345,    0,    0,    0,   80,    0,
 2755, 2368,    0,    0,    0, 2371,    0, 2430, 2767,    0,
 2476, 2779,  101,    0,    0,    0,    0,    0,    0,    0,
    0, 2525,    0,    0,    0, 2730,    0,    0,  798,    0,
    0,    0,  246, 2782, 2783, 2779,  176,    0,    0, 1697,
    0,    0,    0,  347,    0,    0,    0,    0,    0, 1561,
    0,    0,    0,    0,    0,    0,    0,    0, 1697, 1697,
    0, 2787,  676,  -71, 2403, 1813,    0,    0,    0,    0,
    0,    0, 2559, 2474,    0, 2404, 2463,    0,    0,    0,
    0, 2480,72091,    0,25938,  582, 2477,    0,    0,    0,
99241,    0,  986,78391,  931,    0, 2352,99241,78391, 1105,
 1179, 1804,78391, 2352, 1222, 2912,    0,    0, 1210,    0,
 1210,    0,78391,78391,25938,  685,    0,78391,78391,78391,
 2541,78391,78391,78391,78391,78391,68941,68311, 2912,78391,
 1654,78391, 2816,78391,78391,78391,78391,78391, 2817, 2818,
78391,78391,78391,78391,78391,78391,78391,78391,78391,78391,
78391,78391,78391,78391,78391,78391,    0,    0,82171, 1253,
 1253,    0,    0, 2821,    0, 1506, 2007, 2819,    0,    0,
84634,    0,78391,78391,83431,    0,    0, 2824,  753,    0,
78391,    0,  747,    0,    0,78391, 2434, 2453,    0,    0,
    0,69571,78391,99241,82801,82801,82801,82801,82801,78391,
 2841,78391,73351,94132,99241,77761,    0,    0, 2497,    0,
    0, 2519, 2523, 2527,29585, 2594,    0,  191,99241,85028,
 1646,    0,    0,    0,    0,    0,    0,    0, 2852, 2847,
 2637, 2586, 2590,  -29,    0,    0,    0, 1202,    0,    0,
    0,    0,    0,    0,99241, 2022, 1775,78391,99241,99241,
    0, 2352,    0,    0,    0,    0,    0,   20,99241, 2572,
 2578,99241,   20, 2859, 4853, 4904,    0, 2600, 2878,    0,
    0, 6244, 2881, 2884,    0,22254,    0,    0,36944, 1579,
99241,    0,  332,    0,    0,    0,    0, 1096,    0,    0,
  231,78391,    0,99241, 2420,    0, 1286, 2437, 2439,  -88,
 2441,  -46,    0, 2493,    0,    0, 1480,    0, 1697,    0,
99241,99241,    0,99241,87783,    0,    0,    0, 2326,    0,
 2898, 2546,    0,    0,  184,    0,    0, 2899,  149, 2583,
 2587, 2595,    0, 1210, 1229,    0,99241,    0, 2520, 2357,
    0, 2482,99241,99241, 2656,   80,    0,    0,    0,  175,
    0,    0,    0,    0, 1210,    0, 2767,  184,    0,    0,
    0, 4258,    0,    0,  184, 2566,  184,    0, 2928, 1210,
 1210, 1210,    0,    0,    0,    0, 2532, 1704,    0,    0,
    0,99241, 2622,    0,    0, 1217,    6,    0,    0,    0,
 1434, 3394, 2362,31393,32007, 2603,    0,    0,    0,    0,
    0, 2933,    0,  867,99241, 2936,    0,    0,86604,99241,
25938,    0,    0, 2625,    0,    0,    0, 2478,    0,78391,
78391,22868,78391, 2942,78391, 2943, 2941, 5026,78391,78391,
78391,78391,26552, 2945, 2683, 2948,78391,78391,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2677, 2949,
 2953,23482, 2577,78391,    0,78391,    0, 5061,22823, 2952,
99241, 6270, 6294, 6884, 6908, 7498,    0,    0,    0, 3292,
73981,    0,    0,    0,    0,36331, 2954,  273,23437,78391,
78391,36970,    0, 7522,24051, 8112, 4421, 4472,    0,    0,
 8136, 8726, 8750, 9340,24665,25279,25893,26507,27121,27735,
28349,28963,29577,30191,30805,31419, 2535,    0,    0,    0,
    0,99241,88176,    0, 2957,    0, 2931, 1391, 1769,72091,
 2744, 1506,72091,    0,    0, 2690,    0,  829,    0,    0,
 2672,83431, 2824,78391, 2597,78391,27780,    0,78391,    0,
    0,    0, 2967, 2672, 2672,    0, 2740, 1295, 1295, 1253,
 1253,25938, 2393, 2978,    0, 2027,    0,    0, 2981, 2222,
    0, 2627,    0,    0, 2609,  455,  546, 2624,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2613, 2616, 2979, 2983, 2985, 2443,    0,    0,    0,    0,
 2990, 1282, 2992, 2670,    0, 2670, 1201,78391, 2670, 2707,
 2709,78391,    0,99241, 2733,    0,    0, 2681, 2687, 2692,
29585, 2756,  274,    0,    0,    0, 2822,    0,    0, 2477,
    0,25938,    0,    0, 3010,    0,    0,    0,   20,   20,
    0,    0,    0,    0,85422, 2628,78391,99241,86209,78391,
 2573,78391,    0,    0,    0,    0,    0,    0,    0, 2610,
88176,78391, 2040, 2063,    0,99241,    0,    0, 2718, 2725,
    0, 2727,    0,    0, 2784, 2651,99241, 1480, 1702, 1150,
 1017,99241,21682,    0,    0,    0,    0, 2791, 3012,    0,
    0,90595,  -76,    0,99241,   -8,    0, 3035, 2486,78391,
    0,    0,99241,99241,99241,103957,99241,78391,99241,    0,
    0, 2785,87390,    0, 3023,    0,    0,    0,    0,    0,
    0, 2754,    0,    0,    0,    0,    0,    0,  632,    0,
    0,    0,    0,    0,    0,    0, 2762,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3037,    0,99241,    0,
    0,90595, 2655,    0, 2627,    0,    0, 2647,96490,    0,
89376,  833,   58,  826,    0, 2032, 2071,    0,    0, 2825,
    0,    0, 2684,    0, 3043, 3048,    0,    0,    0,    0,
 2256,    0,  185, 2079, 2697, 3068,    0, 2123,    0,    0,
    0,    0,    0,    0,    0,    0, 1502,    0, 3055,99241,
 1603, 1210, 3073, 3074, 3076,  176,    0,    0,    0,    0,
 3057,    0,    0, 2403,    0,    0,    0, 2032,99241, 2071,
 2726,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2638,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2533,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2536, 1817, 2494,    0, 2530, 2805,    0, 2684,
99241,99241,  867, 2828,  944,    0,    0,    0, 2739,    0,
 2833,    0,    0,    0, 3101,    0, 1775, 9364, 9954,90988,
 9978,    0,10568,    0,78391,    0,10592,11182,11206,11796,
79021,    0,    0,11820,12410,78391,    0,    0,78391,74611,
78391,25938, 2839, 2728,    0,78391,78391,78391,    0,    0,
    0,    0,    0,    0,78391,    0,78391,24096, 2729,78391,
78391,78391,78391,32033,32033,78391,    0,78391,    0,78391,
    0,78391,    0,    0,    0,    0,    0,78391,78391,78391,
78391,78391,78391,78391,78391,78391,78391,78391,78391,    0,
 2133,88176,99241,    0, 3104,83431, 3106, 2181,78391, 2835,
    0,    0,    0,78391, 2889,    0, 2672,78391, 2672, 2672,
 2352, 2880, 2477,    0,    0,75241,    0, 2182,99241, 3115,
 2894,    0,99241,99241,99241,99241,99241,99241,99241,    0,
    0,    0,    0,    0,    0, 2897,    0,    0, 2901,    0,
 1952,    0, 1952,    0,    0,    0,    0,99241,    0,    0,
    0,    0,    0, 2826,    0,    0,85422,85422, 2206,99241,
 2852,    0, 2609,  552,  658, 2851, 2854,    0, 2822, 2815,
    8, 1193,    0, 2757,    0, 2648, 2650, 2654,    0,    0,
    0,    0,    0, 2478,    0, 2843, 2696,    0,    0, 3134,
 1282,78391, 2860,    0,    0,    0,    0, 1198,    0,25938,
  332, 2820, 2957,    0, 1775,99241,    0,    0, 2494, 1697,
 1697, 2725,    0,    0, 2789, 2655,    0,    0, 3151, 2919,
    0,    0,    0, 2853, 2855,    0,    0,    0,    0, 2921,
    0,    0,99241,  764,    0, 2831,    0,    0,    0,    0,
    0, 2581,    0, 2913,75871,    0,78391, 2788,25938,    0,
    0,    0,    0,    0, 2873,    0,    0,25938,    0,    0,
    0,    0, 2773,    0,    0,88176,  568, 3169,88176,    0,
    0, 2230,99241, 2791,    0,  149,96883,    0,99241, 1521,
  901,    0,  691,    0, 2842, 2844, 2845, 2846, 2848, 2856,
 2516,    0, 2494, 2861,  899,    0,  166,    0,    0,    0,
    0, 2256, 3057, 3057, 1697, 2866,94525,94525,    0, 3171,
  185,    0,86604, 2827,    0,  184,    0,    0,  184,    0,
  184,    0, 2921, 3193,    0,    0,    0,    0,    0,    0,
    0, 2655,    0, 2239,    0, 1263, 2516, 1410,    0,    0,
    0,    0,    0,    0, 3195,    0, 2530,    0, 2792,    0,
 1697, 2794, 1697, 1697, 1697,    0, 2696,97276,    0,    0,
    0,    0, 3178,  891,    0, 3183, 1018, 2944,    0,99241,
99241,    0,    0,    0,    0, 3200,28961, 1697,    0,    0,
    0,    0, 2879, 3207,    0,    0,    0,    0,12434,    0,
    0,    0,    0,72091,13024,    0,    0,13048,24710,37558,
    0,    0,78391, 2823,13638, 2245,32647,13662,14252,78391,
78391,33261,37569,33875,34489, 2251,78391, 3212, 3213,25324,
14276, 4587, 4688,14866,14890,15480,15504,16094,16118,16708,
16732,17322,17346,17936,17960,    0,    0,    0,    0,    0,
    0,    0,    0,78391, 2672,83431,78391, 2672,78391, 3217,
78391, 3222,    0, 2286,    0,    0, 2791,    0,    0, 2032,
 2849, 2857, 2858, 2862, 2864, 2865, 2868,    0,    0, 1488,
 1156, 1507,    0,    0,    0,    0,  221,97669,    0,103171,
85422,    0,    0, 1623,    0,    0,    0,    0,99241,99241,
99241,99241,99241,99241,99241,    0,    0,    0,    0,  949,
 2748,    0, 2834,    0, 2834,    0,    0, 2863, 1210,    0,
    0, 2867, 1775,   20, 2626,    0,85422, 3000, 2955,    0,
    0,    0, 2911,    0,    0,    0,    0,    0,    0,    0,
99241,    0, 2956,78391,    0,    0,    0, 2742, 2742,    0,
 4258, 4258,    0,98062, 2958,    0, 2976, 3249,25938,    0,
 3252, 3004,    0,88176,    0,    0,  610,    0,    0, 2957,
 2829, 2754, 3006,    0,78391, 2957,    0,    0,    0, 2791,
  -68,    0,99241,    0,    0,    0,91381,    0,    0,    0,
    0,    0, 2960, 1210, 2961,99241, 3033, 3013, 2525,91774,
 2790,    0,    0,    0, 3267,    0, 2892, 2991, 2903, 3026,
 2996, 3034,    0,    0,    0,    0,    0,99241, 2688, 3007,
99241, 3007, 3017,    0,   71,    0, 2655, 1210,    0, 1697,
    0,    0,    0,    0,    0, 3294,    0,    0, 2932, 2921,
 3298, 2791,    0,    0,    0,    0,    0,    0, 2684, 1881,
    0,    0,    0,    0,96883, 2032, 2071,    0, 2032, 2071,
    0,    0, 2890,    0, 2891,    0,    0,    0,    0, 3304,
    0,    0, 2305,    0,    0,    0,85816, 2328, 3305,    0,
    0, 3306, 1068,    0,    0, 2993,94918,98455,    0,    0,
    0,    0,    0,78391, 3307,78391,    0,78391,  545,    0,
    0,78391,    0,    0,18550,18574,78391,78391,78391,78391,
78391,    0,25938,    0,    0,78391, 3041,78391,    0,78391,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2672,78391, 2672,    0, 2683,
    0,    0,99241, 3286,99241, 2516,    0,    0,    0,    0,
    0,    0,    0,  229,92953,  229,    0, 2897,    0, 2901,
    0,    0,    0,    0,    0, 2905,    0,   -1,99241,    0,
    0,    0, 1805,    0,    0,    0,78391, 3309,    0,    0,
99241, 3312, 3044, 3045, 3046, 3047, 3049, 3050, 3051,    0,
    0,  172,  634,    0,    0, 2926,    0,    0,    0,99241,
    0,    0, 3334,    0,    0,99241, 1282,78391,78391, 2022,
    0,    0,    0,99241,    0, 3335, 2980,    0,    0,    0,
99241,    0,    0, 3337,78391,79651, 2962,87783, 2957,    0,
    0,    0,    0,78391,78391, 3065,    0,87783,    0, 3340,
99241,  764, 2758,    0,    0,    0, 1119, 3033, 2790,    0,
  209,    0, 3107,    0, 3040,    0, 3042,    0,    0,    0,
    0,    0,   14,    0, 3129,78391,    0,    0,    0,    0,
    0,    0,    0,  -23,99241,    0, 3007,    0,    0,   71,
 3120, 3058,    0,    0, 1881,    0,    0,    0, 2959,    0,
    0,    0,    0,   93, 2494,    0,    0,    0,    0,    0,
 2725,    0,    0,    0, 2516,    0, 2516,    0,    0,    0,
    0, 1697,    0,    0, 3029,    0,    0, 2859, 3359,    0,
    0, 3098, 5629,28961, 1210,  -77,    0,    0, 1697, 2625,
    0,    0, 2337,    0,93346,    0,99241,    0,25938,    0,
19164,25938, 2986,78391,78391, 3100,19188,    0,    0,19778,
19802,20392,25938, 4733, 4784, 1328,    0,20416,21006, 2672,
    0, 3342, 2339,    0, 2791,    0,    0,    0,    0,    0,
    0,    0,    0, 3089,    0,   -1,99241,99241,99241,99241,
99241,99241,103564,103564,    0,    0,    0,   -1, 3053,97669,
    0, 3139,    0,97669,    0,    0, 1775, 2984,    0,99241,
    0,    0,    0,    0,    0,    0,    0,    0,  173,  173,
    0,    0, 3369,    0, 3102,    0,78391,    0, 3371,    0,
25938,    0,    0,    0,    0,    0,90595, 2627, 3375, 2352,
 2364,72091,    0,25938,87783,    0,25938,25938,99241,  290,
  162,    0, 2873, 3118,    0,    0,    0, 3088, 3091, 1952,
    0,    0, 3152,    0,    0,    0,    0,    0,    0,    0,
21030,    0,    0,    0,    0,93739,    0, 3027, 1697,    0,
    0,   93, 3085,    0,    0,    0,    0, 2725,    0,    0,
    0, 2375,98848, 3391, 1697,    0,    0, 3155,    0,78391,
 5629, 1697, 1210,   43,    0,    0, 3393,    0,    0,    0,
94918,    0,    0,    0,    0,    0,    0, 3404,    0,78391,
    0, 3039,    0,    0,    0,    0,    0,78391,    0,78391,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  229,
  229,  229,  229,  229,  229,  229, 3108,92953,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2984,   42,    0,    0, 2380,    0,    0,
    0,    0,    0,    0,    0,    0,    0,99241, 1576,99241,
    0, 2395,78391,    0,    0, 2791, 3215,99241, 3435,    0,
21620,    0, 3179, 2873,87783,    0,    0,99241,99241,  185,
 3052,    0, 3181, 3218,    0,87783, 1952, 1952, 3003, 3197,
    0,    0,    0,95311,    0,    0,    0,94525,    0,99241,
    0,    0,    0,    0,    0,99241,    0, 3427,    0,    0,
    0,    0,    0,  -18,  214,21644, 3449, 3136,    0,  502,
    0,    0, 2921,    0, 3456,99241,99241,    0,78391,25938,
22234,99241,   -1,   -1,   -1,   -1,   -1,   -1,   -1,    0,
    0,    0,    0,    0, 2939,    0,    0,  173,  173,  173,
  173,  173,  173,  173,    0,    0,    0,   13,    0,    0,
    0,    0,  599,  -68, 2032,    0,    0, 3460,    0,    0,
87783,    0,    0,  162,    0,    0,    0,    0,    0,87783,
 3216,    0,    0,    0,    0, 3111, 3003,  120,    0, 3242,
    0,    0,    0,    0,    0,    0, 2999,98848,    0, 1697,
    0, 2946, 1194, 1409, 2930,    0,    0,    0, 3016, 3018,
    0,    0, 1697,    0, 3072,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2964,  599, 3057, 3255,    0, 3259, 2516,    0,    0,
 1046,    0,    0,    0,99241,99241,    0, 3203, 2907, 2791,
    0, 2791,99241,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,99241, 3204,    0,   96,    0,
 1775,    0, 2655, 3153, 2655, 2032,    0,    0, 1046, 3112,
 3227,78391, 1427,78391,    0,    0, 1952,99241, 3500,    0,
    0, 3261,    0,    0, 2402,    0, 3502,    0,  178,78391,
  486,    0, 2264,    0, 1881,    0,    0, 2516, 2436, 2459,
78391,    0,78391,80281,25938, 3125, 3161, 3128,25938, 3182,
    0, 1474,    0, 3261,    0,    0,99241,    0,    0,78391,
 3219,    0, 3133,    0, 3156,    0,    0,    0,    0,    0,
    0,    0,    0,    0,25938, 2963,    0,25938, 2950,25938,
    0,    0,    0,  547, 3003, 3190, 3198, 3520,    0, 1908,
    0,99241, 3149,    0,  745,99241,99241,78391,78391,78391,
   27,   27,    0, 3273,    0, 3145,    0,    0, 3235,99241,
 3003,    0,    0,    0, 2472, 3245,    0,    0, 3176, 3528,
    0,    0,25938,25938, 3137, 1008,    0,    0,    0, 3003,
 1952,    0,    0,    0, 3154,99241,    0,    0,    0,    0,
 3182,    0, 3538, 3528, 3003, 3157,78391,    0, 3539, 2489,
78391,    0, 2505,    0,
};
static int yyrindex[] = {                                   3186,
    0,  254, 1111,    0,    0,    0,    0,    0,    0,    0,
    0,  244,    0,    0,    0,    0,    0,    0,    0,    0,
 3583,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  541,    0,    0,
  457,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1351,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3258,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1351,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,67490,    0,    0,    0, 3188,    0, 3326,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  796,76501,  475,
    0,    0,    0,  477,    0, 1054,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  186,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  289,    0,
    0, 1054,    0,    0,    0, 3327,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1443,    0,    0,    0,
    0,    0,    0,    0,    0,29002,    0,    0,    0,    0,
    0,  187,    0,    0,    0,    0,    0,  703,    0, 3552,
    0, 1310,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3329,    0,    0,    0,    0,    0,
    0,    0,    0,  322,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1540,    0,    0, 1641,    0,    0,    0,
    0,    0,    0,    0, 1657,    0,  267,    0, 5200,    0,
92167,    0,    0,92560,100813,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3201,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3329,    0,
 1664,    0,    0,    0,    0,    0,    0,101206,    0,    0,
    0,101599,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1034,    0,    0,    0,
    0,77131,70201,    0,    0, 3202, 1089, 1667, 3186,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  359, 3325,    0, 1701,    0,  183,    0, 1712,    0,    0,
 3325, 1701,    0,    0,    0,    0,  298,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1712,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1822,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  321, 1667,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,40222,
    0,    0,    0,    0,    0,    0,    0,    0,    0,40836,
    0,    0,    0,    0, 7066,    0,    0,    0,    0,    0,
 5838, 6452,    0,    0,    0,    0,37766,    0,    0,    0,
41450,42064,    0,    0,    0,    0,42678,43292,    0,    0,
    0,    0,    0,    0, 7680, 8294, 8908, 9522,10136,10750,
11364,11978,12592,13206,13820,14434,15048,15662,16276,16890,
38380,38994,43906,17504,18118,18732,19346,44520,19960,20574,
21188,21802,22416,23030,23644,39608,24258,24872,25486,26100,
26714,27328,27942,28556,29170,29784,30398,31012,31626,32240,
32854,33468,34082,34696,35310,35924,36538,37152,45134,45748,
46362,46976,47590,48204,48818,49432,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 5838, 6452,    0,
    0, 3186,    0,    0,    0, 1717,51893,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1047,56805,    0,    0,    0,    0,  270,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,50046,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,50665,    0,   99,
    0, 2469,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1270,    0,  322,    0,    0,    0,
    0, 3184,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3265,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  797,    0,    0,    0,
 1667,    0,    0,    0,    0,  200,    0,    0,    0, 1782,
101992,    0, 3330,    0,    0,    0,    0,    0, 3208,    0,
  192,    0,    0,    0,  843,    0,    0,    0,    0, 1151,
    0,    0,    0, 3186,    0,    0,    0,    0, 3301, 2117,
 2067, 2735,    0,    0,    0, 3594,    0,    0, 3882,    0,
    0, 4016,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  892,    0,    0,    0, 3790,    0,    0, 3804,    0,
    0,    0, 4052, 3673,    0, 4016,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1054,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1310,    0, 1499,    0, 1309,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3186,    0, 3162, 3565,  223,    0,    0,    0,
    0,    0,80911,    0,80911,    0, 3186,    0,    0,80911,
80911,64594, 3567, 3186,80911,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3177,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
80911,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3186,53121,
53735,    0,    0,    0,35103,35717,    0,    0,    0,51279,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,81541,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3567,    0,    0,    0,  267,    0,    0, 3597,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3186,
 3277,    0,    0,    0,    0,    0,    0,    0,65857,    0,
    0,    0,    0, 2469,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  321, 1667,    0,    0,    0,
    0, 3186,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1185,    0,    0,    0,    0, 3299,    0,
    0,67886,    0,  704,    0,  443,    0,    0, 1233,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1798,    0,    0,    0,    0, 1309,    0, 3274,    0,    0,
    0,    0,    0,    0,    0, 1006,    0,    0,    0,    0,
    0,    0,    0,    0, 1059,    0,    0,    0,    0,    0,
102385,    0,    0,    0,    0,    0,    0, 1800,    0, 1300,
 1465, 1691,    0,    0, 1801, 1309,    0,    0, 1826,    0,
    0,    0,    0,    0,    0, 3313,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3882,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1712,    0,    0,
    0,    0,  315,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1223,    0,    0,    0,    0,
    0,    0,    0, 3316,    0,28347,    0,    0,    0,    0,
    0,    0,    0, 3580,    0,    0,    0,  218,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2515,    0, 3581,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,88784,88795,88854,89061,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1832,    0,    0,    0,65015, 3186,
    0,57419, 3186,    0,    0,    0,    0,    0,    0,    0,
62331,    0,    0,    0,    0,    0,65436,    0,    0,    0,
    0,    0,    0,58033,58647,    0,52507,55577,56191,54349,
54963, 1617,  263,    0,    0,    0,    0,    0,    0, 1717,
    0, 3357, 4169, 3692,102778,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3262,30199, 3333,    0,    0,    0,    0,    0,
    0, 3277, 2363, 3291,    0, 3291, 3277,    0, 3291,    0,
    0,    0,66685,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1462,    0,    0,    0,  223,
    0,  495,    0,    0,    0,  500,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  681,    0,    0,    0,    0,
 1042,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  269,    0,    0,
    0,    0, 3343,90202, 2149,    0, 2183, 1829,    0,    0,
 2367, 2466, 2507,    0,    0,    0, 2540,    0,    0,    0,
    0,    0, 1325,    0,    0,    0,    0,    0,    0,    0,
    0, 3574,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2132,    0,    0,
    0,    0,    0,    0, 1072,    0,    0,89789,    0,    0,
    0,    0,    0,    0,    0, 3325, 1701,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  205, 2743,
    0,    0,    0,    0, 2262,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1830,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3194,    0,    0, 1510,    0,    0,    0, 3325,    0, 1701,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1930,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2457,    0, 1853, 1339, 3164,  333,    0,    0,
    0,    0, 3316,    0, 3336,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1667,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  970,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3596, 3596,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,27166,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,62945,    0,59261,63559,
 3186,    0, 3599,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  216, 5639,    0,  754,    0,
  207,    0,  207,    0,    0,    0,    0,    0,66275,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
65857,    0,102778,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1922,    0,    0,    0,    0,    0,    0,
    0,    0,  203,  218,    0,    0,    0,    0,    0, 1055,
 1570,    0, 1343,    0,    0,    0,    0,    0,    0, 1235,
    0,    0, 1856,    0, 1667,    0,    0,    0, 1853,    0,
    0,  820,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 4126,
    0,    0,    0, 3589,    0,  847,    0,  247,    0,    0,
    0,    0,    0,    0, 3590,    0,    0,    0, 3591,    0,
    0,    0,    0,    0, 3592,    0,    0, 3600,    0,    0,
    0,    0, 3364,    0,    0,    0, 3186,    0,    0,    0,
    0,    0,    0,  151,    0,    0, 1239,    0,    0, 1581,
    0,    0,    0, 1631, 1762, 2003, 2038, 2168, 2315, 2317,
    0,    0, 1853,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3194, 3194,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 4088,    0,    0,    0, 1161,    0,    0,
    0,    0, 2246,    0,    0,    0,    0,    0, 1309,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3164,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3276,    0,    0,    0,    0,
    0,    0, 3619,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3186,    0,    0,    0,    0, 3627,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,59875,    0,    0,64173,    0,    0,
    0,    0,    0,    0,    0,    0, 3613,    0,    0, 3325,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196,    0,    0, 3192,
    0,    0,    0, 3277,    0,    0,67095,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1927,    0, 1927,    0,    0, 2041,    0,    0,
    0,    0, 1667,    0,    0,    0,    0,    0,  386,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1043,    0,    0,    0,    0, 3208,  594,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3617,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  248,
    0,    0,    0,    0,    0, 3618,    0,    0,    0,  919,
 1165,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3638,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1877,    0, 3365,
    0, 3365,    0,  212,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 4387,
    0, 1889,    0,    0,    0,    0,    0,    0,    0,  496,
  532,    0,    0,    0, 1239, 3325, 1701,    0, 3325, 1701,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  623,    0,    0,    0,    0,    0,    0,28388,    0,
    0,    0,  375,    0,    0,    0, 3565,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3379,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3642,    0,    0,    0, 3070,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,60489,    0,61103,    0,  312,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  202,    0,  202,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1894,    0,    0,
    0,    0, 3487,    0,    0,    0,    0,    0,    0,    0,
    0, 1900,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1894,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1956,    0,    0,  697,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  827,  998,    0,
    0,    0,    0,    0,    0,    0,    0,  827,    0,    0,
    0, 2570,    0,    0,    0,    0,    0, 2211, 3279,    0,
 4538,    0, 2705,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1612,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3365,    0,    0, 3365,    0,    0,    0,
    0,    0,    0,    0, 2840,    0,    0,    0,    0,    0,
    0,    0, 1259,    0, 1853,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1921,    0,    0, 1929,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,83845,
84239,    0,    0,    0,    0,    0,    0,    0, 3645,    0,
    0, 3269,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2576,    0,    0,    0,    0,    0,    0,61717,
    0,    0,    0,    0, 2588,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1894,    0,    0,    0,    0,
    0,    0,  222,  389,    0,    0,    0, 1894,    0,    0,
    0,    0,    0,    0,    0,    0,  220,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1894, 1894,
    0,    0, 2101,    0, 2417,    0,    0,    0, 1586,    0,
 1447,    0,    0, 2392,    0,    0,    0, 3357,    0, 3186,
    0, 3186,    0,  519,  827,    0, 3374, 3376,    0,    0,
    0,    0, 3425,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1937,    0,    0,
    0,    0,    0,    0, 1943,  844,    0,    0,    0,    0,
    0,    0,    0,  264,    0,    0,    0,    0,    0,    0,
 3565,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  202,
  202,  202,  202,  202,  202,  202,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  719,    0,
    0,    0,    0,    0,    0,  108,    0,    0,    0,    0,
    0, 1258,86997, 3592,  827,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3396,  827,    0,    0, 1692,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  324,    0,    0,    0,    0,    0,    0, 2589,
    0,    0, 1894, 1894, 1894, 1894, 1894, 1894, 1894,    0,
    0,    0,    0,    0,    0,    0,    0, 1894, 1894, 1894,
 1894, 1894, 1894, 1894,    0,    0,    0,    0,    0,    0,
    0, 2560,    0, 3429, 3325,    0,    0,    0,    0,    0,
  827,    0,    0,    0,    0,    0,    0,    0,    0,  827,
    0,    0,    0,    0,    0,    0, 1692, 3258,    0,    0,
 4930, 4930,    0,    0,    0,    0,  240,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  535,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  233,    0, 3194, 3256,    0,    0,    0,    0, 1354,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1827,
    0, 1827,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2601,    0,    0,    0,
 1667,    0,    0, 3260,    0, 3325,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  268,    0, 4984,    0,
 7453, 1933,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2612,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1426,    0,    0,    0, 1781,  311,
    0,    0,    0, 1933,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2602,    0, 3347, 1901,89215, 1916,
    0,    0,    0,    0, 1692, 4596, 5031,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 8067,    0,    0,    0,    0,    0,  203,    0,    0,  215,
    0,    0, 2623, 1990,    0,    0,    0,    0,    0, 8067,
 4956,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 6839,  203,    0,  238, 8067,    0,    0,    0,    0,    0,
    0,    0,    0,    0,
};
static int yycindex[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3187,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1864,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3059,    0,    0,   -4,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3229,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3661,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3662,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3674, 3675,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   76,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3414,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  436,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1435,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3676,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3415,    0,    0, 3416,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3680,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3461,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3363,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  614,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3423,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3210,
    0,    0,    0,    0,    0,    0,  509,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3367,    0, 3368,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3694,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3185,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3140, 3146,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3697,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3479,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3698,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,
};
static int yygindex[] = {                                      0,
    0,    0,    0,    0,    0,    0, 2074, 2456,    0, 2462,
 2467, 1362, 2468,    0, 1366, 2471,    0, 1361,  -95,    0,
  142,  854,    0,    0,    0,    0,-2150,  712,  715, 2473,
 1698, 1349,  869,    0,    0,    0,-2502,    0, 1476,  940,
    0,    0,  774,    0,    0, 2307,    0,    0,    0,    0,
    0,    0, 3426,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  967,    0,    0,    0,  801,-1575, 1019,-1681,
  721,    0,  427, -540, 3078,    0, 3707, 1582,    0,    0,
 -898,    0,    0,    0,    0,    0,  654,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1565,    0,    0,  999,
-1989,    0,    0,  528, 3437, 2814,    0,    0, 1514,  983,
 1231,    0,    0,-1957,    0,-2067,    0,  -73,  589,    0,
  446,    0, 1238,-2222,    0,-1922,  364,  419,  421,  406,
   88,-1698,-1629,-1163,    0,    0, -978,-1693,    0, 1061,
    0,  665,-1329, 1066,  104,-1621,-1607,-1153,  637, -441,
 -642,    0,    0,   79,    0, 2359,-1197,    0,    0, 3223,
 1902,    0, 1899, -650,    0, 2795,    0,    0,    0,    0,
-1690,-1005,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,-2617,  874, 1642, 1651,    0,    0,    0,
  442,    0,  435,    0,    0,  531,    0,    0,    0,    0,
 -896,-1442,    0,    0,    0,    0, 2084,    0,  737,    0,
 1663,    0,  656,    0,    0,    0,    0,    0, 3854, 2591,
 2240,    0,    0,    0, 1208,   97,    0,    0,    0,  -99,
    0, -342, 2416,    0, 1950,    0, 3189, 2747, -967,    0,
    0,    0,    0, 2137,    0, 1679,    0, 2065,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2521,    0,    0,
    0,    0,    0,    0,-1748,-1676,    0,    0, -662,    0,
 2452, 1644,-2123, -660,    0,    0,    0,-2104,    0, -659,
    0, 2796,    0, 2484,    0,    0,    0,    0,    0,    0,
    0, 3747,    0,    0,    0,    0, 1792,    0, 1466,    0,
 1463,    0,    0,    0,  807,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2902, 3257,-1177,    4,
    0,    0,    0, -634,    0, 3545, 3302,-1419,    0,    0,
  997,    0,    0,    0, 3253,    0,    0,    0, 2205, -851,
    0,    0,-1162,-1702,    0,    0, 1224,    0, 2631,    0,
    0,    0,    0,    0,    0, 1825, 1693,   54, 2248,    0,
    0,  834,    0, -806,-1222, 2763,    0,  903,    0,    0,
  520,    0,-1010,    0, 2218,-1325,    0,    0, 3272, 1821,
    0,    0, 3920,    0, 3921,    0,  863,  864,    0,    0,
 3929,    0,    0, 3930,    0,    0, 3932,    0, -701,    0,
 2966,-2284, -588,    0,-1931,-2394, -971,-1994,  601,    0,
-1102, -551,-1200,-1085, -860,    0,    0,    0,    0,    0,
    0,    0,-1430,    0, 2699,    0,    0,    0,    0,    0,
    0, 2342,    0,    0,    0,    0,    0,-1223,    0, 1669,
 1662,-1960,    0,  722, 3226, 3266, 2504, 3224, -560, -201,
    0,  841,    0,    0,-1651,-1740,    0, 2257, -730, 2250,
    0,-1058,-1284, 3083, 3084,    0, 2704, -862, -850, 2632,
 -930, -949, -612,-1275,-1273,-1269,  -70,  -39,-1712, -651,
    0,  -97, 1172,-1214, -631,    0,-1342,    0,    0,    0,
    0,    0,    0, 1979,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,-1339,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1120,    0,
-1870,    0,    0, -790,-1267,    0, -103, 1743, -705, -116,
    5, 1485,-1431,    0,  -57, 3870,    0,   47,  -66,-1084,
 -800, -456, -101,  -55,   10,    9,  -54,  -56,-2963, 1101,
 -170,   70,  -14,    0,    0, 3849,    0, 1905,  258, -117,
    0,    0, 2720,  390,    0,    0,    0,    0, -323, 1577,
    0, -907,-2392,    0, 2869,    0,-1230,-1178,-2207,    0,
    0,    0,    0,   83, -345, 1412,    0,    0,-2088,-2594,
    0,    0,    0,-1976,    0,  606,    0,    0,-1360,    0,
    0,    0,    0, -582,    0,-1664,    0,-2547,    0,    0,
    0, 2093,    0,    0,    0,    0,    0,  888,    0,    0,
    0,  720,  646, 1509,    0,    0,    0,    0,    0,    0,
  302, 1291,    0,    0,    0,    0,-2183,-1292,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2974,    0,
    0, 2982,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4009,    0,    0,    0, -733,    0,
    0,    0,    0, -674,    0, 1650,-1198, 1032,    0,    0,
    0,    0,  784,    0,    0,-1496,    0,    0,    0, 1337,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  724,    0,    0,-1630, -317,    0,    0,    0,    0,    0,
    0,-1318,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,
};
#define YYTABLESIZE 104606
static int yytable[] = {                                     344,
  350,  477,  363,   47,  968,  572,  463,  560, 1001, 1004,
 1701,  513,  563, 1128, 1021,  492,  489,  564,  498, 1227,
 1043, 1225,  343, 1324,  349,  577, 1376, 1000, 1003, 1044,
 1148, 1083, 1795, 1086, 1089, 1796,  534, 1386, 1932,  537,
  672,  969,  514, 1127, 1738, 1279,  562, 2141,  461,  464,
  557,  472,  475,  478,  485,  344,  490,  493,  344,  499,
  475,  567,  566,  506,  570, 1346, 1387,  342,  517,  464,
  472,  475, 2182,  485, 1027,  344,  490, 1139,  493,  344,
  499,  475,  541, 1680, 1345,  506, 2129,  516, 1513,  553,
 2321,  344,  556,  464, 1520,  553,  472,  475,  478,  485,
 1918,  344,  490,  493,  569,  499,  475,  541, 2432, 1060,
  506, 2195,  579,  474,  343,  344,  344, 1652, 1342,  475,
 2230,  474,  590,  486,  565, 2194, 2491, 1053, 1576, 2395,
 2011, 2396, 1717, 1698, 2537, 2538, 1478, 1840, 2556,  343,
 1687, 1383, 2450,  530, 1920, 1692, 1842,  505, 1843, 1220,
 1221, 1226, 1844, 1715, 1845, 2146, 1098, 1451,  561,  342,
 1306, 2025, 1132, 2017, 1344, 2222, 1350,  571, 2447,  505,
 1804, 2655, 1818, 2595,  678,  524,  989,  991,  546, 2281,
  587,  544,  282,  582,  342,  284,  271, 2213,  520,  717,
  535, 2305, 2827,  611,  576,   94,  578,  721, 1434,  764,
 2980,   92, 1801, 1838,  336, 1617,  574, 2532, 1828,  396,
 1849,  337, 1849, 2122, 1292, 2677, 2885, 1262, 1833, 1315,
 1298, 1786, 1248, 2285, 1305, 1684,  282,  738, 1803, 1136,
 1269, 1303, 1312, 1340, 1648, 1930,  276, 1293, 2666,  341,
 1826,  282, 1332, 1038,  284,  271, 1341, 1222, 1725, 1825,
 1326,  884, 2524, 1038,   94,   13,  605, 2692,  764,   90,
   92, 2553, 2901,  336, 2677, 1786,  651, 1326, 2123,  652,
  337,  999, 2885, 1292, 1712, 2421, 1262, 1270, 1315, 2751,
 1786, 1248, 1225, 1865, 2900, 1430, 2162,  957,  678, 1590,
  957, 1312, 2286, 2507,  884, 2753, 1293,  929,  341, 2282,
 1495, 2785, 1038, 1614,  173,  957,  574,  957, 1326, 2654,
  430, 1326, 1038, 2283,  246, 3140, 1982, 1648,  734, 1353,
 1220, 1218, 2173, 2174, 2175,  651, 1326,  396,  652,  396,
 3004,  350,  296, 3096, 1574, 3104,  464,  472,  475,  485,
  344,  490,  344,  475, 3222,  506, 1014,  678, 1447,  363,
 1356,  430, 1615, 2207,  430,  349,  929, 3330,  902,   34,
  653,  661,  659, 1315,  997, 2791,  127,  997, 2139,  430,
 1578,  396,  740,  246, 2403, 1420, 1396, 3376,  127, 1220,
 1218, 1002, 2834,  645,  547, 1216, 3085, 1279, 1961, 3425,
 2039,  296,  659, 1005,   80, 1403, 3008, 1537, 1538, 1495,
 1616, 3259, 1347, 1866,  884, 3165, 1807, 1722,  530, 1808,
 2131, 1020, 1226,  106,  396,  163,  548,  902,  163, 1399,
 1795,   15, 2752, 1796, 3097, 3009, 1216, 3426, 2529,  505,
 1964, 1006, 1961, 3376,  646, 2901, 2901, 1421,  610, 3360,
 2422,  603, 1253, 1053, 1216, 2800,  728, 1961,  695, 1809,
  472, 3260, 2607,  606,  733,  601, 2983,  326, 2455,   94,
  396, 3223,  509,  510, 2080,   92, 1404, 3098, 1448,  326,
 1576,  396, 1346, 3427, 1248, 1449, 3192, 1409, 3099,  746,
  128, 2166, 2208, 1253, 2802, 1786, 1253,   37, 1567, 1713,
 3141, 1345, 3048,  659, 1323,  357, 1273, 1015, 3004,  317,
  326, 1253,  326, 1422, 1582,   90,  326, 3224, 1222, 3229,
  957, 2108, 2109, 3331,  396, 1248, 1332, 1510, 2546, 1511,
 2547,  964, 1486,  957, 1607, 1608, 1609, 1610, 1611, 1496,
  506,  248, 2111, 1248,  341,  472,  740, 3183, 1323, 2760,
 1128,  957, 2163,  472,  317, 2794,  574,  678, 3225, 2919,
 2920,  326,  678, 1323,  357, 1723,  957,  678, 2754,  741,
  506,  929, 1711,  396, 2511, 3109, 2792,  173,  987, 1677,
 2193, 3100, 2075,  478, 1326,  175, 2804,  576,  972,  341,
  350, 1128,  350,  977, 1222, 2360, 1981, 2088, 3095, 1867,
  248, 2902, 2285,  735,  506, 3361,  997, 1726,  678, 1128,
  326, 3166,  971, 1107,  973, 1681,  349,  929, 1576, 1647,
  493, 2370, 1271, 2115,  725,  730, 1832,  998,  990,  990,
  990,  990,  299, 2972, 2443,  998,  525,  997,  764, 1331,
  766,  509,  510,  276, 1614, 1326, 1038,   15, 2023, 1686,
 1617, 1100, 1297,  513,  742, 1651, 1038, 1110, 1292, 1216,
  768,  769, 1961, 1283,  246,  773,  774, 2676, 1786, 1134,
  651, 2286, 1038,  652,  517, 2884, 1675,  997, 2282, 2104,
  678, 1293,  741,  998, 1121, 1429, 1574, 1685,  725,  929,
 1218,  299, 2283, 1615,  464,  472,  475,  485,  490,  493,
  344,  475, 1220, 1218,  506,  296, 1220, 1216, 2685,   43,
  317,  344, 1218, 1249,  653,  344, 1253,  326,  741, 2595,
 2595,  478, 3206, 3207, 1141,  902, 1679, 1216,  997, 2015,
 2018, 1218, 1248,  741, 1123, 1828, 3040, 3041, 3042, 3043,
 3044, 3045, 3046, 1292,  396,  341, 1262, 1220, 1248, 1218,
 3367, 1248, 1815, 2480, 1249, 1979, 2486, 1104, 2762, 2294,
 1326, 1312, 1104,  969, 1253, 1220, 1293, 1216, 2287, 2963,
 1346, 2530, 1249, 1836, 2902, 2902, 1216, 2284, 1440,  163,
 2044,  997,   91, 1130, 1253,  296,  296,  396,  505, 1345,
 1446, 3364,  576,  998, 3230, 1917, 1248, 1116,   94, 1105,
 1115, 1296, 1439,  430,   92, 1132, 1270,   91, 3101, 2079,
 2794, 1111,  969, 1101, 1128, 2966, 1248, 3039, 1216,  326,
  326, 2531,  296, 1342, 1574, 2969,  538, 1139, 2806,  912,
 1220, 1218, 1216,  969, 2462, 1961, 1831,  858,  859, 3152,
  282, 1705, 1099,  284,  271,  357, 1132, 1270,  175, 1220,
 1218, 2045, 3401,  300, 2987, 1819, 2854, 1266, 3234, 1226,
  576, 2047, 1289, 1436, 1132, 1270, 1273,  451,  296, 1344,
 2124, 1582, 1688, 2490, 2048, 1691, 1323, 2410, 1230, 2790,
 2400,  249, 1128,  957, 2481, 1323, 1331, 2595,  912, 1253,
 2788, 1860,  130, 1273, 1216, 1216,  576, 1787, 1427, 2113,
 1787,  266, 1228, 1273, 2601,  682, 2256, 1857,  576,  296,
  669,  451,  300, 1331, 1216, 1787,  134, 1787, 3190, 2358,
 3365, 1248, 2423, 1331,   81, 2404, 1472,  513, 3168, 3169,
 3170, 3171, 3172, 3173, 3174, 2446, 1253, 2805, 1323, 1323,
 1437, 2559,  675, 2771,  485, 2645, 1473,  956, 2411,  579,
 2819, 1253, 1253, 2187, 1218, 1222, 3264,  363, 1222, 2218,
  266,  344, 2171, 1817,   45,  576, 2171, 2248,  513,  396,
 1220, 1253,  396, 2413,  344,  513,  513, 1249,  576,  670,
 2507, 3402, 1484, 1248, 1248, 3235, 2414, 1128, 2855,  396,
  517, 1706, 1097, 3021,  241,  292, 1514, 1515,  451, 1368,
 1474, 2508, 1218, 1248, 1323,  683, 1379, 1380, 2450,  662,
  135,  676, 1218, 1218,   15,  779, 3271,  136, 1220, 1870,
 3265, 2107, 1218, 1323,   81, 1249, 1333, 1592, 3184, 1304,
 1378, 2551, 2372, 1290, 1849, 2558, 2555,   93, 1220, 1435,
 1236, 2739, 1130, 1130, 1047, 1249, 1216,  137, 3236,  131,
 3418, 1256,  923,   91, 1048,  663, 1523, 2946,  513,  513,
 1586, 2049, 1218, 1417, 1171, 2425,  569, 2952, 2461, 1132,
 1270, 1218,  957,  671,  779,  299,  299, 2188, 1220, 2046,
 2148, 1593, 1426,  602, 1130, 2961, 2219,  912,  607, 1443,
 1444, 2471, 1256, 1576, 2740, 1256, 1576, 1523, 1266,  912,
 1523, 2509, 1130, 1253, 2741, 1171, 1587, 1347, 1594, 3356,
 1256,  923,  292, 1218, 2326, 1523,  451, 1077, 1270,  663,
 1787, 3420, 1417, 1171, 2742, 2357, 1588, 1218, 1516, 1220,
  912, 2209,  912, 1787, 3341, 1248, 2020, 1132, 1270, 1266,
  454, 3356, 2973, 1220, 1475, 2975, 1479, 1606,  610, 1523,
 1249, 1787, 2510,  475, 2242,  241,  241, 1266,  292, 3148,
  751, 3444,  451, 1371,  662, 2210, 1787, 1077, 1247, 2398,
  256, 1619, 2205, 2415,  364, 2211, 2412,  266,  266, 3419,
 2179, 1675, 2021, 2374, 2212, 3303, 1840, 1840, 1289, 1218,
 1218, 1139, 1921, 2249, 1131, 1842, 1842, 1843, 1843,  292,
 1005, 1844, 1844, 1845, 1845, 1220, 1220,  666,  365, 1218,
  663, 2503, 1249, 1249, 1487, 2523,  302,  969, 2691,  751,
 1787,  969, 3320,  396, 3323, 1220,  972, 2257,  711,  256,
  912, 2824, 1249,  472, 1372, 1131, 1136, 2259, 1483, 2743,
 2744, 2745, 1260, 1270, 1261, 2300,  138,  451, 1011,  541,
 1577, 2511, 2277, 1131, 3087, 1005, 2221,  513,  366,  517,
  472, 2568,  513, 1922, 3093,  266, 2715, 2206,  257, 2290,
 3086,  569,  610,  781,  499,  579, 1373, 1736, 1618, 1049,
 1737, 1732, 1732, 1260, 2717, 1261, 1012, 1083, 3240, 1086,
 1089,  671, 2504, 1480, 3277, 1582,  300,  300, 1390, 1574,
  972, 1260, 1574, 1261,  517,  977,  569, 1130,  513,  738,
  923, 2505, 3438,  712,  990, 1256,  781,  990, 1419, 3310,
 1417, 1422,  923, 1683,  971, 1270,  586,  257, 1171, 2506,
  507,  367, 1391,  302, 2526, 2875, 1704,  663, 1049, 1735,
 2291, 1218, 1853, 1854, 1855,  454, 1258, 2703, 1420,  972,
 2836, 1259, 1211,  923, 1595,  923,  585, 1220, 2527, 1290,
 1040, 3439, 1266, 1256, 1249, 2094,  472,  485,  738, 1744,
 1798,  523, 1120,  971, 1005, 1130, 1171, 1419, 2726,  302,
  610, 1576,  369, 1256, 1417,  233, 1171, 1171, 1742, 1417,
 2145,  454,  517, 1211,  971, 3350, 1171, 3198,  472,  485,
  675,  858,  859, 1589, 2139, 1795, 1222, 1420, 1796, 2750,
 1266, 1211, 1489, 1732, 3193, 1795,  781,  233, 1796, 1040,
  302, 2837,  587, 3311,  751, 3205, 2668, 1392, 1523,  373,
 1266, 2490, 3435, 2445,  781, 3312, 1171,  741,  472,  912,
  912, 2958, 2142, 1417, 1260, 1171,  254,  256, 1005,  233,
 1523, 2669, 1042,  923, 2143,  716, 1215, 3446, 1131, 1417,
  344, 2018,  375, 1225, 1141, 1933, 2670,  781, 1136,  676,
  751, 1050, 3403, 2997,  736,  509,  510,  858,  859, 2022,
 1130, 2423,  465, 1787,  472, 1047, 1491, 1171, 1256, 2727,
 2728, 1005, 3313, 2014,  594, 1048,  681, 1215, 3432, 1171,
 1215, 1171, 1816, 3218,  610, 3314, 1260, 2933, 1261, 3441,
 3272, 1042,  376, 2959, 2452, 1215,  475, 3440, 2650, 3274,
 2398, 1346, 1346, 2144,  422, 1654, 1131, 3094, 1927, 1497,
 1050,  571, 3448,  736,  254, 1266, 2566, 1655,  542, 1254,
 1345, 1345,  681, 1255,  259,  257, 1417,  543,  663,  952,
 1256, 1256, 2960, 1358, 1260, 2239, 1261, 1258, 1256, 1656,
 1257,  422, 1259, 1171, 1171, 1359, 1311,  517,  972, 1310,
 1256, 2424, 2081,  738, 1260, 1097, 1261, 1969,  678, 1172,
 1708, 1254,  663, 1171,  969, 1255, 2010, 1574,  678, 1139,
  896, 1139, 1577, 1226, 1124, 1212, 1360, 1266, 1361,  586,
  681,  501, 2277, 1289, 2240, 1422, 1654, 1659,  952, 2128,
 1709, 2909, 1795, 1045,  681, 1796, 1211, 1266, 1655,  738,
 1172,  894,  507, 1172, 2425, 2828, 1524,  588,  513,  513,
 2560, 1131,  259,  422,  896,  571, 1212,  524, 1172, 1097,
 1656, 2426, 1045, 2932, 1097, 1582,  610,  571, 2535,  896,
  947, 1657,  523,  998, 1212, 1417, 2239, 1417, 1417,  485,
 2876,  525,  923,  923, 1211,  894, 1953, 1524, 1045, 1422,
 1524, 1045,  422, 1031, 1422, 1211, 1315,  738, 1674, 1260,
  894, 1261, 2440, 2569, 1211, 1524, 1045,  678, 1659, 1222,
  579,  738, 2441,  977,  517,  587, 1362, 2165, 1097,  594,
  737,  428, 1256,  550,  571, 2243,  972, 1868, 1417,  947,
  477,  541, 1045, 1618, 1097, 1171, 1333,  571, 3412, 1524,
 1215,  274, 2137,  558, 1211, 1953,  654,  517, 1422,  663,
 1577,  588, 1031, 1211, 1136, 1315,  573,  517,  736, 2656,
  464, 2714,  428,  588, 1422,  428, 2147, 1729, 2172, 1933,
 1933, 1933, 2172,  663,  972, 2723, 2161, 3287, 1798,  737,
  428, 1260, 1795, 1261, 2244, 1796, 1045,  594, 1215,  477,
  610,  743,  751, 1795, 1290, 1211, 1796, 2672,  971, 1215,
  274, 3288,  971,  751,  736,  654, 1045, 2712, 1215, 1211,
 1730,  904, 1254, 2058, 2191, 1660, 1255,  517,  588, 1045,
  588, 1097, 2673,  594,  517, 1052, 2204, 1316,  554,  758,
  927, 1869, 3032,  588,  591,  594, 2161, 2674,  751, 2990,
  592, 2991, 3033, 2200, 2567, 2203, 2570, 2060, 1215,  751,
  743, 1422, 2875,  583, 1052,  667,  396, 1215, 1250, 1249,
 1251,  655,  736, 1172, 2763,  653, 1086, 1089,  593,  595,
  904, 1211, 1211, 3316,  598,  672,  736, 2773, 1795, 1212,
 1052, 1796, 1434, 1052,  344, 1317, 1316, 1795,  758,  927,
 1796, 1211,  594, 1250, 1249, 1251,  751,  396, 1052, 1215,
  396,  594, 2941,  970, 1910,  594, 1471, 2258, 2061,  597,
 1731, 1172, 3278, 1215,  667,  396, 1910, 2062,  396, 1910,
  655, 1172, 1172,   96, 1052, 1363, 1364, 1212, 1732,  118,
 1097, 1172, 1097, 1097, 1204, 2795,  472,  485, 1212,   49,
 1758, 1434, 2063, 1005, 1317, 2815,  608, 1212, 2817,   52,
  365, 1071,  970,  638, 2816,  517, 1074, 2818,  235,  637,
 1422, 1733, 1422, 1422, 2389, 1471,  250, 1654, 3068,   55,
 2382, 1172,  313, 2383, 2306, 1215, 1215,  396, 1052, 1655,
 1172, 1540,   96, 1419,  737, 1173,  648, 1212,  118,  593,
 1654,  654, 3289, 3176, 2408, 1215, 1212, 2500, 1052, 2501,
 2418, 1656, 1655,  666,  592, 1289, 1289, 2139, 3177,  365,
 1071, 1052, 1657, 1420, 2140, 1074, 3290,  235, 1524, 2385,
 2687,  679, 1172, 1211, 1656,  250, 1173,  972,  517, 1173,
  737,  313,  744,  688, 1172, 1657, 1172, 1337, 1212, 1338,
 1524,  689,  810, 1658, 1173,  691, 3346, 1618,  764, 1659,
  766, 1577, 1212,  693,  517,  743, 3347, 3348,  344,  472,
  485,  506,  464,  475,  475, 1053, 2460,  740, 1398, 1235,
 1072, 1397, 1659, 1742,  595,  773,  774, 1571,  591,  810,
 1260, 2381, 1236,  499,   58,   61,   64,  696,  737,  513,
  513,  744,  579,  579, 3082,  350,  986, 2035, 1172, 1172,
 1260,  743,  737, 1452, 1235, 1453, 3397, 1452, 3398, 1453,
 2125, 1225, 1758, 1260, 1212, 1212, 1237, 1236, 1172, 2406,
 2448, 2449,  714, 1238, 2386, 2387,  740, 1215, 1454, 1072,
 1065, 1239, 1454, 2127, 1212, 2688, 2126,  986, 1390,  730,
  986,  972,  595, 1455,  719, 2384,  323, 1455, 1240, 2232,
 1241, 1237, 2231,  103,  104,  986, 1660,  986, 1238,  743,
 1242,  720, 1243, 1244, 1245,  971, 1239, 1758,  541,  509,
  510,  737, 1391,  743, 2993,  729, 1290, 1290,  595, 1660,
 1035, 1036,  726, 1240,  513, 1241,  513,  513,  949, 1065,
  595, 2581,  954, 2237,  593, 1242, 2236,  739, 1244, 1245,
 2542,  972,  961, 2356,  972,  323, 2012,  963,  517,  592,
 1247, 1758,  517, 2139, 2499, 2539,  969, 2541, 2543, 1768,
 2484,  966, 1758,  725, 1905, 1577,  969, 1742, 1577,  978,
  513, 2497,  513,  513,  513, 3063, 1905,  561,  422, 1905,
 1896, 1226,  493, 2544,  981, 1247,  983,  595, 1141, 1173,
 1172, 2362, 2376,  979, 1260, 2375,  739,  513, 1906,  984,
  595, 2574,  593, 2576, 2577, 2578, 1212, 1392,  988,  725,
 1906,  548,  995, 1906, 3363,  997, 2405,  592,  985, 1260,
  393, 1896,  986,  591, 1896, 1071, 2807, 2808, 2596, 3036,
 1074,  994, 3307,  541,  244,  244,  744, 1173,  593, 1896,
 2488, 2983,  997, 2487, 3393,  472,  485, 1173, 1173, 2563,
  593, 1010, 2562,  592, 1071, 2611,  997, 1173, 1260,  997,
 1204, 2622, 3409, 1018, 2621,  592,  422,  725, 3410, 1289,
  725,  740,  994, 1022,  997,  994, 2694, 1222, 1029, 2695,
 1071,  725,  744, 1071,  742, 1074,  741,  422, 1074, 1024,
  994,  591,  994,  422,  986, 1031, 2652, 1173, 1071, 1260,
  986, 3411, 3368, 1074, 1037, 1289, 1173,  593,    4,    7,
 1040,  986,  986,  986, 1054, 2825,  986,  740, 2562,  986,
  593, 1041,  592, 1055, 1071, 2697,  422,  591, 1053, 1074,
 1059,  986, 1097,  513, 1118,  592, 1248,  986, 2830,  591,
  744, 2590, 1114,  742, 1072,  741,  986, 3012, 1173, 3038,
 3011, 1133, 3037,  493,  744,  350,  579, 2729, 2730, 1149,
 1173,  347, 1173,  969,  344,  472,  485,  506,  464,  475,
  475, 1248, 1146, 1072, 3090,  740, 2766, 1260, 1071, 2684,
 1151,  323, 1943, 1074, 3217, 3125, 1085, 2693, 3124,  740,
 3167, 1150,  579, 1397, 1943,  547,  591, 1943, 1071, 1072,
  986,  739, 1072, 1074, 1065, 3180,  653, 1153, 1260,  591,
 2796, 1071, 3358, 2391, 2392, 3357, 1074, 1072, 1139,  517,
  347,  986, 2458, 2459, 1173, 1173,  323,  986, 1154,  972,
 2698, 2699, 1155, 1065,  317,  986, 1156,  986, 2732,  513,
 1290, 1157, 1158, 1072, 1173, 1085, 3370,  739, 2499, 3369,
  986, 2696,  517, 1577, 1159,  986, 1896, 1896, 1160, 1065,
  986,  517, 1065, 1896,  317,  517,  317, 1161, 1167, 3372,
 2797, 2764, 3371, 1163, 1164, 1896, 1290, 1065, 1168, 1165,
 2768, 1788, 3433, 2783, 2774, 3357, 2787,  317,  986,  994,
 1166,  997,  997, 1788,  612,  994, 1788, 1072,  997, 3452,
 1169, 1171, 1260, 1065, 3268,  739,  994,  994,  994, 1173,
  997,  994,  317,  969,  994, 3454, 1181, 1072, 1260,  739,
  517, 1178, 1793, 1179,  969, 1523,  994, 1180, 1523,  348,
 1072, 1182,  994, 1183, 1793,  615,  317, 1793, 1184, 2497,
 2898,  994,  517, 1185, 1896, 1570, 1258, 1256,  742, 1257,
  741, 1259,  344,  517, 3450, 1954, 1186, 1065, 3453, 3070,
 3071, 3072, 3073, 3074, 3075, 1896, 1187, 1954,  615, 3334,
 1954, 1896, 2848, 2223, 1188, 2846, 1173, 1065, 2897,  997,
  463,  357,  323,  463, 1189, 1231, 1733,  986,  348, 1733,
 1065, 1190, 2905, 1191,  742,  994,  741, 1233,  396, 1734,
  997,  396, 1734, 2224, 1896, 2225,  997, 1192,  517,  969,
  517, 1245,  585, 1193, 1245,  585,  994, 1194,  969,  347,
  493, 1264,  994, 1195, 1340, 3338, 2226, 1742, 1196, 1742,
  994,  347,  994,  582,  493,  351,  582, 1341, 1197,  997,
  357, 3335,  884, 3337, 1198,  352,  350, 1174,  353, 1199,
  994, 2227,  742, 1200,  741,  994,  347, 2073, 1201, 1174,
 2076, 1202,  347,  986,  347,  344,  742, 1174,  741, 1203,
 2911, 2928, 1204, 2056,  955, 2228, 1205, 1206, 1207, 2935,
 1208, 1174, 1209,  994, 1210, 1211,  517, 1212, 2926, 1213,
  727, 1214, 1174, 1798, 1215, 1216, 1260, 1261, 2057,   64,
 1262,  347, 1263, 1798, 1008, 2939,  517, 3007, 2058,  345,
 1265, 1267,  324, 2059, 1291,  955,  354,  971,  955, 1308,
 1085,  513, 1292, 1293,   64, 1742, 1309,  971, 1312, 1174,
 1318, 1896, 1319,  955,   64, 1348,  727, 1323,  513,   64,
 2974, 1352, 2060, 1355, 1008, 1008,  355, 1369, 1008, 1085,
  356, 1381, 2994, 3050, 1394, 1375, 2268, 3052,   15, 1384,
 1400,  357,  347, 1008, 1410, 1008,  997, 1412,   64, 3010,
 1413,  324, 1481,  345, 1485, 1085, 1415,  968, 1085, 1490,
 1492, 1254,  994, 1414, 1498, 1255, 1417,  348, 1418, 1422,
 1425, 1431, 1432, 1085,  727, 1008, 1445,  727, 1464,  348,
  344, 3051,  517, 2061, 3054, 3053, 1469, 3056,  727,  357,
 1541, 1465, 2062, 2921,  969, 1467, 1470,  968,  645, 1085,
 2269, 3018, 1521, 3017,  348, 2270, 1543, 1549, 1550,   64,
  348, 1568,  348, 1583, 1572,  358, 1174, 2063,   64,  357,
 1598, 1599,  472,  493,  485,  490,  493,  569,  499,  506,
 1613,  357, 1623, 1642,  969,  493, 1625,  347,  994,  493,
 1626, 1662, 1664,   64, 1627,  517, 1665, 1666,  357,  348,
  746, 1667, 1397, 1085, 1689, 3139,  357,  350,  513, 2271,
 1690,  359,  357, 1695,  357, 2878, 2879, 2880, 2881, 2882,
 2883, 1697,  517, 1085,  513, 2272, 1699, 1700, 1716, 1727,
 1798,  513, 1719, 1721, 1933, 1724, 1085, 1799, 1800, 3121,
 1802, 2161, 1806, 3089, 3153, 3154, 3155, 3156, 3157, 3158,
 3159,  357, 1822, 1812,  971, 3131, 1820, 1813, 1827,  357,
  348, 3119, 3138, 3057, 1824, 1814, 1850, 1852, 1856, 1861,
 1885,  350, 1919, 1914,  360, 1928, 2013, 1014, 3128, 1934,
  955,  955, 1942, 1944, 1945, 1952, 1145,  955, 1953, 1957,
 1956, 2897, 1008, 1958, 1961, 1968,  344, 1980, 1008,  955,
 2012,  347,  347, 2019, 1239, 2016, 2031, 1008, 2032, 1008,
 1008, 1008,  357, 1162, 1008, 2028, 1254, 1008, 2034, 2846,
 2036, 2040, 2053,  357, 2050, 2042, 2054, 3049, 2055, 1008,
 2069, 2051, 2070,  493, 2052, 1008, 1175,  324, 1008, 3058,
 3195, 2077, 2071, 2078, 1008, 2087, 2082, 3215, 2083,  764,
 2105,  766,  509,  510, 2084,  348, 2118, 2130, 2135, 2085,
 3076, 3077, 2112,  344, 2131,  344, 2134, 2153,  955, 2136,
 2155,  768,  769,  517, 2167, 2168,  773,  774, 1008, 3238,
 1798, 2185,  324,  464, 3197, 2186, 2926, 2180, 3179,  955,
  326, 1798, 3186, 2189, 2190,  955,  998, 2198, 1008, 3119,
 2214, 2218, 2215, 3216,  971,  653, 2219,  357, 2235, 1705,
 2233, 3219, 2241, 2245, 2246,  971, 2247, 2251, 2278, 1008,
  326, 2273,  326, 2274, 2275, 1008, 2260, 2261,  955, 1008,
 2289,  478,  517, 2295,  357, 1008, 2298,  517, 2265, 2262,
 2299, 2322, 2263,  326, 2359, 2323, 2361, 2331, 2364,  513,
 2366, 3239, 2371, 1008, 2379, 2090, 1742, 2380, 1008, 2393,
 2401, 1343,  513, 2394, 2416, 2420, 3324, 2417,  326,  348,
  348, 2429, 2430, 2428, 2431, 2434, 1798, 2437, 2435,  357,
 3285, 2438, 1008, 1758, 2091, 1798, 1008,  357, 2444, 2451,
 2454, 1180,  326, 3294, 2139, 1426, 2456, 2464, 2457, 2466,
  971, 2467, 1343, 3128, 2474, 1343, 2181, 2472, 2485,  971,
 2092, 2545, 2517, 2093, 2518, 2519, 2520,  357, 2521,  357,
 1343,  357,  357, 2540, 1758, 2549, 2522, 1758, 2094, 1772,
 2525, 1180, 1180, 2557, 2571, 1180, 2584, 2573,  324, 2575,
  357, 2585, 1758, 2590, 1758, 2598, 2586, 2599,  858,  859,
 1180, 3351, 2624, 2625, 2095, 1325, 2608, 2649, 1326, 1706,
 1933,  344, 2651, 1332, 2707,  357, 1336, 2657,  541, 2705,
 1339, 2716, 2718, 2711, 1332, 2658, 2659, 2719, 1841, 2721,
 2660,  478, 2661, 2662, 3317, 1008, 2663, 2734, 2735,  357,
 3391, 2724, 2737, 2713, 3243, 3244, 3245, 3246, 3247, 3248,
 3249, 2733, 2738,  478, 2748, 2769, 2776, 2770, 2096, 3252,
 3253, 3254, 3255, 3256, 3257, 3258, 2777, 2775, 2166, 1841,
 2778, 2780, 1841, 2765, 2767, 2781, 3377, 2779, 2097, 2782,
 2789, 2785, 1976, 2784, 2798,  357, 2799, 1841, 2801, 2820,
 2821, 2098,  478, 2822, 2831, 2835, 2872, 2850, 2910, 2839,
 2899, 1250, 1249, 1251, 2866, 2885, 2922, 2912, 2913, 2914,
 2915, 1008, 2916, 2917, 2918, 1499, 1500, 1501, 1502, 1503,
 1504, 1505, 1506, 2927, 2937, 2936, 2940,  478, 2949, 2945,
 2954,  972, 1704, 2967, 2957, 2968, 2507, 1758, 1758, 1758,
 1758, 1758, 2970, 1758, 2978,  344, 2998, 2979, 3000, 1471,
 1832, 3002, 3023, 3020,  884,  971, 1758, 1758, 1758, 3047,
 1482, 3061, 3078, 3079, 3083, 1488, 3106, 3065, 3431, 1493,
 3088,  972, 3059, 3107, 3110, 1343, 3108, 3120, 3123, 1512,
 1145, 3129, 3135, 3143, 1518, 1519, 1145, 1758, 1522, 1523,
 1524, 1525, 1526, 1530, 1536,  971, 1539, 1758, 1542, 3147,
 1544, 1545, 1546, 1547, 1548, 1180, 3149, 1551, 1552, 1553,
 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563,
 1564, 1565, 1566, 1343, 1507, 3187, 1343, 3160, 3185, 3200,
 3191, 3201, 1758, 1343, 1343, 3208, 1182, 3220, 1343, 3232,
 1579, 3210, 3233, 1343, 3199, 3237, 1343, 1591, 3250, 3269,
 1508, 3276, 1597, 1180, 3275, 3279, 1180, 3283, 1604, 1605,
 1343, 3291, 3286, 1180, 1180, 3292, 1612, 3293, 1180, 3295,
 3304, 1343, 3306, 1180, 3300,  699, 1180, 1182, 3336, 1343,
 1182, 3318, 3327, 1343, 3319,  700, 3344, 3343,  701, 3352,
 1180, 3359, 1343, 2493, 3381, 1182, 3382, 3383, 3394, 3384,
 3395, 1180, 3400, 1234, 1841, 1841, 3396, 3404, 1343, 1180,
 3408, 1841, 1235, 1180, 1682, 3406, 3416, 3399, 3401, 3402,
 3430, 1305, 1180, 1841, 3434, 1236, 3436, 3447, 3451, 1343,
 3443, 3437,    1, 3449, 1343, 1136, 1253, 1138, 1180, 1182,
 1326,  368, 1953, 1009,  500, 1343, 1343, 1123, 1343,  501,
 1137, 1749,  451,  483, 1225, 1975,  702, 1521, 1758, 1237,
 1731, 1204, 1161,  911, 1180,  482, 1238, 1758,  492, 1230,
  454, 1522,   86, 1758, 1239, 1209, 1180, 1758, 1180,   65,
 1758,  517,  538, 1009, 1009,  320, 1616, 1009,  493, 1248,
  703, 1240, 1841, 1241, 1343,  704, 1097,  463,  558,  602,
  567,  705, 1009, 1242, 1009, 1243, 1244, 1245,  549, 1787,
 1343, 1343, 1246, 1841, 1758, 1343,  525, 1695, 1871, 1841,
  156, 1758, 1003,  396, 1180,  559,  603,  393, 1468, 1758,
 1343, 1724, 1617, 1608, 1009, 1696, 1730,  647,  567,  648,
 1180, 1180,  472, 1872,  617, 1180, 1758,  354, 1758, 1873,
    9,  355, 1841, 1247,   19,    0,   21,   25, 1758, 1874,
 1758, 1758, 1758, 1003,   28,   31, 1003, 1758,   40,   67,
   70,   21, 1875,   72,   76,  706,   79,   85,   88,   97,
   97, 1003,  106, 1003,  100,  103, 1938, 1939,  109, 1941,
  112, 1943,  115,   21, 2086, 1947, 1948, 1949, 1950, 1668,
 1182, 2667, 2675, 1954, 1955, 1669, 2671, 3062, 1758, 3161,
 1670, 1671, 3162, 1003, 1672, 2399, 2702, 1673, 3060, 2588,
 1962,  707, 1145, 3006, 3137, 1931,  600, 2988, 3388, 2964,
 1876,  500, 3122, 1113, 2512, 3221, 2536, 1978, 2977,  972,
 3302,  604, 1313, 2583, 2989, 2813, 1984, 1985, 1182, 3389,
 3282, 1182, 2814,  997, 3445, 3407, 3405, 3429, 1182, 1182,
 1877, 2955, 1343, 1182, 1878,  708, 3242, 2956, 1182, 1879,
 3267, 1182, 1923, 2292, 2288, 1880, 3105, 1377, 2482, 1841,
  972,  980, 3422,  972,  709, 1182, 1471, 2483, 3421, 3342,
 2177, 3204, 1180, 1881,  997, 2479, 1182,  997,  972, 3273,
 2027, 1009, 2029,   32, 1182, 2030, 1620, 1009, 1182, 2037,
 2871, 1864,  997, 2264, 2138, 1049, 1009, 1182, 1009, 1009,
 1009,   78, 1458, 1009, 2492, 2202, 1009, 1718, 1851,  586,
 2419, 1024, 2554, 1182, 3175, 2704,   78, 2709, 1009, 1248,
  596, 1433,  994, 1321, 1009, 1009,   78, 1009,  974, 1882,
 1837, 2114,   78, 1009, 2074, 2407, 2906,   78, 1476, 1182,
 1653, 3415,   78, 3144, 1145,   78, 3181, 2117, 1016,   50,
   52, 1182, 1024, 1182, 2433, 1024, 3163, 3164,   53,   56,
 1003,   59, 1307, 3366, 2026, 2572, 1003, 1009, 2579, 3284,
 1024, 1596, 1024, 1859, 1758, 1003, 1131, 1003, 1003, 1003,
 1056, 1776, 1003, 1332, 3213, 1003, 1336, 1009, 2120, 2121,
 1217, 1152, 1218, 2339,   62, 1614,   76, 1003, 1332, 1182,
 2981, 1703, 1024, 1003, 3022, 2548, 1003, 2756, 1009,  559,
  584,   85, 1003,   78, 1009, 1182, 1182, 2409, 1009, 1883,
 1182,   76, 3055, 2701, 1009, 3414, 1646,   76, 2829, 3212,
 3322, 3390,   76, 1466, 2757, 1182, 2169,   76, 1884, 1367,
   76, 2280, 1009,   78, 2178, 1015, 1003, 1009, 2938, 1389,
  133, 3297, 2908, 3333,    0,    0,    0,    0,   78,    0,
    0,    0,    0,    0,    0,    0, 1003,    0,    0,    0,
    0, 1009,    0,    0,    0, 1009,   78,    0,    0,    0,
    0, 1000,    0,    0,    0,    0, 1015, 1003,    0, 1015,
    0,    0,    0, 1003,    0,  972,  972, 1003,    0,  972,
    0,    0,  972, 1003, 1015,    0, 1015,    0,   76,  997,
  997,    0,    0,  997,  972,    0,  997,  992,    0,    0,
    0, 1003, 1000,    0,    0, 1000, 1003,    0,  997,    0,
    0,    0,   78,    0,    0,   78, 1015,    0,   76,    0,
 1000,    0, 1000,    0,    0,    0,    0,    0,    0,    0,
 1003,    0,    0,   76, 1003,  997,    0,    0,  992,    0,
    0,  992,    0,    0,    0,    0,    0, 1182,    0, 1024,
    0,   76, 1000,    0, 1009, 1024,  992,    0,  992,    0,
    0,    0,    0,  972, 1024,    0,    0, 1024, 1024,    0,
    0, 1024,    0,    0, 1024,    0,  997,  997,    0,  997,
    0,    0,    0,    0,  972,    0, 1024,    0,    0,    0,
  972,    0, 1024,    0,  997, 1024,  997,    0,  997,    0,
    0, 1024,    0,    0,  997,    0,    0,   76,    0,    0,
   76, 2309,    0,    0,    0,    0,    0, 2315,    0,    0,
    0,   78, 2318,  972,    0, 2319, 2320, 1962,    0,    0,
 1009,    0, 2325, 1003, 2327, 1024,    0,  997,    0,    0,
    0, 2328,    0, 2329,    0,    0, 2332, 2333, 2334, 2335,
    0,    0, 2340,    0, 2341, 1024, 2342,    0, 2343,    0,
    0,    0,    0,    0, 2344, 2345, 2346, 2347, 2348, 2349,
 2350, 2351, 2352, 2353, 2354, 2355, 1024,    0,    0,    0,
    0,    0, 1024, 1015,    0, 2363, 1024,    0,    0, 1015,
 2365,    0, 1024,    0, 2368,    0,    0,    0, 1015,    0,
    0, 1015, 1015,    0,    0, 1015,    0,    0, 1015, 1003,
 1024,    0, 1340,    0,    0, 1024,   76,    0,    0, 1000,
 1015,    0,    0,    0,    0, 1000, 1015,    0,    0, 1015,
    0,    0,    0,    0, 1000, 1015,    0, 1000, 1000, 1024,
    0, 1000,    0, 1024, 1000,    0,    0,    0,    0,    0,
  972,    0,    0,    0,    0,  992, 1000,    0,    0,    0,
    0,  992, 1000,    0,  997, 1000,    0,    0,    0, 1015,
    0, 1000,  992,  992,  992,    0,    0,  992, 1145,    0,
  992,    0,    0,    0,    0,    0,    0,    0,    0, 1015,
    0,    0,  992,  997,    0,    0,  997,    0,  992,  997,
    0,    0,    0,    0,    0, 1000,    0,  992,  997,    0,
 1015,    0,  997,    0,    0,  997, 1015,    0,    0,    0,
 1015,    0,    0,    0,    0, 1000, 1015,    0,    0,    0,
  997, 2469,    0, 1145,    0,    0,  997,  997,    0,  997,
  997,    0, 1024,    0, 1015,  997, 1000,    0,    0, 1015,
    0,    0, 1000,   79,    0,  997, 1000,  997,    0,    0,
    0,  992, 1000,    0,    0,    0,    0,    0,   79,    0,
    0, 1991,    0, 1015, 1990,    0,    0, 1015,   79,  997,
 1000,    0,  992,    0,   79, 1000,    0,    0,  992,   79,
 1250, 1249, 1251,    0,   79,    0,    0,   79,  992,  997,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1000,
    0,    0,    0, 1000,    0,    0,  992,    0, 1024,    0,
    0,  992, 1993,    0,    0, 1992,    0,    0,    0,    0,
  997,    0,    0,    0,    0,    0,  997,    0,    0,    0,
    0, 1250, 1249, 1251,    0,    0,   63,  266,    0,  992,
    0,    0,    0,    0,  997,    0,    0,    0,  746,    0,
    0,    0,    0,    0,    0,   79,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1015,    0,    0,    0,
    0,    0,    0,  997,  749,    0,    0,  997,  266, 1962,
    0,  266,    0,    0,    0,   79, 2615, 2616,    0,    0,
    0,    0,    0, 2623,    0,  431,  266,    0,    0,    0,
   79,  751, 1000,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   79,    0,
 2644,    0,    0, 2646,    0, 2648,    0, 2629,    0,    0,
 2628,    0,    0,    0,    0,    0,  431,    0,  992,  431,
    0,    0, 1015,    0,  997,    0, 1250, 1249, 1251,    0,
  997,    0,    0,    0,  431,    0,    0,    0,    0,    0,
    0,    0,  997,  997,    0,    0,  997,  761,    0,  997,
    0,    0,    0,    0,   79,    0,  997,   79, 1000,    0,
    0,  997, 1234,  763,    0,    0,    0,  997,    0,    0,
    0, 1235,    0,    0,    0,    0,  997,  764,    0,  766,
  509,  510,    0,    0, 1236,    0,    0,    0,    0,    0,
 1145,    0,    0,    0,  992,    0,    0,    0,    0,  768,
  769,  770,  771,  772,  773,  774,  775,  776, 2631,    0,
    0, 2630,    0, 1234,  778,  779,    0,    0, 1237,    0,
    0, 1145, 1235,  783,    0, 1238,    0, 1250, 1249, 1251,
  997,    0,  997, 1239,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,  997, 1241, 3029,    0,    0, 3028,  997,    0,    0,
    0,    0, 1242,   79, 1243, 1244, 1245,  997,    0, 1237,
    0, 1246, 1250, 1249, 1251,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,  997,    0,    0,    0,    0,
  997,    0,    0,  266,  266,    0,    0,    0,    0,    0,
  266, 1240,    0, 1241, 3031,    0,    0,    0,    0,    0,
    0,    0, 1247, 1242,    0, 1243, 1244, 1245,  997,    0,
    0,    0, 1246, 1250, 1249, 1251,    0,    0, 1234,    0,
    0,    0,    0,    0,    0,    0,    0, 1235,    0,    0,
 2849,    0, 2851,    0, 2852,    0,    0,    0, 2857,    0,
 1236,  431,  431, 2860, 2861, 2862, 2863, 2864,  431,    0,
    0,    0, 2865, 1247, 2868,    0, 2869,    0,    0,    0,
    0,    0,    0, 1693,  857,    0,  858,  859,  860,    0,
    0,  266,    0, 2870, 1237,    0,    0,    0,    0,    0,
    0, 1238, 1250, 1249, 1251,    0,    0,    0,    0, 1239,
    0,    0,  266,    0,    0,  878,  879,    0,  266,  408,
    0,    0,    0,    0,    0,    0, 1240,  997, 1241,    0,
    0,    0,    0, 1145, 1694,    0,    0,    0, 1242, 1234,
 1243, 1244, 1245,    0,    0, 1326,    0, 1246, 1235,  431,
    0,  266,    0, 1250, 1249, 1251,    0,    0,    0,    0,
  408, 1236,    0,  408, 2931, 1145,    0,    0,    0,    0,
  431,    0,    0,  386,    0,    0,  431,    0,  408,    0,
    0,    0, 2944,    0, 1234,    0, 1326,    0, 1247, 1326,
 2947, 2948,    0, 1235,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238,  997, 1326,    0, 1236,    0, 1248,  431,
 1239,    0,    0,    0,  386,    0,    0,  386,    0,    0,
  432,    0, 2971,    0,    0,    0,    0, 1240,    0, 1241,
    0,    0,  386,    0,    0, 1234,    0,    0,    0, 1242,
 1237, 1243, 1244, 1245, 1235,    0,    0, 1238, 1246,    0,
    0,    0,    0,    0,    0, 1239, 1946, 1236,    0, 1248,
    0,  432,    0,    0,  432,    0,    0,    0,  431,    0,
    0,    0, 1240,    0, 1241, 1250, 1249, 1251,    0,  432,
    0,    0,    0,    0, 1242, 3030, 1243, 1244, 1245, 1247,
    0, 1237,    0, 1246, 1966,    0,    0,    0, 1238,    0,
 1962, 2852,    0,    0, 1234,    0, 1239,    0,    0,    0,
 1250, 1249, 1251, 1235,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0, 1241, 1236,    0,    0,    0,
    0,    0,    0,    0, 1247, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
 1237,    0,    0,    0, 1235,    0,    0, 1238,    0,    0,
    0,    0,    0,    0, 1248, 1239,    0, 1236,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 3091, 1770,
    0,    0, 1240,    0, 1241,  409,  408,    0,    0,    0,
    0,    0,  409,    0, 1242,    0, 1243, 1244, 1245,    0,
    0, 1237,    0, 1246,    0,    0,    0,    0, 1238,    0,
    0, 1326, 1326,    0,    0,    0, 1239,    0, 1326, 1770,
 1770,    0, 1770, 1770, 1770, 1779,    0,    0,    0,    0,
    0,    0,    0, 1240,    0, 1241, 3136, 1770, 1770,  386,
  386,    0, 1770,    0, 1247, 1242,  386, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0, 1962,    0,    0,    0,
    0,    0,    0,    0, 3150, 1248, 3151, 1234,    0,    0,
    0,    0,    0,  409,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  432,  432,    0, 1236,
    0,    0,    0,  432,  409, 1247,    0,    0,    0, 1326,
  409,    0, 1234, 1326,    0,    0,    0,    0,    0,    0,
 1248, 1235,    0,    0,    0,    0,    0,    0,    0, 2931,
 1326,    0,    0, 1237, 1236,    0, 1326,  386,    0,    0,
 1238,    0,    0,  409,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  386,    0,
    0,    0,    0,    0,  386, 1240,    0, 1241, 1237, 1326,
    0, 1248,    0,    0,    0, 1238,    0, 1242,    0, 1243,
 1244, 1245,    0, 1239,  432,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0, 1962,    0,  386,    0,    0,
 1240,    0, 1241,    0,    0,  432,    0,    0,    0,    0,
    0,  432, 1242,    0, 1243, 1244, 1245,    0,    0,    0,
    0, 1246,    0,    0,    0,    0,    0, 1247, 1326,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1248,    0,    0,    0,  432,    0, 1770,    0, 1770,    0,
    0,    0,    0, 1770, 1770,    0, 1770, 1770, 1770,    0,
    0,    0, 1247, 1770,    0,    0,    0,    0, 1770, 1770,
    0, 1770,    0, 1770, 1770,    0, 1770,    0,    0, 1770,
 1770, 1770,    0,    0,    0,    0, 1770,    0, 1770, 1770,
    0, 1248,    0, 1770,    0, 1770,    0, 1770, 1770,    0,
    0, 1770,    0,  432, 1770,    0, 1770,    0, 1770, 1770,
    0, 1770, 1770, 1770,    0, 1770, 1770, 1770,    0,    0,
    0, 1770,    0, 1770, 1770, 1770,    0,    0,    0, 1770,
    0,    0,    0, 1770,    0, 1770, 1770, 1770, 1770,    0,
 1770,    0, 1770, 1770,    0, 1770, 1770, 1770,    0, 1770,
    0,    0,    0, 1770,    0,    0,    0, 1770, 3345, 1770,
 3349, 1770,    0, 1770, 1770, 1770, 1770, 1770,    0, 1770,
 1770, 1770,    0,    0,    0, 1770, 1145, 1770, 1770,    0,
    0, 1770, 1770, 1770,    0,    0, 1770, 3375, 1770, 3378,
 3380, 1770, 1770, 1770, 1770,    0, 1770,    0, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1145,    0,    0, 1770,
    0, 1770, 1770, 1248,    0, 1770,    0,    0,    0,    0,
    0,    0, 1770,    0, 1770,    0, 1770, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770,    0, 1770, 1770, 1770, 1770,
    0, 1770, 1770,    0, 3375, 3423, 3424,    0, 1248, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770,    0, 1770, 1770, 1770, 1770, 1770,    0, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0,    0, 1770,
 1770, 1770, 1770, 1770, 1770, 1770,    0,    0, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0, 1770,    0,
 1770, 1770, 1770,    0, 1770, 1770,    0, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0,
 1770, 1770, 1770, 1770, 1770, 1770,    0, 1770, 1770, 1770,
 1770,    0, 1770,    0, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770,    0, 1770, 1770, 1770, 1770,    0, 1770, 1770,
 1770, 1770, 1770,    0, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0, 1770, 1770,
 1770, 1770, 1770, 1770,    0, 1770, 1770, 1770, 1770, 1770,
 1770, 1770, 1770,    0, 1770, 1770, 1770, 1770,    0, 1770,
 1770, 1770, 1770, 1770, 1770,    0,    0, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1516, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,
 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770, 1770,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1516, 1516,
 1516, 1516, 1516,    0, 1516,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1516, 1516, 1516, 1516,
 2591,    0,    0, 1062,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   82,    0, 2592,    0,    0,    0, 1063,
    0, 1064,    0,    0,    0,    0,    0,    0,   89,    0,
 1516,    0,    0,    0,    0,    0,    0,    0,   82,    0,
    0,    0,    0,    0,   82,    0,    0,    0,    0,   82,
    0,    0,    0,    0,   82,    0,    0,   82,    0, 1065,
    0,    0,    0,    0,    0, 1066, 1067, 1068,    0, 1069,
 1070, 1071,    0, 1072,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1073,    0, 1074,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3003,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1075,    0,
    0,    0,    0,    0,    0,   82,    0,    0,    0,    0,
    0,    0,    0,    0, 1076,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   82, 1077,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   82,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   82,    0,
 1078, 1079,    0,    0, 1516, 1516, 1516,    0,    0, 1516,
    0, 1516, 1516,    0,    0, 1516, 1516, 1080, 1516,    0,
    0,    0,    0, 1516, 1516,    0, 1516, 1516, 1516, 1516,
 1516, 1516,    0,    0, 1516,    0,    0, 1516,    0,    0,
    0,    0,    0,    0, 1516,    0, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516,   82,    0, 1516,   82,    0, 1516,
    0, 1516, 1516,    0,    0, 1516, 1516, 1516,    0, 1516,
 1516, 1516, 1516, 1516, 1516, 1516,    0,    0,    0, 1516,
 1516, 1516, 1516, 1516,    0,    0,    0, 1516,    0,    0,
    0,    0,    0,    0,    0, 1516, 1516, 1516, 1516, 1516,
 1516,    0,    0,    0, 1516, 1516,    0, 1516,    0, 1516,
    0, 1516, 1516, 1516,    0, 1516,    0, 1516, 1516, 1516,
    0, 1516, 1516, 1516, 1516, 1516,    0, 1516, 1516,    0,
    0,    0, 1516, 1516,    0, 1516, 1516,    0, 1516, 1516,
 1516, 1516,    0,    0, 1516,    0, 1516,    0, 1516, 1516,
 1516, 1516, 1516,    0, 1516,    0, 1516,    0, 1516, 1516,
 1516, 1516, 1516,   82,    0, 1516, 1516, 1516,    0, 1516,
 1516, 1516,    0,    0,    0,    0, 1081,    0,    0,    0,
 1516, 1516, 1516,    0, 1516, 1516, 1516,    0, 1516,    0,
    0,    0, 1516,    0, 1516, 1516, 1516, 1516,    0, 1516,
    0, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,    0,
    0,    0,    0, 1250, 1249, 1251,    0,    0, 1516, 1516,
 1970, 1516, 1516, 1516,    0,    0,    0,    0, 1516, 1516,
 1516, 1516, 1516,    0, 1516,    0,    0, 1516, 1516, 1250,
 1249, 1251, 1516, 1516, 1971,    0, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516, 1516,    0, 1516,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516, 1516, 1516, 1516,    0, 1516, 1516,
 1516, 1516, 1516, 1516,    0, 1516, 1516, 1516, 1516,    0,
 1516,    0, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
    0, 1516, 1516, 1516, 1516,    0, 1516, 1516, 1516, 1516,
 1516,    0, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
 1516, 1516,    0, 1516, 1516, 1516, 1516, 1516, 1516, 1516,
 1516, 1518, 1516, 1516, 1516, 1516,    0, 1516, 1516, 1516,
 1516, 1516, 1516,    0,    0, 1516, 1516, 1516, 1516, 1516,
 1516, 1516, 1516, 1516,    0,    0,    0,    0,    0, 1516,
    0, 1516, 1516, 1516, 1516, 1516, 1516,    0, 1516,    0,
    0,    0, 1518, 1518, 1518, 1518, 1518,    0, 1518,    0,
    0,    0,    0,    0,    0, 1234,    0,  594,    0,    0,
 1518, 1518, 1518, 1518, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0,    0,    0, 1518,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0, 1237,    0,    0, 1235,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0, 1240, 1238, 1241,    0,    0,    0,    0,
    0,    0, 1239,    0,    0, 1242,    0, 1243, 1244, 1245,
    0, 1237,    0,    0, 1246,    0,    0,    0, 1238, 1240,
    0, 1241,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1518, 1518,
 1518,    0,    0, 1518,    0, 1518, 1518,    0,    0, 1518,
 1518,    0, 1518,    0,    0,    0,    0, 1518, 1518,    0,
 1518, 1518, 1518, 1518, 1518, 1518,    0,    0, 1518,    0,
    0, 1518,    0,    0,    0,    0,    0,    0, 1518,    0,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,    0,    0,
 1518,    0,    0, 1518,    0, 1518, 1518,    0,    0, 1518,
 1518, 1518,    0, 1518, 1518, 1518, 1518, 1518, 1518, 1518,
    0,    0,    0, 1518, 1518, 1518, 1518, 1518,    0,    0,
    0, 1518,    0,    0,    0,    0,    0,    0,    0, 1518,
 1518, 1518, 1518, 1518, 1518,    0,    0,    0, 1518, 1518,
    0, 1518,    0, 1518,    0, 1518, 1518, 1518,    0, 1518,
    0, 1518, 1518, 1518,    0, 1518, 1518, 1518, 1518, 1518,
    0, 1518, 1518,    0,    0,    0, 1518, 1518,  430, 1518,
 1518, 1248, 1518, 1518, 1518, 1518,    0,    0, 1518,    0,
 1518,    0, 1518, 1518, 1518, 1518, 1518,    0, 1518,    0,
 1518,    0, 1518, 1518, 1518, 1518, 1518, 1248,    0, 1518,
 1518, 1518,    0, 1518, 1518, 1518,    0,    0,    0,  430,
    0,    0,  430,    0, 1518, 1518, 1518,    0, 1518, 1518,
 1518, 1248, 1518,    0,    0,    0, 1518,  430, 1518, 1518,
 1518, 1518,    0, 1518,    0, 1518, 1518, 1518, 1518, 1518,
 1518, 1518, 1518,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1518, 1518, 1972, 1518, 1518, 1518,    0,    0,
    0,    0, 1518, 1518, 1518, 1518, 1518,    0, 1518,    0,
    0, 1518, 1518, 1250, 1249, 1251, 1518, 1518, 1973,    0,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,    0,
 1518,    0,    0,    0,    0,    0,    0, 1250, 1249, 1251,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,
 1518,    0, 1518, 1518, 1518, 1518, 1518, 1518,    0, 1518,
 1518, 1518, 1518,    0, 1518,    0, 1518, 1518, 1518, 1518,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,
 1518, 1518, 1518, 1518,    0, 1518, 1518, 1518, 1518,    0,
 1518, 1518, 1518, 1518, 1518,    0, 1518, 1518, 1518, 1518,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,
 1518, 1518, 1518, 1518, 1518, 1518,    0, 1518, 1518, 1518,
 1518, 1518, 1518, 1518, 1518, 1780, 1518, 1518, 1518, 1518,
    0, 1518, 1518, 1518, 1518, 1518, 1518,    0,    0, 1518,
 1518, 1518, 1518, 1518, 1518, 1518, 1518, 1518,    0,    0,
    0,    0,    0, 1518,    0, 1518, 1518, 1518, 1518, 1518,
 1518,    0, 1518,    0,    0, 1753, 1780, 1780, 1780, 1780,
 1780, 1780, 1780,    0,  430,  430,    0,    0,    0,    0,
    0,  430,    0, 1780, 1780, 1780, 1780, 1780,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1780,    0, 1780,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,  430,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,  430,    0, 1237,    0,    0,    0,  430,
    0,    0, 1238, 1240,    0, 1241,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0, 1240,    0, 1241,
    0,    0,  430,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,  430, 1780,    0, 1780,    0,    0, 1780,    0, 1780,
 1780,    0,    0, 1780, 1780,    0, 1780,    0,    0,    0,
    0,    0, 1780,    0, 1780, 1780, 1780, 1780,    0, 1780,
    0,    0, 1780,    0,    0, 1780,    0,    0,    0,    0,
    0,    0, 1780,    0, 1780, 1780,    0, 1780, 1780, 1780,
 1780, 1780,    0,    0, 1780,    0,    0, 1780,    0, 1780,
 1780,    0,    0, 1780, 1780, 1780,    0, 1780, 1780, 1780,
 1780, 1780, 1780, 1780,    0,    0,    0, 1780, 1780, 1780,
 1780, 1780,    0,    0,    0, 1780,    0,    0,    0,    0,
    0,    0,    0, 1780, 1780, 1780, 1780, 1780, 1780,    0,
    0,    0, 1780, 1780,    0, 1780,    0, 1780,    0, 1780,
 1780, 1780,    0, 1780,    0, 1780, 1780, 1780,    0, 1780,
 1780, 1780, 1780, 1780,    0, 1780, 1780,    0,    0,    0,
    0, 1780,  410, 1780, 1780,    0,    0, 1780, 1780, 1780,
    0,    0, 1780,    0, 1780,    0,    0, 1780, 1780, 1780,
 1780,    0, 1780,    0, 1780,    0, 1780, 1780, 1780, 1780,
 1780, 1248,    0, 1780, 1780, 1780,    0, 1780, 1780,    0,
    0,    0,    0,  410,    0,    0,  410,    0, 1780, 1780,
 1780,    0, 1780, 1780, 1780, 1248, 1780,    0,    0,    0,
 1780,  410, 1780, 1780, 1780, 1780,    0, 1780,    0, 1780,
 1780, 1780, 1780, 1780, 1780, 1780, 1780,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1780, 1780, 1974, 1780,
 1780, 1780,    0,    0,    0,    0, 1780, 1780, 1780, 1780,
 1780,    0, 1780,    0,    0, 1780, 1780, 1250, 1249, 1251,
 1780, 1780, 1987,    0, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780,    0, 1780,    0,    0,    0,    0,    0,
    0, 1250, 1249, 1251, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780, 1780, 1780,    0, 1780, 1780, 1780, 1780,
 1780, 1780,    0, 1780, 1780, 1780, 1780,    0, 1780,    0,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780,    0, 1780,
 1780, 1780, 1780,    0, 1780, 1780, 1780, 1780, 1780,    0,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1780, 1817,
 1780, 1780, 1780, 1780,    0, 1780, 1780, 1780, 1780, 1780,
 1780,    0,    0, 1780, 1780, 1780, 1780, 1780, 1780, 1780,
 1780, 1780,    0,    0,    0,    0,    0, 1780,    0, 1780,
 1780, 1780, 1780, 1780, 1780,    0, 1780,    0,    0, 1630,
 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,  412,  410,
    0,    0,    0,    0,    0,  412,    0, 1817, 1817, 1817,
 1817, 1817,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1817,    0, 1817,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,  412,    0,    0,    0,
    0,    0, 1238,    0,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,  412,    0, 1237,
    0,    0,    0,  412,    0,    0, 1238, 1240,    0, 1241,
    0,    0,    0,    0, 1239,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0, 1240,    0, 1241,    0,    0,  412,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0, 1817,    0, 1817,    0,
    0, 1817,    0, 1817, 1817,    0,    0, 1817, 1817,    0,
 1817,    0,    0,    0,    0,    0, 1817,    0, 1817, 1817,
 1817, 1817,    0, 1817,    0,    0, 1817,    0,    0, 1817,
    0,    0,    0,    0,    0,    0, 1817,    0, 1817, 1817,
    0, 1817, 1817, 1817, 1817, 1817,    0,    0, 1817,    0,
    0, 1817,    0, 1817, 1817,    0,    0, 1817, 1817, 1817,
    0, 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,    0,
    0, 1817, 1817, 1817, 1817, 1817,    0,    0,    0, 1817,
    0,    0,    0,    0,    0,    0,    0, 1817, 1817, 1817,
 1817, 1817, 1817,    0,    0,    0, 1817, 1817,    0, 1817,
    0, 1817,    0, 1817, 1817, 1817,    0, 1817,    0, 1817,
 1817, 1817,    0, 1817, 1817, 1817, 1817, 1817,    0, 1817,
 1817,    0,    0,    0,    0, 1817,  428, 1817, 1817,    0,
    0, 1817, 1817, 1817,    0,    0, 1817,    0, 1817,    0,
    0, 1817, 1817, 1817, 1817,    0, 1817,    0, 1817,    0,
 1817, 1817, 1817, 1817, 1817, 1248,    0, 1817, 1817, 1817,
    0, 1817, 1817,    0,    0,    0,    0,  428,    0,    0,
  428,    0, 1817, 1817, 1817,    0, 1817, 1817, 1817, 1248,
 1817,    0,    0,    0, 1817,  428, 1817, 1817, 1817, 1817,
    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1817, 1817, 1989, 1817, 1817, 1817,    0,    0,    0,    0,
 1817, 1817, 1817, 1817, 1817,    0, 1817,    0,    0, 1817,
 1817, 1250, 1249, 1251, 1817, 1817, 1994,    0, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0, 1817,    0,
    0,    0,    0,    0,    0, 1250, 1249, 1251, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,    0,
 1817, 1817, 1817, 1817, 1817, 1817,    0, 1817, 1817, 1817,
 1817,    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817,    0, 1817, 1817, 1817, 1817,    0, 1817, 1817,
 1817, 1817, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817, 1817,
 1817, 1817, 1817, 1819, 1817, 1817, 1817, 1817,    0, 1817,
 1817, 1817, 1817, 1817, 1817,    0,    0, 1817, 1817, 1817,
 1817, 1817, 1817, 1817, 1817, 1817,    0,    0,    0,    0,
    0, 1817,    0, 1817, 1817, 1817, 1817, 1817, 1817,    0,
 1817,    0,    0, 1631, 1819, 1819, 1819, 1819, 1819, 1819,
 1819,    0,  428,  428,    0,    0,    0,    0,    0,  428,
    0, 1819, 1819, 1819, 1819, 1819,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1819,    0, 1819,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
  428,    0,    0,    0,    0,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,  428,    0, 1237,    0,    0,    0,  428,    0,    0,
 1238, 1240,    0, 1241,    0,    0,    0,    0, 1239,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0, 1240,    0, 1241,    0,    0,
  428,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
 1819,    0, 1819,    0,    0, 1819,    0, 1819, 1819,    0,
    0, 1819, 1819,    0, 1819,    0,    0,    0,    0,    0,
 1819,    0, 1819, 1819, 1819, 1819,    0, 1819,    0,    0,
 1819,    0,    0, 1819,    0,    0,    0,    0,    0,    0,
 1819,    0, 1819, 1819,    0, 1819, 1819, 1819, 1819, 1819,
    0,    0, 1819,    0,    0, 1819,    0, 1819, 1819,    0,
    0, 1819, 1819, 1819,    0, 1819, 1819, 1819, 1819, 1819,
 1819, 1819,    0,    0,    0, 1819, 1819, 1819, 1819, 1819,
    0,    0,    0, 1819,    0,    0,    0,    0,    0,    0,
    0, 1819, 1819, 1819, 1819, 1819, 1819,    0,    0,    0,
 1819, 1819,    0, 1819,    0, 1819,    0, 1819, 1819, 1819,
    0, 1819,    0, 1819, 1819, 1819,    0, 1819, 1819, 1819,
 1819, 1819,    0, 1819, 1819,    0,    0,    0,    0, 1819,
    0, 1819, 1819,    0,    0, 1819, 1819, 1819,    0,    0,
 1819,    0, 1819,    0,    0, 1819, 1819, 1819, 1819,    0,
 1819,    0, 1819,    0, 1819, 1819, 1819, 1819, 1819, 1248,
    0, 1819, 1819, 1819,    0, 1819, 1819,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1819, 1819, 1819,    0,
 1819, 1819, 1819, 1248, 1819,    0,    0,    0, 1819,    0,
 1819, 1819, 1819, 1819,    0, 1819,    0, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1819, 1819, 1995, 1819, 1819, 1819,
    0,    0,    0,    0, 1819, 1819, 1819, 1819, 1819,    0,
 1819,    0,    0, 1819, 1819, 1250, 1249, 1251, 1819, 1819,
 1996,    0, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819,    0, 1819,    0,    0,    0,    0,    0,    0, 1250,
 1249, 1251, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819,    0, 1819, 1819, 1819, 1819, 1819, 1819,
    0, 1819, 1819, 1819, 1819,    0, 1819,    0, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819,    0, 1819, 1819, 1819,
 1819,    0, 1819, 1819, 1819, 1819, 1819,    0, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1821, 1819, 1819,
 1819, 1819,    0, 1819, 1819, 1819, 1819, 1819, 1819,    0,
    0, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819, 1819,
    0,    0,    0,    0,    0, 1819,    0, 1819, 1819, 1819,
 1819, 1819, 1819,    0, 1819,    0,    1, 1633, 1821, 1821,
 1821, 1821, 1821, 1821, 1821,    0,    0,    0,    0,    0,
    0,    0,    0,    2,    0, 1821, 1821, 1821, 1821, 1821,
    0,    3,    0,    0,    0,    0,    0,    0,    0,    4,
    0,    5,    0,    0,    0,    0,    6, 1234,    0,    0,
    0,    0,    7,    0,    0,    0, 1235,    0, 1821,    0,
 1821,    0,    0,    0,    0,    0,    8,    0,    0, 1236,
    0, 1234,    0,    0,    0,    9,    0,    0,    0,    0,
 1235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
   10,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238,    0,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238, 1240,    0, 1241,    0,    0,
    0,   11, 1239,   12,    0,    0,   13, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
   14, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,   15,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   16,    0,
    0, 1247,    0,    0, 1821,    0, 1821,    0,    0, 1821,
    0, 1821, 1821,   17,   18, 1821, 1821,    0, 1821,    0,
    0,    0,    0,    0, 1821,    0, 1821, 1821, 1821, 1821,
    0, 1821,    0,    0, 1821,   19,    0, 1821,    0,    0,
    0,    0,    0,    0, 1821,    0, 1821, 1821,    0, 1821,
 1821, 1821, 1821, 1821,    0,    0, 1821,    0,    0, 1821,
    0, 1821, 1821,    0,    0, 1821, 1821, 1821,    0, 1821,
 1821, 1821, 1821, 1821, 1821, 1821,    0,    0,    0, 1821,
 1821, 1821, 1821, 1821,    0,    0,    0, 1821,    0,    0,
    0,    0,    0,    0,    0, 1821, 1821, 1821, 1821, 1821,
 1821,    0,    0,    0, 1821, 1821,    0, 1821,    0, 1821,
    0, 1821, 1821, 1821,    0, 1821,    0, 1821, 1821, 1821,
    0, 1821, 1821, 1821, 1821, 1821,    0, 1821, 1821,    0,
    0,    0,    0, 1821,    0, 1821, 1821,    0,    0, 1821,
 1821, 1821,    0,    0, 1821,    0, 1821,    0,    0, 1821,
 1821, 1821, 1821,    0, 1821,    0, 1821,    0, 1821, 1821,
 1821, 1821, 1821, 1248,    0, 1821, 1821, 1821,    0, 1821,
 1821,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1821, 1821, 1821,    0, 1821, 1821, 1821, 1248, 1821,    0,
    0,    0, 1821,    0, 1821, 1821, 1821, 1821,    0, 1821,
    0, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1821, 1821,
 1997, 1821, 1821, 1821,    0,    0,    0,    0, 1821, 1821,
 1821, 1821, 1821,    0, 1821,    0,    0, 1821, 1821, 1250,
 1249, 1251, 1821, 1821, 2301,    0, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821,    0, 1821,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821,    0, 1821, 1821,
 1821, 1821, 1821, 1821,    0, 1821, 1821, 1821, 1821,    0,
 1821,    0, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
    0, 1821, 1821, 1821, 1821,    0, 1821, 1821, 1821, 1821,
 1821,    0, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821, 1821,
 1821, 1822, 1821, 1821, 1821, 1821,    0, 1821, 1821, 1821,
 1821, 1821, 1821,    0,    0, 1821, 1821, 1821, 1821, 1821,
 1821, 1821, 1821, 1821,    0,    0,    0,    0,    0, 1821,
    0, 1821, 1821, 1821, 1821, 1821, 1821,    0, 1821,    0,
    0, 1634, 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1822,
 1822, 1822, 1822, 1822,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1822,    0, 1822,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238,    0,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238, 1240,
    0, 1241,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1822,    0,
 1822,    0,    0, 1822,    0, 1822, 1822,    0,    0, 1822,
 1822,    0, 1822,    0,    0,    0,    0,    0, 1822,    0,
 1822, 1822, 1822, 1822,    0, 1822,    0,    0, 1822,    0,
    0, 1822,    0,    0,    0,    0,    0,    0, 1822,    0,
 1822, 1822,    0, 1822, 1822, 1822, 1822, 1822,    0,    0,
 1822,    0,    0, 1822,    0, 1822, 1822,    0,    0, 1822,
 1822, 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
    0,    0,    0, 1822, 1822, 1822, 1822, 1822,    0,    0,
    0, 1822,    0,    0,    0,    0,    0,    0,    0, 1822,
 1822, 1822, 1822, 1822, 1822,    0,    0,    0, 1822, 1822,
    0, 1822,    0, 1822,    0, 1822, 1822, 1822,    0, 1822,
    0, 1822, 1822, 1822,    0, 1822, 1822, 1822, 1822, 1822,
    0, 1822, 1822,    0,    0,    0,    0, 1822,    0, 1822,
 1822,    0,    0, 1822, 1822, 1822,    0,    0, 1822,    0,
 1822,    0,    0, 1822, 1822, 1822, 1822,    0, 1822,    0,
 1822,    0, 1822, 1822, 1822, 1822, 1822, 1248,    0, 1822,
 1822, 1822,    0, 1822, 1822,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1822, 1822, 1822,    0, 1822, 1822,
 1822, 1248, 1822,    0,    0,    0, 1822,    0, 1822, 1822,
 1822, 1822,    0, 1822,    0, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1822, 1822, 2302, 1822, 1822, 1822,    0,    0,
    0,    0, 1822, 1822, 1822, 1822, 1822,    0, 1822,    0,
    0, 1822, 1822, 1250, 1249, 1251, 1822, 1822, 2307,    0,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,
 1822,    0,    0,    0,    0,    0,    0, 1250, 1249, 1251,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822,    0, 1822, 1822, 1822, 1822, 1822, 1822,    0, 1822,
 1822, 1822, 1822,    0, 1822,    0, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822,    0, 1822, 1822, 1822, 1822,    0,
 1822, 1822, 1822, 1822, 1822,    0, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,
 1822, 1822, 1822, 1822, 1822, 1823, 1822, 1822, 1822, 1822,
    0, 1822, 1822, 1822, 1822, 1822, 1822,    0,    0, 1822,
 1822, 1822, 1822, 1822, 1822, 1822, 1822, 1822,    0,    0,
    0,    0,    0, 1822,    0, 1822, 1822, 1822, 1822, 1822,
 1822,    0, 1822,    0,    0, 1635, 1823, 1823, 1823, 1823,
 1823, 1823, 1823,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1823, 1823, 1823, 1823, 1823,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1823,    0, 1823,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238, 1240,    0, 1241,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0, 1823,    0, 1823,    0,    0, 1823,    0, 1823,
 1823,    0,    0, 1823, 1823,    0, 1823,    0,    0,    0,
    0,    0, 1823,    0, 1823, 1823, 1823, 1823,    0, 1823,
    0,    0, 1823,    0,    0, 1823,    0,    0,    0,    0,
    0,    0, 1823,    0, 1823, 1823,    0, 1823, 1823, 1823,
 1823, 1823,    0,    0, 1823,    0,    0, 1823,    0, 1823,
 1823,    0,    0, 1823, 1823, 1823,    0, 1823, 1823, 1823,
 1823, 1823, 1823, 1823,    0,    0,    0, 1823, 1823, 1823,
 1823, 1823,    0,    0,    0, 1823,    0,    0,    0,    0,
    0,    0,    0, 1823, 1823, 1823, 1823, 1823, 1823,    0,
    0,    0, 1823, 1823,    0, 1823,    0, 1823,    0, 1823,
 1823, 1823,    0, 1823,    0, 1823, 1823, 1823,    0, 1823,
 1823, 1823, 1823, 1823,    0, 1823, 1823,    0,    0,    0,
    0, 1823,    0, 1823, 1823,    0,    0, 1823, 1823, 1823,
    0,    0, 1823,    0, 1823,    0,    0, 1823, 1823, 1823,
 1823,    0, 1823,    0, 1823,    0, 1823, 1823, 1823, 1823,
 1823, 1248,    0, 1823, 1823, 1823,    0, 1823, 1823,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1823, 1823,
 1823,    0, 1823, 1823, 1823, 1248, 1823,    0,    0,    0,
 1823,    0, 1823, 1823, 1823, 1823,    0, 1823,    0, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1823, 1823, 2308, 1823,
 1823, 1823,    0,    0,    0,    0, 1823, 1823, 1823, 1823,
 1823,    0, 1823,    0,    0, 1823, 1823, 1250, 1249, 1251,
 1823, 1823, 2310,    0, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823,    0, 1823,    0,    0,    0,    0,    0,
    0, 1250, 1249, 1251, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823,    0, 1823, 1823, 1823, 1823,
 1823, 1823,    0, 1823, 1823, 1823, 1823,    0, 1823,    0,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,    0, 1823,
 1823, 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823,    0,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1823, 1824,
 1823, 1823, 1823, 1823,    0, 1823, 1823, 1823, 1823, 1823,
 1823,    0,    0, 1823, 1823, 1823, 1823, 1823, 1823, 1823,
 1823, 1823,    0,    0,    0,    0,    0, 1823,    0, 1823,
 1823, 1823, 1823, 1823, 1823,    0, 1823,    0,    0, 1637,
 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1824, 1824, 1824,
 1824, 1824,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1824,    0, 1824,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238,    0,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238, 1240,    0, 1241,
    0,    0,    0,    0, 1239,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0, 1824,    0, 1824,    0,
    0, 1824,    0, 1824, 1824,    0,    0, 1824, 1824,    0,
 1824,    0,    0,    0,    0,    0, 1824,    0, 1824, 1824,
 1824, 1824,    0, 1824,    0,    0, 1824,    0,    0, 1824,
    0,    0,    0,    0,    0,    0, 1824,    0, 1824, 1824,
    0, 1824, 1824, 1824, 1824, 1824,    0,    0, 1824,    0,
    0, 1824,    0, 1824, 1824,    0,    0, 1824, 1824, 1824,
    0, 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0,    0,
    0, 1824, 1824, 1824, 1824, 1824,    0,    0,    0, 1824,
    0,    0,    0,    0,    0,    0,    0, 1824, 1824, 1824,
 1824, 1824, 1824,    0,    0,    0, 1824, 1824,    0, 1824,
    0, 1824,    0, 1824, 1824, 1824,    0, 1824,    0, 1824,
 1824, 1824,    0, 1824, 1824, 1824, 1824, 1824,    0, 1824,
 1824,    0,    0,    0,    0, 1824,    0, 1824, 1824,    0,
    0, 1824, 1824, 1824,    0,    0, 1824,    0, 1824,    0,
    0, 1824, 1824, 1824, 1824,    0, 1824,    0, 1824,    0,
 1824, 1824, 1824, 1824, 1824, 1248,    0, 1824, 1824, 1824,
    0, 1824, 1824,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1824, 1824, 1824,    0, 1824, 1824, 1824, 1248,
 1824,    0,    0,    0, 1824,    0, 1824, 1824, 1824, 1824,
    0, 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1824, 1824, 2311, 1824, 1824, 1824,    0,    0,    0,    0,
 1824, 1824, 1824, 1824, 1824,    0, 1824,    0,    0, 1824,
 1824, 1250, 1249, 1251, 1824, 1824, 2312,    0, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0, 1824,    0,
    0,    0,    0,    0,    0, 1250, 1249, 1251, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,    0,
 1824, 1824, 1824, 1824, 1824, 1824,    0, 1824, 1824, 1824,
 1824,    0, 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824,    0, 1824, 1824, 1824, 1824,    0, 1824, 1824,
 1824, 1824, 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824, 1824,
 1824, 1824, 1824, 1825, 1824, 1824, 1824, 1824,    0, 1824,
 1824, 1824, 1824, 1824, 1824,    0,    0, 1824, 1824, 1824,
 1824, 1824, 1824, 1824, 1824, 1824,    0,    0,    0,    0,
    0, 1824,    0, 1824, 1824, 1824, 1824, 1824, 1824,    0,
 1824,    0,    0, 1638, 1825, 1825, 1825, 1825, 1825, 1825,
 1825,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1825, 1825, 1825, 1825, 1825,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1825,    0, 1825,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238, 1240,    0, 1241,    0,    0,    0,    0, 1239,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0, 1240,    0, 1241,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
 1825,    0, 1825,    0,    0, 1825,    0, 1825, 1825,    0,
    0, 1825, 1825,    0, 1825,    0,    0,    0,    0,    0,
 1825,    0, 1825, 1825, 1825, 1825,    0, 1825,    0,    0,
 1825,    0,    0, 1825,    0,    0,    0,    0,    0,    0,
 1825,    0, 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825,
    0,    0, 1825,    0,    0, 1825,    0, 1825, 1825,    0,
    0, 1825, 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825,
 1825, 1825,    0,    0,    0, 1825, 1825, 1825, 1825, 1825,
    0,    0,    0, 1825,    0,    0,    0,    0,    0,    0,
    0, 1825, 1825, 1825, 1825, 1825, 1825,    0,    0,    0,
 1825, 1825,    0, 1825,    0, 1825,    0, 1825, 1825, 1825,
    0, 1825,    0, 1825, 1825, 1825,    0, 1825, 1825, 1825,
 1825, 1825,    0, 1825, 1825,    0,    0,    0,    0, 1825,
    0, 1825, 1825,    0,    0, 1825, 1825, 1825,    0,    0,
 1825,    0, 1825,    0,    0, 1825, 1825, 1825, 1825,    0,
 1825,    0, 1825,    0, 1825, 1825, 1825, 1825, 1825, 1248,
    0, 1825, 1825, 1825,    0, 1825, 1825,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1825, 1825, 1825,    0,
 1825, 1825, 1825, 1248, 1825,    0,    0,    0, 1825,    0,
 1825, 1825, 1825, 1825,    0, 1825,    0, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1825, 1825, 2313, 1825, 1825, 1825,
    0,    0,    0,    0, 1825, 1825, 1825, 1825, 1825,    0,
 1825,    0,    0, 1825, 1825, 1250, 1249, 1251, 1825, 1825,
 2316,    0, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825,    0, 1825,    0,    0,    0,    0,    0,    0, 1250,
 1249, 1251, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825, 1825,
    0, 1825, 1825, 1825, 1825,    0, 1825,    0, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825,    0, 1825, 1825, 1825,
 1825,    0, 1825, 1825, 1825, 1825, 1825,    0, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1826, 1825, 1825,
 1825, 1825,    0, 1825, 1825, 1825, 1825, 1825, 1825,    0,
    0, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825, 1825,
    0,    0,    0,    0,    0, 1825,    0, 1825, 1825, 1825,
 1825, 1825, 1825,    0, 1825,    0,    0, 1640, 1826, 1826,
 1826, 1826, 1826, 1826, 1826,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1826, 1826, 1826, 1826, 1826,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1826,    0,
 1826,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238,    0,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238, 1240,    0, 1241,    0,    0,
    0,    0, 1239,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0, 1826,    0, 1826,    0,    0, 1826,
    0, 1826, 1826,    0,    0, 1826, 1826,    0, 1826,    0,
    0,    0,    0,    0, 1826,    0, 1826, 1826, 1826, 1826,
    0, 1826,    0,    0, 1826,    0,    0, 1826,    0,    0,
    0,    0,    0,    0, 1826,    0, 1826, 1826,    0, 1826,
 1826, 1826, 1826, 1826,    0,    0, 1826,    0,    0, 1826,
    0, 1826, 1826,    0,    0, 1826, 1826, 1826,    0, 1826,
 1826, 1826, 1826, 1826, 1826, 1826,    0,    0,    0, 1826,
 1826, 1826, 1826, 1826,    0,    0,    0, 1826,    0,    0,
    0,    0,    0,    0,    0, 1826, 1826, 1826, 1826, 1826,
 1826,    0,    0,    0, 1826, 1826,    0, 1826,    0, 1826,
    0, 1826, 1826, 1826,    0, 1826,    0, 1826, 1826, 1826,
    0, 1826, 1826, 1826, 1826, 1826,    0, 1826, 1826,    0,
    0,    0,    0, 1826,    0, 1826, 1826,    0,    0, 1826,
 1826, 1826,    0,    0, 1826,    0, 1826,    0,    0, 1826,
 1826, 1826, 1826,    0, 1826,    0, 1826,    0, 1826, 1826,
 1826, 1826, 1826, 1248,    0, 1826, 1826, 1826,    0, 1826,
 1826,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1826, 1826, 1826,    0, 1826, 1826, 1826, 1248, 1826,    0,
    0,    0, 1826,    0, 1826, 1826, 1826, 1826,    0, 1826,
    0, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1826, 1826,
 2317, 1826, 1826, 1826,    0,    0,    0,    0, 1826, 1826,
 1826, 1826, 1826,    0, 1826,    0,    0, 1826, 1826, 1250,
 1249, 1251, 1826, 1826, 2600,    0, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826,    0, 1826,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826,    0, 1826, 1826,
 1826, 1826, 1826, 1826,    0, 1826, 1826, 1826, 1826,    0,
 1826,    0, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
    0, 1826, 1826, 1826, 1826,    0, 1826, 1826, 1826, 1826,
 1826,    0, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826, 1826,
 1826, 1827, 1826, 1826, 1826, 1826,    0, 1826, 1826, 1826,
 1826, 1826, 1826,    0,    0, 1826, 1826, 1826, 1826, 1826,
 1826, 1826, 1826, 1826,    0,    0,    0,    0,    0, 1826,
    0, 1826, 1826, 1826, 1826, 1826, 1826,    0, 1826,    0,
    0, 1642, 1827, 1827, 1827, 1827, 1827, 1827, 1827,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1827,
 1827, 1827, 1827, 1827,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1827,    0, 1827,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238,    0,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238, 1240,
    0, 1241,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1827,    0,
 1827,    0,    0, 1827,    0, 1827, 1827,    0,    0, 1827,
 1827,    0, 1827,    0,    0,    0,    0,    0, 1827,    0,
 1827, 1827, 1827, 1827,    0, 1827,    0,    0, 1827,    0,
    0, 1827,    0,    0,    0,    0,    0,    0, 1827,    0,
 1827, 1827,    0, 1827, 1827, 1827, 1827, 1827,    0,    0,
 1827,    0,    0, 1827,    0, 1827, 1827,    0,    0, 1827,
 1827, 1827,    0, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
    0,    0,    0, 1827, 1827, 1827, 1827, 1827,    0,    0,
    0, 1827,    0,    0,    0,    0,    0,    0,    0, 1827,
 1827, 1827, 1827, 1827, 1827,    0,    0,    0, 1827, 1827,
    0, 1827,    0, 1827,    0, 1827, 1827, 1827,    0, 1827,
    0, 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827, 1827,
    0, 1827, 1827,    0,    0,    0,    0, 1827,    0, 1827,
 1827,    0,    0, 1827, 1827, 1827,    0,    0, 1827,    0,
 1827,    0,    0, 1827, 1827, 1827, 1827,    0, 1827,    0,
 1827,    0, 1827, 1827, 1827, 1827, 1827, 1248,    0, 1827,
 1827, 1827,    0, 1827, 1827,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1827, 1827, 1827,    0, 1827, 1827,
 1827, 1248, 1827,    0,    0,    0, 1827,    0, 1827, 1827,
 1827, 1827,    0, 1827,    0, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1827, 1827, 2602, 1827, 1827, 1827,    0,    0,
    0,    0, 1827, 1827, 1827, 1827, 1827,    0, 1827,    0,
    0, 1827, 1827, 1250, 1249, 1251, 1827, 1827, 2603,    0,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,    0,
 1827,    0,    0,    0,    0,    0,    0, 1250, 1249, 1251,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827,    0, 1827, 1827, 1827, 1827, 1827, 1827,    0, 1827,
 1827, 1827, 1827,    0, 1827,    0, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827,    0,
 1827, 1827, 1827, 1827, 1827,    0, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,
 1827, 1827, 1827, 1827, 1827, 1828, 1827, 1827, 1827, 1827,
    0, 1827, 1827, 1827, 1827, 1827, 1827,    0,    0, 1827,
 1827, 1827, 1827, 1827, 1827, 1827, 1827, 1827,    0,    0,
    0,    0,    0, 1827,    0, 1827, 1827, 1827, 1827, 1827,
 1827,    0, 1827,    0,    0, 1643, 1828, 1828, 1828, 1828,
 1828, 1828, 1828,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1828, 1828, 1828, 1828, 1828,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1828,    0, 1828,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238, 1240,    0, 1241,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0, 1828,    0, 1828,    0,    0, 1828,    0, 1828,
 1828,    0,    0, 1828, 1828,    0, 1828,    0,    0,    0,
    0,    0, 1828,    0, 1828, 1828, 1828, 1828,    0, 1828,
    0,    0, 1828,    0,    0, 1828,    0,    0,    0,    0,
    0,    0, 1828,    0, 1828, 1828,    0, 1828, 1828, 1828,
 1828, 1828,    0,    0, 1828,    0,    0, 1828,    0, 1828,
 1828,    0,    0, 1828, 1828, 1828,    0, 1828, 1828, 1828,
 1828, 1828, 1828, 1828,    0,    0,    0, 1828, 1828, 1828,
 1828, 1828,    0,    0,    0, 1828,    0,    0,    0,    0,
    0,    0,    0, 1828, 1828, 1828, 1828, 1828, 1828,    0,
    0,    0, 1828, 1828,    0, 1828,    0, 1828,    0, 1828,
 1828, 1828,    0, 1828,    0, 1828, 1828, 1828,    0, 1828,
 1828, 1828, 1828, 1828,    0, 1828, 1828,    0,    0,    0,
    0, 1828,    0, 1828, 1828,    0,    0, 1828, 1828, 1828,
    0,    0, 1828,    0, 1828,    0,    0, 1828, 1828, 1828,
 1828,    0, 1828,    0, 1828,    0, 1828, 1828, 1828, 1828,
 1828, 1248,    0, 1828, 1828, 1828,    0, 1828, 1828,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1828, 1828,
 1828,    0, 1828, 1828, 1828, 1248, 1828,    0,    0,    0,
 1828,    0, 1828, 1828, 1828, 1828,    0, 1828,    0, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1828, 1828, 2610, 1828,
 1828, 1828,    0,    0,    0,    0, 1828, 1828, 1828, 1828,
 1828,    0, 1828,    0,    0, 1828, 1828, 1250, 1249, 1251,
 1828, 1828, 2613,    0, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828,    0, 1828,    0,    0,    0,    0,    0,
    0, 1250, 1249, 1251, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828,    0, 1828, 1828, 1828, 1828,
 1828, 1828,    0, 1828, 1828, 1828, 1828,    0, 1828,    0,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,    0, 1828,
 1828, 1828, 1828,    0, 1828, 1828, 1828, 1828, 1828,    0,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1828, 1829,
 1828, 1828, 1828, 1828,    0, 1828, 1828, 1828, 1828, 1828,
 1828,    0,    0, 1828, 1828, 1828, 1828, 1828, 1828, 1828,
 1828, 1828,    0,    0,    0,    0,    0, 1828,    0, 1828,
 1828, 1828, 1828, 1828, 1828,    0, 1828,    0,    0, 1644,
 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1829, 1829, 1829,
 1829, 1829,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1829,    0, 1829,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238,    0,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238, 1240,    0, 1241,
    0,    0,    0,    0, 1239,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0, 1829,    0, 1829,    0,
    0, 1829,    0, 1829, 1829,    0,    0, 1829, 1829,    0,
 1829,    0,    0,    0,    0,    0, 1829,    0, 1829, 1829,
 1829, 1829,    0, 1829,    0,    0, 1829,    0,    0, 1829,
    0,    0,    0,    0,    0,    0, 1829,    0, 1829, 1829,
    0, 1829, 1829, 1829, 1829, 1829,    0,    0, 1829,    0,
    0, 1829,    0, 1829, 1829,    0,    0, 1829, 1829, 1829,
    0, 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0,    0,
    0, 1829, 1829, 1829, 1829, 1829,    0,    0,    0, 1829,
    0,    0,    0,    0,    0,    0,    0, 1829, 1829, 1829,
 1829, 1829, 1829,    0,    0,    0, 1829, 1829,    0, 1829,
    0, 1829,    0, 1829, 1829, 1829,    0, 1829,    0, 1829,
 1829, 1829,    0, 1829, 1829, 1829, 1829, 1829,    0, 1829,
 1829,    0,    0,    0,    0, 1829,    0, 1829, 1829,    0,
    0, 1829, 1829, 1829,    0,    0, 1829,    0, 1829,    0,
    0, 1829, 1829, 1829, 1829,    0, 1829,    0, 1829,    0,
 1829, 1829, 1829, 1829, 1829, 1248,    0, 1829, 1829, 1829,
    0, 1829, 1829,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1829, 1829, 1829,    0, 1829, 1829, 1829, 1248,
 1829,    0,    0,    0, 1829,    0, 1829, 1829, 1829, 1829,
    0, 1829,    0, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1829, 1829, 2614, 1829, 1829, 1829,    0,    0,    0,    0,
 1829, 1829, 1829, 1829, 1829,    0, 1829,    0,    0, 1829,
 1829, 1250, 1249, 1251, 1829, 1829, 2627,    0, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0, 1829,    0,
    0,    0,    0,    0,    0, 1250, 1249, 1251, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,    0,
 1829, 1829, 1829, 1829, 1829, 1829,    0, 1829, 1829, 1829,
 1829,    0, 1829,    0, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829,    0, 1829, 1829, 1829, 1829,    0, 1829, 1829,
 1829, 1829, 1829,    0, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829, 1829,
 1829, 1829, 1829, 1830, 1829, 1829, 1829, 1829,    0, 1829,
 1829, 1829, 1829, 1829, 1829,    0,    0, 1829, 1829, 1829,
 1829, 1829, 1829, 1829, 1829, 1829,    0,    0,    0,    0,
    0, 1829,    0, 1829, 1829, 1829, 1829, 1829, 1829,    0,
 1829,    0,    0, 1645, 1830, 1830, 1830, 1830, 1830, 1830,
 1830,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1830, 1830, 1830, 1830, 1830,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1830,    0, 1830,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238, 1240,    0, 1241,    0,    0,    0,    0, 1239,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0, 1240,    0, 1241,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
 1830,    0, 1830,    0,    0, 1830,    0, 1830, 1830,    0,
    0, 1830, 1830,    0, 1830,    0,    0,    0,    0,    0,
 1830,    0, 1830, 1830, 1830, 1830,    0, 1830,    0,    0,
 1830,    0,    0, 1830,    0,    0,    0,    0,    0,    0,
 1830,    0, 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830,
    0,    0, 1830,    0,    0, 1830,    0, 1830, 1830,    0,
    0, 1830, 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830,
 1830, 1830,    0,    0,    0, 1830, 1830, 1830, 1830, 1830,
    0,    0,    0, 1830,    0,    0,    0,    0,    0,    0,
    0, 1830, 1830, 1830, 1830, 1830, 1830,    0,    0,    0,
 1830, 1830,    0, 1830,    0, 1830,    0, 1830, 1830, 1830,
    0, 1830,    0, 1830, 1830, 1830,    0, 1830, 1830, 1830,
 1830, 1830,    0, 1830, 1830,    0,    0,    0,    0, 1830,
    0, 1830, 1830,    0,    0, 1830, 1830, 1830,    0,    0,
 1830,    0, 1830,    0,    0, 1830, 1830, 1830, 1830,    0,
 1830,    0, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1248,
    0, 1830, 1830, 1830,    0, 1830, 1830,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1830, 1830, 1830,    0,
 1830, 1830, 1830, 1248, 1830,    0,    0,    0, 1830,    0,
 1830, 1830, 1830, 1830,    0, 1830,    0, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1830, 1830, 2632, 1830, 1830, 1830,
    0,    0,    0,    0, 1830, 1830, 1830, 1830, 1830,    0,
 1830,    0,    0, 1830, 1830, 1250, 1249, 1251, 1830, 1830,
 2633,    0, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830,    0, 1830,    0,    0,    0,    0,    0,    0, 1250,
 1249, 1251, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830,
    0, 1830, 1830, 1830, 1830,    0, 1830,    0, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830,    0, 1830, 1830, 1830,
 1830,    0, 1830, 1830, 1830, 1830, 1830,    0, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1831, 1830, 1830,
 1830, 1830,    0, 1830, 1830, 1830, 1830, 1830, 1830,    0,
    0, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830, 1830,
    0,    0,    0,    0,    0, 1830,    0, 1830, 1830, 1830,
 1830, 1830, 1830,    0, 1830,    0,    0, 1646, 1831, 1831,
 1831, 1831, 1831, 1831, 1831,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1831, 1831, 1831, 1831, 1831,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1831,    0,
 1831,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238,    0,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238, 1240,    0, 1241,    0,    0,
    0,    0, 1239,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0, 1831,    0, 1831,    0,    0, 1831,
    0, 1831, 1831,    0,    0, 1831, 1831,    0, 1831,    0,
    0,    0,    0,    0, 1831,    0, 1831, 1831, 1831, 1831,
    0, 1831,    0,    0, 1831,    0,    0, 1831,    0,    0,
    0,    0,    0,    0, 1831,    0, 1831, 1831,    0, 1831,
 1831, 1831, 1831, 1831,    0,    0, 1831,    0,    0, 1831,
    0, 1831, 1831,    0,    0, 1831, 1831, 1831,    0, 1831,
 1831, 1831, 1831, 1831, 1831, 1831,    0,    0,    0, 1831,
 1831, 1831, 1831, 1831,    0,    0,    0, 1831,    0,    0,
    0,    0,    0,    0,    0, 1831, 1831, 1831, 1831, 1831,
 1831,    0,    0,    0, 1831, 1831,    0, 1831,    0, 1831,
    0, 1831, 1831, 1831,    0, 1831,    0, 1831, 1831, 1831,
    0, 1831, 1831, 1831, 1831, 1831,    0, 1831, 1831,    0,
    0,    0,    0, 1831,    0, 1831, 1831,    0,    0, 1831,
 1831, 1831,    0,    0, 1831,    0, 1831,    0,    0, 1831,
 1831, 1831, 1831,    0, 1831,    0, 1831,    0, 1831, 1831,
 1831, 1831, 1831, 1248,    0, 1831, 1831, 1831,    0, 1831,
 1831,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1831, 1831, 1831,    0, 1831, 1831, 1831, 1248, 1831,    0,
    0,    0, 1831,    0, 1831, 1831, 1831, 1831,    0, 1831,
    0, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1831, 1831,
 2634, 1831, 1831, 1831,    0,    0,    0,    0, 1831, 1831,
 1831, 1831, 1831,    0, 1831,    0,    0, 1831, 1831, 1250,
 1249, 1251, 1831, 1831, 2635,    0, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831,    0, 1831,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831,    0, 1831, 1831,
 1831, 1831, 1831, 1831,    0, 1831, 1831, 1831, 1831,    0,
 1831,    0, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
    0, 1831, 1831, 1831, 1831,    0, 1831, 1831, 1831, 1831,
 1831,    0, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831, 1831,
 1831, 1832, 1831, 1831, 1831, 1831,    0, 1831, 1831, 1831,
 1831, 1831, 1831,    0,    0, 1831, 1831, 1831, 1831, 1831,
 1831, 1831, 1831, 1831,    0,    0,    0,    0,    0, 1831,
    0, 1831, 1831, 1831, 1831, 1831, 1831,    0, 1831,    0,
    0, 1648, 1832, 1832, 1832, 1832, 1832, 1832, 1832,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1832,
 1832, 1832, 1832, 1832,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1832,    0, 1832,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238,    0,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238, 1240,
    0, 1241,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1832,    0,
 1832,    0,    0, 1832,    0, 1832, 1832,    0,    0, 1832,
 1832,    0, 1832,    0,    0,    0,    0,    0, 1832,    0,
 1832, 1832, 1832, 1832,    0, 1832,    0,    0, 1832,    0,
    0, 1832,    0,    0,    0,    0,    0,    0, 1832,    0,
 1832, 1832,    0, 1832, 1832, 1832, 1832, 1832,    0,    0,
 1832,    0,    0, 1832,    0, 1832, 1832,    0,    0, 1832,
 1832, 1832,    0, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
    0,    0,    0, 1832, 1832, 1832, 1832, 1832,    0,    0,
    0, 1832,    0,    0,    0,    0,    0,    0,    0, 1832,
 1832, 1832, 1832, 1832, 1832,    0,    0,    0, 1832, 1832,
    0, 1832,    0, 1832,    0, 1832, 1832, 1832,    0, 1832,
    0, 1832, 1832, 1832,    0, 1832, 1832, 1832, 1832, 1832,
    0, 1832, 1832,    0,    0,    0,    0, 1832,    0, 1832,
 1832,    0,    0, 1832, 1832, 1832,    0,    0, 1832,    0,
 1832,    0,    0, 1832, 1832, 1832, 1832,    0, 1832,    0,
 1832,    0, 1832, 1832, 1832, 1832, 1832, 1248,    0, 1832,
 1832, 1832,    0, 1832, 1832,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1832, 1832, 1832,    0, 1832, 1832,
 1832, 1248, 1832,    0,    0,    0, 1832,    0, 1832, 1832,
 1832, 1832,    0, 1832,    0, 1832, 1832, 1832, 1832, 1832,
 1832, 1832, 1832,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1832, 1832, 2636, 1832, 1832, 1832,    0,    0,
    0,    0, 1832, 1832, 1832, 1832, 1832,    0, 1832,    0,
    0, 1832, 1832, 1250, 1249, 1251, 1832, 1832, 2637,    0,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,    0,
 1832,    0,    0,    0,    0,    0,    0, 1250, 1249, 1251,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
 1832,    0, 1832, 1832, 1832, 1832, 1832, 1832,    0, 1832,
 1832, 1832, 1832,    0, 1832,    0, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832,    0, 1832, 1832, 1832, 1832,    0,
 1832, 1832, 1832, 1832, 1832,    0, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,
 1832, 1832, 1832, 1832, 1832, 1833, 1832, 1832, 1832, 1832,
    0, 1832, 1832, 1832, 1832, 1832, 1832,    0,    0, 1832,
 1832, 1832, 1832, 1832, 1832, 1832, 1832, 1832,    0,    0,
    0,    0,    0, 1832,    0, 1832, 1832, 1832, 1832, 1832,
 1832,    0, 1832,    0,    0, 1649, 1833, 1833, 1833, 1833,
 1833, 1833, 1833,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1833, 1833, 1833, 1833, 1833,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1833,    0, 1833,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238, 1240,    0, 1241,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0, 1833,    0, 1833,    0,    0, 1833,    0, 1833,
 1833,    0,    0, 1833, 1833,    0, 1833,    0,    0,    0,
    0,    0, 1833,    0, 1833, 1833, 1833, 1833,    0, 1833,
    0,    0, 1833,    0,    0, 1833,    0,    0,    0,    0,
    0,    0, 1833,    0, 1833, 1833,    0, 1833, 1833, 1833,
 1833, 1833,    0,    0, 1833,    0,    0, 1833,    0, 1833,
 1833,    0,    0, 1833, 1833, 1833,    0, 1833, 1833, 1833,
 1833, 1833, 1833, 1833,    0,    0,    0, 1833, 1833, 1833,
 1833, 1833,    0,    0,    0, 1833,    0,    0,    0,    0,
    0,    0,    0, 1833, 1833, 1833, 1833, 1833, 1833,    0,
    0,    0, 1833, 1833,    0, 1833,    0, 1833,    0, 1833,
 1833, 1833,    0, 1833,    0, 1833, 1833, 1833,    0, 1833,
 1833, 1833, 1833, 1833,    0, 1833, 1833,    0,    0,    0,
    0, 1833,    0, 1833, 1833,    0,    0, 1833, 1833, 1833,
    0,    0, 1833,    0, 1833,    0,    0, 1833, 1833, 1833,
 1833,    0, 1833,    0, 1833,    0, 1833, 1833, 1833, 1833,
 1833, 1248,    0, 1833, 1833, 1833,    0, 1833, 1833,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1833, 1833,
 1833,    0, 1833, 1833, 1833, 1248, 1833,    0,    0,    0,
 1833,    0, 1833, 1833, 1833, 1833,    0, 1833,    0, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1833, 1833, 2638, 1833,
 1833, 1833,    0,    0,    0,    0, 1833, 1833, 1833, 1833,
 1833,    0, 1833,    0,    0, 1833, 1833, 1250, 1249, 1251,
 1833, 1833, 2639,    0, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833,    0, 1833,    0,    0,    0,    0,    0,
    0, 1250, 1249, 1251, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833,
 1833, 1833,    0, 1833, 1833, 1833, 1833,    0, 1833,    0,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,    0, 1833,
 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833, 1833,    0,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1833, 1834,
 1833, 1833, 1833, 1833,    0, 1833, 1833, 1833, 1833, 1833,
 1833,    0,    0, 1833, 1833, 1833, 1833, 1833, 1833, 1833,
 1833, 1833,    0,    0,    0,    0,    0, 1833,    0, 1833,
 1833, 1833, 1833, 1833, 1833,    0, 1833,    0,    0, 1650,
 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1834, 1834, 1834,
 1834, 1834,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1834,    0, 1834,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238,    0,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238, 1240,    0, 1241,
    0,    0,    0,    0, 1239,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0, 1834,    0, 1834,    0,
    0, 1834,    0, 1834, 1834,    0,    0, 1834, 1834,    0,
 1834,    0,    0,    0,    0,    0, 1834,    0, 1834, 1834,
 1834, 1834,    0, 1834,    0,    0, 1834,    0,    0, 1834,
    0,    0,    0,    0,    0,    0, 1834,    0, 1834, 1834,
    0, 1834, 1834, 1834, 1834, 1834,    0,    0, 1834,    0,
    0, 1834,    0, 1834, 1834,    0,    0, 1834, 1834, 1834,
    0, 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,    0,
    0, 1834, 1834, 1834, 1834, 1834,    0,    0,    0, 1834,
    0,    0,    0,    0,    0,    0,    0, 1834, 1834, 1834,
 1834, 1834, 1834,    0,    0,    0, 1834, 1834,    0, 1834,
    0, 1834,    0, 1834, 1834, 1834,    0, 1834,    0, 1834,
 1834, 1834,    0, 1834, 1834, 1834, 1834, 1834,    0, 1834,
 1834,    0,    0,    0,    0, 1834,    0, 1834, 1834,    0,
    0, 1834, 1834, 1834,    0,    0, 1834,    0, 1834,    0,
    0, 1834, 1834, 1834, 1834,    0, 1834,    0, 1834,    0,
 1834, 1834, 1834, 1834, 1834, 1248,    0, 1834, 1834, 1834,
    0, 1834, 1834,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1834, 1834, 1834,    0, 1834, 1834, 1834, 1248,
 1834,    0,    0,    0, 1834,    0, 1834, 1834, 1834, 1834,
    0, 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1834, 1834, 2640, 1834, 1834, 1834,    0,    0,    0,    0,
 1834, 1834, 1834, 1834, 1834,    0, 1834,    0,    0, 1834,
 1834, 1250, 1249, 1251, 1834, 1834, 2641,    0, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0, 1834,    0,
    0,    0,    0,    0,    0, 1250, 1249, 1251, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,    0,
 1834, 1834, 1834, 1834, 1834, 1834,    0, 1834, 1834, 1834,
 1834,    0, 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834,    0, 1834, 1834, 1834, 1834,    0, 1834, 1834,
 1834, 1834, 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834, 1834,
 1834, 1834, 1834, 1838, 1834, 1834, 1834, 1834,    0, 1834,
 1834, 1834, 1834, 1834, 1834,    0,    0, 1834, 1834, 1834,
 1834, 1834, 1834, 1834, 1834, 1834,    0,    0,    0,    0,
    0, 1834,    0, 1834, 1834, 1834, 1834, 1834, 1834,    0,
 1834,    0,    0, 1651, 1838, 1838, 1838, 1838, 1838, 1838,
 1838,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1838, 1838, 1838, 1838, 1838,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1838,    0, 1838,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238, 1240,    0, 1241,    0,    0,    0,    0, 1239,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0, 1240,    0, 1241,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
 1838,    0, 1838,    0,    0, 1838,    0, 1838, 1838,    0,
    0, 1838, 1838,    0, 1838,    0,    0,    0,    0,    0,
 1838,    0, 1838, 1838, 1838, 1838,    0, 1838,    0,    0,
 1838,    0,    0, 1838,    0,    0,    0,    0,    0,    0,
 1838,    0, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838,
    0,    0, 1838,    0,    0, 1838,    0, 1838, 1838,    0,
    0, 1838, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838,
 1838, 1838,    0,    0,    0, 1838, 1838, 1838, 1838, 1838,
    0,    0,    0, 1838,    0,    0,    0,    0,    0,    0,
    0, 1838, 1838, 1838, 1838, 1838, 1838,    0,    0,    0,
 1838, 1838,    0, 1838,    0, 1838,    0, 1838, 1838, 1838,
    0, 1838,    0, 1838, 1838, 1838,    0, 1838, 1838, 1838,
 1838, 1838,    0, 1838, 1838,    0,    0,    0,    0, 1838,
    0, 1838, 1838,    0,    0, 1838, 1838, 1838,    0,    0,
 1838,    0, 1838,    0,    0, 1838, 1838, 1838, 1838,    0,
 1838,    0, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1248,
    0, 1838, 1838, 1838,    0, 1838, 1838,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1838, 1838, 1838,    0,
 1838, 1838, 1838, 1248, 1838,    0,    0,    0, 1838,    0,
 1838, 1838, 1838, 1838,    0, 1838,    0, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1838, 1838, 2642, 1838, 1838, 1838,
    0,    0,    0,    0, 1838, 1838, 1838, 1838, 1838,    0,
 1838,    0,    0, 1838, 1838, 1250, 1249, 1251, 1838, 1838,
 2643,    0, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838,    0, 1838,    0,    0,    0,    0,    0,    0, 1250,
 1249, 1251, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1838,
    0, 1838, 1838, 1838, 1838,    0, 1838,    0, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838,    0, 1838, 1838, 1838,
 1838,    0, 1838, 1838, 1838, 1838, 1838,    0, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1839, 1838, 1838,
 1838, 1838,    0, 1838, 1838, 1838, 1838, 1838, 1838,    0,
    0, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838, 1838,
    0,    0,    0,    0,    0, 1838,    0, 1838, 1838, 1838,
 1838, 1838, 1838,    0, 1838,    0,    0, 1652, 1839, 1839,
 1839, 1839, 1839, 1839, 1839,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1839, 1839, 1839, 1839, 1839,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1839,    0,
 1839,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238,    0,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238, 1240,    0, 1241,    0,    0,
    0,    0, 1239,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0, 1839,    0, 1839,    0,    0, 1839,
    0, 1839, 1839,    0,    0, 1839, 1839,    0, 1839,    0,
    0,    0,    0,    0, 1839,    0, 1839, 1839, 1839, 1839,
    0, 1839,    0,    0, 1839,    0,    0, 1839,    0,    0,
    0,    0,    0,    0, 1839,    0, 1839, 1839,    0, 1839,
 1839, 1839, 1839, 1839,    0,    0, 1839,    0,    0, 1839,
    0, 1839, 1839,    0,    0, 1839, 1839, 1839,    0, 1839,
 1839, 1839, 1839, 1839, 1839, 1839,    0,    0,    0, 1839,
 1839, 1839, 1839, 1839,    0,    0,    0, 1839,    0,    0,
    0,    0,    0,    0,    0, 1839, 1839, 1839, 1839, 1839,
 1839,    0,    0,    0, 1839, 1839,    0, 1839,    0, 1839,
    0, 1839, 1839, 1839,    0, 1839,    0, 1839, 1839, 1839,
    0, 1839, 1839, 1839, 1839, 1839,    0, 1839, 1839,    0,
    0,    0,    0, 1839,    0, 1839, 1839,    0,    0, 1839,
 1839, 1839,    0,    0, 1839,    0, 1839,    0,    0, 1839,
 1839, 1839, 1839,    0, 1839,    0, 1839,    0, 1839, 1839,
 1839, 1839, 1839, 1248,    0, 1839, 1839, 1839,    0, 1839,
 1839,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1839, 1839, 1839,    0, 1839, 1839, 1839, 1248, 1839,    0,
    0,    0, 1839,    0, 1839, 1839, 1839, 1839,    0, 1839,
    0, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1839, 1839,
 2858, 1839, 1839, 1839,    0,    0,    0,    0, 1839, 1839,
 1839, 1839, 1839,    0, 1839,    0,    0, 1839, 1839, 1250,
 1249, 1251, 1839, 1839, 2859,    0, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839,    0, 1839,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839, 1839, 1839,    0, 1839, 1839,
 1839, 1839, 1839, 1839,    0, 1839, 1839, 1839, 1839,    0,
 1839,    0, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
    0, 1839, 1839, 1839, 1839,    0, 1839, 1839, 1839, 1839,
 1839,    0, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839, 1839,
 1839, 1840, 1839, 1839, 1839, 1839,    0, 1839, 1839, 1839,
 1839, 1839, 1839,    0,    0, 1839, 1839, 1839, 1839, 1839,
 1839, 1839, 1839, 1839,    0,    0,    0,    0,    0, 1839,
    0, 1839, 1839, 1839, 1839, 1839, 1839,    0, 1839,    0,
    0, 1653, 1840, 1840, 1840, 1840, 1840, 1840, 1840,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1840,
 1840, 1840, 1840, 1840,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1840,    0, 1840,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238,    0,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238, 1240,
    0, 1241,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1840,    0,
 1840,    0,    0, 1840,    0, 1840, 1840,    0,    0, 1840,
 1840,    0, 1840,    0,    0,    0,    0,    0, 1840,    0,
 1840, 1840, 1840, 1840,    0, 1840,    0,    0, 1840,    0,
    0, 1840,    0,    0,    0,    0,    0,    0, 1840,    0,
 1840, 1840,    0, 1840, 1840, 1840, 1840, 1840,    0,    0,
 1840,    0,    0, 1840,    0, 1840, 1840,    0,    0, 1840,
 1840, 1840,    0, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
    0,    0,    0, 1840, 1840, 1840, 1840, 1840,    0,    0,
    0, 1840,    0,    0,    0,    0,    0,    0,    0, 1840,
 1840, 1840, 1840, 1840, 1840,    0,    0,    0, 1840, 1840,
    0, 1840,    0, 1840,    0, 1840, 1840, 1840,    0, 1840,
    0, 1840, 1840, 1840,    0, 1840, 1840, 1840, 1840, 1840,
    0, 1840, 1840,    0,    0,    0,    0, 1840,    0, 1840,
 1840,    0,    0, 1840, 1840, 1840,    0,    0, 1840,    0,
 1840,    0,    0, 1840, 1840, 1840, 1840,    0, 1840,    0,
 1840,    0, 1840, 1840, 1840, 1840, 1840, 1248,    0, 1840,
 1840, 1840,    0, 1840, 1840,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1840, 1840, 1840,    0, 1840, 1840,
 1840, 1248, 1840,    0,    0,    0, 1840,    0, 1840, 1840,
 1840, 1840,    0, 1840,    0, 1840, 1840, 1840, 1840, 1840,
 1840, 1840, 1840,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1840, 1840, 3019, 1840, 1840, 1840,    0,    0,
    0,    0, 1840, 1840, 1840, 1840, 1840,    0, 1840,    0,
    0, 1840, 1840, 1250, 1249, 1251, 1840, 1840, 3024,    0,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,    0,
 1840,    0,    0,    0,    0,    0,    0, 1250, 1249, 1251,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
 1840,    0, 1840, 1840, 1840, 1840, 1840, 1840,    0, 1840,
 1840, 1840, 1840,    0, 1840,    0, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840,    0, 1840, 1840, 1840, 1840,    0,
 1840, 1840, 1840, 1840, 1840,    0, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,
 1840, 1840, 1840, 1840, 1840, 1842, 1840, 1840, 1840, 1840,
    0, 1840, 1840, 1840, 1840, 1840, 1840,    0,    0, 1840,
 1840, 1840, 1840, 1840, 1840, 1840, 1840, 1840,    0,    0,
    0,    0,    0, 1840,    0, 1840, 1840, 1840, 1840, 1840,
 1840,    0, 1840,    0,    0, 1654, 1842, 1842, 1842, 1842,
 1842, 1842, 1842,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1842, 1842, 1842, 1842, 1842,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1842,    0, 1842,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238, 1240,    0, 1241,    0,    0,    0,    0,
 1239,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0, 1842,    0, 1842,    0,    0, 1842,    0, 1842,
 1842,    0,    0, 1842, 1842,    0, 1842,    0,    0,    0,
    0,    0, 1842,    0, 1842, 1842, 1842, 1842,    0, 1842,
    0,    0, 1842,    0,    0, 1842,    0,    0,    0,    0,
    0,    0, 1842,    0, 1842, 1842,    0, 1842, 1842, 1842,
 1842, 1842,    0,    0, 1842,    0,    0, 1842,    0, 1842,
 1842,    0,    0, 1842, 1842, 1842,    0, 1842, 1842, 1842,
 1842, 1842, 1842, 1842,    0,    0,    0, 1842, 1842, 1842,
 1842, 1842,    0,    0,    0, 1842,    0,    0,    0,    0,
    0,    0,    0, 1842, 1842, 1842, 1842, 1842, 1842,    0,
    0,    0, 1842, 1842,    0, 1842,    0, 1842,    0, 1842,
 1842, 1842,    0, 1842,    0, 1842, 1842, 1842,    0, 1842,
 1842, 1842, 1842, 1842,    0, 1842, 1842,    0,    0,    0,
    0, 1842,    0, 1842, 1842,    0,    0, 1842, 1842, 1842,
    0,    0, 1842,    0, 1842,    0,    0, 1842, 1842, 1842,
 1842,    0, 1842,    0, 1842,    0, 1842, 1842, 1842, 1842,
 1842, 1248,    0, 1842, 1842, 1842,    0, 1842, 1842,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1842, 1842,
 1842,    0, 1842, 1842, 1842, 1248, 1842,    0,    0,    0,
 1842,    0, 1842, 1842, 1842, 1842,    0, 1842,    0, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1842, 1842, 3025, 1842,
 1842, 1842,    0,    0,    0,    0, 1842, 1842, 1842, 1842,
 1842,    0, 1842,    0,    0, 1842, 1842, 1250, 1249, 1251,
 1842, 1842, 3026,    0, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842,    0, 1842,    0,    0,    0,    0,    0,
    0, 1250, 1249, 1251, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842,    0, 1842, 1842, 1842, 1842,
 1842, 1842,    0, 1842, 1842, 1842, 1842,    0, 1842,    0,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,    0, 1842,
 1842, 1842, 1842,    0, 1842, 1842, 1842, 1842, 1842,    0,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1844,
 1842, 1842, 1842, 1842,    0, 1842, 1842, 1842, 1842, 1842,
 1842,    0,    0, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842,    0,    0,    0,    0,    0, 1842,    0, 1842,
 1842, 1842, 1842, 1842, 1842,    0, 1842,    0,    0, 1656,
 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1844, 1844, 1844,
 1844, 1844,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1844,    0, 1844,    0,    0,    0,    0,    0,    0,    0,
    0, 1236,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1237,    0,    0,    0,    0,
    0,    0, 1238,    0,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238, 1240,    0, 1241,
    0,    0,    0,    0, 1239,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0, 1844,    0, 1844,    0,
    0, 1844,    0, 1844, 1844,    0,    0, 1844, 1844,    0,
 1844,    0,    0,    0,    0,    0, 1844,    0, 1844, 1844,
 1844, 1844,    0, 1844,    0,    0, 1844,    0,    0, 1844,
    0,    0,    0,    0,    0,    0, 1844,    0, 1844, 1844,
    0, 1844, 1844, 1844, 1844, 1844,    0,    0, 1844,    0,
    0, 1844,    0, 1844, 1844,    0,    0, 1844, 1844, 1844,
    0, 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0,    0,
    0, 1844, 1844, 1844, 1844, 1844,    0,    0,    0, 1844,
    0,    0,    0,    0,    0,    0,    0, 1844, 1844, 1844,
 1844, 1844, 1844,    0,    0,    0, 1844, 1844,    0, 1844,
    0, 1844,    0, 1844, 1844, 1844,    0, 1844,    0, 1844,
 1844, 1844,    0, 1844, 1844, 1844, 1844, 1844,    0, 1844,
 1844,    0,    0,    0,    0, 1844,    0, 1844, 1844,    0,
    0, 1844, 1844, 1844,    0,    0, 1844,    0, 1844,    0,
    0, 1844, 1844, 1844, 1844,    0, 1844,    0, 1844,    0,
 1844, 1844, 1844, 1844, 1844, 1248,    0, 1844, 1844, 1844,
    0, 1844, 1844,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1844, 1844, 1844,    0, 1844, 1844, 1844, 1248,
 1844,    0,    0,    0, 1844,    0, 1844, 1844, 1844, 1844,
    0, 1844,    0, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1844, 1844, 3027, 1844, 1844, 1844,    0,    0,    0,    0,
 1844, 1844, 1844, 1844, 1844,    0, 1844,    0,    0, 1844,
 1844, 1250, 1249, 1251, 1844, 1844, 3034,    0, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0, 1844,    0,
    0,    0,    0,    0,    0, 1250, 1249, 1251, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,    0,
 1844, 1844, 1844, 1844, 1844, 1844,    0, 1844, 1844, 1844,
 1844,    0, 1844,    0, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844,    0, 1844, 1844, 1844, 1844,    0, 1844, 1844,
 1844, 1844, 1844,    0, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844, 1844,
 1844, 1844, 1844, 1845, 1844, 1844, 1844, 1844,    0, 1844,
 1844, 1844, 1844, 1844, 1844,    0,    0, 1844, 1844, 1844,
 1844, 1844, 1844, 1844, 1844, 1844,    0,    0,    0,    0,
    0, 1844,    0, 1844, 1844, 1844, 1844, 1844, 1844,    0,
 1844,    0,    0, 1657, 1845, 1845, 1845, 1845, 1845, 1845,
 1845,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1845, 1845, 1845, 1845, 1845,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1845,    0, 1845,    0,    0,    0,
    0,    0,    0,    0,    0, 1236,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1237,
    0,    0,    0,    0,    0,    0, 1238,    0,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238, 1240,    0, 1241,    0,    0,    0,    0, 1239,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,
    0,    0, 1246,    0,    0, 1240,    0, 1241,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
 1845,    0, 1845,    0,    0, 1845,    0, 1845, 1845,    0,
    0, 1845, 1845,    0, 1845,    0,    0,    0,    0,    0,
 1845,    0, 1845, 1845, 1845, 1845,    0, 1845,    0,    0,
 1845,    0,    0, 1845,    0,    0,    0,    0,    0,    0,
 1845,    0, 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845,
    0,    0, 1845,    0,    0, 1845,    0, 1845, 1845,    0,
    0, 1845, 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845,
 1845, 1845,    0,    0,    0, 1845, 1845, 1845, 1845, 1845,
    0,    0,    0, 1845,    0,    0,    0,    0,    0,    0,
    0, 1845, 1845, 1845, 1845, 1845, 1845,    0,    0,    0,
 1845, 1845,    0, 1845,    0, 1845,    0, 1845, 1845, 1845,
    0, 1845,    0, 1845, 1845, 1845,    0, 1845, 1845, 1845,
 1845, 1845,    0, 1845, 1845,    0,    0,    0,    0, 1845,
    0, 1845, 1845,    0,    0, 1845, 1845, 1845,    0,    0,
 1845,    0, 1845,    0,    0, 1845, 1845, 1845, 1845,    0,
 1845,    0, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1248,
    0, 1845, 1845, 1845,    0, 1845, 1845,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1845, 1845, 1845,    0,
 1845, 1845, 1845, 1248, 1845,    0,    0,    0, 1845,    0,
 1845, 1845, 1845, 1845,    0, 1845,    0, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1845, 1845, 3035, 1845, 1845, 1845,
    0,    0,    0,    0, 1845, 1845, 1845, 1845, 1845,    0,
 1845,    0,    0, 1845, 1845, 1250, 1249, 1251, 1845, 1845,
 3113,    0, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845,    0, 1845,    0,    0,    0,    0,    0,    0, 1250,
 1249, 1251, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845,
    0, 1845, 1845, 1845, 1845,    0, 1845,    0, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845,    0, 1845, 1845, 1845,
 1845,    0, 1845, 1845, 1845, 1845, 1845,    0, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1846, 1845, 1845,
 1845, 1845,    0, 1845, 1845, 1845, 1845, 1845, 1845,    0,
    0, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845, 1845,
    0,    0,    0,    0,    0, 1845,    0, 1845, 1845, 1845,
 1845, 1845, 1845,    0, 1845,    0,    0, 1658, 1846, 1846,
 1846, 1846, 1846, 1846, 1846,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1846, 1846, 1846, 1846, 1846,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1846,    0,
 1846,    0,    0,    0,    0,    0,    0,    0,    0, 1236,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1237,    0,    0,    0,    0,    0,    0,
 1238,    0,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238, 1240,    0, 1241,    0,    0,
    0,    0, 1239,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245,    0,    0,    0,    0, 1246,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0, 1846,    0, 1846,    0,    0, 1846,
    0, 1846, 1846,    0,    0, 1846, 1846,    0, 1846,    0,
    0,    0,    0,    0, 1846,    0, 1846, 1846, 1846, 1846,
    0, 1846,    0,    0, 1846,    0,    0, 1846,    0,    0,
    0,    0,    0,    0, 1846,    0, 1846, 1846,    0, 1846,
 1846, 1846, 1846, 1846,    0,    0, 1846,    0,    0, 1846,
    0, 1846, 1846,    0,    0, 1846, 1846, 1846,    0, 1846,
 1846, 1846, 1846, 1846, 1846, 1846,    0,    0,    0, 1846,
 1846, 1846, 1846, 1846,    0,    0,    0, 1846,    0,    0,
    0,    0,    0,    0,    0, 1846, 1846, 1846, 1846, 1846,
 1846,    0,    0,    0, 1846, 1846,    0, 1846,    0, 1846,
    0, 1846, 1846, 1846,    0, 1846,    0, 1846, 1846, 1846,
    0, 1846, 1846, 1846, 1846, 1846,    0, 1846, 1846,    0,
    0,    0,    0, 1846,    0, 1846, 1846,    0,    0, 1846,
 1846, 1846,    0,    0, 1846,    0, 1846,    0,    0, 1846,
 1846, 1846, 1846,    0, 1846,    0, 1846,    0, 1846, 1846,
 1846, 1846, 1846, 1248,    0, 1846, 1846, 1846,    0, 1846,
 1846,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1846, 1846, 1846,    0, 1846, 1846, 1846, 1248, 1846,    0,
    0,    0, 1846,    0, 1846, 1846, 1846, 1846,    0, 1846,
    0, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1846, 1846,
 3188, 1846, 1846, 1846,    0,    0,    0,    0, 1846, 1846,
 1846, 1846, 1846,    0, 1846,    0,    0, 1846, 1846, 1250,
 1249, 1251, 1846, 1846, 3231,    0, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846,    0, 1846,    0,    0,    0,
    0,    0,    0, 1250, 1249, 1251, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846, 1846, 1846,    0, 1846, 1846,
 1846, 1846, 1846, 1846,    0, 1846, 1846, 1846, 1846,    0,
 1846,    0, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
    0, 1846, 1846, 1846, 1846,    0, 1846, 1846, 1846, 1846,
 1846,    0, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846, 1846,
 1846, 1847, 1846, 1846, 1846, 1846,    0, 1846, 1846, 1846,
 1846, 1846, 1846,    0,    0, 1846, 1846, 1846, 1846, 1846,
 1846, 1846, 1846, 1846,    0,    0,    0,    0,    0, 1846,
    0, 1846, 1846, 1846, 1846, 1846, 1846,    0, 1846,    0,
    0, 1659, 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1847,
 1847, 1847, 1847, 1847,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1847,    0, 1847,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0,    0, 1238,    0,    0,    0,    0,    0,
    0,    0, 1239, 1061,    0,    0, 1062,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238, 1240,
    0, 1241, 1063,    0, 1064,    0, 1239,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0, 1065,    0, 1246,    0,    0,    0, 1066, 1067,
 1068,    0, 1069, 1070, 1071,    0, 1072,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
 1073,    0, 1074,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0, 1847,    0,
 1847,    0,    0, 1847,    0, 1847, 1847,    0,    0, 1847,
 1847, 1075, 1847,    0,    0,    0,    0,    0, 1847,    0,
 1847, 1847, 1847, 1847,    0, 1847,    0, 1076, 1847,    0,
    0, 1847,    0,    0,    0,    0,    0,    0, 1847,    0,
 1847, 1847,    0, 1847, 1847, 1847, 1847, 1847,    0, 1077,
 1847,    0,    0, 1847,    0, 1847, 1847,    0,    0, 1847,
 1847, 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
    0,    0,    0, 1847, 1847, 1847, 1847, 1847,    0,    0,
    0, 1847,    0, 1078, 1079,    0,    0,    0,    0, 1847,
 1847, 1847, 1847, 1847, 1847,    0,    0,    0, 1847, 1847,
 1080, 1847,    0, 1847,    0, 1847, 1847, 1847,    0, 1847,
    0, 1847, 1847, 1847,    0, 1847, 1847, 1847, 1847, 1847,
    0, 1847, 1847,    0,    0,    0,    0, 1847,    0, 1847,
 1847,    0,    0, 1847, 1847, 1847,    0,    0, 1847,    0,
 1847,    0,    0, 1847, 1847, 1847, 1847,    0, 1847,    0,
 1847,    0, 1847, 1847, 1847, 1847, 1847, 1248,    0, 1847,
 1847, 1847,    0, 1847, 1847,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1847, 1847, 1847,    0, 1847, 1847,
 1847, 1248, 1847,    0,    0,    0, 1847,    0, 1847, 1847,
 1847, 1847,    0, 1847,    0, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1847, 1847, 3241, 1847, 1847, 1847,    0,    0,
    0,    0, 1847, 1847, 1847, 1847, 1847,    0, 1847,    0,
    0, 1847, 1847, 1250, 1249, 1251, 1847, 1847,    0,    0,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,
 1847,    0,    0, 1250, 1249, 1251,    0,    0,    0, 1081,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847,    0, 1847, 1847, 1847, 1847, 1847, 1847,    0, 1847,
 1847, 1847, 1847,    0, 1847,    0, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847,    0, 1847, 1847, 1847, 1847,    0,
 1847, 1847, 1847, 1847, 1847,    0, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,
 1847, 1847, 1847, 1847, 1847, 1850, 1847, 1847, 1847, 1847,
    0, 1847, 1847, 1847, 1847, 1847, 1847,    0,    0, 1847,
 1847, 1847, 1847, 1847, 1847, 1847, 1847, 1847,    0,    0,
    0,    0,    0, 1847,    0, 1847, 1847, 1847, 1847, 1847,
 1847,    0, 1847,    0,    0, 1660, 1850, 1850, 1850, 1850,
 1850, 1850, 1850,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1850, 1850, 1850, 1850, 1850,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1850,    0, 1850,    0,
    0,    0,    0,    0,    0, 1234,    0, 1236,  547,    0,
    0,    0,    0,    0, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  548, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0, 1240,    0, 1241, 1239,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0, 1240, 1246, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0, 1850,    0, 1850,    0,    0, 1850,    0, 1850,
 1850,    0,    0, 1850, 1850,    0, 1850,    0,    0,    0,
    0,    0, 1850,    0, 1850, 1850, 1850, 1850,    0, 1850,
    0,    0, 1850,    0,    0, 1850,    0,    0,    0,    0,
    0,    0, 1850,    0, 1850, 1850,    0, 1850, 1850, 1850,
 1850, 1850,    0,    0, 1850,    0,    0, 1850,    0, 1850,
 1850,    0,    0, 1850, 1850, 1850,    0, 1850, 1850, 1850,
 1850, 1850, 1850, 1850,    0,    0,    0, 1850, 1850, 1850,
 1850, 1850,    0,    0,    0, 1850,    0,    0,    0,    0,
    0,    0,    0, 1850, 1850, 1850, 1850, 1850, 1850,    0,
    0,    0, 1850, 1850,    0, 1850,    0, 1850,    0, 1850,
 1850, 1850,    0, 1850,    0, 1850, 1850, 1850,    0, 1850,
 1850, 1850, 1850, 1850,    0, 1850, 1850,    0,    0,    0,
    0, 1850,    0, 1850, 1850,    0,    0, 1850, 1850, 1850,
    0,    0, 1850,    0, 1850,    0,    0, 1850, 1850, 1850,
 1850,    0, 1850,    0, 1850,    0, 1850, 1850, 1850, 1850,
 1850, 1248,    0, 1850, 1850, 1850,    0, 1850, 1850,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1850, 1850,
 1850, 1248, 1850, 1850, 1850,    0, 1850,    0,    0,    0,
 1850,    0, 1850, 1850, 1850, 1850, 1967, 1850,    0, 1850,
 1850, 1850, 1850, 1850, 1850, 1850, 1850,    0,    0,    0,
    0,    0, 1250, 1249, 1251,    0, 1850, 1850,    0, 1850,
 1850, 1850,    0,    0,    0,    0, 1850, 1850, 1850, 1850,
 1850,    0, 1850,    0,    0, 1850, 1850,    0,    0,    0,
 1850, 1850,    0,    0, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850,    0, 1850,    0,    0, 1250, 1249, 1251,
    0,    0,    0,    0, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850, 1850, 1850,    0, 1850, 1850, 1850, 1850,
 1850, 1850,    0, 1850, 1850, 1850, 1850,    0, 1850,    0,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850,    0, 1850,
 1850, 1850, 1850,    0, 1850, 1850, 1850, 1850, 1850,    0,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1850, 1852,
 1850, 1850, 1850, 1850,    0, 1850, 1850, 1850, 1850, 1850,
 1850,    0,    0, 1850, 1850, 1850, 1850, 1850, 1850, 1850,
 1850, 1850,    0,    0,    0,    0,    0, 1850,    0, 1850,
 1850, 1850, 1850, 1850, 1850,    0, 1850,    0,    0, 1661,
 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,    0,    0,
    0,    0,    0,    0, 1234,    0,    0, 1852, 1852, 1852,
 1852, 1852,    0, 1235,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1236,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1852,    0, 1852,    0,    0,    0,    0,    0,    0, 1234,
    0, 1940,    0,    0,    0,    0,    0,    0, 1235,    0,
 1237,    0,    0,    0,    0,    0,    0, 1238,    0,    0,
    0, 1236,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1240,    0, 1241,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1242, 1237, 1243, 1244, 1245,    0,
    0,    0, 1238, 1246,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245, 1247,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0, 1852,    0, 1852,    0,
    0, 1852,    0, 1852, 1852,    0,    0, 1852, 1852,    0,
 1852,    0,    0,    0,    0,    0, 1852,    0, 1852, 1852,
 1852, 1852,    0, 1852,    0,    0, 1852,    0,    0, 1852,
    0,    0,    0,    0,    0,    0, 1852,    0, 1852, 1852,
    0, 1852, 1852, 1852, 1852, 1852,    0,    0, 1852,    0,
    0, 1852,    0, 1852, 1852,    0,    0, 1852, 1852, 1852,
    0, 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,    0,
    0, 1852, 1852, 1852, 1852, 1852,    0,    0,    0, 1852,
    0,    0,    0,    0,    0,    0,    0, 1852, 1852, 1852,
 1852, 1852, 1852,    0,    0,    0, 1852, 1852,    0, 1852,
    0, 1852,    0, 1852, 1852, 1852,    0, 1852,    0, 1852,
 1852, 1852,    0, 1852, 1852, 1852, 1852, 1852,    0, 1852,
 1852,    0,    0,    0,    0, 1852,    0, 1852, 1852,    0,
 1248, 1852, 1852, 1852,    0,    0, 1852,    0, 1852,    0,
    0, 1852, 1852, 1852, 1852,    0, 1852,    0, 1852,    0,
 1852, 1852, 1852, 1852, 1852,    0,    0, 1852, 1852, 1852,
    0, 1852, 1852,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1852, 1852, 1852, 1248, 1852, 1852, 1852,    0,
 1852,    0,    0,    0, 1852,    0, 1852, 1852, 1852, 1852,
 1983, 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852,    0,    0,    0,    0,    0, 1250, 1249, 1251,    0,
 1852, 1852,    0, 1852, 1852, 1852,    0,    0,    0,    0,
 1852, 1852, 1852, 1852, 1852,    0, 1852,    0,    0, 1852,
 1852,    0,    0,    0, 1852, 1852,    0,    0, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0, 1852,    0,
    0, 1250, 1249, 1251,    0,    0,    0,    0, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,    0,
 1852, 1852, 1852, 1852, 1852, 1852,    0, 1852, 1852, 1852,
 1852,    0, 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852,    0, 1852, 1852, 1852, 1852,    0, 1852, 1852,
 1852, 1852, 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852, 1852,
 1852, 1852, 1852, 1853, 1852, 1852, 1852, 1852,    0, 1852,
 1852, 1852, 1852, 1852, 1852,    0,    0, 1852, 1852, 1852,
 1852, 1852, 1852, 1852, 1852, 1852,    0,    0,    0,    0,
    0, 1852,    0, 1852, 1852, 1852, 1852, 1852, 1852,    0,
 1852,    0,    0, 1662, 1853, 1853, 1853, 1853, 1853, 1853,
 1853,    0,    0,    0,    0,    0,    0,    0, 1234,    0,
    0, 1853, 1853, 1853, 1853, 1853,    0, 1235,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1236,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1853,    0, 1853,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1237,    0,    0,    0,    0,    0,
    0, 1238,    0,    0,    0, 1236,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0, 1241,    0,
    0,    0,    0,    0,    0, 1959,    0,    0, 1242, 1237,
 1243, 1244, 1245,    0,    0,    0, 1238, 1246,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245, 1247,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
 1853,    0, 1853,    0,    0, 1853,    0, 1853, 1853,    0,
    0, 1853, 1853,    0, 1853,    0,    0,    0,    0,    0,
 1853,    0, 1853, 1853, 1853, 1853,    0, 1853,    0,    0,
 1853,    0,    0, 1853,    0,    0,    0,    0,    0,    0,
 1853,    0, 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853,
    0,    0, 1853,    0,    0, 1853,    0, 1853, 1853,    0,
    0, 1853, 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853,
 1853, 1853,    0,    0,    0, 1853, 1853, 1853, 1853, 1853,
    0,    0,    0, 1853,    0,    0,    0,    0,    0,    0,
    0, 1853, 1853, 1853, 1853, 1853, 1853,    0,    0,    0,
 1853, 1853,    0, 1853,    0, 1853,    0, 1853, 1853, 1853,
    0, 1853,    0, 1853, 1853, 1853,    0, 1853, 1853, 1853,
 1853, 1853,    0, 1853, 1853,    0,    0,    0,    0, 1853,
    0, 1853, 1853,    0, 1248, 1853, 1853, 1853,    0,    0,
 1853,    0, 1853,    0,    0, 1853, 1853, 1853, 1853,    0,
 1853,    0, 1853,    0, 1853, 1853, 1853, 1853, 1853,    0,
    0, 1853, 1853, 1853,    0, 1853, 1853,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1853, 1853, 1853, 1960,
 1853, 1853, 1853,    0, 1853,    0,    0,    0, 1853,    0,
 1853, 1853, 1853, 1853, 1988, 1853,    0, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853,    0,    0,    0,    0,    0,
 1250, 1249, 1251,    0, 1853, 1853,    0, 1853, 1853, 1853,
    0,    0,    0,    0, 1853, 1853, 1853, 1853, 1853,    0,
 1853,    0,    0, 1853, 1853,    0,    0,    0, 1853, 1853,
    0,    0, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853,    0, 1853,    0,    0, 1250, 1249, 1251,    0,    0,
    0,    0, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853, 1853,
    0, 1853, 1853, 1853, 1853,    0, 1853,    0, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853,    0, 1853, 1853, 1853,
 1853,    0, 1853, 1853, 1853, 1853, 1853,    0, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1856, 1853, 1853,
 1853, 1853,    0, 1853, 1853, 1853, 1853, 1853, 1853,    0,
    0, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853, 1853,
    0,    0,    0,    0,    0, 1853,    0, 1853, 1853, 1853,
 1853, 1853, 1853,    0, 1853,    0,    0, 1663, 1856, 1856,
 1856, 1856, 1856, 1856, 1856,    0,    0,    0,    0,    0,
    0,    0, 1234,    0,    0, 1856, 1856, 1856, 1856, 1856,
    0, 1235,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1236,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1856,    0,
 1856,    0,    0,    0,    0,    0,    0, 1234,    0,    0,
    0,    0,    0,    0,    0,    0, 1235,    0, 1237,    0,
    0,    0,    0,    0,    0, 1238,    0,    0,    0, 1236,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0, 1241,    0,    0,    0,    0,    0,    0, 2330,
    0,    0, 1242, 1237, 1243, 1244, 1245,    0,    0,    0,
 1238, 1246,    0,    0,    0,    0,    0,    0, 1239,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1240,    0, 1241,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1242,    0, 1243,
 1244, 1245, 1247,    0,    0,    0, 1246,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1247,    0,    0,
    0,    0,    0,    0, 1856,    0, 1856,    0,    0, 1856,
    0, 1856, 1856,    0,    0, 1856, 1856,    0, 1856,    0,
    0,    0,    0,    0, 1856,    0, 1856, 1856, 1856, 1856,
    0, 1856,    0,    0, 1856,    0,    0, 1856,    0,    0,
    0,    0,    0,    0, 1856,    0, 1856, 1856,    0, 1856,
 1856, 1856, 1856, 1856,    0,    0, 1856,    0,    0, 1856,
    0, 1856, 1856,    0,    0, 1856, 1856, 1856,    0, 1856,
 1856, 1856, 1856, 1856, 1856, 1856,    0,    0,    0, 1856,
 1856, 1856, 1856, 1856,    0,    0,    0, 1856,    0,    0,
    0,    0,    0,    0,    0, 1856, 1856, 1856, 1856, 1856,
 1856,    0,    0,    0, 1856, 1856,    0, 1856,    0, 1856,
    0, 1856, 1856, 1856,    0, 1856,    0, 1856, 1856, 1856,
    0, 1856, 1856, 1856, 1856, 1856,    0, 1856, 1856,    0,
    0,    0,    0, 1856,    0, 1856, 1856,    0, 1248, 1856,
 1856, 1856,    0,    0, 1856,    0, 1856,    0,    0, 1856,
 1856, 1856, 1856,    0, 1856,    0, 1856,    0, 1856, 1856,
 1856, 1856, 1856,    0,    0, 1856, 1856, 1856,    0, 1856,
 1856,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1856, 1856, 1856, 1248, 1856, 1856, 1856,    0, 1856,    0,
    0,    0, 1856,    0, 1856, 1856, 1856, 1856, 1998, 1856,
    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,    0,
    0,    0,    0,    0, 1250, 1249, 1251,    0, 1856, 1856,
    0, 1856, 1856, 1856,    0,    0,    0,    0, 1856, 1856,
 1856, 1856, 1856,    0, 1856,    0,    0, 1856, 1856,    0,
    0,    0, 1856, 1856,    0,    0, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856,    0, 1856,    0,    0, 1250,
 1249, 1251,    0,    0,    0,    0, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856,    0, 1856, 1856,
 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856, 1856,    0,
 1856,    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
    0, 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856, 1856,
 1856,    0, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856, 1856,
 1856, 1858, 1856, 1856, 1856, 1856,    0, 1856, 1856, 1856,
 1856, 1856, 1856,    0,    0, 1856, 1856, 1856, 1856, 1856,
 1856, 1856, 1856, 1856,    0,    0,    0,    0,    0, 1856,
    0, 1856, 1856, 1856, 1856, 1856, 1856,    0, 1856,    0,
    0, 1664, 1858, 1858, 1858, 1858, 1858, 1858, 1858,    0,
    0,    0,    0,    0,    0,    0, 1234,    0,    0, 1858,
 1858, 1858, 1858, 1858,    0, 1235,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1236,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1858,    0, 1858,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1237,    0,    0,    0,    0,    0,    0, 1238,
    0,    0,    0, 1236,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1240,    0, 1241,    0,    0,    0,
    0, 2604,    0,    0,    0,    0, 1242, 1237, 1243, 1244,
 1245,    0,    0,    0, 1238, 1246,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245, 1247,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0, 1858,    0,
 1858,    0,    0, 1858,    0, 1858, 1858,    0,    0, 1858,
 1858,    0, 1858,    0,    0,    0,    0,    0, 1858,    0,
 1858, 1858, 1858, 1858,    0, 1858,    0,    0, 1858,    0,
    0, 1858,    0,    0,    0,    0,    0,    0, 1858,    0,
 1858, 1858,    0, 1858, 1858, 1858, 1858, 1858,    0,    0,
 1858,    0,    0, 1858,    0, 1858, 1858,    0,    0, 1858,
 1858, 1858,    0, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
    0,    0,    0, 1858, 1858, 1858, 1858, 1858,    0,    0,
    0, 1858,    0,    0,    0,    0,    0,    0,    0, 1858,
 1858, 1858, 1858, 1858, 1858,    0,    0,    0, 1858, 1858,
    0, 1858,    0, 1858,    0, 1858, 1858, 1858,    0, 1858,
    0, 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858, 1858,
    0, 1858, 1858,    0,    0,    0,    0, 1858,    0, 1858,
 1858,    0, 1248, 1858, 1858, 1858,    0,    0, 1858,    0,
 1858,    0,    0, 1858, 1858, 1858, 1858,    0, 1858,    0,
 1858,    0, 1858, 1858, 1858, 1858, 1858,    0,    0, 1858,
 1858, 1858,    0, 1858, 1858,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1858, 1858, 1858, 1248, 1858, 1858,
 1858,    0, 1858,    0,    0,    0, 1858,    0, 1858, 1858,
 1858, 1858, 1999, 1858,    0, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858,    0,    0,    0,    0,    0, 1250, 1249,
 1251,    0, 1858, 1858,    0, 1858, 1858, 1858,    0,    0,
    0,    0, 1858, 1858, 1858, 1858, 1858,    0, 1858,    0,
    0, 1858, 1858,    0,    0,    0, 1858, 1858,    0,    0,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,    0,
 1858,    0,    0, 1250, 1249, 1251,    0,    0,    0,    0,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858,    0, 1858, 1858, 1858, 1858, 1858, 1858,    0, 1858,
 1858, 1858, 1858,    0, 1858,    0, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858,    0,
 1858, 1858, 1858, 1858, 1858,    0, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,
 1858, 1858, 1858, 1858, 1858, 1860, 1858, 1858, 1858, 1858,
    0, 1858, 1858, 1858, 1858, 1858, 1858,    0,    0, 1858,
 1858, 1858, 1858, 1858, 1858, 1858, 1858, 1858,    0,    0,
    0,    0,    0, 1858,    0, 1858, 1858, 1858, 1858, 1858,
 1858,    0, 1858,    0,    0, 1665, 1860, 1860, 1860, 1860,
 1860, 1860, 1860,    0,    0,    0,    0,    0,    0,    0,
 1234,    0,    0, 1860, 1860, 1860, 1860, 1860,    0, 1235,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1236,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1860,    0, 1860,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0,    0,
    0,    0,    0,    0, 1235,    0, 1237,    0,    0,    0,
    0,    0,    0, 1238,    0,    0,    0, 1236,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
 1241,    0,    0,    0,    0,    0,    0, 2626,    0,    0,
 1242, 1237, 1243, 1244, 1245,    0,    0,    0, 1238, 1246,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1240,    0, 1241,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1242,    0, 1243, 1244, 1245,
 1247,    0,    0,    0, 1246,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0, 1860,    0, 1860,    0,    0, 1860,    0, 1860,
 1860,    0,    0, 1860, 1860,    0, 1860,    0,    0,    0,
    0,    0, 1860,    0, 1860, 1860, 1860, 1860,    0, 1860,
    0,    0, 1860,    0,    0, 1860,    0,    0,    0,    0,
    0,    0, 1860,    0, 1860, 1860,    0, 1860, 1860, 1860,
 1860, 1860,    0,    0, 1860,    0,    0, 1860,    0, 1860,
 1860,    0,    0, 1860, 1860, 1860,    0, 1860, 1860, 1860,
 1860, 1860, 1860, 1860,    0,    0,    0, 1860, 1860, 1860,
 1860, 1860,    0,    0,    0, 1860,    0,    0,    0,    0,
    0,    0,    0, 1860, 1860, 1860, 1860, 1860, 1860,    0,
    0,    0, 1860, 1860,    0, 1860,    0, 1860,    0, 1860,
 1860, 1860,    0, 1860,    0, 1860, 1860, 1860,    0, 1860,
 1860, 1860, 1860, 1860,    0, 1860, 1860,    0,    0,    0,
    0, 1860,    0, 1860, 1860,    0, 1248, 1860, 1860, 1860,
    0,    0, 1860,    0, 1860,    0,    0, 1860, 1860, 1860,
 1860,    0, 1860,    0, 1860,    0, 1860, 1860, 1860, 1860,
 1860,    0,    0, 1860, 1860, 1860,    0, 1860, 1860,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1860, 1860,
 1860, 1248, 1860, 1860, 1860,    0, 1860,    0,    0,    0,
 1860,    0, 1860, 1860, 1860, 1860, 2000, 1860,    0, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0,    0,    0,
    0,    0, 1250, 1249, 1251,    0, 1860, 1860,    0, 1860,
 1860, 1860,    0,    0,    0,    0, 1860, 1860, 1860, 1860,
 1860,    0, 1860,    0,    0, 1860, 1860,    0,    0,    0,
 1860, 1860,    0,    0, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860,    0, 1860,    0,    0, 1250, 1249, 1251,
    0,    0,    0,    0, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860,    0, 1860, 1860, 1860, 1860,
 1860, 1860,    0, 1860, 1860, 1860, 1860,    0, 1860,    0,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,    0, 1860,
 1860, 1860, 1860,    0, 1860, 1860, 1860, 1860, 1860,    0,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1860, 1861,
 1860, 1860, 1860, 1860,    0, 1860, 1860, 1860, 1860, 1860,
 1860,    0,    0, 1860, 1860, 1860, 1860, 1860, 1860, 1860,
 1860, 1860,    0,    0,    0,    0,    0, 1860,    0, 1860,
 1860, 1860, 1860, 1860, 1860,    0, 1860,    0,    0, 1668,
 1861, 1861, 1861, 1861, 1861, 1861, 1861,    0,    0,    0,
    0,    0,    0,    0, 1234,    0,    0, 1861, 1861, 1861,
 1861, 1861,    0, 1235,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1236,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1861,    0, 1861,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0,    0,    0,    0,    0,    0, 1235,    0,
 1237,    0,    0,    0,    0,    0,    0, 1238,    0,    0,
    0, 1236,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1240,    0, 1241,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1242, 1237, 1243, 1244, 1245,    0,
    0,    0, 1238, 1246,    0,    0,    0,    0,    0,    0,
 1239,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1242,
    0, 1243, 1244, 1245, 1247,    0,    0,    0, 1246,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0, 1861,    0, 1861,    0,
    0, 1861,    0, 1861, 1861,    0,    0, 1861, 1861,    0,
 1861,    0,    0,    0,    0,    0, 1861,    0, 1861, 1861,
 1861, 1861,    0, 1861,    0,    0, 1861,    0,    0, 1861,
    0,    0,    0,    0,    0,    0, 1861,    0, 1861, 1861,
    0, 1861, 1861, 1861, 1861, 1861,    0,    0, 1861,    0,
    0, 1861,    0, 1861, 1861,    0,    0, 1861, 1861, 1861,
    0, 1861, 1861, 1861, 1861, 1861, 1861, 1861,    0,    0,
    0, 1861, 1861, 1861, 1861, 1861,    0,    0,    0, 1861,
    0,    0,    0,    0,    0,    0,    0, 1861, 1861, 1861,
 1861, 1861, 1861,    0,    0,    0, 1861, 1861,    0, 1861,
    0, 1861,    0, 1861, 1861, 1861,    0, 1861,    0, 1861,
 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861,    0, 1861,
 1861,    0,    0,    0,    0, 1861,    0, 1861, 1861,    0,
 1248, 1861, 1861, 1861,    0,    0, 1861,    0, 1861,    0,
    0, 1861, 1861, 1861, 1861,    0, 1861,    0, 1861,    0,
 1861, 1861, 1861, 1861, 1861,    0,    0, 1861, 1861, 1861,
    0, 1861, 1861,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1861, 1861, 1861, 1248, 1861, 1861, 1861,    0,
 1861,    0,    0,    0, 1861,    0, 1861, 1861, 1861, 1861,
 2001, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861,    0,    0,    0,    0,    0, 1250, 1249, 1251,    0,
 1861, 1861,    0, 1861, 1861, 1861,    0,    0,    0,    0,
 1861, 1861, 1861, 1861, 1861,    0, 1861,    0,    0, 1861,
 1861,    0,    0,    0, 1861, 1861,    0,    0, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861,    0, 1861,    0,
    0, 1250, 1249, 1251,    0,    0,    0,    0, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,    0,
 1861, 1861, 1861, 1861, 1861, 1861,    0, 1861, 1861, 1861,
 1861,    0, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861,    0, 1861, 1861, 1861, 1861,    0, 1861, 1861,
 1861, 1861, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861, 1861,
 1861, 1861, 1861, 1862, 1861, 1861, 1861, 1861,    0, 1861,
 1861, 1861, 1861, 1861, 1861,    0,    0, 1861, 1861, 1861,
 1861, 1861, 1861, 1861, 1861, 1861,    0,    0,    0,    0,
    0, 1861,    0, 1861, 1861, 1861, 1861, 1861, 1861,    0,
 1861,    0,    0, 1669, 1862, 1862, 1862, 1862, 1862, 1862,
 1862,    0,    0,    0,    0,    0,    0,    0, 1234,    0,
    0, 1862, 1862, 1862, 1862, 1862,    0, 1235,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1236,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1862,    0, 1862,    0,    0,    0,
    0,    0,    0, 1234,    0,    0,    0,    0,    0,    0,
    0,    0, 1235,    0, 1237,    0,    0,    0,    0,    0,
    0, 1238,    0,    0,    0, 1236,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0, 1241,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1242, 1237,
 1243, 1244, 1245,    0,    0,    0, 1951, 1246,    0,    0,
    0,    0,    0,    0, 1239,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1240,    0, 1241,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1242,    0, 1243, 1244, 1245, 1247,    0,
    0,    0, 1246,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1247,    0,    0,    0,    0,    0,    0,
 1862,    0, 1862,    0,    0, 1862,    0, 1862, 1862,    0,
    0, 1862, 1862,    0, 1862,    0,    0,    0,    0,    0,
 1862,    0, 1862, 1862, 1862, 1862,    0, 1862,    0,    0,
 1862,    0,    0, 1862,    0,    0,    0,    0,    0,    0,
 1862,    0, 1862, 1862,    0, 1862, 1862, 1862, 1862, 1862,
    0,    0, 1862,    0,    0, 1862,    0, 1862, 1862,    0,
    0, 1862, 1862, 1862,    0, 1862, 1862, 1862, 1862, 1862,
 1862, 1862,    0,    0,    0, 1862, 1862, 1862, 1862, 1862,
    0,    0,    0, 1862,    0,    0,    0,    0,    0,    0,
    0, 1862, 1862, 1862, 1862, 1862, 1862,    0,    0,    0,
 1862, 1862,    0, 1862,    0, 1862,    0, 1862, 1862, 1862,
    0, 1862,    0, 1862, 1862, 1862,    0, 1862, 1862, 1862,
 1862, 1862,    0, 1862, 1862,    0,    0,    0,    0, 1862,
    0, 1862, 1862,    0, 1248, 1862, 1862, 1862,    0,    0,
 1862,    0, 1862,    0,    0, 1862, 1862, 1862, 1862,    0,
 1862,    0, 1862,    0, 1862, 1862, 1862, 1862, 1862,    0,
    0, 1862, 1862, 1862,    0, 1862, 1862,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1862, 1862, 1862, 1248,
 1862, 1862, 1862,    0, 1862,    0,    0,    0, 1862,    0,
 1862, 1862, 1862, 1862, 2002, 1862,    0, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862,    0,    0,    0,    0,    0,
 1250, 1249, 1251,    0, 1862, 1862,    0, 1862, 1862, 1862,
    0,    0,    0,    0, 1862, 1862, 1862, 1862, 1862,    0,
 1862,    0,    0, 1862, 1862,    0,    0,    0, 1862, 1862,
    0,    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862,    0, 1862,    0,    0, 1475, 1475, 1475,    0,    0,
    0,    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862,    0, 1862, 1862, 1862, 1862, 1862, 1862,
    0, 1862, 1862, 1862, 1862,    0, 1862,    0, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862,    0, 1862, 1862, 1862,
 1862,    0, 1862, 1862, 1862, 1862, 1862,    0, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1863, 1862, 1862,
 1862, 1862,    0, 1862, 1862, 1862, 1862, 1862, 1862,    0,
    0, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862, 1862,
    0,    0,    0,    0,    0, 1862,    0, 1862, 1862, 1862,
 1862, 1862, 1862,    0, 1862,    0,    0, 1671, 1863, 1863,
 1863, 1863, 1863, 1863, 1863,    0,    0,    0,    0,    0,
    0,    0, 1234,    0,    0, 1863, 1863, 1863, 1863, 1863,
    0, 1235,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1236,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1863,    0,
 1863,    0,    0,    0,    0,    0,    0, 1475,    0,    0,
    0,    0,    0,    0,    0,    0, 1475,    0, 1237,    0,
    0,    0,    0,    0,    0, 1238,    0,    0,    0, 1475,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0, 1241,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1242, 1475, 1243, 1244, 1245,    0,    0,    0,
 1475, 1246,    0,    0,    0,    0,    0,    0, 1475,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1475,    0, 1475,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1475,    0, 1475,
 1475, 1475, 1247,    0,    0,    0, 1475,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1475,    0,    0,
    0,    0,    0,    0, 1863,    0, 1863,    0,    0, 1863,
    0, 1863, 1863,    0,    0, 1863, 1863,    0, 1863,    0,
    0,    0,    0,    0, 1863,    0, 1863, 1863, 1863, 1863,
    0, 1863,    0,    0, 1863,    0,    0, 1863,    0,    0,
    0,    0,    0,    0, 1863,    0, 1863, 1863,    0, 1863,
 1863, 1863, 1863, 1863,    0,    0, 1863,    0,    0, 1863,
    0, 1863, 1863,    0,    0, 1863, 1863, 1863,    0, 1863,
 1863, 1863, 1863, 1863, 1863, 1863,    0,    0,    0, 1863,
 1863, 1863, 1863, 1863,    0,    0,    0, 1863,    0,    0,
    0,    0,    0,    0,    0, 1863, 1863, 1863, 1863, 1863,
 1863,    0,    0,    0, 1863, 1863,    0, 1863,    0, 1863,
    0, 1863, 1863, 1863,    0, 1863,    0, 1863, 1863, 1863,
    0, 1863, 1863, 1863, 1863, 1863,    0, 1863, 1863,    0,
    0,    0,    0, 1863,    0, 1863, 1863,    0, 1248, 1863,
 1863, 1863,    0,    0, 1863,    0, 1863,    0,    0, 1863,
 1863, 1863, 1863,    0, 1863,    0, 1863,    0, 1863, 1863,
 1863, 1863, 1863,    0,    0, 1863, 1863, 1863,    0, 1863,
 1863,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1863, 1863, 1863, 1475, 1863, 1863, 1863,    0, 1863,    0,
    0,    0, 1863,    0, 1863, 1863, 1863, 1863, 2003, 1863,
    0, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,    0,
    0,    0,    0,    0, 1250, 1249, 1251,    0, 1863, 1863,
    0, 1863, 1863, 1863,    0,    0,    0,    0, 1863, 1863,
 1863, 1863, 1863,    0, 1863,    0,    0, 1863, 1863,    0,
    0,    0, 1863, 1863,    0,    0, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863,    0, 1863,    0,    0, 1250,
 1249, 1251,    0,    0,    0,    0, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863, 1863, 1863,    0, 1863, 1863,
 1863, 1863, 1863, 1863,    0, 1863, 1863, 1863, 1863,    0,
 1863,    0, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
    0, 1863, 1863, 1863, 1863,    0, 1863, 1863, 1863, 1863,
 1863,    0, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863, 1863,
 1863, 1864, 1863, 1863, 1863, 1863,    0, 1863, 1863, 1863,
 1863, 1863, 1863,    0,    0, 1863, 1863, 1863, 1863, 1863,
 1863, 1863, 1863, 1863,    0,    0,    0,    0,    0, 1863,
    0, 1863, 1863, 1863, 1863, 1863, 1863,    0, 1863,    0,
    0, 1672, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,
    0,    0,    0,    0,    0,    0, 1234,    0,    0, 1864,
 1864, 1864, 1864, 1864,    0, 1235,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1236,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1864,    0, 1864,    0,    0,    0,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1237,    0,    0,    0,    0,    0,    0, 1238,
    0,    0,    0, 1236,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1240,    0, 1241,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1242, 1237, 1243, 1244,
 1245,    0,    0,    0, 1238, 1246,    0,    0,    0,    0,
    0,    0, 1239,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245, 1247,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0, 1864,    0,
 1864,    0,    0, 1864,    0, 1864, 1864,    0,    0, 1864,
 1864,    0, 1864,    0,    0,    0,    0,    0, 1864,    0,
 1864, 1864, 1864, 1864,    0, 1864,    0,    0, 1864,    0,
    0, 1864,    0,    0,    0,    0,    0,    0, 1864,    0,
 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864,    0,    0,
 1864,    0,    0, 1864,    0, 1864, 1864,    0,    0, 1864,
 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
    0,    0,    0, 1864, 1864, 1864, 1864, 1864,    0,    0,
    0, 1864,    0,    0,    0,    0,    0,    0,    0, 1864,
 1864, 1864, 1864, 1864, 1864,    0,    0,    0, 1864, 1864,
    0, 1864,    0, 1864,    0, 1864, 1864, 1864,    0, 1864,
    0, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864, 1864,
    0, 1864, 1864,    0,    0,    0,    0, 1864,    0, 1864,
 1864,    0, 1248, 1864, 1864, 1864,    0,    0, 1864,    0,
 1864,    0,    0, 1864, 1864, 1864, 1864,    0, 1864,    0,
 1864,    0, 1864, 1864, 1864, 1864, 1864,    0,    0, 1864,
 1864, 1864,    0, 1864, 1864,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1864, 1864, 1864, 1248, 1864, 1864,
 1864,    0, 1864,    0,    0,    0, 1864,    0, 1864, 1864,
 1864, 1864, 2004, 1864,    0, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864,    0,    0,    0,    0,    0, 1250, 1249,
 1251,    0, 1864, 1864,    0, 1864, 1864, 1864,    0,    0,
    0,    0, 1864, 1864, 1864, 1864, 1864,    0, 1864,    0,
    0, 1864, 1864,    0,    0,    0, 1864, 1864,    0,    0,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,
 1864,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864,    0, 1864, 1864, 1864, 1864, 1864, 1864,    0, 1864,
 1864, 1864, 1864,    0, 1864,    0, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864,    0,
 1864, 1864, 1864, 1864, 1864,    0, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,
 1864, 1864, 1864, 1864, 1864, 1865, 1864, 1864, 1864, 1864,
    0, 1864, 1864, 1864, 1864, 1864, 1864,    0,    0, 1864,
 1864, 1864, 1864, 1864, 1864, 1864, 1864, 1864,    0,    0,
    0,    0,    0, 1864,    0, 1864, 1864, 1864, 1864, 1864,
 1864,    0, 1864,    0,    0, 1673, 1865, 1865, 1865, 1865,
 1865, 1865, 1865,    0,    0,    0,    0,    0,    0,    0,
 1234,    0,    0, 1865, 1865, 1865, 1865, 1865,  155, 1235,
    0,  155,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1236,  155,    0,    0,    0,  155,    0,  155,
    0,    0,    0,    0,    0,    0, 1865,    0, 1865,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  167,
    0,    0,  167,    0,    0,    0, 1237,    0,    0,    0,
    0,    0,    0, 1238,  167,    0,    0,  155,  167,    0,
  167, 1239,    0,  155,  155,  155,    0,  155,  155,  155,
    0,  155,    0,    0,    0,    0,    0,    0, 1240,    0,
 1241,    0,    0,    0,    0,  155,    0,  155,    0,    0,
 1242,    0, 1243, 1244, 1245,    0,    0,    0,  167, 1246,
    0,    0,    0,    0,  167,  167,  167,    0,  167,  167,
  167,    0,  167,    0,    0,    0,  155,    0,    0,    0,
    0,  154,    0,    0,    0,    0,  167,    0,  167,    0,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
 1247,    0,    0,    0,    0,    0,  167,    0,    0,    0,
    0,    0,    0,    0,  155,    0,    0,  167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  167,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  155,  155,
    0,    0, 1865,    0, 1865,  167,    0, 1865,    0, 1865,
 1865,    0,    0, 1865, 1865,  155, 1865,    0,    0,    0,
    0,    0, 1865,    0, 1865, 1865, 1865, 1865,    0, 1865,
    0,    0, 1865,    0,    0, 1865,    0,    0,    0,  167,
  167,    0, 1865,    0, 1865, 1865,    0, 1865, 1865, 1865,
 1865, 1865,    0,    0, 1865,    0,  167, 1865,    0, 1865,
 1865,    0,    0, 1865, 1865, 1865,    0, 1865, 1865, 1865,
 1865, 1865, 1865, 1865,    0,    0,    0, 1865, 1865, 1865,
 1865, 1865,    0,    0,    0, 1865,    0,    0,    0,    0,
    0,    0,    0, 1865, 1865, 1865, 1865, 1865, 1865,    0,
    0,    0, 1865, 1865,    0, 1865,    0, 1865,    0, 1865,
 1865, 1865,    0, 1865,    0, 1865, 1865, 1865,    0, 1865,
 1865, 1865, 1865, 1865,    0, 1865, 1865,    0,    0,    0,
    0, 1865,    0, 1865, 1865,    0, 1248, 1865, 1865, 1865,
    0,    0, 1865,    0, 1865,    0,    0, 1865, 1865, 1865,
 1865,    0, 1865,    0, 1865,    0, 1865, 1865, 1865, 1865,
 1865,    0,    0, 1865, 1865, 1865,    0, 1865, 1865,    0,
    0,    0,    0,    0,  155,    0,    0,    0, 1865, 1865,
 1865,    0, 1865, 1865, 1865,    0, 1865,    0,    0,    0,
 1865,    0, 1865, 1865, 1865, 1865, 2005, 1865,    0, 1865,
 1865, 1865, 1865, 1865, 1865, 1865, 1865,    0,    0,    0,
    0,    0, 1250, 1249, 1251,  167, 1865, 1865,    0, 1865,
 1865, 1865,    0,    0,    0,    0, 1865, 1865, 1865, 1865,
 1865,    0, 1865,    0,    0, 1865, 1865,    0,    0,    0,
 1865, 1865,    0,    0, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865,    0, 1865,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865, 1865, 1865,    0, 1865, 1865, 1865, 1865,
 1865, 1865,    0, 1865, 1865, 1865, 1865,    0, 1865,    0,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865,    0, 1865,
 1865, 1865, 1865,    0, 1865, 1865, 1865, 1865, 1865,    0,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1865, 1866,
 1865, 1865, 1865, 1865,    0, 1865, 1865, 1865, 1865, 1865,
 1865,    0,    0, 1865, 1865, 1865, 1865, 1865, 1865, 1865,
 1865, 1865,    0,    0,    0,    0,    0, 1865,    0, 1865,
 1865, 1865, 1865, 1865, 1865,    0, 1865,    0,    0, 1674,
 1866, 1866, 1866, 1866, 1866, 1866, 1866,    0,    0,    0,
    0,    0,    0,    0, 1234,    0,    0, 1866, 1866, 1866,
 1866, 1866, 2591, 1235,    0, 1062,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1236, 2592,    0,    0,
    0, 1063,    0, 1064,    0,    0,    0,    0,    0,    0,
 1866,    0, 1866,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  263,    0,    0,  263,    0,    0,    0,
 1237,    0,    0,    0,    0,    0,    0, 1238,    0,    0,
    0, 1065,  263,    0,  263, 1239,    0, 1066, 1067, 1068,
    0, 1069, 1070, 1071,    0, 1072,    0,    0,    0,    0,
    0,    0, 1240,    0, 1241,    0,    0,    0,    0, 1073,
    0, 1074,    0,    0, 1242,    0, 1243, 1244, 1245,    0,
    0,    0,  263, 1246,    0,    0,    0,    0,  263,  263,
  263,    0,  263,  263,  263,    0,  263,    0,    0,    0,
 1075,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  263,    0,  263,    0,    0,    0, 1076,    0,    0,    0,
    0,    0,    0,    0, 1247,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1077,    0,
    0,  263,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  263,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1078, 1079,    0,    0, 1866,    0, 1866,  263,
    0, 1866,    0, 1866, 1866,    0,    0, 1866, 1866, 1080,
 1866,    0,    0,    0,    0,    0, 1866,    0, 1866, 1866,
 1866, 1866,    0, 1866,    0,    0, 1866,    0,    0, 1866,
    0,    0,    0,  263,  263,    0, 1866,    0, 1866, 1866,
    0, 1866, 1866, 1866, 1866, 1866,    0,    0, 1866,    0,
  263, 1866,    0, 1866, 1866,    0,    0, 1866, 1866, 1866,
    0, 1866, 1866, 1866, 1866, 1866, 1866, 1866,    0,    0,
    0, 1866, 1866, 1866, 1866, 1866,    0,    0,    0, 1866,
    0,    0,    0,    0,    0,    0,    0, 1866, 1866, 1866,
 1866, 1866, 1866,    0,    0,    0, 1866, 1866,    0, 1866,
    0, 1866,    0, 1866, 1866, 1866,    0, 1866,    0, 1866,
 1866, 1866,    0, 1866, 1866, 1866, 1866, 1866,    0, 1866,
 1866,    0,    0,    0,    0, 1866,    0, 1866, 1866,    0,
 1248, 1866, 1866, 1866,    0,    0, 1866,    0, 1866,    0,
    0, 1866, 1866, 1866, 1866,    0, 1866,    0, 1866,    0,
 1866, 1866, 1866, 1866, 1866,    0,    0, 1866, 1866, 1866,
    0, 1866, 1866,    0,    0,    0,    0,    0, 1081,    0,
    0,    0, 1866, 1866, 1866,    0, 1866, 1866, 1866,    0,
 1866,    0,    0,    0, 1866,    0, 1866, 1866, 1866, 1866,
 2006, 1866,    0, 1866, 1866, 1866, 1866, 1866, 1866, 1866,
 1866,    0,    0,    0,    0,    0, 1250, 1249, 1251,  263,
 1866, 1866,    0, 1866, 1866, 1866,    0,    0,    0,    0,
 1866, 1866, 1866, 1866, 1866,    0, 1866,    0,    0, 1866,
 1866,    0,    0,    0, 1866, 1866,    0,    0, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866,    0, 1866,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866,    0,
 1866, 1866, 1866, 1866, 1866, 1866,    0, 1866, 1866, 1866,
 1866,    0, 1866,    0, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866,    0, 1866, 1866, 1866, 1866,    0, 1866, 1866,
 1866, 1866, 1866,    0, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866, 1866,
 1866, 1866, 1866, 1867, 1866, 1866, 1866, 1866,    0, 1866,
 1866, 1866, 1866, 1866, 1866,    0,    0, 1866, 1866, 1866,
 1866, 1866, 1866, 1866, 1866, 1866,    0,    0,    0,    0,
    0, 1866,    0, 1866, 1866, 1866, 1866, 1866, 1866,    0,
 1866,    0,    0, 1675, 1867, 1867, 1867, 1867, 1867, 1867,
 1867,    0,    0,    0,    0,    0,    0,    0, 1234,    0,
    0, 1867, 1867, 1867, 1867, 1867,    0, 1235,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1628,
 1236,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1867,    0, 1867,    0,    0,    0,
    0,    0,    0,    0, 1629,    0,    0,    0,    0,    0,
 1630,    0,    0,    0, 1237, 1631,    0,    0,    0,    0,
 1632, 1238,    0, 1633,    0,    0,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0, 1241,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1242,    0,
 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1634,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1247,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1635,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1636,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1637,    0,    0,    0,    0,    0,
 1867,    0, 1867,    0,    0, 1867,    0, 1867, 1867,    0,
    0, 1867, 1867,    0, 1867,    0,    0,    0,    0,    0,
 1867,    0, 1867, 1867, 1867, 1867,    0, 1867,    0,    0,
 1867,    0,    0, 1867,    0,    0,    0,    0,    0,    0,
 1867,    0, 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867,
 1638,    0, 1867, 1639,    0, 1867,    0, 1867, 1867,    0,
    0, 1867, 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867,
 1867, 1867,    0,    0,    0, 1867, 1867, 1867, 1867, 1867,
    0,    0,    0, 1867,    0,    0,    0,    0,    0,    0,
    0, 1867, 1867, 1867, 1867, 1867, 1867,    0,    0,    0,
 1867, 1867,    0, 1867,    0, 1867,    0, 1867, 1867, 1867,
    0, 1867,    0, 1867, 1867, 1867,    0, 1867, 1867, 1867,
 1867, 1867,    0, 1867, 1867,    0,    0,    0,    0, 1867,
    0, 1867, 1867,    0, 1248, 1867, 1867, 1867,    0,    0,
 1867,    0, 1867,    0,    0, 1867, 1867, 1867, 1867,    0,
 1867,    0, 1867,    0, 1867, 1867, 1867, 1867, 1867, 1640,
    0, 1867, 1867, 1867,    0, 1867, 1867,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1867, 1867, 1867,    0,
 1867, 1867, 1867,    0, 1867,    0,    0,    0, 1867,    0,
 1867, 1867, 1867, 1867, 2007, 1867,    0, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867,    0,    0,    0,    0,    0,
 1250, 1249, 1251,    0, 1867, 1867,    0, 1867, 1867, 1867,
    0,    0,    0,    0, 1867, 1867, 1867, 1867, 1867,    0,
 1867,    0,    0, 1867, 1867,    0,    0,    0, 1867, 1867,
    0,    0, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867,    0, 1867,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867, 1867,
    0, 1867, 1867, 1867, 1867,    0, 1867,    0, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867,    0, 1867, 1867, 1867,
 1867,    0, 1867, 1867, 1867, 1867, 1867,    0, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1869, 1867, 1867,
 1867, 1867,    0, 1867, 1867, 1867, 1867, 1867, 1867,    0,
    0, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867, 1867,
    0,    0,    0,    0,    0, 1867,    0, 1867, 1867, 1867,
 1867, 1867, 1867,    0, 1867,    0,    0, 1676, 1869, 1869,
 1869, 1869, 1869, 1869, 1869,    0,    0,    0,    0,    0,
    0,    0, 1234,    0,    0, 1869, 1869, 1869, 1869, 1869,
    0, 1235,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   77, 1236,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1869,    0,
 1869,    0,    0,    0,    0,    0,    0,    0,   77,    0,
    0,    0,    0,    0,   77,    0,    0,    0, 1237,   77,
    0,    0,    0,    0,   77, 1238,    0,   77,    0,    0,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0, 1241,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,
    0, 1246,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   77,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1247,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   77,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   77,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   77,    0,
    0,    0,    0,    0, 1869,    0, 1869,    0,    0, 1869,
    0, 1869, 1869,    0,    0, 1869, 1869,    0, 1869,    0,
    0,    0,    0,    0, 1869,    0, 1869, 1869, 1869, 1869,
    0, 1869,    0,    0, 1869,    0,    0, 1869,    0,    0,
    0,    0,    0,    0, 1869,    0, 1869, 1869,    0, 1869,
 1869, 1869, 1869, 1869,   77,    0, 1869,   77,    0, 1869,
    0, 1869, 1869,    0,    0, 1869, 1869, 1869,    0, 1869,
 1869, 1869, 1869, 1869, 1869, 1869,    0,    0,    0, 1869,
 1869, 1869, 1869, 1869,    0,    0,    0, 1869,    0,    0,
    0,    0,    0,    0,    0, 1869, 1869, 1869, 1869, 1869,
 1869,    0,    0,    0, 1869, 1869,    0, 1869,    0, 1869,
    0, 1869, 1869, 1869,    0, 1869,    0, 1869, 1869, 1869,
    0, 1869, 1869, 1869, 1869, 1869,    0, 1869, 1869,    0,
    0,    0,    0, 1869,    0, 1869, 1869,    0, 1248, 1869,
 1869, 1869,    0,    0, 1869,    0, 1869,    0,    0, 1869,
 1869, 1869, 1869,    0, 1869,    0, 1869,    0, 1869, 1869,
 1869, 1869, 1869,   77,    0, 1869, 1869, 1869,    0, 1869,
 1869,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1869, 1869, 1869,    0, 1869, 1869, 1869,    0, 1869,    0,
    0,    0, 1869,    0, 1869, 1869, 1869, 1869, 2008, 1869,
    0, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,    0,
    0,    0,    0,    0, 1250, 1249, 1251,    0, 1869, 1869,
    0, 1869, 1869, 1869,    0,    0,    0,    0, 1869, 1869,
 1869, 1869, 1869,    0, 1869,    0,    0, 1869, 1869,    0,
    0,    0, 1869, 1869,    0,    0, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869,    0, 1869,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869, 1869, 1869,    0, 1869, 1869,
 1869, 1869, 1869, 1869,    0, 1869, 1869, 1869, 1869,    0,
 1869,    0, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
    0, 1869, 1869, 1869, 1869,    0, 1869, 1869, 1869, 1869,
 1869,    0, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869, 1869,
 1869, 1870, 1869, 1869, 1869, 1869,    0, 1869, 1869, 1869,
 1869, 1869, 1869,    0,    0, 1869, 1869, 1869, 1869, 1869,
 1869, 1869, 1869, 1869,    0,    0,    0,    0,    0, 1869,
    0, 1869, 1869, 1869, 1869, 1869, 1869,    0, 1869,    0,
    0, 1677, 1870, 1870, 1870, 1870, 1870, 1870, 1870,    0,
    0,    0,    0,    0,    0,    0, 1234,    0,    0, 1870,
 1870, 1870, 1870, 1870,    0, 1235,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1236,    0,
    0,    0,    0,    0,    0,    0,    0,  107,    0,    0,
    0,    0, 1870,  108, 1870,    0,    0,  109,  110,    0,
    0,    0,    0,  111,    0,    0,  112,    0,    0,    0,
    0,    0, 1237,    0,    0,    0,  113,    0,    0, 1238,
    0,    0,    0,    0,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1240,    0, 1241,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1242,    0, 1243, 1244,
 1245,    0,    0,    0,    0, 1246,    0,    0,    0,    0,
    0,    0,    0,    0,  114,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  115,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  116,    0, 1247,    0,  117,    0,
    0,    0,    0,  118,    0,    0,    0,    0,    0,  119,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  120,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1870,    0,
 1870,    0,    0, 1870,    0, 1870, 1870,    0,    0, 1870,
 1870,    0, 1870,    0,    0,    0,    0,    0, 1870,    0,
 1870, 1870, 1870, 1870,    0, 1870,    0,    0, 1870,    0,
    0, 1870,    0,  121,    0,    0,  122,    0, 1870,    0,
 1870, 1870,    0, 1870, 1870, 1870, 1870, 1870,    0,    0,
 1870,    0,    0, 1870,    0, 1870, 1870,    0,    0, 1870,
 1870, 1870,    0, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
    0,    0,    0, 1870, 1870, 1870, 1870, 1870,    0,  123,
    0, 1870,    0,    0,    0,    0,    0,    0,    0, 1870,
 1870, 1870, 1870, 1870, 1870,    0,    0,    0, 1870, 1870,
    0, 1870,    0, 1870,    0, 1870, 1870, 1870,    0, 1870,
    0, 1870, 1870, 1870,    0, 1870, 1870, 1870, 1870, 1870,
    0, 1870, 1870,  124,    0,    0,    0, 1870,    0, 1870,
 1870,    0, 1248, 1870, 1870, 1870,    0,    0, 1870,    0,
 1870,    0,  125, 1870, 1870, 1870, 1870,    0, 1870,    0,
 1870,    0, 1870, 1870, 1870, 1870, 1870,    0,    0, 1870,
 1870, 1870,    0, 1870, 1870,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1870, 1870, 1870,    0, 1870, 1870,
 1870,    0, 1870,    0,    0,    0, 1870,    0, 1870, 1870,
 1870, 1870, 2009, 1870,    0, 1870, 1870, 1870, 1870, 1870,
 1870, 1870, 1870,    0,    0,    0,    0,    0, 1250, 1249,
 1251,    0, 1870, 1870,    0, 1870, 1870, 1870,    0,    0,
    0,    0, 1870, 1870, 1870, 1870, 1870,    0, 1870,    0,
    0, 1870, 1870,    0,    0,    0, 1870, 1870,    0,    0,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,    0,
 1870,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
 1870,    0, 1870, 1870, 1870, 1870, 1870, 1870,    0, 1870,
 1870, 1870, 1870,    0, 1870,    0, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870,    0, 1870, 1870, 1870, 1870,    0,
 1870, 1870, 1870, 1870, 1870,    0, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,
 1870, 1870, 1870, 1870, 1870, 1871, 1870, 1870, 1870, 1870,
    0, 1870, 1870, 1870, 1870, 1870, 1870,    0,    0, 1870,
 1870, 1870, 1870, 1870, 1870, 1870, 1870, 1870,    0,    0,
    0,    0,    0, 1870,    0, 1870, 1870, 1870, 1870, 1870,
 1870,    0, 1870,    0,    0, 1678, 1871, 1871, 1871, 1871,
 1871, 1871, 1871,    0,    0,    0,    0,    0,    0,    0,
 1234,    0,    0, 1871, 1871, 1871, 1871, 1871,    0, 1235,
    0,    0, 1886,    0,    0,    0,    0,    0, 1887,    0,
    0,    0, 1236,    0,    0,    0,    0,    0, 1888,    0,
    0,    0,    0,    0,    0,    0, 1871,    0, 1871,    0,
    0, 1889,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1237,    0,    0,    0,
    0,    0,    0, 1238,    0,    0,    0,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
 1241,    0,    0,    0,    0,    0,    0,    0,    0, 1890,
 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1891,
    0,    0,    0, 1892,    0,    0,    0,    0, 1893,    0,
    0,    0,    0,    0, 1894,    0,    0,    0,    0,    0,
 1247,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1895,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1871,    0, 1871,    0,    0, 1871,    0, 1871,
 1871,    0,    0, 1871, 1871,    0, 1871,    0, 1896,    0,
    0, 1897, 1871,    0, 1871, 1871, 1871, 1871,    0, 1871,
    0,    0, 1871,    0,    0, 1871,    0,    0,    0,    0,
    0,    0, 1871,    0, 1871, 1871,    0, 1871, 1871, 1871,
 1871, 1871,    0,    0, 1871,    0,    0, 1871,    0, 1871,
 1871,    0,    0, 1871, 1871, 1871,    0, 1871, 1871, 1871,
 1871, 1871, 1871, 1871,    0,    0,    0, 1871, 1871, 1871,
 1871, 1871,    0,    0,    0, 1871,    0,    0,    0,    0,
    0,    0,    0, 1871, 1871, 1871, 1871, 1871, 1871,    0,
    0,    0, 1871, 1871,    0, 1871,    0, 1871, 1898, 1871,
 1871, 1871,    0, 1871,    0, 1871, 1871, 1871,    0, 1871,
 1871, 1871, 1871, 1871,    0, 1871, 1871, 1899,    0,    0,
    0, 1871,    0, 1871, 1871,    0, 1248, 1871, 1871, 1871,
    0,    0, 1871,    0, 1871,    0,    0, 1871, 1871, 1871,
 1871,    0, 1871,    0, 1871,    0, 1871, 1871, 1871, 1871,
 1871,    0,    0, 1871, 1871, 1871,    0, 1871, 1871,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1871, 1871,
 1871,    0, 1871, 1871, 1871,    0, 1871,    0,    0,    0,
 1871,    0, 1871, 1871, 1871, 1871, 2337, 1871,    0, 1871,
 1871, 1871, 1871, 1871, 1871, 1871, 1871,    0,    0,    0,
    0,    0, 1250, 1249, 1251,    0, 1871, 1871,    0, 1871,
 1871, 1871,    0,    0,    0,    0, 1871, 1871, 1871, 1871,
 1871,    0, 1871,    0,    0, 1871, 1871,    0,    0,    0,
 1871, 1871,    0,    0, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871,    0, 1871,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871, 1871, 1871,    0, 1871, 1871, 1871, 1871,
 1871, 1871,    0, 1871, 1871, 1871, 1871,    0, 1871,    0,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871,    0, 1871,
 1871, 1871, 1871,    0, 1871, 1871, 1871, 1871, 1871,    0,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1871, 1873,
 1871, 1871, 1871, 1871,    0, 1871, 1871, 1871, 1871, 1871,
 1871,    0,    0, 1871, 1871, 1871, 1871, 1871, 1871, 1871,
 1871, 1871,    0,    0,    0,    0,    0, 1871,    0, 1871,
 1871, 1871, 1871, 1871, 1871,    0, 1871,    0,    0, 1679,
 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,    0,
    0,    0,    0,    0, 1234,    0,    0, 1873, 1873, 1873,
 1873, 1873,    0, 1235,    0,    0, 1900,    0,    0,    0,
    0,    0, 1901,    0,    0,    0, 1236,    0,    0,    0,
    0,    0, 1902,    0,    0,    0,    0,    0,    0,    0,
 1873,    0, 1873,    0,    0, 1903,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1237,    0,    0,    0,    0,    0,    0, 1238,    0,    0,
    0,    0,    0,    0,    0, 1239,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1240,    0, 1241,    0,    0,    0,    0,    0,
    0,    0,    0, 1904, 1242,    0, 1243, 1244, 1245,    0,
    0,    0,    0, 1246,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1905,    0,    0,    0, 1906,    0,    0,
    0,    0, 1907,    0,    0,    0,    0,    0, 1908,    0,
    0,    0,    0,    0, 1247,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1909,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1873,    0, 1873,    0,
    0, 1873,    0, 1873, 1873,    0,    0, 1873, 1873,    0,
 1873,    0, 1910,    0,    0, 1911, 1873,    0, 1873, 1873,
 1873, 1873,    0, 1873,    0,    0, 1873,    0,    0, 1873,
    0,    0,    0,    0,    0,    0, 1873,    0, 1873, 1873,
    0, 1873, 1873, 1873, 1873, 1873,    0,    0, 1873,    0,
    0, 1873,    0, 1873, 1873,    0,    0, 1873, 1873, 1873,
    0, 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,
    0, 1873, 1873, 1873, 1873, 1873,    0,    0,    0, 1873,
    0,    0,    0,    0,    0,    0,    0, 1873, 1873, 1873,
 1873, 1873, 1873,    0,    0,    0, 1873, 1873,    0, 1873,
    0, 1873, 1912, 1873, 1873, 1873,    0, 1873,    0, 1873,
 1873, 1873,    0, 1873, 1873, 1873, 1873, 1873,    0, 1873,
 1873, 1913,    0,    0,    0, 1873,    0, 1873, 1873,    0,
 1248, 1873, 1873, 1873,    0,    0, 1873,    0, 1873,    0,
    0, 1873, 1873, 1873, 1873,    0, 1873,    0, 1873,    0,
 1873, 1873, 1873, 1873, 1873,    0,    0, 1873, 1873, 1873,
    0, 1873, 1873,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1873, 1873, 1873,    0, 1873, 1873, 1873,    0,
 1873,    0,    0,    0, 1873,    0, 1873, 1873, 1873, 1873,
 2612, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873,    0,    0,    0,    0,    0, 1250, 1249, 1251,    0,
 1873, 1873,    0, 1873, 1873, 1873,    0,    0,    0,    0,
 1873, 1873, 1873, 1873, 1873,    0, 1873,    0,    0, 1873,
 1873,    0,    0,    0, 1873, 1873,    0,    0, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0, 1873,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,    0,
 1873, 1873, 1873, 1873, 1873, 1873,    0, 1873, 1873, 1873,
 1873,    0, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873,    0, 1873, 1873, 1873, 1873,    0, 1873, 1873,
 1873, 1873, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873, 1873,
 1873, 1873, 1873, 1876, 1873, 1873, 1873, 1873,    0, 1873,
 1873, 1873, 1873, 1873, 1873,    0,    0, 1873, 1873, 1873,
 1873, 1873, 1873, 1873, 1873, 1873,    0,    0,    0,    0,
    0, 1873,    0, 1873, 1873, 1873, 1873, 1873, 1873,    0,
 1873,    0,    0, 1647, 1876, 1876, 1876, 1876, 1876, 1876,
 1876,    0,    0,    0,    0,    0,    0,    0, 1234,    0,
    0, 1876, 1876, 1876, 1876, 1876,    0, 1235,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1236,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1876,    0, 1876,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1237,    0,    0,    0,    0,    0,
    0, 1238,    0,    0,    0,    0,    0,    0,    0, 1239,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1240,    0, 1241,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1242,    0,
 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1247,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1876,    0, 1876,    0,    0, 1876,    0, 1876, 1876,    0,
    0, 1876, 1876,    0, 1876,    0,    0,    0,    0,    0,
 1876,    0, 1876, 1876, 1876, 1876,    0, 1876,    0,    0,
 1876,    0,    0, 1876,    0,    0,    0,    0,    0,    0,
 1876,    0, 1876, 1876,    0, 1876, 1876, 1876, 1876, 1876,
    0,    0, 1876,    0,    0, 1876,    0, 1876, 1876,    0,
    0, 1876, 1876, 1876,    0, 1876, 1876, 1876, 1876, 1876,
 1876, 1876,    0,    0,    0, 1876, 1876, 1876, 1876, 1876,
    0,    0,    0, 1876,    0,    0,    0,    0,    0,    0,
    0, 1876, 1876, 1876, 1876, 1876, 1876,    0,    0,    0,
 1876, 1876,    0, 1876,    0, 1876,    0, 1876, 1876, 1876,
    0, 1876,    0, 1876, 1876, 1876,    0, 1876, 1876, 1876,
 1876, 1876,    0, 1876, 1876,    0,    0,    0,    0, 1876,
    0, 1876, 1876,    0, 1248, 1876, 1876, 1876,    0,    0,
 1876,    0, 1876,    0,    0, 1876, 1876, 1876, 1876,    0,
 1876,    0, 1876,    0, 1876, 1876, 1876, 1876, 1876,    0,
    0, 1876, 1876, 1876,    0, 1876, 1876,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1876, 1876, 1876,    0,
 1876, 1876, 1876,    0, 1876,    0,    0,    0, 1876,    0,
 1876, 1876, 1876, 1876, 2617, 1876,    0, 1876, 1876, 1876,
 1876, 1876, 1876, 1876, 1876,    0,    0,    0,    0,    0,
 1250, 1249, 1251,    0, 1876, 1876,    0, 1876, 1876, 1876,
    0,    0,    0,    0, 1876, 1876, 1876, 1876, 1876,    0,
 1876,    0,    0, 1876, 1876,    0,    0,    0, 1876, 1876,
    0,    0, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876,    0, 1876,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876, 1876, 1876,    0, 1876, 1876, 1876, 1876, 1876, 1876,
    0, 1876, 1876, 1876, 1876,    0, 1876,    0, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876,    0, 1876, 1876, 1876,
 1876,    0, 1876, 1876, 1876, 1876, 1876,    0, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1882, 1876, 1876,
 1876, 1876,    0, 1876, 1876, 1876, 1876, 1876, 1876,    0,
    0, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876, 1876,
    0,    0,    0,    0,    0, 1876,    0, 1876, 1876, 1876,
 1876, 1876, 1876,    0, 1876,    0,    0, 1680, 1882, 1882,
 1882, 1882, 1882, 1882, 1882,    0,    0,    0,    0,    0,
    0,    0, 1234,    0,    0, 1882, 1882, 1882, 1882, 1882,
    0, 1235,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1236,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1882,    0,
 1882,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1237,    0,
    0,    0,    0,    0,    0, 1238,    0,    0,    0,    0,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0, 1241,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,
    0, 1246,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1247,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1882,    0, 1882,    0,    0, 1882,
    0, 1882, 1882,    0,    0, 1882, 1882,    0, 1882,    0,
    0,    0,    0,    0, 1882,    0, 1882, 1882, 1882, 1882,
    0, 1882,    0,    0, 1882,    0,    0, 1882,    0,    0,
    0,    0,    0,    0, 1882,    0, 1882, 1882,    0, 1882,
 1882, 1882, 1882, 1882,    0,    0, 1882,    0,    0, 1882,
    0, 1882, 1882,    0,    0, 1882, 1882, 1882,    0, 1882,
 1882, 1882, 1882, 1882, 1882, 1882,    0,    0,    0, 1882,
 1882, 1882, 1882, 1882,    0,    0,    0, 1882,    0,    0,
    0,    0,    0,    0,    0, 1882, 1882, 1882, 1882, 1882,
 1882,    0,    0,    0, 1882, 1882,    0, 1882,    0, 1882,
    0, 1882, 1882, 1882,    0, 1882,    0, 1882, 1882, 1882,
    0, 1882, 1882, 1882, 1882, 1882,    0, 1882, 1882,    0,
    0,    0,    0, 1882,    0, 1882, 1882,    0, 1248, 1882,
 1882, 1882,    0,    0, 1882,    0, 1882,    0,    0, 1882,
 1882, 1882, 1882,    0, 1882,    0, 1882,    0, 1882, 1882,
 1882, 1882, 1882,    0,    0, 1882, 1882, 1882,    0, 1882,
 1882,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1882, 1882, 1882,    0, 1882, 1882, 1882,    0, 1882,    0,
    0,    0, 1882,    0, 1882, 1882, 1882, 1882, 2619, 1882,
    0, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,    0,
    0,    0,    0,    0, 1250, 1249, 1251,    0, 1882, 1882,
    0, 1882, 1882, 1882,    0,    0,    0,    0, 1882, 1882,
 1882, 1882, 1882,    0, 1882,    0,    0, 1882, 1882,    0,
    0,    0, 1882, 1882,    0,    0, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882,    0, 1882,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882, 1882, 1882,    0, 1882, 1882,
 1882, 1882, 1882, 1882,    0, 1882, 1882, 1882, 1882,    0,
 1882,    0, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
    0, 1882, 1882, 1882, 1882,    0, 1882, 1882, 1882, 1882,
 1882,    0, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882, 1882,
 1882, 1889, 1882, 1882, 1882, 1882,    0, 1882, 1882, 1882,
 1882, 1882, 1882,    0,    0, 1882, 1882, 1882, 1882, 1882,
 1882, 1882, 1882, 1882,    0,    0,    0,    0,    0, 1882,
    0, 1882, 1882, 1882, 1882, 1882, 1882,    0, 1882,    0,
    0, 1641, 1889, 1889, 1889, 1889, 1889, 1889, 1889,    0,
    0,    0,    0,    0,    0,    0, 1234,    0,    0, 1889,
 1889, 1889, 1889, 1889,    0, 1235,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1236,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1889,    0, 1889,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1237,    0,    0,    0,    0,    0,    0, 1238,
    0,    0,    0,    0,    0,    0,    0, 1239,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1240,    0, 1241,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1242,    0, 1243, 1244,
 1245,    0,    0,    0,    0, 1246,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1247,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1889,    0,
 1889,    0,    0, 1889,    0, 1889, 1889,    0,    0, 1889,
 1889,    0, 1889,    0,    0,    0,    0,    0, 1889,    0,
 1889, 1889, 1889, 1889,    0, 1889,    0,    0, 1889,    0,
    0, 1889,    0,    0,    0,    0,    0,    0, 1889,    0,
 1889, 1889,    0, 1889, 1889, 1889, 1889, 1889,    0,    0,
 1889,    0,    0, 1889,    0, 1889, 1889,    0,    0, 1889,
 1889, 1889,    0, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
    0,    0,    0, 1889, 1889, 1889, 1889, 1889,    0,    0,
    0, 1889,    0,    0,    0,    0,    0,    0,    0, 1889,
 1889, 1889, 1889, 1889, 1889,    0,    0,    0, 1889, 1889,
    0, 1889,    0, 1889,    0, 1889, 1889, 1889,    0, 1889,
    0, 1889, 1889, 1889,    0, 1889, 1889, 1889, 1889, 1889,
    0, 1889, 1889,    0,    0,    0,    0, 1889,    0, 1889,
 1889,    0, 1248, 1889, 1889, 1889,    0,    0, 1889,    0,
 1889,    0,    0, 1889, 1889, 1889, 1889,    0, 1889,    0,
 1889,    0, 1889, 1889, 1889, 1889, 1889,    0,    0, 1889,
 1889, 1889,    0, 1889, 1889,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1889, 1889, 1889,    0, 1889, 1889,
 1889,    0, 1889,    0,    0,    0, 1889,    0, 1889, 1889,
 1889, 1889, 2620, 1889,    0, 1889, 1889, 1889, 1889, 1889,
 1889, 1889, 1889,    0,    0,    0,    0,    0, 1250, 1249,
 1251,    0, 1889, 1889,    0, 1889, 1889, 1889,    0,    0,
    0,    0, 1889, 1889, 1889, 1889, 1889,    0, 1889,    0,
    0, 1889, 1889,    0,    0,    0, 1889, 1889,    0,    0,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,    0,
 1889,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
 1889,    0, 1889, 1889, 1889, 1889, 1889, 1889,    0, 1889,
 1889, 1889, 1889,    0, 1889,    0, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889,    0, 1889, 1889, 1889, 1889,    0,
 1889, 1889, 1889, 1889, 1889,    0, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,
 1889, 1889, 1889, 1889, 1889, 1964, 1889, 1889, 1889, 1889,
    0, 1889, 1889, 1889, 1889, 1889, 1889,    0,    0, 1889,
 1889, 1889, 1889, 1889, 1889, 1889, 1889, 1889,    0,    0,
    0,    0,    0, 1889,    0, 1889, 1889, 1889, 1889, 1889,
 1889,    0, 1889,    0,    0, 1666, 1964, 1964, 1964, 1964,
 1964, 1964, 1964,    0,    0,    0,    0,    0,    0,    0,
 1234,    0,    0, 1964, 1964, 1964, 1964, 1964,    0, 1235,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1236,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1964,    0, 1964,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1237,    0,    0,    0,
    0,    0,    0, 1238,    0,    0,    0,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1240,    0,
 1241,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1247,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1964,    0, 1964,    0,    0, 1964,    0, 1964,
 1964,    0,    0, 1964, 1964,    0, 1964,    0,    0,    0,
    0,    0, 1964,    0, 1964, 1964, 1964, 1964,    0, 1964,
    0,    0, 1964,    0,    0, 1964,    0,    0,    0,    0,
    0,    0, 1964,    0, 1964, 1964,    0, 1964, 1964, 1964,
 1964, 1964,    0,    0, 1964,    0,    0, 1964,    0, 1964,
 1964,    0,    0, 1964, 1964, 1964,    0, 1964, 1964, 1964,
 1964, 1964, 1964, 1964,    0,    0,    0, 1964, 1964, 1964,
 1964, 1964,    0,    0,    0, 1964,    0,    0,    0,    0,
    0,    0,    0, 1964, 1964, 1964, 1964, 1964, 1964,    0,
    0,    0, 1964, 1964,    0, 1964,    0, 1964,    0, 1964,
 1964, 1964,    0, 1964,    0, 1964, 1964, 1964,    0, 1964,
 1964, 1964, 1964, 1964,    0, 1964, 1964,    0,    0,    0,
    0, 1964,    0, 1964, 1964,    0, 1248, 1964, 1964, 1964,
    0,    0, 1964,    0, 1964,    0,    0, 1964, 1964, 1964,
 1964,    0, 1964,    0, 1964,    0, 1964, 1964, 1964, 1964,
 1964,    0,    0, 1964, 1964, 1964,    0, 1964, 1964,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1964, 1964,
 1964,    0, 1964, 1964, 1964,    0, 1964,    0,    0,    0,
 1964,    0, 1964, 1964, 1964, 1964, 1475, 1964,    0, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0,    0,    0,
    0,    0, 1475, 1475, 1475,    0, 1964, 1964,    0, 1964,
 1964, 1964,    0,    0,    0,    0, 1964, 1964, 1964, 1964,
 1964,    0, 1964,    0,    0, 1964, 1964,    0,    0,    0,
 1964, 1964,    0,    0, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964,    0, 1964,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964,    0, 1964, 1964, 1964, 1964,
 1964, 1964,    0, 1964, 1964, 1964, 1964,    0, 1964,    0,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,    0, 1964,
 1964, 1964, 1964,    0, 1964, 1964, 1964, 1964, 1964,    0,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1964, 1965,
 1964, 1964, 1964, 1964,    0, 1964, 1964, 1964, 1964, 1964,
 1964,    0,    0, 1964, 1964, 1964, 1964, 1964, 1964, 1964,
 1964, 1964,    0,    0,    0,    0,    0, 1964,    0, 1964,
 1964, 1964, 1964, 1964, 1964,    0, 1964,    0,    0, 1667,
 1965, 1965, 1965, 1965, 1965, 1965, 1965,    0,    0,    0,
    0,    0,    0,    0, 1475,    0,    0, 1965, 1965, 1965,
 1965, 1965,    0, 1475,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1475,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1965,    0, 1965,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1475,    0,    0,    0,    0,    0,    0, 1475,    0,    0,
    0,    0,    0,    0,    0, 1475,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1475,    0, 1475,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1475,    0, 1475, 1475, 1475,    0,
    0,    0,    0, 1475,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1475,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1965,    0, 1965,    0,
    0, 1965,    0, 1965, 1965,    0,    0, 1965, 1965,    0,
 1965,    0,    0,    0,    0,    0, 1965,    0, 1965, 1965,
 1965, 1965,    0, 1965,    0,    0, 1965,    0,    0, 1965,
    0,    0,    0,    0,    0,    0, 1965,    0, 1965, 1965,
    0, 1965, 1965, 1965, 1965, 1965,    0,    0, 1965,    0,
    0, 1965,    0, 1965, 1965,    0,    0, 1965, 1965, 1965,
    0, 1965, 1965, 1965, 1965, 1965, 1965, 1965,    0,    0,
    0, 1965, 1965, 1965, 1965, 1965,    0,    0,    0, 1965,
    0,    0,    0,    0,    0,    0,    0, 1965, 1965, 1965,
 1965, 1965, 1965,    0,    0,    0, 1965, 1965,    0, 1965,
    0, 1965,    0, 1965, 1965, 1965,    0, 1965,    0, 1965,
 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965,    0, 1965,
 1965,    0,    0,    0,    0, 1965,    0, 1965, 1965,    0,
 1475, 1965, 1965, 1965,    0,    0, 1965,    0, 1965,    0,
    0, 1965, 1965, 1965, 1965,    0, 1965,    0, 1965,    0,
 1965, 1965, 1965, 1965, 1965,    0,    0, 1965, 1965, 1965,
    0, 1965, 1965,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1965, 1965, 1965,    0, 1965, 1965, 1965,    0,
 1965,    0,    0,    0, 1965,    0, 1965, 1965, 1965, 1965,
 1474, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965,    0,    0,    0,    0,    0, 1474, 1474, 1474,    0,
 1965, 1965,    0, 1965, 1965, 1965,    0,    0,    0,    0,
 1965, 1965, 1965, 1965, 1965,    0, 1965,    0,    0, 1965,
 1965,    0,    0,    0, 1965, 1965,    0,    0, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965,    0, 1965,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,    0,
 1965, 1965, 1965, 1965, 1965, 1965,    0, 1965, 1965, 1965,
 1965,    0, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965,    0, 1965, 1965, 1965, 1965,    0, 1965, 1965,
 1965, 1965, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965, 1965,
 1965, 1965, 1965, 1950, 1965, 1965, 1965, 1965,    0, 1965,
 1965, 1965, 1965, 1965, 1965,    0,    0, 1965, 1965, 1965,
 1965, 1965, 1965, 1965, 1965, 1965,    0,    0,    0,    0,
    0, 1965,    0, 1965, 1965, 1965, 1965, 1965, 1965,    0,
 1965,    0,    0, 1632, 1950, 1950, 1950, 1950, 1950, 1950,
 1950,    0,    0,    0,    0,    0,    0,    0, 1474,    0,
    0, 1950, 1950, 1950, 1950, 1950,    0, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1474,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1950,    0, 1950,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1474,    0,    0,    0,    0,    0,
    0, 1474,    0,    0,    0,    0,    0,    0,    0, 1474,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1474,    0, 1474,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1474,    0,
 1474, 1474, 1474,    0,    0,    0,    0, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1474,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1950,    0, 1950,    0,    0, 1950,    0, 1950, 1950,    0,
    0, 1950, 1950,    0, 1950,    0,    0,    0,    0,    0,
 1950,    0, 1950, 1950, 1950, 1950,    0, 1950,    0,    0,
 1950,    0,    0, 1950,    0,    0,    0,    0,    0,    0,
 1950,    0, 1950, 1950,    0, 1950, 1950, 1950, 1950, 1950,
    0,    0, 1950,    0,    0, 1950,    0, 1950, 1950,    0,
    0, 1950, 1950, 1950,    0, 1950, 1950, 1950, 1950, 1950,
 1950, 1950,    0,    0,    0, 1950, 1950, 1950, 1950, 1950,
    0,    0,    0, 1950,    0,    0,    0,    0,    0,    0,
    0, 1950, 1950, 1950, 1950, 1950, 1950,    0,    0,    0,
 1950, 1950,    0, 1950,    0, 1950,    0, 1950, 1950, 1950,
    0, 1950,    0, 1950, 1950, 1950,    0, 1950, 1950, 1950,
 1950, 1950,    0, 1950, 1950,    0,    0,    0,    0, 1950,
    0, 1950, 1950,    0, 1474, 1950, 1950, 1950,    0,    0,
 1950,    0, 1950,    0,    0, 1950, 1950, 1950, 1950,    0,
 1950,    0, 1950,    0, 1950, 1950, 1950, 1950, 1950,    0,
    0, 1950, 1950, 1950,    0, 1950, 1950,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1950, 1950, 1950,    0,
 1950, 1950, 1950,    0, 1950,    0,    0,    0, 1950,    0,
 1950, 1950, 1950, 1950,    0, 1950,    0, 1950, 1950, 1950,
 1950, 1950, 1950, 1950, 1950,    0,    0,    0,    0,    0,
 1250, 1249, 1251,    0, 1950, 1950,    0, 1950, 1950, 1950,
    0,    0,    0,    0, 1950, 1950, 1950, 1950, 1950,    0,
 1950,    0,    0, 1950, 1950,    0,    0,    0, 1950, 1950,
    0,    0, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950,    0, 1950,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950, 1950, 1950,    0, 1950, 1950, 1950, 1950, 1950, 1950,
    0, 1950, 1950, 1950, 1950,    0, 1950,    0, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950,    0, 1950, 1950, 1950,
 1950,    0, 1950, 1950, 1950, 1950, 1950,    0, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1951, 1950, 1950,
 1950, 1950,    0, 1950, 1950, 1950, 1950, 1950, 1950,    0,
    0, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950, 1950,
    0,    0,    0,    0,    0, 1950,    0, 1950, 1950, 1950,
 1950, 1950, 1950,    0, 1950,    0,    0, 1636, 1951, 1951,
 1951, 1951, 1951, 1951, 1951,    0,    0,    0,    0,    0,
    0,    0, 1234,    0,    0, 1951, 1951, 1951, 1951, 1951,
    0, 1235,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1236,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1951,    0,
 1951,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1237,    0,
    0,    0,    0,    0,    0, 1238,    0,    0,    0,    0,
    0,    0,    0, 1239,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1240,    0, 1241,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,
    0, 1246,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1247,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1499, 1500, 1501, 1502, 1503, 1504,
 1505, 1506,    0,    0, 1951,    0, 1951,    0,    0, 1951,
    0, 1951, 1951,    0,    0, 1951, 1951,    0, 1951,    0,
    0,    0,    0,    0, 1951,    0, 1951, 1951, 1951, 1951,
    0, 1951,    0,    0, 1951,    0,    0, 1951,    0,    0,
    0,    0,    0,    0, 1951,    0, 1951, 1951,    0, 1951,
 1951, 1951, 1951, 1951,    0,    0, 1951,    0,    0, 1951,
    0, 1951, 1951,    0,    0, 1951, 1951, 1951,    0, 1951,
 1951, 1951, 1951, 1951, 1951, 1951,    0,    0,    0, 1951,
 1951, 1951, 1951, 1951,    0,    0,    0, 1951,    0,    0,
    0,    0,    0,    0,    0, 1951, 1951, 1951, 1951, 1951,
 1951,    0,    0, 1507, 1951, 1951,    0, 1951,    0, 1951,
    0, 1951, 1951, 1951,    0, 1951,    0, 1951, 1951, 1951,
    0, 1951, 1951, 1951, 1951, 1951,    0, 1951, 1951, 1508,
    0,    0,    0, 1951,    0, 1951, 1951,    0, 1248, 1951,
 1951, 1951,    0,    0, 1951,    0, 1951,    0,    0, 1951,
 1951, 1951, 1951,    0, 1951,    0, 1951,    0, 1951, 1951,
 1951, 1951, 1951,    0,    0, 1951, 1951, 1951,    0, 1951,
 1951,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1951, 1951, 1951,    0, 1951, 1951, 1951,    0, 1951,    0,
    0,    0, 1951,    0, 1951, 1951, 1951, 1951,    0, 1951,
    0, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,    0,
    0,    0,    0, 1250, 1249, 1251,    0,    0, 1951, 1951,
    0, 1951, 1951, 1951,    0,    0,    0,    0, 1951, 1951,
 1951, 1951, 1951,    0, 1951,    0,    0, 1951, 1951, 1250,
 1249, 1251, 1951, 1951,    0,    0, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951,    0, 1951,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951, 1951, 1951,    0, 1951, 1951,
 1951, 1951, 1951, 1951,    0, 1951, 1951, 1951, 1951,    0,
 1951,    0, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
    0, 1951, 1951, 1951, 1951,    0, 1951, 1951, 1951, 1951,
 1951,    0, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951, 1951,
 1951, 1952, 1951, 1951, 1951, 1951,    0, 1951, 1951, 1951,
 1951, 1951, 1951,    0,    0, 1951, 1951, 1951, 1951, 1951,
 1951, 1951, 1951, 1951,    0,    0,    0,    0,    0, 1951,
    0, 1951, 1951, 1951, 1951, 1951, 1951,    0, 1951,    0,
    0, 1639, 1952, 1952, 1952, 1952, 1952, 1952, 1952,    0,
    0,    0,    0,    0,    0, 1234,    0,    0,    0, 1952,
 1952, 1952, 1952, 1952, 1235,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1236,    0,    0,
    0, 1234,    0,    0,    0,    0,    0,    0,    0,    0,
 1235,    0, 1952,    0, 1952,    0,    0,    0,    0,    0,
    0,    0,    0, 1236,    0,    0,    0,    0,    0,    0,
    0, 1237,    0,    0,    0,    0,    0,    0, 1238,    0,
    0,    0,    0,    0,    0,    0, 1239,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1237,    0,    0,
    0,    0,    0, 1240, 1238, 1241,    0,    0,    0,    0,
    0,    0, 1239,    0,    0, 1242,    0, 1243, 1244, 1245,
    0,    0,    0,    0, 1246,    0,    0,    0,    0, 1240,
    0, 1241,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0,
 1246,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1247,    0,    0,    0,    0,
    0,    0, 1702,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1247,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1952,    0,
 1952,    0,    0, 1952,    0, 1952, 1952,    0,    0, 1952,
 1952,    0, 1952,    0,    0,    0,    0,    0, 1952,    0,
 1952, 1952, 1952, 1952,    0, 1952,    0,    0, 1952,    0,
    0, 1952,    0,    0,    0,    0,    0,    0, 1952,    0,
 1952, 1952,    0, 1952, 1952, 1952, 1952, 1952,    0,    0,
 1952,    0,    0, 1952,    0, 1952, 1952,    0,    0, 1952,
 1952, 1952,    0, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
    0,    0,    0, 1952, 1952, 1952, 1952, 1952,    0,    0,
    0, 1952,    0,    0,    0,    0,    0,    0,    0, 1952,
 1952, 1952, 1952, 1952, 1952,    0,    0,    0, 1952, 1952,
    0, 1952,    0, 1952,    0, 1952, 1952, 1952,    0, 1952,
    0, 1952, 1952, 1952,    0, 1952, 1952, 1952, 1952, 1952,
    0, 1952, 1952,    0,    0,    0,    0, 1952, 1986, 1952,
 1952, 1248,    0, 1952, 1952, 1952,    0,    0, 1952,    0,
 1952,    0,    0, 1952, 1952, 1952, 1952,    0, 1952,    0,
 1952,    0, 1952, 1952, 1952, 1952, 1952, 1248,    0, 1952,
 1952, 1952,    0, 1952, 1952,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1952, 1952, 1952,    0, 1952, 1952,
 1952,    0, 1952,    0,    0,    0, 1952,    0, 1952, 1952,
 1952, 1952,    0, 1952,    0, 1952, 1952, 1952, 1952, 1952,
 1952, 1952, 1952,    0,    0,    0,    0, 1250, 1249, 1251,
    0,    0, 1952, 1952,    0, 1952, 1952, 1952, 1250, 1249,
 1251,    0, 1952, 1952, 1952, 1952, 1952,    0, 1952,    0,
    0, 1952, 1952,    0,    0,    0, 1952, 1952,    0,    0,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,    0,
 1952,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
 1952,    0, 1952, 1952, 1952, 1952, 1952, 1952,    0, 1952,
 1952, 1952, 1952,    0, 1952,    0, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952,    0, 1952, 1952, 1952, 1952,    0,
 1952, 1952, 1952, 1952, 1952,    0, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,
 1952, 1952, 1952, 1952, 1952, 1790, 1952, 1952, 1952, 1952,
    0, 1952, 1952, 1952, 1952, 1952, 1952,    0,    0, 1952,
 1952, 1952, 1952, 1952, 1952, 1952, 1952, 1952,    0,    0,
    0,    0,    0, 1952,    0, 1952, 1952, 1952, 1952, 1952,
 1952,    0, 1952,    0,    0,    0, 1790, 1790, 1790, 1790,
 1790, 1790, 1790,    0,    0,    0,    0,    0,    0, 1234,
    0,    0,    0, 1790, 1790, 1790, 1790, 1790, 1235,    0,
 1234,    0,    0,    0,    0,   60,    0,    0,    0, 1235,
    0, 1236,    0,    0,    0,    0,    0,    0,   61,    0,
   62,    0, 1236,    0,    0,    0, 1790,    0, 1790,    0,
   63,    0, 2606,    0,    0,    0,   64,    0,    0,    0,
   65,    0,    0,    0,    0, 1237,   66,    0,    0,   67,
    0,    0, 1238,    0,    0,    0, 1237,    0,    0,   68,
 1239,    0,    0, 1238,    0,    0,    0,    0,    0,    0,
    0, 1239,    0,    0,    0,    0,    0, 1240,    0, 1241,
    0,    0,    0,    0,    0,    0,    0,    0, 1240, 1242,
 1241, 1243, 1244, 1245,    0,    0,    0,    0, 1246,    0,
 1242,    0, 1243, 1244, 1245,    0,    0,    0,    0, 1246,
    0,    0,    0,    0,    0,    0,    0,   69,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1247,
    0,    0,    0,    0,    0,    0,    0,   70,    0,    0,
 1247,   71,    0,    0,    0,    0,   72, 2618,    0,    0,
    0,    0,   73,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   74,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1790,    0, 1790,    0,    0, 1790,    0, 1790,
 1790,    0,    0, 1790, 1790,    0, 1790,    0,    0,    0,
    0,    0, 1790,    0, 1790, 1790, 1790, 1790,    0, 1790,
    0,    0, 1790,    0,    0, 1790,    0,    0,    0,    0,
    0,    0, 1790,    0, 1790, 1790,   75, 1790, 1790, 1790,
 1790, 1790,    0,    0, 1790,    0,    0, 1790,    0, 1790,
 1790,    0,    0, 1790, 1790, 1790,    0, 1790, 1790, 1790,
 1790, 1790, 1790, 1790,    0,    0,    0, 1790, 1790, 1790,
 1790, 1790,    0,    0,    0, 1790,    0,    0,    0,    0,
    0,    0,   76, 1790, 1790, 1790, 1790, 1790, 1790,    0,
    0,    0, 1790, 1790,    0, 1790,    0, 1790,    0, 1790,
 1790, 1790,    0, 1790,    0, 1790, 1790, 1790,    0, 1790,
 1790, 1790, 1790, 1790,    0, 1790, 1790,    0,    0,    0,
    0, 1790,    0, 1790, 1790, 1248,   77, 1790, 1790, 1790,
    0,    0, 1790,    0, 1790,    0, 1248, 1790, 1790, 1790,
 1790,    0, 1790,    0, 1790,   78, 1790, 1790, 1790, 1790,
 1790,    0,    0, 1790, 1790, 1790,    0, 1790, 1790,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1790, 1790,
 1790,    0, 1790, 1790, 1790,    0, 1790,    0,    0,    0,
 1790,    0, 1790, 1790, 1790, 1790,    0, 1790,    0, 1790,
 1790, 1790, 1790, 1790, 1790, 1790, 1790,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1790, 1790,    0, 1790,
 1790, 1790,    0,    0,    0,    0, 1790, 1790, 1790, 1790,
 1790,    0, 1790,    0,    0, 1790, 1790,    0,    0,    0,
 1790, 1790,    0,    0, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790,    0, 1790,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790, 1790, 1790,    0, 1790, 1790, 1790, 1790,
 1790, 1790,    0, 1790, 1790, 1790, 1790,    0, 1790,    0,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790,    0, 1790,
 1790, 1790, 1790,    0, 1790, 1790, 1790, 1790, 1790,    0,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1790, 1835,
 1790, 1790, 1790, 1790,    0, 1790, 1790, 1790, 1790, 1790,
 1790,    0,    0, 1790, 1790, 1790, 1790, 1790, 1790, 1790,
 1790, 1790,    0,    0,    0,    0,    0, 1790,    0, 1790,
 1790, 1790, 1790, 1790, 1790,    0, 1790,    0,    0,    0,
 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1835, 1835, 1835,
 1835, 1835,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  612,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1835,  613, 1835,    0,    0,    0,    0,    0,    0,    0,
    0,  614,    0,    0,    0,    0,    0,  615,    0,    0,
    0,  616,  617,    0,    0,    0,    0,  618,    0,    0,
  619,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  620,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  621,    0,    0,    0,    0,    0,    0,    0,  622,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  623,    0,
    0,    0,  624,    0,    0,    0,    0,  625,    0,    0,
    0,    0,    0,  626,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  627,  628,    0,    0,    0, 1835,    0, 1835,    0,
    0, 1835,    0, 1835, 1835,    0,    0, 1835, 1835,    0,
 1835,    0,    0,    0,    0,    0, 1835,    0, 1835, 1835,
 1835, 1835,    0, 1835,    0,    0, 1835,    0,    0, 1835,
    0,    0,    0,    0,    0,    0, 1835,    0, 1835, 1835,
    0, 1835, 1835, 1835, 1835, 1835,    0,  629, 1835,    0,
  630, 1835,    0, 1835, 1835,    0,    0, 1835, 1835, 1835,
    0, 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,    0,
    0, 1835, 1835, 1835, 1835, 1835,    0,    0,    0, 1835,
    0,    0,    0,    0,    0,    0,    0, 1835, 1835, 1835,
 1835, 1835, 1835,    0,    0,    0, 1835, 1835,    0, 1835,
    0, 1835,    0, 1835, 1835, 1835,    0, 1835,    0, 1835,
 1835, 1835,    0, 1835, 1835, 1835, 1835, 1835,    0, 1835,
 1835,    0,    0,    0,    0, 1835,    0, 1835, 1835,    0,
    0, 1835, 1835, 1835,    0,    0, 1835,    0, 1835,    0,
    0, 1835, 1835, 1835, 1835,    0, 1835,    0, 1835,    0,
 1835, 1835, 1835, 1835, 1835,    0,  631, 1835, 1835, 1835,
    0, 1835, 1835,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1835, 1835, 1835,    0, 1835, 1835, 1835,    0,
 1835,    0,    0,    0, 1835,    0, 1835, 1835, 1835, 1835,
    0, 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1835, 1835,    0, 1835, 1835, 1835,    0,    0,    0,    0,
 1835, 1835, 1835, 1835, 1835,    0, 1835,    0,    0, 1835,
 1835,    0,    0,    0, 1835, 1835,    0,    0, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0, 1835,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,    0,
 1835, 1835, 1835, 1835, 1835, 1835,    0, 1835, 1835, 1835,
 1835,    0, 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835,    0, 1835, 1835, 1835, 1835,    0, 1835, 1835,
 1835, 1835, 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835, 1835,
 1835, 1835, 1835, 1836, 1835, 1835, 1835, 1835,    0, 1835,
 1835, 1835, 1835, 1835, 1835,    0,    0, 1835, 1835, 1835,
 1835, 1835, 1835, 1835, 1835, 1835,    0,    0,    0,    0,
    0, 1835,    0, 1835, 1835, 1835, 1835, 1835, 1835,    0,
 1835,    0,    0,    0, 1836, 1836, 1836, 1836, 1836, 1836,
 1836,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1836, 1836, 1836, 1836, 1836,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   82,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   83,
    0,    0,    0,    0, 1836,   84, 1836,    0,    0,    0,
    0,    0,    0,    0,    0,   85,    0,    0,   86,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   87,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   88,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   89,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   90,    0,    0,    0,
   91,    0,    0,   92,    0,   93,    0,    0,    0,    0,
    0,   94,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   95,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1836,    0, 1836,    0,    0, 1836,    0, 1836, 1836,    0,
    0, 1836, 1836,    0, 1836,    0,    0,    0,    0,    0,
 1836,    0, 1836, 1836, 1836, 1836,    0, 1836,    0,    0,
 1836,    0,    0, 1836,    0,   96,    0,    0,   97,    0,
 1836,    0, 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836,
    0,    0, 1836,    0,    0, 1836,    0, 1836, 1836,    0,
    0, 1836, 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836,
 1836, 1836,    0,    0,    0, 1836, 1836, 1836, 1836, 1836,
    0,   98,    0, 1836,    0,    0,    0,    0,    0,    0,
    0, 1836, 1836, 1836, 1836, 1836, 1836,    0,    0,    0,
 1836, 1836,    0, 1836,    0, 1836,    0, 1836, 1836, 1836,
    0, 1836,    0, 1836, 1836, 1836,    0, 1836, 1836, 1836,
 1836, 1836,    0, 1836, 1836,   99,    0,    0,    0, 1836,
    0, 1836, 1836,    0,    0, 1836, 1836, 1836,    0,    0,
 1836,    0, 1836,    0,  100, 1836, 1836, 1836, 1836,    0,
 1836,    0, 1836,    0, 1836, 1836, 1836, 1836, 1836,    0,
    0, 1836, 1836, 1836,    0, 1836, 1836,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1836, 1836, 1836,    0,
 1836, 1836, 1836,    0, 1836,    0,    0,    0, 1836,    0,
 1836, 1836, 1836, 1836,    0, 1836,    0, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1836, 1836,    0, 1836, 1836, 1836,
    0,    0,    0,    0, 1836, 1836, 1836, 1836, 1836,    0,
 1836,    0,    0, 1836, 1836,    0,    0,    0, 1836, 1836,
    0,    0, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836,    0, 1836,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836, 1836,
    0, 1836, 1836, 1836, 1836,    0, 1836,    0, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836,    0, 1836, 1836, 1836,
 1836,    0, 1836, 1836, 1836, 1836, 1836,    0, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1854, 1836, 1836,
 1836, 1836,    0, 1836, 1836, 1836, 1836, 1836, 1836,    0,
    0, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836, 1836,
    0,    0,    0,    0,    0, 1836,    0, 1836, 1836, 1836,
 1836, 1836, 1836,    0, 1836,    0,    0,    0, 1854, 1854,
 1854, 1854, 1854, 1854, 1854,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1854, 1854, 1854, 1854, 1854,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1854,    0,
 1854,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1854,    0, 1854,    0,    0, 1854,
    0, 1854, 1854,    0,    0, 1854, 1854,    0, 1854,    0,
    0,    0,    0,    0, 1854,    0, 1854, 1854, 1854, 1854,
    0, 1854,    0,    0, 1854,    0,    0, 1854,    0,    0,
    0,    0,    0,    0, 1854,    0, 1854, 1854,    0, 1854,
 1854, 1854, 1854, 1854,    0,    0, 1854,    0,    0, 1854,
    0, 1854, 1854,    0,    0, 1854, 1854, 1854,    0, 1854,
 1854, 1854, 1854, 1854, 1854, 1854,    0,    0,    0, 1854,
 1854, 1854, 1854, 1854,    0,    0,    0, 1854,    0,    0,
    0,    0,    0,    0,    0, 1854, 1854, 1854, 1854, 1854,
 1854,    0,    0,    0, 1854, 1854,    0, 1854,    0, 1854,
    0, 1854, 1854, 1854,    0, 1854,    0, 1854, 1854, 1854,
    0, 1854, 1854, 1854, 1854, 1854,    0, 1854, 1854,    0,
    0,    0,    0, 1854,    0, 1854, 1854,    0,    0, 1854,
 1854, 1854,    0,    0, 1854,    0, 1854,    0,    0, 1854,
 1854, 1854, 1854,    0, 1854,    0, 1854,    0, 1854, 1854,
 1854, 1854, 1854,    0,    0, 1854, 1854, 1854,    0, 1854,
 1854,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1854, 1854, 1854,    0, 1854, 1854, 1854,    0, 1854,    0,
    0,    0, 1854,    0, 1854, 1854, 1854, 1854,    0, 1854,
    0, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1854, 1854,
    0, 1854, 1854, 1854,    0,    0,    0,    0, 1854, 1854,
 1854, 1854, 1854,    0, 1854,    0,    0, 1854, 1854,    0,
    0,    0, 1854, 1854,    0,    0, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854,    0, 1854,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854,    0, 1854, 1854,
 1854, 1854, 1854, 1854,    0, 1854, 1854, 1854, 1854,    0,
 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
    0, 1854, 1854, 1854, 1854,    0, 1854, 1854, 1854, 1854,
 1854,    0, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854, 1854,
 1854, 1909, 1854, 1854, 1854, 1854,    0, 1854, 1854, 1854,
 1854, 1854, 1854,    0,    0, 1854, 1854, 1854, 1854, 1854,
 1854, 1854, 1854, 1854,    0,    0,    0,    0,    0, 1854,
    0, 1854, 1854, 1854, 1854, 1854, 1854,    0, 1854,    0,
    0,    0, 1909, 1909, 1909, 1909, 1909, 1909, 1909,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1909, 1909, 1909, 1909,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1909,    0, 1909,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1909,    0,
 1909,    0,    0, 1909,    0, 1909, 1909,    0,    0, 1909,
 1909,    0, 1909,    0,    0,    0,    0,    0, 1909,    0,
 1909, 1909, 1909, 1909,    0, 1909,    0,    0, 1909,    0,
    0, 1909,    0,    0,    0,    0,    0,    0, 1909,    0,
 1909, 1909,    0, 1909, 1909, 1909, 1909, 1909,    0,    0,
 1909,    0,    0, 1909,    0, 1909, 1909,    0,    0, 1909,
 1909, 1909,    0, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
    0,    0,    0, 1909, 1909, 1909, 1909, 1909,    0,    0,
    0, 1909,    0,    0,    0,    0,    0,    0,    0, 1909,
 1909, 1909, 1909, 1909, 1909,    0,    0,    0, 1909, 1909,
    0, 1909,    0, 1909,    0, 1909, 1909, 1909,    0, 1909,
    0, 1909, 1909, 1909,    0, 1909, 1909, 1909, 1909, 1909,
    0, 1909, 1909,    0,    0,    0,    0, 1909,    0, 1909,
 1909,    0,    0, 1909, 1909, 1909,    0,    0, 1909,    0,
 1909,    0,    0, 1909, 1909, 1909, 1909,    0, 1909,    0,
 1909,    0, 1909, 1909, 1909, 1909, 1909,    0,    0, 1909,
 1909, 1909,    0, 1909, 1909,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1909, 1909, 1909,    0, 1909, 1909,
 1909,    0, 1909,    0,    0,    0, 1909,    0, 1909, 1909,
 1909, 1909,    0, 1909,    0, 1909, 1909, 1909, 1909, 1909,
 1909, 1909, 1909,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1909, 1909,    0, 1909, 1909, 1909,    0,    0,
    0,    0, 1909, 1909, 1909, 1909, 1909,    0, 1909,    0,
    0, 1909, 1909,    0,    0,    0, 1909, 1909,    0,    0,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,    0,
 1909,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
 1909,    0, 1909, 1909, 1909, 1909, 1909, 1909,    0, 1909,
 1909, 1909, 1909,    0, 1909,    0, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909,    0, 1909, 1909, 1909, 1909,    0,
 1909, 1909, 1909, 1909, 1909,    0, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,
 1909, 1909, 1909, 1909, 1909, 1935, 1909, 1909, 1909, 1909,
    0, 1909, 1909, 1909, 1909, 1909, 1909,    0,    0, 1909,
 1909, 1909, 1909, 1909, 1909, 1909, 1909, 1909,    0,    0,
    0,    0,    0, 1909,    0, 1909, 1909, 1909, 1909, 1909,
 1909,    0, 1909,    0,    0,    0, 1935, 1935, 1935, 1935,
 1935, 1935, 1935,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1935, 1935, 1935, 1935,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1935,    0, 1935,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1935,    0, 1935,    0,    0, 1935,    0, 1935,
 1935,    0,    0, 1935, 1935,    0, 1935,    0,    0,    0,
    0,    0, 1935,    0, 1935, 1935, 1935, 1935,    0, 1935,
    0,    0, 1935,    0,    0, 1935,    0,    0,    0,    0,
    0,    0, 1935,    0, 1935, 1935,    0, 1935, 1935, 1935,
 1935, 1935,    0,    0, 1935,    0,    0, 1935,    0, 1935,
 1935,    0,    0, 1935, 1935, 1935,    0, 1935, 1935, 1935,
 1935, 1935, 1935, 1935,    0,    0,    0, 1935, 1935, 1935,
 1935, 1935,    0,    0,    0, 1935,    0,    0,    0,    0,
    0,    0,    0, 1935, 1935, 1935, 1935, 1935, 1935,    0,
    0,    0, 1935, 1935,    0, 1935,    0, 1935,    0, 1935,
 1935, 1935,    0, 1935,    0, 1935, 1935, 1935,    0, 1935,
 1935, 1935, 1935, 1935,    0, 1935, 1935,    0,    0,    0,
    0, 1935,    0, 1935, 1935,    0,    0, 1935, 1935, 1935,
    0,    0, 1935,    0, 1935,    0,    0, 1935, 1935, 1935,
 1935,    0, 1935,    0, 1935,    0, 1935, 1935, 1935, 1935,
 1935,    0,    0, 1935, 1935, 1935,    0, 1935, 1935,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1935, 1935,
 1935,    0, 1935, 1935, 1935,    0, 1935,    0,    0,    0,
 1935,    0, 1935, 1935, 1935, 1935,    0, 1935,    0, 1935,
 1935, 1935, 1935, 1935, 1935, 1935, 1935,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1935, 1935,    0, 1935,
 1935, 1935,    0,    0,    0,    0, 1935, 1935, 1935, 1935,
 1935,    0, 1935,    0,    0, 1935, 1935,    0,    0,    0,
 1935, 1935,    0,    0, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935,    0, 1935,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935, 1935, 1935,    0, 1935, 1935, 1935, 1935,
 1935, 1935,    0, 1935, 1935, 1935, 1935,    0, 1935,    0,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935,    0, 1935,
 1935, 1935, 1935,    0, 1935, 1935, 1935, 1935, 1935,    0,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1935, 1795,
 1935, 1935, 1935, 1935,    0, 1935, 1935, 1935, 1935, 1935,
 1935,    0,    0, 1935, 1935, 1935, 1935, 1935, 1935, 1935,
 1935, 1935,    0,    0,    0,    0,    0, 1935,    0, 1935,
 1935, 1935, 1935, 1935, 1935,    0, 1935,    0,    0,    0,
 1795, 1795, 1795, 1795, 1795, 1795, 1795,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1795, 1795,
 1795, 1795,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1795,    0, 1795,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1795,    0, 1795,    0,
    0, 1795,    0, 1795, 1795,    0,    0, 1795, 1795,    0,
 1795,    0,    0,    0,    0,    0, 1795,    0, 1795, 1795,
 1795, 1795,    0, 1795,    0,    0, 1795,    0,    0, 1795,
    0,    0,    0,    0,    0,    0, 1795,    0, 1795, 1795,
    0, 1795, 1795, 1795, 1795, 1795,    0,    0, 1795,    0,
    0, 1795,    0, 1795, 1795,    0,    0, 1795, 1795, 1795,
    0, 1795, 1795, 1795, 1795, 1795, 1795, 1795,    0,    0,
    0, 1795, 1795, 1795, 1795, 1795,    0,    0,    0, 1795,
    0,    0,    0,    0,    0,    0,    0, 1795, 1795, 1795,
 1795, 1795, 1795,    0,    0,    0, 1795, 1795,    0, 1795,
    0, 1795,    0, 1795, 1795, 1795,    0, 1795,    0, 1795,
 1795, 1795,    0, 1795, 1795, 1795, 1795, 1795,    0, 1795,
 1795,    0,    0,    0,    0, 1795,    0, 1795, 1795,    0,
    0, 1795, 1795, 1795,    0,    0, 1795,    0, 1795,    0,
    0, 1795, 1795, 1795, 1795,    0, 1795,    0, 1795,    0,
 1795, 1795, 1795, 1795, 1795,    0,    0, 1795, 1795, 1795,
    0, 1795, 1795,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1795, 1795, 1795,    0, 1795, 1795, 1795,    0,
 1795,    0,    0,    0, 1795,    0, 1795, 1795, 1795, 1795,
    0, 1795,    0, 1795, 1795, 1795, 1795, 1795, 1795, 1795,
 1795,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1795, 1795,    0, 1795, 1795, 1795,    0,    0,    0,    0,
 1795, 1795, 1795, 1795, 1795,    0, 1795,    0,    0, 1795,
 1795,    0,    0,    0, 1795, 1795,    0,    0, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795,    0, 1795,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795,    0,
 1795, 1795, 1795, 1795, 1795, 1795,    0, 1795, 1795, 1795,
 1795,    0, 1795,    0, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795,    0, 1795, 1795, 1795, 1795,    0, 1795, 1795,
 1795, 1795, 1795,    0, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795, 1795,
 1795, 1795, 1795, 1791, 1795, 1795, 1795, 1795,    0, 1795,
 1795, 1795, 1795, 1795, 1795,    0,    0, 1795, 1795, 1795,
 1795, 1795, 1795, 1795, 1795, 1795,    0,    0,    0,    0,
    0, 1795,    0, 1795, 1795, 1795, 1795, 1795, 1795,    0,
 1795,    0,    0,    0, 1791, 1791, 1791, 1791, 1791, 1791,
 1791,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1791, 1791, 1791, 1791,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1791,    0, 1791,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1791,    0, 1791,    0,    0, 1791,    0, 1791, 1791,    0,
    0, 1791, 1791,    0, 1791,    0,    0,    0,    0,    0,
 1791,    0, 1791, 1791, 1791, 1791,    0, 1791,    0,    0,
 1791,    0,    0, 1791,    0,    0,    0,    0,    0,    0,
 1791,    0, 1791, 1791,    0, 1791, 1791, 1791, 1791, 1791,
    0,    0, 1791,    0,    0, 1791,    0, 1791, 1791,    0,
    0, 1791, 1791, 1791,    0, 1791, 1791, 1791, 1791, 1791,
 1791, 1791,    0,    0,    0, 1791, 1791, 1791, 1791, 1791,
    0,    0,    0, 1791,    0,    0,    0,    0,    0,    0,
    0, 1791, 1791, 1791, 1791, 1791, 1791,    0,    0,    0,
 1791, 1791,    0, 1791,    0, 1791,    0, 1791, 1791, 1791,
    0, 1791,    0, 1791, 1791, 1791,    0, 1791, 1791, 1791,
 1791, 1791,    0, 1791, 1791,    0,    0,    0,    0, 1791,
    0, 1791, 1791,    0,    0, 1791, 1791, 1791,    0,    0,
 1791,    0, 1791,    0,    0, 1791, 1791, 1791, 1791,    0,
 1791,    0, 1791,    0, 1791, 1791, 1791, 1791, 1791,    0,
    0, 1791, 1791, 1791,    0, 1791, 1791,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1791, 1791, 1791,    0,
 1791, 1791, 1791,    0, 1791,    0,    0,    0, 1791,    0,
 1791, 1791, 1791, 1791,    0, 1791,    0, 1791, 1791, 1791,
 1791, 1791, 1791, 1791, 1791,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1791, 1791,    0, 1791, 1791, 1791,
    0,    0,    0,    0, 1791, 1791, 1791, 1791, 1791,    0,
 1791,    0,    0, 1791, 1791,    0,    0,    0, 1791, 1791,
    0,    0, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791,    0, 1791,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791, 1791, 1791,    0, 1791, 1791, 1791, 1791, 1791, 1791,
    0, 1791, 1791, 1791, 1791,    0, 1791,    0, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791,    0, 1791, 1791, 1791,
 1791,    0, 1791, 1791, 1791, 1791, 1791,    0, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1803, 1791, 1791,
 1791, 1791,    0, 1791, 1791, 1791, 1791, 1791, 1791,    0,
    0, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791, 1791,
    0,    0,    0,    0,    0, 1791,    0, 1791, 1791, 1791,
 1791, 1791, 1791,    0, 1791,    0,    0,    0, 1803, 1803,
 1803, 1803, 1803, 1803, 1803,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1803, 1803, 1803, 1803,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1803,    0,
 1803,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1803,    0, 1803,    0,    0, 1803,
    0, 1803, 1803,    0,    0, 1803, 1803,    0, 1803,    0,
    0,    0,    0,    0, 1803,    0, 1803, 1803, 1803, 1803,
    0, 1803,    0,    0, 1803,    0,    0, 1803,    0,    0,
    0,    0,    0,    0, 1803,    0, 1803, 1803,    0, 1803,
 1803, 1803, 1803, 1803,    0,    0, 1803,    0,    0, 1803,
    0, 1803, 1803,    0,    0, 1803, 1803, 1803,    0, 1803,
 1803, 1803, 1803, 1803, 1803, 1803,    0,    0,    0, 1803,
 1803, 1803, 1803, 1803,    0,    0,    0, 1803,    0,    0,
    0,    0,    0,    0,    0, 1803, 1803, 1803, 1803, 1803,
 1803,    0,    0,    0, 1803, 1803,    0, 1803,    0, 1803,
    0, 1803, 1803, 1803,    0, 1803,    0, 1803, 1803, 1803,
    0, 1803, 1803, 1803, 1803, 1803,    0, 1803, 1803,    0,
    0,    0,    0, 1803,    0, 1803, 1803,    0,    0, 1803,
 1803, 1803,    0,    0, 1803,    0, 1803,    0,    0, 1803,
 1803, 1803, 1803,    0, 1803,    0, 1803,    0, 1803, 1803,
 1803, 1803, 1803,    0,    0, 1803, 1803, 1803,    0, 1803,
 1803,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1803, 1803, 1803,    0, 1803, 1803, 1803,    0, 1803,    0,
    0,    0, 1803,    0, 1803, 1803, 1803, 1803,    0, 1803,
    0, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1803, 1803,
    0, 1803, 1803, 1803,    0,    0,    0,    0, 1803, 1803,
 1803, 1803, 1803,    0, 1803,    0,    0, 1803, 1803,    0,
    0,    0, 1803, 1803,    0,    0, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803,    0, 1803,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803, 1803, 1803,    0, 1803, 1803,
 1803, 1803, 1803, 1803,    0, 1803, 1803, 1803, 1803,    0,
 1803,    0, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
    0, 1803, 1803, 1803, 1803,    0, 1803, 1803, 1803, 1803,
 1803,    0, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803, 1803,
 1803, 1808, 1803, 1803, 1803, 1803,    0, 1803, 1803, 1803,
 1803, 1803, 1803,    0,    0, 1803, 1803, 1803, 1803, 1803,
 1803, 1803, 1803, 1803,    0,    0,    0,    0,    0, 1803,
    0, 1803, 1803, 1803, 1803, 1803, 1803,    0, 1803,    0,
    0,    0, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1808, 1808, 1808, 1808,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1808,    0, 1808,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1808,    0,
 1808,    0,    0, 1808,    0, 1808, 1808,    0,    0, 1808,
 1808,    0, 1808,    0,    0,    0,    0,    0, 1808,    0,
 1808, 1808, 1808, 1808,    0, 1808,    0,    0, 1808,    0,
    0, 1808,    0,    0,    0,    0,    0,    0, 1808,    0,
 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808,    0,    0,
 1808,    0,    0, 1808,    0, 1808, 1808,    0,    0, 1808,
 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
    0,    0,    0, 1808, 1808, 1808, 1808, 1808,    0,    0,
    0, 1808,    0,    0,    0,    0,    0,    0,    0, 1808,
 1808, 1808, 1808, 1808, 1808,    0,    0,    0, 1808, 1808,
    0, 1808,    0, 1808,    0, 1808, 1808, 1808,    0, 1808,
    0, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808, 1808,
    0, 1808, 1808,    0,    0,    0,    0, 1808,    0, 1808,
 1808,    0,    0, 1808, 1808, 1808,    0,    0, 1808,    0,
 1808,    0,    0, 1808, 1808, 1808, 1808,    0, 1808,    0,
 1808,    0, 1808, 1808, 1808, 1808, 1808,    0,    0, 1808,
 1808, 1808,    0, 1808, 1808,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1808, 1808, 1808,    0, 1808, 1808,
 1808,    0, 1808,    0,    0,    0, 1808,    0, 1808, 1808,
 1808, 1808,    0, 1808,    0, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1808, 1808,    0, 1808, 1808, 1808,    0,    0,
    0,    0, 1808, 1808, 1808, 1808, 1808,    0, 1808,    0,
    0, 1808, 1808,    0,    0,    0, 1808, 1808,    0,    0,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,
 1808,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808,    0, 1808, 1808, 1808, 1808, 1808, 1808,    0, 1808,
 1808, 1808, 1808,    0, 1808,    0, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808,    0,
 1808, 1808, 1808, 1808, 1808,    0, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,
 1808, 1808, 1808, 1808, 1808, 1837, 1808, 1808, 1808, 1808,
    0, 1808, 1808, 1808, 1808, 1808, 1808,    0,    0, 1808,
 1808, 1808, 1808, 1808, 1808, 1808, 1808, 1808,    0,    0,
    0,    0,    0, 1808,    0, 1808, 1808, 1808, 1808, 1808,
 1808,    0, 1808,    0,    0,    0, 1837, 1837, 1837, 1837,
 1837, 1837, 1837,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1837, 1837, 1837, 1837,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1837,    0, 1837,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1837,    0, 1837,    0,    0, 1837,    0, 1837,
 1837,    0,    0, 1837, 1837,    0, 1837,    0,    0,    0,
    0,    0, 1837,    0, 1837, 1837, 1837, 1837,    0, 1837,
    0,    0, 1837,    0,    0, 1837,    0,    0,    0,    0,
    0,    0, 1837,    0, 1837, 1837,    0, 1837, 1837, 1837,
 1837, 1837,    0,    0, 1837,    0,    0, 1837,    0, 1837,
 1837,    0,    0, 1837, 1837, 1837,    0, 1837, 1837, 1837,
 1837, 1837, 1837, 1837,    0,    0,    0, 1837, 1837, 1837,
 1837, 1837,    0,    0,    0, 1837,    0,    0,    0,    0,
    0,    0,    0, 1837, 1837, 1837, 1837, 1837, 1837,    0,
    0,    0, 1837, 1837,    0, 1837,    0, 1837,    0, 1837,
 1837, 1837,    0, 1837,    0, 1837, 1837, 1837,    0, 1837,
 1837, 1837, 1837, 1837,    0, 1837, 1837,    0,    0,    0,
    0, 1837,    0, 1837, 1837,    0,    0, 1837, 1837, 1837,
    0,    0, 1837,    0, 1837,    0,    0, 1837, 1837, 1837,
 1837,    0, 1837,    0, 1837,    0, 1837, 1837, 1837, 1837,
 1837,    0,    0, 1837, 1837, 1837,    0, 1837, 1837,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1837, 1837,
 1837,    0, 1837, 1837, 1837,    0, 1837,    0,    0,    0,
 1837,    0, 1837, 1837, 1837, 1837,    0, 1837,    0, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1837, 1837,    0, 1837,
 1837, 1837,    0,    0,    0,    0, 1837, 1837, 1837, 1837,
 1837,    0, 1837,    0,    0, 1837, 1837,    0,    0,    0,
 1837, 1837,    0,    0, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837,    0, 1837,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837,    0, 1837, 1837, 1837, 1837,
 1837, 1837,    0, 1837, 1837, 1837, 1837,    0, 1837,    0,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,    0, 1837,
 1837, 1837, 1837,    0, 1837, 1837, 1837, 1837, 1837,    0,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1837, 1843,
 1837, 1837, 1837, 1837,    0, 1837, 1837, 1837, 1837, 1837,
 1837,    0,    0, 1837, 1837, 1837, 1837, 1837, 1837, 1837,
 1837, 1837,    0,    0,    0,    0,    0, 1837,    0, 1837,
 1837, 1837, 1837, 1837, 1837,    0, 1837,    0,    0,    0,
 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1843, 1843,
 1843, 1843,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1843,    0, 1843,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1843,    0, 1843,    0,
    0, 1843,    0, 1843, 1843,    0,    0, 1843, 1843,    0,
 1843,    0,    0,    0,    0,    0, 1843,    0, 1843, 1843,
 1843, 1843,    0, 1843,    0,    0, 1843,    0,    0, 1843,
    0,    0,    0,    0,    0,    0, 1843,    0, 1843, 1843,
    0, 1843, 1843, 1843, 1843, 1843,    0,    0, 1843,    0,
    0, 1843,    0, 1843, 1843,    0,    0, 1843, 1843, 1843,
    0, 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,    0,
    0, 1843, 1843, 1843, 1843, 1843,    0,    0,    0, 1843,
    0,    0,    0,    0,    0,    0,    0, 1843, 1843, 1843,
 1843, 1843, 1843,    0,    0,    0, 1843, 1843,    0, 1843,
    0, 1843,    0, 1843, 1843, 1843,    0, 1843,    0, 1843,
 1843, 1843,    0, 1843, 1843, 1843, 1843, 1843,    0, 1843,
 1843,    0,    0,    0,    0, 1843,    0, 1843, 1843,    0,
    0, 1843, 1843, 1843,    0,    0, 1843,    0, 1843,    0,
    0, 1843, 1843, 1843, 1843,    0, 1843,    0, 1843,    0,
 1843, 1843, 1843, 1843, 1843,    0,    0, 1843, 1843, 1843,
    0, 1843, 1843,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1843, 1843, 1843,    0, 1843, 1843, 1843,    0,
 1843,    0,    0,    0, 1843,    0, 1843, 1843, 1843, 1843,
    0, 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1843, 1843,    0, 1843, 1843, 1843,    0,    0,    0,    0,
 1843, 1843, 1843, 1843, 1843,    0, 1843,    0,    0, 1843,
 1843,    0,    0,    0, 1843, 1843,    0,    0, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0, 1843,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,    0,
 1843, 1843, 1843, 1843, 1843, 1843,    0, 1843, 1843, 1843,
 1843,    0, 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843,    0, 1843, 1843, 1843, 1843,    0, 1843, 1843,
 1843, 1843, 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843, 1843,
 1843, 1843, 1843, 1967, 1843, 1843, 1843, 1843,    0, 1843,
 1843, 1843, 1843, 1843, 1843,    0,    0, 1843, 1843, 1843,
 1843, 1843, 1843, 1843, 1843, 1843,    0,    0,    0,    0,
    0, 1843,    0, 1843, 1843, 1843, 1843, 1843, 1843,    0,
 1843,    0,    0,    0, 1967, 1967, 1967, 1967, 1967, 1967,
 1967,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1967, 1967, 1967, 1967,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1967,    0, 1967,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1967,    0, 1967,    0,    0, 1967,    0, 1967, 1967,    0,
    0, 1967, 1967,    0, 1967,    0,    0,    0,    0,    0,
 1967,    0, 1967, 1967, 1967, 1967,    0, 1967,    0,    0,
 1967,    0,    0, 1967,    0,    0,    0,    0,    0,    0,
 1967,    0, 1967, 1967,    0, 1967, 1967, 1967, 1967, 1967,
    0,    0, 1967,    0,    0, 1967,    0, 1967, 1967,    0,
    0, 1967, 1967, 1967,    0, 1967, 1967, 1967, 1967, 1967,
 1967, 1967,    0,    0,    0, 1967, 1967, 1967, 1967, 1967,
    0,    0,    0, 1967,    0,    0,    0,    0,    0,    0,
    0, 1967, 1967, 1967, 1967, 1967, 1967,    0,    0,    0,
 1967, 1967,    0, 1967,    0, 1967,    0, 1967, 1967, 1967,
    0, 1967,    0, 1967, 1967, 1967,    0, 1967, 1967, 1967,
 1967, 1967,    0, 1967, 1967,    0,    0,    0,    0, 1967,
    0, 1967, 1967,    0,    0, 1967, 1967, 1967,    0,    0,
 1967,    0, 1967,    0,    0, 1967, 1967, 1967, 1967,    0,
 1967,    0, 1967,    0, 1967, 1967, 1967, 1967, 1967,    0,
    0, 1967, 1967, 1967,    0, 1967, 1967,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1967, 1967, 1967,    0,
 1967, 1967, 1967,    0, 1967,    0,    0,    0, 1967,    0,
 1967, 1967, 1967, 1967,    0, 1967,    0, 1967, 1967, 1967,
 1967, 1967, 1967, 1967, 1967,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1967, 1967,    0, 1967, 1967, 1967,
    0,    0,    0,    0, 1967, 1967, 1967, 1967, 1967,    0,
 1967,    0,    0, 1967, 1967,    0,    0,    0, 1967, 1967,
    0,    0, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967,    0, 1967,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967, 1967, 1967,    0, 1967, 1967, 1967, 1967, 1967, 1967,
    0, 1967, 1967, 1967, 1967,    0, 1967,    0, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967,    0, 1967, 1967, 1967,
 1967,    0, 1967, 1967, 1967, 1967, 1967,    0, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1968, 1967, 1967,
 1967, 1967,    0, 1967, 1967, 1967, 1967, 1967, 1967,    0,
    0, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967, 1967,
    0,    0,    0,    0,    0, 1967,    0, 1967, 1967, 1967,
 1967, 1967, 1967,    0, 1967,    0,    0,    0, 1968, 1968,
 1968, 1968, 1968, 1968, 1968,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1968, 1968, 1968, 1968,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1968,    0,
 1968,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1968,    0, 1968,    0,    0, 1968,
    0, 1968, 1968,    0,    0, 1968, 1968,    0, 1968,    0,
    0,    0,    0,    0, 1968,    0, 1968, 1968, 1968, 1968,
    0, 1968,    0,    0, 1968,    0,    0, 1968,    0,    0,
    0,    0,    0,    0, 1968,    0, 1968, 1968,    0, 1968,
 1968, 1968, 1968, 1968,    0,    0, 1968,    0,    0, 1968,
    0, 1968, 1968,    0,    0, 1968, 1968, 1968,    0, 1968,
 1968, 1968, 1968, 1968, 1968, 1968,    0,    0,    0, 1968,
 1968, 1968, 1968, 1968,    0,    0,    0, 1968,    0,    0,
    0,    0,    0,    0,    0, 1968, 1968, 1968, 1968, 1968,
 1968,    0,    0,    0, 1968, 1968,    0, 1968,    0, 1968,
    0, 1968, 1968, 1968,    0, 1968,    0, 1968, 1968, 1968,
    0, 1968, 1968, 1968, 1968, 1968,    0, 1968, 1968,    0,
    0,    0,    0, 1968,    0, 1968, 1968,    0,    0, 1968,
 1968, 1968,    0,    0, 1968,    0, 1968,    0,    0, 1968,
 1968, 1968, 1968,    0, 1968,    0, 1968,    0, 1968, 1968,
 1968, 1968, 1968,    0,    0, 1968, 1968, 1968,    0, 1968,
 1968,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1968, 1968, 1968,    0, 1968, 1968, 1968,    0, 1968,    0,
    0,    0, 1968,    0, 1968, 1968, 1968, 1968,    0, 1968,
    0, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1968, 1968,
    0, 1968, 1968, 1968,    0,    0,    0,    0, 1968, 1968,
 1968, 1968, 1968,    0, 1968,    0,    0, 1968, 1968,    0,
    0,    0, 1968, 1968,    0,    0, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968,    0, 1968,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968, 1968, 1968,    0, 1968, 1968,
 1968, 1968, 1968, 1968,    0, 1968, 1968, 1968, 1968,    0,
 1968,    0, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
    0, 1968, 1968, 1968, 1968,    0, 1968, 1968, 1968, 1968,
 1968,    0, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968, 1968,
 1968, 1969, 1968, 1968, 1968, 1968,    0, 1968, 1968, 1968,
 1968, 1968, 1968,    0,    0, 1968, 1968, 1968, 1968, 1968,
 1968, 1968, 1968, 1968,    0,    0,    0,    0,    0, 1968,
    0, 1968, 1968, 1968, 1968, 1968, 1968,    0, 1968,    0,
    0,    0, 1969, 1969, 1969, 1969, 1969, 1969, 1969,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1969, 1969, 1969, 1969,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1969,    0, 1969,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1969,    0,
 1969,    0,    0, 1969,    0, 1969, 1969,    0,    0, 1969,
 1969,    0, 1969,    0,    0,    0,    0,    0, 1969,    0,
 1969, 1969, 1969, 1969,    0, 1969,    0,    0, 1969,    0,
    0, 1969,    0,    0,    0,    0,    0,    0, 1969,    0,
 1969, 1969,    0, 1969, 1969, 1969, 1969, 1969,    0,    0,
 1969,    0,    0, 1969,    0, 1969, 1969,    0,    0, 1969,
 1969, 1969,    0, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
    0,    0,    0, 1969, 1969, 1969, 1969, 1969,    0,    0,
    0, 1969,    0,    0,    0,    0,    0,    0,    0, 1969,
 1969, 1969, 1969, 1969, 1969,    0,    0,    0, 1969, 1969,
    0, 1969,    0, 1969,    0, 1969, 1969, 1969,    0, 1969,
    0, 1969, 1969, 1969,    0, 1969, 1969, 1969, 1969, 1969,
    0, 1969, 1969,    0,    0,    0,    0, 1969,    0, 1969,
 1969,    0,    0, 1969, 1969, 1969,    0,    0, 1969,    0,
 1969,    0,    0, 1969, 1969, 1969, 1969,    0, 1969,    0,
 1969,    0, 1969, 1969, 1969, 1969, 1969,    0,    0, 1969,
 1969, 1969,    0, 1969, 1969,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1969, 1969, 1969,    0, 1969, 1969,
 1969,    0, 1969,    0,    0,    0, 1969,    0, 1969, 1969,
 1969, 1969,    0, 1969,    0, 1969, 1969, 1969, 1969, 1969,
 1969, 1969, 1969,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1969, 1969,    0, 1969, 1969, 1969,    0,    0,
    0,    0, 1969, 1969, 1969, 1969, 1969,    0, 1969,    0,
    0, 1969, 1969,    0,    0,    0, 1969, 1969,    0,    0,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,    0,
 1969,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
 1969,    0, 1969, 1969, 1969, 1969, 1969, 1969,    0, 1969,
 1969, 1969, 1969,    0, 1969,    0, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969,    0, 1969, 1969, 1969, 1969,    0,
 1969, 1969, 1969, 1969, 1969,    0, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,
 1969, 1969, 1969, 1969, 1969, 1970, 1969, 1969, 1969, 1969,
    0, 1969, 1969, 1969, 1969, 1969, 1969,    0,    0, 1969,
 1969, 1969, 1969, 1969, 1969, 1969, 1969, 1969,    0,    0,
    0,    0,    0, 1969,    0, 1969, 1969, 1969, 1969, 1969,
 1969,    0, 1969,    0,    0,    0, 1970, 1970, 1970, 1970,
 1970, 1970, 1970,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1970, 1970, 1970, 1970,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1970,    0, 1970,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1970,    0, 1970,    0,    0, 1970,    0, 1970,
 1970,    0,    0, 1970, 1970,    0, 1970,    0,    0,    0,
    0,    0, 1970,    0, 1970, 1970, 1970, 1970,    0, 1970,
    0,    0, 1970,    0,    0, 1970,    0,    0,    0,    0,
    0,    0, 1970,    0, 1970, 1970,    0, 1970, 1970, 1970,
 1970, 1970,    0,    0, 1970,    0,    0, 1970,    0, 1970,
 1970,    0,    0, 1970, 1970, 1970,    0, 1970, 1970, 1970,
 1970, 1970, 1970, 1970,    0,    0,    0, 1970, 1970, 1970,
 1970, 1970,    0,    0,    0, 1970,    0,    0,    0,    0,
    0,    0,    0, 1970, 1970, 1970, 1970, 1970, 1970,    0,
    0,    0, 1970, 1970,    0, 1970,    0, 1970,    0, 1970,
 1970, 1970,    0, 1970,    0, 1970, 1970, 1970,    0, 1970,
 1970, 1970, 1970, 1970,    0, 1970, 1970,    0,    0,    0,
    0, 1970,    0, 1970, 1970,    0,    0, 1970, 1970, 1970,
    0,    0, 1970,    0, 1970,    0,    0, 1970, 1970, 1970,
 1970,    0, 1970,    0, 1970,    0, 1970, 1970, 1970, 1970,
 1970,    0,    0, 1970, 1970, 1970,    0, 1970, 1970,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1970, 1970,
 1970,    0, 1970, 1970, 1970,    0, 1970,    0,    0,    0,
 1970,    0, 1970, 1970, 1970, 1970,    0, 1970,    0, 1970,
 1970, 1970, 1970, 1970, 1970, 1970, 1970,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1970, 1970,    0, 1970,
 1970, 1970,    0,    0,    0,    0, 1970, 1970, 1970, 1970,
 1970,    0, 1970,    0,    0, 1970, 1970,    0,    0,    0,
 1970, 1970,    0,    0, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970,    0, 1970,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970, 1970, 1970,    0, 1970, 1970, 1970, 1970,
 1970, 1970,    0, 1970, 1970, 1970, 1970,    0, 1970,    0,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970,    0, 1970,
 1970, 1970, 1970,    0, 1970, 1970, 1970, 1970, 1970,    0,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1970, 1971,
 1970, 1970, 1970, 1970,    0, 1970, 1970, 1970, 1970, 1970,
 1970,    0,    0, 1970, 1970, 1970, 1970, 1970, 1970, 1970,
 1970, 1970,    0,    0,    0,    0,    0, 1970,    0, 1970,
 1970, 1970, 1970, 1970, 1970,    0, 1970,    0,    0,    0,
 1971, 1971, 1971, 1971, 1971, 1971, 1971,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1971, 1971,
 1971, 1971,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1971,    0, 1971,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1971,    0, 1971,    0,
    0, 1971,    0, 1971, 1971,    0,    0, 1971, 1971,    0,
 1971,    0,    0,    0,    0,    0, 1971,    0, 1971, 1971,
 1971, 1971,    0, 1971,    0,    0, 1971,    0,    0, 1971,
    0,    0,    0,    0,    0,    0, 1971,    0, 1971, 1971,
    0, 1971, 1971, 1971, 1971, 1971,    0,    0, 1971,    0,
    0, 1971,    0, 1971, 1971,    0,    0, 1971, 1971, 1971,
    0, 1971, 1971, 1971, 1971, 1971, 1971, 1971,    0,    0,
    0, 1971, 1971, 1971, 1971, 1971,    0,    0,    0, 1971,
    0,    0,    0,    0,    0,    0,    0, 1971, 1971, 1971,
 1971, 1971, 1971,    0,    0,    0, 1971, 1971,    0, 1971,
    0, 1971,    0, 1971, 1971, 1971,    0, 1971,    0, 1971,
 1971, 1971,    0, 1971, 1971, 1971, 1971, 1971,    0, 1971,
 1971,    0,    0,    0,    0, 1971,    0, 1971, 1971,    0,
    0, 1971, 1971, 1971,    0,    0, 1971,    0, 1971,    0,
    0, 1971, 1971, 1971, 1971,    0, 1971,    0, 1971,    0,
 1971, 1971, 1971, 1971, 1971,    0,    0, 1971, 1971, 1971,
    0, 1971, 1971,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1971, 1971, 1971,    0, 1971, 1971, 1971,    0,
 1971,    0,    0,    0, 1971,    0, 1971, 1971, 1971, 1971,
    0, 1971,    0, 1971, 1971, 1971, 1971, 1971, 1971, 1971,
 1971,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1971, 1971,    0, 1971, 1971, 1971,    0,    0,    0,    0,
 1971, 1971, 1971, 1971, 1971,    0, 1971,    0,    0, 1971,
 1971,    0,    0,    0, 1971, 1971,    0,    0, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971,    0, 1971,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971,    0,
 1971, 1971, 1971, 1971, 1971, 1971,    0, 1971, 1971, 1971,
 1971,    0, 1971,    0, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971,    0, 1971, 1971, 1971, 1971,    0, 1971, 1971,
 1971, 1971, 1971,    0, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971, 1971,
 1971, 1971, 1971, 1972, 1971, 1971, 1971, 1971,    0, 1971,
 1971, 1971, 1971, 1971, 1971,    0,    0, 1971, 1971, 1971,
 1971, 1971, 1971, 1971, 1971, 1971,    0,    0,    0,    0,
    0, 1971,    0, 1971, 1971, 1971, 1971, 1971, 1971,    0,
 1971,    0,    0,    0, 1972, 1972, 1972, 1972, 1972, 1972,
 1972,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1972, 1972, 1972, 1972,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1972,    0, 1972,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1972,    0, 1972,    0,    0, 1972,    0, 1972, 1972,    0,
    0, 1972, 1972,    0, 1972,    0,    0,    0,    0,    0,
 1972,    0, 1972, 1972, 1972, 1972,    0, 1972,    0,    0,
 1972,    0,    0, 1972,    0,    0,    0,    0,    0,    0,
 1972,    0, 1972, 1972,    0, 1972, 1972, 1972, 1972, 1972,
    0,    0, 1972,    0,    0, 1972,    0, 1972, 1972,    0,
    0, 1972, 1972, 1972,    0, 1972, 1972, 1972, 1972, 1972,
 1972, 1972,    0,    0,    0, 1972, 1972, 1972, 1972, 1972,
    0,    0,    0, 1972,    0,    0,    0,    0,    0,    0,
    0, 1972, 1972, 1972, 1972, 1972, 1972,    0,    0,    0,
 1972, 1972,    0, 1972,    0, 1972,    0, 1972, 1972, 1972,
    0, 1972,    0, 1972, 1972, 1972,    0, 1972, 1972, 1972,
 1972, 1972,    0, 1972, 1972,    0,    0,    0,    0, 1972,
    0, 1972, 1972,    0,    0, 1972, 1972, 1972,    0,    0,
 1972,    0, 1972,    0,    0, 1972, 1972, 1972, 1972,    0,
 1972,    0, 1972,    0, 1972, 1972, 1972, 1972, 1972,    0,
    0, 1972, 1972, 1972,    0, 1972, 1972,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1972, 1972, 1972,    0,
 1972, 1972, 1972,    0, 1972,    0,    0,    0, 1972,    0,
 1972, 1972, 1972, 1972,    0, 1972,    0, 1972, 1972, 1972,
 1972, 1972, 1972, 1972, 1972,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1972, 1972,    0, 1972, 1972, 1972,
    0,    0,    0,    0, 1972, 1972, 1972, 1972, 1972,    0,
 1972,    0,    0, 1972, 1972,    0,    0,    0, 1972, 1972,
    0,    0, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972,    0, 1972,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972, 1972, 1972,    0, 1972, 1972, 1972, 1972, 1972, 1972,
    0, 1972, 1972, 1972, 1972,    0, 1972,    0, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972,    0, 1972, 1972, 1972,
 1972,    0, 1972, 1972, 1972, 1972, 1972,    0, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1973, 1972, 1972,
 1972, 1972,    0, 1972, 1972, 1972, 1972, 1972, 1972,    0,
    0, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972, 1972,
    0,    0,    0,    0,    0, 1972,    0, 1972, 1972, 1972,
 1972, 1972, 1972,    0, 1972,    0,    0,    0, 1973, 1973,
 1973, 1973, 1973, 1973, 1973,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1973, 1973, 1973, 1973,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1973,    0,
 1973,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1973,    0, 1973,    0,    0, 1973,
    0, 1973, 1973,    0,    0, 1973, 1973,    0, 1973,    0,
    0,    0,    0,    0, 1973,    0, 1973, 1973, 1973, 1973,
    0, 1973,    0,    0, 1973,    0,    0, 1973,    0,    0,
    0,    0,    0,    0, 1973,    0, 1973, 1973,    0, 1973,
 1973, 1973, 1973, 1973,    0,    0, 1973,    0,    0, 1973,
    0, 1973, 1973,    0,    0, 1973, 1973, 1973,    0, 1973,
 1973, 1973, 1973, 1973, 1973, 1973,    0,    0,    0, 1973,
 1973, 1973, 1973, 1973,    0,    0,    0, 1973,    0,    0,
    0,    0,    0,    0,    0, 1973, 1973, 1973, 1973, 1973,
 1973,    0,    0,    0, 1973, 1973,    0, 1973,    0, 1973,
    0, 1973, 1973, 1973,    0, 1973,    0, 1973, 1973, 1973,
    0, 1973, 1973, 1973, 1973, 1973,    0, 1973, 1973,    0,
    0,    0,    0, 1973,    0, 1973, 1973,    0,    0, 1973,
 1973, 1973,    0,    0, 1973,    0, 1973,    0,    0, 1973,
 1973, 1973, 1973,    0, 1973,    0, 1973,    0, 1973, 1973,
 1973, 1973, 1973,    0,    0, 1973, 1973, 1973,    0, 1973,
 1973,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1973, 1973, 1973,    0, 1973, 1973, 1973,    0, 1973,    0,
    0,    0, 1973,    0, 1973, 1973, 1973, 1973,    0, 1973,
    0, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1973, 1973,
    0, 1973, 1973, 1973,    0,    0,    0,    0, 1973, 1973,
 1973, 1973, 1973,    0, 1973,    0,    0, 1973, 1973,    0,
    0,    0, 1973, 1973,    0,    0, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973,    0, 1973,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973, 1973, 1973,    0, 1973, 1973,
 1973, 1973, 1973, 1973,    0, 1973, 1973, 1973, 1973,    0,
 1973,    0, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
    0, 1973, 1973, 1973, 1973,    0, 1973, 1973, 1973, 1973,
 1973,    0, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973, 1973,
 1973, 1974, 1973, 1973, 1973, 1973,    0, 1973, 1973, 1973,
 1973, 1973, 1973,    0,    0, 1973, 1973, 1973, 1973, 1973,
 1973, 1973, 1973, 1973,    0,    0,    0,    0,    0, 1973,
    0, 1973, 1973, 1973, 1973, 1973, 1973,    0, 1973,    0,
    0,    0, 1974, 1974, 1974, 1974, 1974, 1974, 1974,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1974, 1974, 1974, 1974,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1974,    0, 1974,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1974,    0,
 1974,    0,    0, 1974,    0, 1974, 1974,    0,    0, 1974,
 1974,    0, 1974,    0,    0,    0,    0,    0, 1974,    0,
 1974, 1974, 1974, 1974,    0, 1974,    0,    0, 1974,    0,
    0, 1974,    0,    0,    0,    0,    0,    0, 1974,    0,
 1974, 1974,    0, 1974, 1974, 1974, 1974, 1974,    0,    0,
 1974,    0,    0, 1974,    0, 1974, 1974,    0,    0, 1974,
 1974, 1974,    0, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
    0,    0,    0, 1974, 1974, 1974, 1974, 1974,    0,    0,
    0, 1974,    0,    0,    0,    0,    0,    0,    0, 1974,
 1974, 1974, 1974, 1974, 1974,    0,    0,    0, 1974, 1974,
    0, 1974,    0, 1974,    0, 1974, 1974, 1974,    0, 1974,
    0, 1974, 1974, 1974,    0, 1974, 1974, 1974, 1974, 1974,
    0, 1974, 1974,    0,    0,    0,    0, 1974,    0, 1974,
 1974,    0,    0, 1974, 1974, 1974,    0,    0, 1974,    0,
 1974,    0,    0, 1974, 1974, 1974, 1974,    0, 1974,    0,
 1974,    0, 1974, 1974, 1974, 1974, 1974,    0,    0, 1974,
 1974, 1974,    0, 1974, 1974,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1974, 1974, 1974,    0, 1974, 1974,
 1974,    0, 1974,    0,    0,    0, 1974,    0, 1974, 1974,
 1974, 1974,    0, 1974,    0, 1974, 1974, 1974, 1974, 1974,
 1974, 1974, 1974,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1974, 1974,    0, 1974, 1974, 1974,    0,    0,
    0,    0, 1974, 1974, 1974, 1974, 1974,    0, 1974,    0,
    0, 1974, 1974,    0,    0,    0, 1974, 1974,    0,    0,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,    0,
 1974,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
 1974,    0, 1974, 1974, 1974, 1974, 1974, 1974,    0, 1974,
 1974, 1974, 1974,    0, 1974,    0, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974,    0, 1974, 1974, 1974, 1974,    0,
 1974, 1974, 1974, 1974, 1974,    0, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,
 1974, 1974, 1974, 1974, 1974, 1561, 1974, 1974, 1974, 1974,
    0, 1974, 1974, 1974, 1974, 1974, 1974,    0,    0, 1974,
 1974, 1974, 1974, 1974, 1974, 1974, 1974, 1974,    0,    0,
    0,    0,    0, 1974,    0, 1974, 1974, 1974, 1974, 1974,
 1974,    0, 1974,    0,    0,    0, 1561, 1561, 1561, 1561,
 1561,    0, 1561,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1561, 1561, 1561, 1561,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1561,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1561,    0, 1561,    0,    0, 1561,    0, 1561,
 1561,    0,    0, 1561, 1561,    0, 1561,    0,    0,    0,
    0,    0, 1561,    0, 1561, 1561, 1561, 1561,    0, 1561,
    0,    0, 1561,    0,    0, 1561,    0,    0,    0,    0,
    0,    0, 1561,    0, 1561, 1561,    0, 1561, 1561, 1561,
 1561, 1561,    0,    0, 1561,    0,    0, 1561,    0, 1561,
 1561,    0,    0, 1561, 1561, 1561,    0, 1561, 1561, 1561,
 1561, 1561, 1561, 1561,    0,    0,    0, 1561, 1561, 1561,
 1561, 1561,    0,    0,    0, 1561,    0,    0,    0,    0,
    0,    0,    0, 1561, 1561, 1561, 1561, 1561, 1561,    0,
    0,    0, 1561, 1561,    0, 1561,    0, 1561,    0, 1561,
 1561, 1561,    0, 1561,    0, 1561, 1561, 1561,    0, 1561,
 1561, 1561, 1561, 1561,    0, 1561, 1561,    0,    0,    0,
    0, 1561,    0, 1561, 1561,    0,    0, 1561, 1561, 1561,
    0,    0, 1561,    0, 1561,    0,    0, 1561, 1561, 1561,
 1561,    0, 1561,    0, 1561,    0, 1561, 1561, 1561, 1561,
 1561,    0,    0, 1561, 1561, 1561,    0, 1561, 1561,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1561, 1561,
 1561,    0, 1561, 1561, 1561,    0, 1561,    0,    0,    0,
 1561,    0, 1561, 1561, 1561, 1561,    0, 1561,    0, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1561, 1561,    0, 1561,
 1561, 1561,    0,    0,    0,    0, 1561, 1561, 1561, 1561,
 1561,    0, 1561,    0,    0, 1561, 1561,    0,    0,    0,
 1561, 1561,    0,    0, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561,    0, 1561,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561,    0, 1561, 1561, 1561, 1561,
 1561, 1561,    0, 1561, 1561, 1561, 1561,    0, 1561,    0,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,    0, 1561,
 1561, 1561, 1561,    0, 1561, 1561, 1561, 1561, 1561,    0,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1611,
 1561, 1561, 1561, 1561, 1758, 1561, 1561, 1561, 1561, 1561,
 1561,    0,    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561,    0,    0,    0,    0,    0, 1561,    0, 1561,
 1561, 1561, 1561, 1561, 1561,    0, 1561,    0,    0,    0,
    0,    0,    0,    0,    0, 1758, 1758, 1758, 1758, 1758,
    0, 1758,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1758, 1758, 1758, 1758,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1758,    0, 1758,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1758,    0, 1758,    0,    0, 1758,    0, 1758, 1758,
    0,    0, 1758, 1758,    0, 1758,    0,    0,    0,    0,
    0, 1758,    0, 1758, 1758, 1758, 1758,    0, 1758,    0,
    0, 1758,    0,    0, 1758,    0,    0,    0,    0,    0,
    0, 1758,    0, 1758, 1758,    0, 1758, 1758, 1758, 1758,
 1758,    0,    0, 1758,    0,    0, 1758,    0, 1758, 1758,
    0,    0, 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758,
 1758, 1758, 1758,    0,    0,    0, 1758, 1758, 1758, 1758,
 1758,    0,    0,    0, 1758,    0,    0,    0,    0,    0,
    0,    0, 1758, 1758, 1758, 1758, 1758, 1758,    0,    0,
    0, 1758, 1758,    0, 1758,    0, 1758,    0, 1758, 1758,
 1758,    0, 1758,    0, 1758, 1758, 1758,    0, 1758, 1758,
 1758, 1758, 1758,    0, 1758, 1758,    0,    0,    0,    0,
 1758,    0, 1758, 1758,    0,    0, 1758, 1758, 1758,    0,
    0, 1758,    0, 1758,    0,    0, 1758, 1758, 1758, 1758,
    0, 1758,    0, 1758,    0, 1758, 1758, 1758, 1758, 1758,
    0,    0, 1758, 1758, 1758,    0, 1758, 1758,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1758, 1758, 1758,
    0, 1758, 1758, 1758,    0, 1758,    0,    0,    0, 1758,
    0, 1758, 1758, 1758, 1758,    0, 1758,    0, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1758, 1758,    0, 1758, 1758,
 1758,    0,    0,    0,    0, 1758, 1758, 1758, 1758, 1758,
    0, 1758,    0,    0, 1758, 1758,    0,    0,    0, 1758,
 1758,    0,    0, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758,    0, 1758,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758, 1758,
 1758,    0, 1758, 1758, 1758, 1758,    0, 1758,    0, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758,    0, 1758, 1758,
 1758, 1758,    0, 1758, 1758, 1758, 1758, 1758,    0, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,    0,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1776, 1758,
 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758, 1758, 1758,
    0,    0, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758,    0,    0,    0,    0,    0, 1758,    0, 1758, 1758,
 1758, 1758, 1758, 1758,    0, 1758,    0,    0,    0, 1776,
 1776, 1776, 1776, 1776, 1772, 1776,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1776, 1776, 1776,
 1776,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1776,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1776,    0, 1776,    0,    0,
 1776,    0, 1776, 1776,    0,    0, 1776, 1776,    0, 1776,
    0,    0,    0,    0,    0, 1776,    0, 1776, 1776, 1776,
 1776,    0, 1776,    0,    0, 1776,    0,    0, 1776,    0,
    0,    0,    0,    0,    0, 1776,    0, 1776, 1776,    0,
 1776, 1776, 1776, 1776, 1776,    0,    0, 1776,    0,    0,
 1776,    0, 1776, 1776,    0,    0, 1776, 1776, 1776,    0,
 1776, 1776, 1776, 1776, 1776, 1776, 1776,    0,    0,    0,
 1776, 1776, 1776, 1776, 1776,    0,    0,    0, 1776,    0,
    0,    0,    0,    0,    0,    0, 1776, 1776, 1776, 1776,
 1776, 1776,    0,    0,    0, 1776, 1776,    0, 1776,    0,
 1776,    0, 1776, 1776, 1776,    0, 1776,    0, 1776, 1776,
 1776,    0, 1776, 1776, 1776, 1776, 1776,    0, 1776, 1776,
    0,    0,    0,    0, 1776,    0, 1776, 1776,    0,    0,
 1776, 1776, 1776,    0,    0, 1776,    0, 1776,    0,    0,
 1776, 1776, 1776, 1776,    0, 1776,    0, 1776,    0, 1776,
 1776, 1776, 1776, 1776,    0,    0, 1776, 1776, 1776,    0,
 1776, 1776,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1776, 1776, 1776,    0, 1776, 1776, 1776,    0, 1776,
    0,    0,    0, 1776,    0, 1776, 1776, 1776, 1776,    0,
 1776,    0, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1776,
 1776,    0, 1776, 1776, 1776,    0,    0,    0,    0, 1776,
 1776, 1776, 1776, 1776,    0, 1776,    0,    0, 1776, 1776,
    0,    0,    0, 1776, 1776,    0,    0, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776, 1776,    0, 1776,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776,    0, 1776,
 1776, 1776, 1776, 1776, 1776,    0, 1776, 1776, 1776, 1776,
    0, 1776,    0, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
 1776,    0, 1776, 1776, 1776, 1776,    0, 1776, 1776, 1776,
 1776, 1776,    0, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776, 1776,
 1776, 1776, 1776,    0, 1776, 1776, 1776, 1776, 1776, 1776,
 1776, 1776, 1481, 1776, 1776, 1776, 1776,    0, 1776, 1776,
 1776, 1776, 1776, 1776,    0,    0, 1776, 1776, 1776, 1776,
 1776, 1776, 1776, 1776, 1776,    0,    0,    0,    0,    0,
 1776,    0, 1776, 1776, 1776, 1776, 1776, 1776,    0, 1776,
    0,    0,    0, 1481, 1481, 1481, 1481, 1481,    0, 1481,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1481, 1481, 1481, 1481,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1481,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1481,
    0, 1481,    0,    0, 1481,    0, 1481, 1481,    0,    0,
 1481, 1481,    0, 1481,    0,    0,    0,    0,    0, 1481,
    0, 1481, 1481, 1481, 1481,    0, 1481,    0,    0, 1481,
    0,    0, 1481,    0,    0,    0,    0,    0,    0, 1481,
    0, 1481, 1481,    0, 1481, 1481, 1481, 1481, 1481,    0,
    0, 1481,    0,    0, 1481,    0, 1481, 1481,    0,    0,
 1481, 1481, 1481,    0, 1481, 1481, 1481, 1481, 1481, 1481,
 1481,    0,    0,    0, 1481, 1481, 1481, 1481, 1481,    0,
    0,    0, 1481,    0,    0,    0,    0,    0,    0,    0,
 1481, 1481, 1481, 1481, 1481, 1481,    0,    0,    0, 1481,
 1481,    0, 1481,    0, 1481,    0, 1481, 1481, 1481,    0,
 1481,    0, 1481, 1481, 1481,    0, 1481, 1481, 1481, 1481,
 1481,    0, 1481, 1481,    0,    0,    0,    0, 1481,    0,
 1481, 1481,    0,    0, 1481, 1481, 1481,    0,    0, 1481,
    0, 1481,    0,    0, 1481, 1481, 1481, 1481,    0, 1481,
    0, 1481,    0, 1481, 1481, 1481, 1481, 1481,    0,    0,
 1481, 1481, 1481,    0, 1481, 1481,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1481, 1481, 1481,    0, 1481,
 1481, 1481,    0, 1481,    0,    0,    0, 1481,    0, 1481,
 1481, 1481, 1481,    0, 1481,    0, 1481, 1481, 1481, 1481,
 1481, 1481, 1481, 1481,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1481, 1481,    0, 1481, 1481, 1481,    0,
    0,    0,    0, 1481, 1481, 1481, 1481, 1481,    0, 1481,
    0,    0, 1481, 1481,    0,    0,    0, 1481, 1481,    0,
    0, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,
    0, 1481,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,
 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,
 1481, 1481,    0, 1481, 1481, 1481, 1481, 1481, 1481,    0,
 1481, 1481, 1481, 1481,    0, 1481,    0, 1481, 1481, 1481,
 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,
 1481, 1481, 1481, 1481, 1481,    0, 1481, 1481, 1481, 1481,
    0, 1481, 1481, 1481, 1481, 1481,    0, 1481, 1481, 1481,
 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,
 1481, 1481, 1481, 1481, 1481, 1481, 1481,    0, 1481, 1481,
 1481, 1481, 1481, 1481, 1481, 1481, 1495, 1481, 1481, 1481,
 1481,    0, 1481, 1481, 1481, 1481, 1481, 1481,    0,    0,
 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481, 1481,    0,
    0,    0,    0,    0, 1481,    0, 1481, 1481, 1481, 1481,
 1481, 1481,    0, 1481,    0,    0,    0, 1495, 1495, 1495,
 1495, 1495,    0, 1495,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1495, 1495, 1495, 1495,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1495,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1495,    0, 1495,    0,    0, 1495,    0,
 1495, 1495,    0,    0, 1495, 1495,    0, 1495,    0,    0,
    0,    0,    0,    0,    0, 1495, 1495, 1495, 1495,    0,
 1495,    0,    0, 1495,    0,    0, 1495,    0,    0,    0,
    0,    0,    0, 1495,    0, 1495, 1495,    0, 1495, 1495,
 1495, 1495, 1495,    0,    0, 1495,    0,    0, 1495,    0,
 1495, 1495,    0,    0, 1495, 1495, 1495,    0, 1495, 1495,
 1495, 1495, 1495, 1495, 1495,    0,    0,    0, 1495, 1495,
 1495, 1495, 1495,    0,    0,    0, 1495,    0,    0,    0,
    0,    0,    0,    0, 1495, 1495, 1495, 1495, 1495, 1495,
    0,    0,    0, 1495, 1495,    0, 1495,    0, 1495,    0,
 1495, 1495, 1495,    0, 1495,    0, 1495, 1495, 1495,    0,
 1495, 1495, 1495, 1495, 1495,    0, 1495, 1495,    0,    0,
    0,    0, 1495,    0, 1495, 1495,    0,    0, 1495, 1495,
 1495,    0,    0, 1495,    0, 1495,    0,    0, 1495, 1495,
 1495, 1495,    0, 1495,    0, 1495,    0, 1495, 1495, 1495,
 1495, 1495,    0,    0, 1495, 1495, 1495,    0, 1495, 1495,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1495,
 1495, 1495,    0, 1495, 1495, 1495,    0, 1495,    0,    0,
    0, 1495,    0, 1495, 1495, 1495, 1495,    0, 1495,    0,
 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1495, 1495,    0,
 1495, 1495, 1495,    0,    0,    0,    0, 1495, 1495, 1495,
 1495, 1495,    0, 1495,    0,    0, 1495, 1495,    0,    0,
    0, 1495, 1495,    0,    0, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495, 1495,    0, 1495,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495, 1495, 1495, 1495,    0, 1495, 1495, 1495,
 1495, 1495, 1495,    0, 1495, 1495, 1495, 1495,    0, 1495,
    0, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,    0,
 1495, 1495, 1495, 1495,    0, 1495, 1495, 1495, 1495, 1495,
    0, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,
 1495,    0, 1495, 1495, 1495, 1495, 1495, 1495, 1495, 1495,
 1493, 1495, 1495, 1495, 1495,    0, 1495, 1495, 1495, 1495,
 1495, 1495,    0,    0, 1495, 1495, 1495, 1495, 1495, 1495,
 1495, 1495, 1495,    0,    0,    0,    0,    0, 1495,    0,
 1495, 1495, 1495, 1495, 1495, 1495,    0, 1495,    0,    0,
    0, 1493, 1493, 1493, 1493, 1493,    0, 1493,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1493,
 1493, 1493, 1493,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1493,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1493,    0, 1493,
    0,    0, 1493,    0, 1493, 1493,    0,    0, 1493, 1493,
    0, 1493,    0,    0,    0,    0,    0,    0,    0, 1493,
 1493,    0, 1493,    0, 1493,    0,    0, 1493,    0,    0,
 1493,    0,    0,    0,    0,    0,    0, 1493,    0, 1493,
 1493,    0, 1493, 1493, 1493, 1493, 1493,    0,    0, 1493,
    0,    0, 1493,    0, 1493, 1493,    0,    0, 1493, 1493,
 1493,    0, 1493, 1493, 1493, 1493, 1493, 1493, 1493,    0,
    0,    0, 1493, 1493, 1493, 1493, 1493,    0,    0,    0,
 1493,    0,    0,    0,    0,    0,    0,    0, 1493, 1493,
 1493, 1493, 1493, 1493,    0,    0,    0, 1493, 1493,    0,
 1493,    0, 1493,    0, 1493, 1493, 1493,    0, 1493,    0,
 1493, 1493, 1493,    0, 1493, 1493, 1493, 1493, 1493,    0,
 1493, 1493,    0,    0,    0,    0, 1493,    0, 1493, 1493,
    0,    0, 1493, 1493, 1493,    0,    0, 1493,    0, 1493,
    0,    0, 1493, 1493, 1493, 1493,    0, 1493,    0, 1493,
    0, 1493, 1493, 1493, 1493, 1493,    0,    0, 1493, 1493,
 1493,    0, 1493, 1493,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1493, 1493, 1493,    0, 1493, 1493, 1493,
    0, 1493,    0,    0,    0, 1493,    0, 1493, 1493, 1493,
 1493,    0, 1493,    0, 1493, 1493, 1493, 1493, 1493, 1493,
 1493, 1493,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1493, 1493,    0, 1493, 1493, 1493,    0,    0,    0,
    0, 1493, 1493, 1493, 1493, 1493,    0, 1493,    0,    0,
 1493, 1493,    0,    0,    0, 1493, 1493,    0,    0, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493,    0, 1493,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493,
    0, 1493, 1493, 1493, 1493, 1493, 1493,    0, 1493, 1493,
 1493, 1493,    0, 1493,    0, 1493, 1493, 1493, 1493, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493,
 1493, 1493, 1493,    0, 1493, 1493, 1493, 1493,    0, 1493,
 1493, 1493, 1493, 1493,    0, 1493, 1493, 1493, 1493, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493, 1493,
 1493, 1493, 1493, 1493, 1493,    0, 1493, 1493, 1493, 1493,
 1493, 1493, 1493, 1493, 1492, 1493, 1493, 1493, 1493,    0,
 1493, 1493, 1493, 1493, 1493, 1493,    0,    0, 1493, 1493,
 1493, 1493, 1493, 1493, 1493, 1493, 1493,    0,    0,    0,
    0,    0, 1493,    0, 1493, 1493, 1493, 1493, 1493, 1493,
    0, 1493,    0,    0,    0, 1492, 1492, 1492, 1492, 1492,
    0, 1492,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492, 1492, 1492,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1492,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1492,    0, 1492,    0,    0, 1492,    0, 1492, 1492,
    0,    0, 1492, 1492,    0, 1492,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492,    0, 1492,    0, 1492,    0,
    0, 1492,    0,    0, 1492,    0,    0,    0,    0,    0,
    0, 1492,    0, 1492, 1492,    0, 1492, 1492, 1492, 1492,
 1492,    0,    0, 1492,    0,    0, 1492,    0, 1492, 1492,
    0,    0, 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492,
 1492, 1492, 1492,    0,    0,    0, 1492, 1492, 1492, 1492,
 1492,    0,    0,    0, 1492,    0,    0,    0,    0,    0,
    0,    0, 1492, 1492, 1492, 1492, 1492, 1492,    0,    0,
    0, 1492, 1492,    0, 1492,    0, 1492,    0, 1492, 1492,
 1492,    0, 1492,    0, 1492, 1492, 1492,    0, 1492, 1492,
 1492, 1492, 1492,    0, 1492, 1492,    0,    0,    0,    0,
 1492,    0, 1492, 1492,    0,    0, 1492, 1492, 1492,    0,
    0, 1492,    0, 1492,    0,    0, 1492, 1492, 1492, 1492,
    0, 1492,    0, 1492,    0, 1492, 1492, 1492, 1492, 1492,
    0,    0, 1492, 1492, 1492,    0, 1492, 1492,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1492, 1492, 1492,
    0, 1492, 1492, 1492,    0, 1492,    0,    0,    0, 1492,
    0, 1492, 1492, 1492, 1492,    0, 1492,    0, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1492, 1492,    0, 1492, 1492,
 1492,    0,    0,    0,    0, 1492, 1492, 1492, 1492, 1492,
    0, 1492,    0,    0, 1492, 1492,    0,    0,    0, 1492,
 1492,    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492,    0, 1492,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492,
 1492,    0, 1492, 1492, 1492, 1492,    0, 1492,    0, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492,    0, 1492, 1492,
 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492,    0, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,    0,
 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1498, 1492,
 1492, 1492, 1492,    0, 1492, 1492, 1492, 1492, 1492, 1492,
    0,    0, 1492, 1492, 1492, 1492, 1492, 1492, 1492, 1492,
 1492,    0,    0,    0,    0,    0, 1492,    0, 1492, 1492,
 1492, 1492, 1492, 1492,    0, 1492,    0,    0,    0, 1498,
 1498, 1498, 1498, 1498,    0, 1498,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1498, 1498, 1498,
 1498,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1498,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1498,    0, 1498,    0,    0,
 1498,    0, 1498, 1498,    0,    0, 1498, 1498,    0, 1498,
    0,    0,    0,    0,    0,    0,    0, 1498, 1498,    0,
 1498,    0, 1498,    0,    0, 1498,    0,    0, 1498,    0,
    0,    0,    0,    0,    0, 1498,    0, 1498, 1498,    0,
 1498, 1498, 1498, 1498, 1498,    0,    0, 1498,    0,    0,
 1498,    0, 1498, 1498,    0,    0, 1498, 1498, 1498,    0,
 1498, 1498, 1498, 1498, 1498, 1498, 1498,    0,    0,    0,
 1498, 1498, 1498, 1498, 1498,    0,    0,    0, 1498,    0,
    0,    0,    0,    0,    0,    0, 1498, 1498, 1498, 1498,
 1498, 1498,    0,    0,    0, 1498, 1498,    0, 1498,    0,
 1498,    0, 1498, 1498, 1498,    0, 1498,    0, 1498, 1498,
 1498,    0, 1498, 1498, 1498, 1498, 1498,    0, 1498, 1498,
    0,    0,    0,    0, 1498,    0, 1498, 1498,    0,    0,
 1498, 1498, 1498,    0,    0, 1498,    0, 1498,    0,    0,
 1498, 1498, 1498, 1498,    0, 1498,    0, 1498,    0, 1498,
 1498, 1498, 1498, 1498,    0,    0, 1498, 1498, 1498,    0,
 1498, 1498,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1498, 1498, 1498,    0, 1498, 1498, 1498,    0, 1498,
    0,    0,    0, 1498,    0, 1498, 1498, 1498, 1498,    0,
 1498,    0, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1498,
 1498,    0, 1498, 1498, 1498,    0,    0,    0,    0, 1498,
 1498, 1498, 1498, 1498,    0, 1498,    0,    0, 1498, 1498,
    0,    0,    0, 1498, 1498,    0,    0, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498, 1498,    0, 1498,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498,    0, 1498,
 1498, 1498, 1498, 1498, 1498,    0, 1498, 1498, 1498, 1498,
    0, 1498,    0, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
 1498,    0, 1498, 1498, 1498, 1498,    0, 1498, 1498, 1498,
 1498, 1498,    0, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498, 1498,
 1498, 1498, 1498,    0, 1498, 1498, 1498, 1498, 1498, 1498,
 1498, 1498, 1499, 1498, 1498, 1498, 1498,    0, 1498, 1498,
 1498, 1498, 1498, 1498,    0,    0, 1498, 1498, 1498, 1498,
 1498, 1498, 1498, 1498, 1498,    0,    0,    0,    0,    0,
 1498,    0, 1498, 1498, 1498, 1498, 1498, 1498,    0, 1498,
    0,    0,    0, 1499, 1499, 1499, 1499, 1499,    0, 1499,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1499, 1499, 1499, 1499,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1499,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1499,
    0, 1499,    0,    0, 1499,    0, 1499, 1499,    0,    0,
 1499, 1499,    0, 1499,    0,    0,    0,    0,    0,    0,
    0, 1499, 1499,    0, 1499,    0, 1499,    0,    0, 1499,
    0,    0, 1499,    0,    0,    0,    0,    0,    0, 1499,
    0, 1499, 1499,    0, 1499, 1499, 1499, 1499, 1499,    0,
    0, 1499,    0,    0, 1499,    0, 1499, 1499,    0,    0,
 1499, 1499, 1499,    0, 1499, 1499, 1499, 1499, 1499, 1499,
 1499,    0,    0,    0, 1499, 1499, 1499, 1499, 1499,    0,
    0,    0, 1499,    0,    0,    0,    0,    0,    0,    0,
 1499, 1499, 1499, 1499, 1499, 1499,    0,    0,    0, 1499,
 1499,    0, 1499,    0, 1499,    0, 1499, 1499, 1499,    0,
 1499,    0, 1499, 1499, 1499,    0, 1499, 1499, 1499, 1499,
 1499,    0, 1499, 1499,    0,    0,    0,    0, 1499,    0,
 1499, 1499,    0,    0, 1499, 1499, 1499,    0,    0, 1499,
    0, 1499,    0,    0, 1499, 1499, 1499, 1499,    0, 1499,
    0, 1499,    0, 1499, 1499, 1499, 1499, 1499,    0,    0,
 1499, 1499, 1499,    0, 1499, 1499,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1499, 1499, 1499,    0, 1499,
 1499, 1499,    0, 1499,    0,    0,    0, 1499,    0, 1499,
 1499, 1499, 1499,    0, 1499,    0, 1499, 1499, 1499, 1499,
 1499, 1499, 1499, 1499,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1499, 1499,    0, 1499, 1499, 1499,    0,
    0,    0,    0, 1499, 1499, 1499, 1499, 1499,    0, 1499,
    0,    0, 1499, 1499,    0,    0,    0, 1499, 1499,    0,
    0, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,
    0, 1499,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,
 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,
 1499, 1499,    0, 1499, 1499, 1499, 1499, 1499, 1499,    0,
 1499, 1499, 1499, 1499,    0, 1499,    0, 1499, 1499, 1499,
 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,
 1499, 1499, 1499, 1499, 1499,    0, 1499, 1499, 1499, 1499,
    0, 1499, 1499, 1499, 1499, 1499,    0, 1499, 1499, 1499,
 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,
 1499, 1499, 1499, 1499, 1499, 1499, 1499,    0, 1499, 1499,
 1499, 1499, 1499, 1499, 1499, 1499, 1494, 1499, 1499, 1499,
 1499,    0, 1499, 1499, 1499, 1499, 1499, 1499,    0,    0,
 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499, 1499,    0,
    0,    0,    0,    0, 1499,    0, 1499, 1499, 1499, 1499,
 1499, 1499,    0, 1499,    0,    0,    0, 1494,    0, 1494,
 1494, 1494,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1494, 1494, 1494, 1494,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1494,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1494,    0, 1494,    0,    0, 1494,    0,
 1494, 1494,    0,    0, 1494, 1494,    0, 1494,    0,    0,
    0,    0,    0,    0,    0, 1494, 1494,    0, 1494,    0,
 1494,    0,    0, 1494,    0,    0, 1494,    0,    0,    0,
    0,    0,    0, 1494,    0, 1494, 1494,    0, 1494, 1494,
 1494, 1494, 1494,    0,    0, 1494,    0,    0, 1494,    0,
 1494, 1494,    0,    0, 1494, 1494, 1494,    0, 1494, 1494,
 1494, 1494, 1494, 1494, 1494,    0,    0,    0, 1494, 1494,
 1494, 1494, 1494,    0,    0,    0, 1494,    0,    0,    0,
    0,    0,    0,    0, 1494, 1494, 1494, 1494, 1494, 1494,
    0,    0,    0, 1494, 1494,    0, 1494,    0, 1494,    0,
 1494, 1494, 1494,    0, 1494,    0, 1494, 1494, 1494,    0,
 1494, 1494, 1494, 1494, 1494,    0, 1494, 1494,    0,    0,
    0,    0, 1494,    0, 1494, 1494,    0,    0, 1494, 1494,
 1494,    0,    0, 1494,    0, 1494,    0,    0, 1494, 1494,
 1494, 1494,    0, 1494,    0, 1494,    0, 1494, 1494, 1494,
 1494, 1494,    0,    0, 1494, 1494, 1494,    0, 1494, 1494,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1494,
 1494, 1494,    0, 1494, 1494, 1494,    0, 1494,    0,    0,
    0, 1494,    0, 1494, 1494, 1494, 1494,    0, 1494,    0,
 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1494, 1494,    0,
 1494, 1494, 1494,    0,    0,    0,    0, 1494, 1494, 1494,
 1494, 1494,    0, 1494,    0,    0, 1494, 1494,    0,    0,
    0, 1494, 1494,    0,    0, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494, 1494,    0, 1494,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494, 1494, 1494, 1494,    0, 1494, 1494, 1494,
 1494, 1494, 1494,    0, 1494, 1494, 1494, 1494,    0, 1494,
    0, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,    0,
 1494, 1494, 1494, 1494,    0, 1494, 1494, 1494, 1494, 1494,
    0, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,
 1494,    0, 1494, 1494, 1494, 1494, 1494, 1494, 1494, 1494,
 1497, 1494, 1494, 1494, 1494,    0, 1494, 1494, 1494, 1494,
 1494, 1494,    0,    0, 1494, 1494, 1494, 1494, 1494, 1494,
 1494, 1494, 1494,    0,    0,    0,    0,    0, 1494,    0,
 1494, 1494, 1494, 1494, 1494, 1494,    0, 1494,    0,    0,
    0, 1497,    0, 1497, 1497, 1497,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1497,
 1497, 1497, 1497,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1497,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1497,    0, 1497,
    0,    0, 1497,    0, 1497, 1497,    0,    0, 1497, 1497,
    0, 1497,    0,    0,    0,    0,    0,    0,    0, 1497,
 1497,    0, 1497,    0, 1497,    0,    0, 1497,    0,    0,
 1497,    0,    0,    0,    0,    0,    0, 1497,    0, 1497,
 1497,    0, 1497, 1497, 1497, 1497, 1497,    0,    0, 1497,
    0,    0, 1497,    0, 1497, 1497,    0,    0, 1497, 1497,
 1497,    0, 1497, 1497, 1497, 1497, 1497, 1497, 1497,    0,
    0,    0, 1497, 1497, 1497, 1497, 1497,    0,    0,    0,
 1497,    0,    0,    0,    0,    0,    0,    0, 1497, 1497,
 1497, 1497, 1497, 1497,    0,    0,    0, 1497, 1497,    0,
 1497,    0, 1497,    0, 1497, 1497, 1497,    0, 1497,    0,
 1497, 1497, 1497,    0, 1497, 1497, 1497, 1497, 1497,    0,
 1497, 1497,    0,    0,    0,    0, 1497,    0, 1497, 1497,
    0,    0, 1497, 1497, 1497,    0,    0, 1497,    0, 1497,
    0,    0, 1497, 1497, 1497, 1497,    0, 1497,    0, 1497,
    0, 1497, 1497, 1497, 1497, 1497,    0,    0, 1497, 1497,
 1497,    0, 1497, 1497,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1497, 1497, 1497,    0, 1497, 1497, 1497,
    0, 1497,    0,    0,    0, 1497,    0, 1497, 1497, 1497,
 1497,    0, 1497,    0, 1497, 1497, 1497, 1497, 1497, 1497,
 1497, 1497,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1497, 1497,    0, 1497, 1497, 1497,    0,    0,    0,
    0, 1497, 1497, 1497, 1497, 1497,    0, 1497,    0,    0,
 1497, 1497,    0,    0,    0, 1497, 1497,    0,    0, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497,    0, 1497,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497,
    0, 1497, 1497, 1497, 1497, 1497, 1497,    0, 1497, 1497,
 1497, 1497,    0, 1497,    0, 1497, 1497, 1497, 1497, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497,
 1497, 1497, 1497,    0, 1497, 1497, 1497, 1497,    0, 1497,
 1497, 1497, 1497, 1497,    0, 1497, 1497, 1497, 1497, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497, 1497,
 1497, 1497, 1497, 1497, 1497,    0, 1497, 1497, 1497, 1497,
 1497, 1497, 1497, 1497, 1474, 1497, 1497, 1497, 1497,    0,
 1497, 1497, 1497, 1497, 1497, 1497,    0,    0, 1497, 1497,
 1497, 1497, 1497, 1497, 1497, 1497, 1497,    0,    0,    0,
    0,    0, 1497,    0, 1497, 1497, 1497, 1497, 1497, 1497,
    0, 1497,    0,    0,    0, 1474,    0,    0, 1474,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1474, 1474, 1474, 1474,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1474,    0, 1474,    0,    0, 1474,    0, 1474, 1474,
    0,    0, 1474, 1474,    0, 1474,    0,    0,    0,    0,
    0,    0,    0, 1474, 1474,    0, 1474,    0, 1474,    0,
    0, 1474,    0,    0, 1474,    0,    0,    0,    0,    0,
    0, 1474,    0, 1474, 1474,    0, 1474, 1474, 1474, 1474,
 1474,    0,    0, 1474,    0,    0, 1474,    0, 1474, 1474,
    0,    0, 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474,
 1474, 1474, 1474,    0,    0,    0, 1474, 1474, 1474, 1474,
 1474,    0,    0,    0, 1474,    0,    0,    0,    0,    0,
    0,    0, 1474, 1474, 1474, 1474, 1474, 1474,    0,    0,
    0, 1474, 1474,    0, 1474,    0, 1474,    0, 1474, 1474,
 1474,    0, 1474,    0, 1474, 1474, 1474,    0, 1474, 1474,
 1474, 1474, 1474,    0, 1474, 1474,    0,    0,    0,    0,
 1474,    0, 1474, 1474,    0,    0, 1474, 1474, 1474,    0,
    0, 1474,    0, 1474,    0,    0, 1474, 1474, 1474, 1474,
    0, 1474,    0, 1474,    0, 1474, 1474, 1474, 1474, 1474,
    0,    0, 1474, 1474, 1474,    0, 1474, 1474,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1474, 1474, 1474,
    0, 1474, 1474, 1474,    0, 1474,    0,    0,    0, 1474,
    0, 1474, 1474, 1474, 1474,    0, 1474,    0, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1474, 1474,    0, 1474, 1474,
 1474,    0,    0,    0,    0, 1474, 1474, 1474, 1474, 1474,
    0, 1474,    0,    0, 1474, 1474,    0,    0,    0, 1474,
 1474,    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474,    0, 1474,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474,
 1474,    0, 1474, 1474, 1474, 1474,    0, 1474,    0, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474,    0, 1474, 1474,
 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474,    0, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,    0,
 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1379, 1474,
 1474, 1474, 1474,    0, 1474, 1474, 1474, 1474, 1474, 1474,
    0,    0, 1474, 1474, 1474, 1474, 1474, 1474, 1474, 1474,
 1474,    0,    0,    0,    0,    0, 1474,    0, 1474, 1474,
 1474, 1474, 1474, 1474,    0, 1474,    0,    0,    0, 1379,
    0,    0, 1379,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1379, 1379, 1379,
 1379,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1379,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1379,    0, 1379,    0,    0,
 1379,    0, 1379, 1379,    0,    0, 1379, 1379,    0, 1379,
    0,    0,    0,    0,    0,    0,    0, 1379, 1379,    0,
 1379,    0, 1379,    0,    0, 1379,    0,    0, 1379,    0,
    0,    0,    0,    0,    0, 1379,    0, 1379, 1379,    0,
 1379, 1379, 1379, 1379, 1379,    0,    0, 1379,    0,    0,
 1379,    0, 1379, 1379,    0,    0, 1379, 1379, 1379,    0,
 1379, 1379, 1379, 1379, 1379, 1379, 1379,    0,    0,    0,
 1379, 1379, 1379, 1379, 1379,    0,    0,    0, 1379,    0,
    0,    0,    0,    0,    0,    0, 1379, 1379, 1379, 1379,
 1379, 1379,    0,    0,    0, 1379, 1379,    0, 1379,    0,
 1379,    0, 1379, 1379, 1379,    0, 1379,    0, 1379, 1379,
 1379,    0, 1379, 1379, 1379, 1379, 1379,    0, 1379, 1379,
    0,    0,    0,    0, 1379,    0, 1379, 1379,    0,    0,
 1379, 1379, 1379,    0,    0, 1379,    0, 1379,    0,    0,
 1379, 1379, 1379, 1379,    0, 1379,    0, 1379,    0, 1379,
 1379, 1379, 1379, 1379,    0,    0, 1379, 1379, 1379,    0,
 1379, 1379,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1379, 1379, 1379,    0, 1379, 1379, 1379,    0, 1379,
    0,    0,    0, 1379,    0, 1379, 1379, 1379, 1379,    0,
 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1379,
 1379,    0, 1379, 1379, 1379,    0,    0,    0,    0, 1379,
 1379, 1379, 1379, 1379,    0, 1379,    0,    0, 1379, 1379,
    0,    0,    0, 1379, 1379,    0,    0, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379,    0, 1379,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,    0, 1379,
 1379, 1379, 1379, 1379, 1379,    0, 1379, 1379, 1379, 1379,
    0, 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379,    0, 1379, 1379, 1379, 1379,    0, 1379, 1379, 1379,
 1379, 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379,
 1379, 1379, 1362, 1379, 1379, 1379, 1379,    0, 1379, 1379,
 1379, 1379, 1379, 1379,    0,    0, 1379, 1379, 1379, 1379,
 1379, 1379, 1379, 1379, 1379,    0,    0,    0,    0,    0,
 1379,    0, 1379, 1379, 1379, 1379, 1379, 1379,    0, 1379,
    0,    0,    0, 1362,    0,    0, 1362,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1362, 1362, 1362, 1362,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1362,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1362,
    0, 1362,    0,    0, 1362,    0, 1362, 1362,    0,    0,
 1362, 1362,    0, 1362,    0,    0,    0,    0,    0,    0,
    0, 1362, 1362,    0, 1362,    0, 1362,    0,    0, 1362,
    0,    0, 1362,    0,    0,    0,    0,    0,    0, 1362,
    0, 1362, 1362,    0, 1362, 1362, 1362, 1362, 1362,    0,
    0, 1362,    0,    0, 1362,    0, 1362, 1362,    0,    0,
 1362, 1362, 1362,    0, 1362, 1362, 1362, 1362, 1362, 1362,
 1362,    0,    0,    0, 1362,    0, 1362, 1362, 1362,    0,
    0,    0, 1362,    0,    0,    0,    0,    0,    0,    0,
 1362, 1362, 1362, 1362, 1362, 1362,    0,    0,    0, 1362,
 1362,    0, 1362,    0, 1362,    0, 1362, 1362, 1362,    0,
 1362,    0, 1362, 1362, 1362,    0, 1362, 1362, 1362, 1362,
 1362,    0, 1362, 1362,    0,    0,    0,    0, 1362,    0,
 1362, 1362,    0,    0, 1362, 1362, 1362,    0,    0, 1362,
    0, 1362,    0,    0, 1362, 1362, 1362, 1362,    0, 1362,
    0, 1362,    0, 1362, 1362, 1362, 1362, 1362,    0,    0,
 1362, 1362, 1362,    0, 1362, 1362,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1362, 1362, 1362,    0, 1362,
 1362, 1362,    0, 1362,    0,    0,    0, 1362,    0, 1362,
 1362, 1362, 1362,    0, 1362,    0, 1362, 1362, 1362, 1362,
 1362, 1362, 1362, 1362,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1362, 1362,    0, 1362, 1362, 1362,    0,
    0,    0,    0, 1362, 1362, 1362, 1362, 1362,    0, 1362,
    0,    0, 1362, 1362,    0,    0,    0, 1362, 1362,    0,
    0, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,
    0, 1362,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,
 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,
 1362, 1362,    0, 1362, 1362, 1362, 1362, 1362, 1362,    0,
 1362, 1362, 1362, 1362,    0, 1362,    0, 1362, 1362, 1362,
 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,
 1362, 1362, 1362, 1362, 1362,    0, 1362, 1362, 1362, 1362,
    0, 1362, 1362, 1362, 1362, 1362,    0, 1362, 1362, 1362,
 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,
 1362, 1362, 1362, 1362, 1362, 1362, 1362,    0, 1362, 1362,
 1362, 1362, 1362, 1362, 1362, 1362, 1381, 1362, 1362, 1362,
 1362,    0, 1362, 1362, 1362, 1362, 1362, 1362,    0,    0,
 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362, 1362,    0,
    0,    0,    0,    0, 1362,    0, 1362, 1362, 1362, 1362,
 1362, 1362,    0, 1362,    0,    0,    0, 1381,    0,    0,
 1381,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381, 1381, 1381,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1381,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1381,    0, 1381,    0,    0, 1381,    0,
 1381, 1381,    0,    0, 1381, 1381,    0, 1381,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381,    0, 1381,    0,
 1381,    0,    0, 1381,    0,    0, 1381,    0,    0,    0,
    0,    0,    0, 1381,    0, 1381, 1381,    0, 1381, 1381,
 1381, 1381, 1381,    0,    0, 1381,    0,    0, 1381,    0,
 1381, 1381,    0,    0, 1381, 1381, 1381,    0, 1381, 1381,
 1381, 1381, 1381, 1381, 1381,    0,    0,    0, 1381,    0,
 1381, 1381, 1381,    0,    0,    0, 1381,    0,    0,    0,
    0,    0,    0,    0, 1381, 1381, 1381, 1381, 1381, 1381,
    0,    0,    0, 1381, 1381,    0, 1381,    0, 1381,    0,
 1381, 1381, 1381,    0, 1381,    0, 1381, 1381, 1381,    0,
 1381, 1381, 1381, 1381, 1381,    0, 1381, 1381,    0,    0,
    0,    0, 1381,    0, 1381, 1381,    0,    0, 1381, 1381,
 1381,    0,    0, 1381,    0, 1381,    0,    0, 1381, 1381,
 1381, 1381,    0, 1381,    0, 1381,    0, 1381, 1381, 1381,
 1381, 1381,    0,    0, 1381, 1381, 1381,    0, 1381, 1381,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1381,
 1381, 1381,    0, 1381, 1381, 1381,    0, 1381,    0,    0,
    0, 1381,    0, 1381, 1381, 1381, 1381,    0, 1381,    0,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1381, 1381,    0,
 1381, 1381, 1381,    0,    0,    0,    0, 1381, 1381, 1381,
 1381, 1381,    0, 1381,    0,    0, 1381, 1381,    0,    0,
    0, 1381, 1381,    0,    0, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381,    0, 1381,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381,
 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381,    0, 1381,
    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,    0,
 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381, 1381,
    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1381,    0, 1381, 1381, 1381, 1381, 1381, 1381, 1381, 1381,
 1382, 1381, 1381, 1381, 1381,    0, 1381, 1381, 1381, 1381,
 1381, 1381,    0,    0, 1381, 1381, 1381, 1381, 1381, 1381,
 1381, 1381, 1381,    0,    0,    0,    0,    0, 1381,    0,
 1381, 1381, 1381, 1381, 1381, 1381,    0, 1381,    0,    0,
    0, 1382,    0,    0, 1382,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382, 1382, 1382,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1382,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1382,    0, 1382,
    0,    0, 1382,    0, 1382, 1382,    0,    0, 1382, 1382,
    0, 1382,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382,    0, 1382,    0, 1382,    0,    0, 1382,    0,    0,
 1382,    0,    0,    0,    0,    0,    0, 1382,    0, 1382,
 1382,    0, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382,
    0,    0, 1382,    0, 1382, 1382,    0,    0, 1382, 1382,
 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0,
    0,    0, 1382,    0, 1382, 1382, 1382,    0,    0,    0,
 1382,    0,    0,    0,    0,    0,    0,    0, 1382, 1382,
 1382, 1382, 1382, 1382,    0,    0,    0, 1382, 1382,    0,
 1382,    0, 1382,    0, 1382, 1382, 1382,    0, 1382,    0,
 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382, 1382,    0,
 1382, 1382,    0,    0,    0,    0, 1382,    0, 1382, 1382,
    0,    0, 1382, 1382, 1382,    0,    0, 1382,    0, 1382,
    0,    0, 1382, 1382, 1382, 1382,    0, 1382,    0, 1382,
    0, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382, 1382,
 1382,    0, 1382, 1382,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1382, 1382, 1382,    0, 1382, 1382, 1382,
    0, 1382,    0,    0,    0, 1382,    0, 1382, 1382, 1382,
 1382,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1382, 1382,    0, 1382, 1382, 1382,    0,    0,    0,
    0, 1382, 1382, 1382, 1382, 1382,    0, 1382,    0,    0,
 1382, 1382,    0,    0,    0, 1382, 1382,    0,    0, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0, 1382,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
    0, 1382, 1382, 1382, 1382, 1382, 1382,    0, 1382, 1382,
 1382, 1382,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382,    0, 1382,
 1382, 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1382,    0, 1382, 1382, 1382, 1382,
 1382, 1382, 1382, 1382, 1387, 1382, 1382, 1382, 1382,    0,
 1382, 1382, 1382, 1382, 1382, 1382,    0,    0, 1382, 1382,
 1382, 1382, 1382, 1382, 1382, 1382, 1382,    0,    0,    0,
    0,    0, 1382,    0, 1382, 1382, 1382, 1382, 1382, 1382,
    0, 1382,    0,    0,    0, 1387,    0,    0, 1387,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1387, 1387, 1387, 1387,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1387,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1387,    0, 1387,    0,    0, 1387,    0, 1387, 1387,
    0,    0, 1387, 1387,    0, 1387,    0,    0,    0,    0,
    0,    0,    0, 1387, 1387,    0, 1387,    0, 1387,    0,
    0, 1387,    0,    0, 1387,    0,    0,    0,    0,    0,
    0, 1387,    0, 1387, 1387,    0, 1387, 1387, 1387, 1387,
 1387,    0,    0, 1387,    0,    0, 1387,    0, 1387, 1387,
    0,    0, 1387, 1387, 1387,    0, 1387, 1387, 1387, 1387,
 1387, 1387, 1387,    0,    0,    0, 1387,    0, 1387, 1387,
 1387,    0,    0,    0, 1387,    0,    0,    0,    0,    0,
    0,    0, 1387, 1387, 1387, 1387, 1387, 1387,    0,    0,
    0, 1387, 1387,    0, 1387,    0, 1387,    0, 1387, 1387,
 1387,    0, 1387,    0, 1387, 1387, 1387,    0, 1387, 1387,
 1387, 1387, 1387,    0, 1387, 1387,    0,    0,    0,    0,
 1387,    0, 1387, 1387,    0,    0, 1387, 1387, 1387,    0,
    0, 1387,    0, 1387,    0,    0, 1387, 1387, 1387, 1387,
    0, 1387,    0, 1387,    0, 1387, 1387, 1387, 1387, 1387,
    0,    0, 1387, 1387, 1387,    0, 1387, 1387,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1387, 1387, 1387,
    0, 1387, 1387, 1387,    0, 1387,    0,    0,    0, 1387,
    0, 1387, 1387, 1387, 1387,    0, 1387,    0, 1387, 1387,
 1387, 1387, 1387, 1387, 1387, 1387,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1387, 1387,    0, 1387, 1387,
 1387,    0,    0,    0,    0, 1387, 1387, 1387, 1387, 1387,
    0, 1387,    0,    0, 1387, 1387,    0,    0,    0, 1387,
 1387,    0,    0, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387, 1387,    0, 1387,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387, 1387, 1387, 1387,    0, 1387, 1387, 1387, 1387, 1387,
 1387,    0, 1387, 1387, 1387, 1387,    0, 1387,    0, 1387,
 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387, 1387, 1387, 1387, 1387, 1387, 1387,    0, 1387, 1387,
 1387, 1387,    0, 1387, 1387, 1387, 1387, 1387,    0, 1387,
 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387,    0,
 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1389, 1387,
 1387, 1387, 1387,    0, 1387, 1387, 1387, 1387, 1387, 1387,
    0,    0, 1387, 1387, 1387, 1387, 1387, 1387, 1387, 1387,
 1387,    0,    0,    0,    0,    0, 1387,    0, 1387, 1387,
 1387, 1387, 1387, 1387,    0, 1387,    0,    0,    0, 1389,
    0,    0, 1389,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1389, 1389, 1389,
 1389,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1389,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1389,    0, 1389,    0,    0,
 1389,    0, 1389, 1389,    0,    0, 1389, 1389,    0, 1389,
    0,    0,    0,    0,    0,    0,    0, 1389, 1389,    0,
 1389,    0, 1389,    0,    0, 1389,    0,    0, 1389,    0,
    0,    0,    0,    0,    0, 1389,    0, 1389, 1389,    0,
 1389, 1389, 1389, 1389, 1389,    0,    0, 1389,    0,    0,
 1389,    0, 1389, 1389,    0,    0, 1389, 1389, 1389,    0,
 1389, 1389, 1389, 1389, 1389, 1389, 1389,    0,    0,    0,
 1389,    0, 1389, 1389, 1389,    0,    0,    0, 1389,    0,
    0,    0,    0,    0,    0,    0, 1389, 1389, 1389, 1389,
 1389, 1389,    0,    0,    0, 1389, 1389,    0, 1389,    0,
 1389,    0, 1389, 1389, 1389,    0, 1389,    0, 1389, 1389,
 1389,    0, 1389, 1389, 1389, 1389, 1389,    0, 1389, 1389,
    0,    0,    0,    0, 1389,    0, 1389, 1389,    0,    0,
 1389, 1389, 1389,    0,    0, 1389,    0, 1389,    0,    0,
 1389, 1389, 1389, 1389,    0, 1389,    0, 1389,    0, 1389,
 1389, 1389, 1389, 1389,    0,    0, 1389, 1389, 1389,    0,
 1389, 1389,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1389, 1389, 1389,    0, 1389, 1389, 1389,    0, 1389,
    0,    0,    0, 1389,    0, 1389, 1389, 1389, 1389,    0,
 1389,    0, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1389,
 1389,    0, 1389, 1389, 1389,    0,    0,    0,    0, 1389,
 1389, 1389, 1389, 1389,    0, 1389,    0,    0, 1389, 1389,
    0,    0,    0, 1389, 1389,    0,    0, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389, 1389,    0, 1389,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389,    0, 1389,
 1389, 1389, 1389, 1389, 1389,    0, 1389, 1389, 1389, 1389,
    0, 1389,    0, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
 1389,    0, 1389, 1389, 1389, 1389,    0, 1389, 1389, 1389,
 1389, 1389,    0, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389, 1389,
 1389, 1389, 1389,    0, 1389, 1389, 1389, 1389, 1389, 1389,
 1389, 1389, 1391, 1389, 1389, 1389, 1389,    0, 1389, 1389,
 1389, 1389, 1389, 1389,    0,    0, 1389, 1389, 1389, 1389,
 1389, 1389, 1389, 1389, 1389,    0,    0,    0,    0,    0,
 1389,    0, 1389, 1389, 1389, 1389, 1389, 1389,    0, 1389,
    0,    0,    0, 1391,    0,    0, 1391,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1391, 1391, 1391, 1391,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1391,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1391,
    0, 1391,    0,    0, 1391,    0, 1391, 1391,    0,    0,
 1391, 1391,    0, 1391,    0,    0,    0,    0,    0,    0,
    0, 1391, 1391,    0, 1391,    0, 1391,    0,    0, 1391,
    0,    0, 1391,    0,    0,    0,    0,    0,    0, 1391,
    0, 1391, 1391,    0, 1391, 1391, 1391, 1391, 1391,    0,
    0, 1391,    0,    0, 1391,    0, 1391, 1391,    0,    0,
 1391, 1391, 1391,    0, 1391, 1391, 1391, 1391, 1391, 1391,
 1391,    0,    0,    0, 1391,    0, 1391, 1391, 1391,    0,
    0,    0, 1391,    0,    0,    0,    0,    0,    0,    0,
 1391, 1391, 1391, 1391, 1391, 1391,    0,    0,    0, 1391,
 1391,    0, 1391,    0, 1391,    0, 1391, 1391, 1391,    0,
 1391,    0, 1391, 1391, 1391,    0, 1391, 1391, 1391, 1391,
 1391,    0, 1391, 1391,    0,    0,    0,    0, 1391,    0,
 1391, 1391,    0,    0, 1391, 1391, 1391,    0,    0, 1391,
    0, 1391,    0,    0, 1391, 1391, 1391, 1391,    0, 1391,
    0, 1391,    0, 1391, 1391, 1391, 1391, 1391,    0,    0,
 1391, 1391, 1391,    0, 1391, 1391,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1391, 1391, 1391,    0, 1391,
 1391, 1391,    0, 1391,    0,    0,    0, 1391,    0, 1391,
 1391, 1391, 1391,    0, 1391,    0, 1391, 1391, 1391, 1391,
 1391, 1391, 1391, 1391,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1391, 1391,    0, 1391, 1391, 1391,    0,
    0,    0,    0, 1391, 1391, 1391, 1391, 1391,    0, 1391,
    0,    0, 1391, 1391,    0,    0,    0, 1391, 1391,    0,
    0, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,
    0, 1391,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,
 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,
 1391, 1391,    0, 1391, 1391, 1391, 1391, 1391, 1391,    0,
 1391, 1391, 1391, 1391,    0, 1391,    0, 1391, 1391, 1391,
 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,
 1391, 1391, 1391, 1391, 1391,    0, 1391, 1391, 1391, 1391,
    0, 1391, 1391, 1391, 1391, 1391,    0, 1391, 1391, 1391,
 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,
 1391, 1391, 1391, 1391, 1391, 1391, 1391,    0, 1391, 1391,
 1391, 1391, 1391, 1391, 1391, 1391, 1393, 1391, 1391, 1391,
 1391,    0, 1391, 1391, 1391, 1391, 1391, 1391,    0,    0,
 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391, 1391,    0,
    0,    0,    0,    0, 1391,    0, 1391, 1391, 1391, 1391,
 1391, 1391,    0, 1391,    0,    0,    0, 1393,    0,    0,
 1393,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1393, 1393, 1393, 1393,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1393,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1393,    0, 1393,    0,    0, 1393,    0,
 1393, 1393,    0,    0, 1393, 1393,    0, 1393,    0,    0,
    0,    0,    0,    0,    0, 1393, 1393,    0, 1393,    0,
 1393,    0,    0, 1393,    0,    0, 1393,    0,    0,    0,
    0,    0,    0, 1393,    0, 1393, 1393,    0, 1393, 1393,
 1393, 1393, 1393,    0,    0, 1393,    0,    0, 1393,    0,
 1393, 1393,    0,    0, 1393, 1393, 1393,    0, 1393, 1393,
 1393, 1393, 1393, 1393, 1393,    0,    0,    0, 1393,    0,
 1393, 1393, 1393,    0,    0,    0, 1393,    0,    0,    0,
    0,    0,    0,    0, 1393, 1393, 1393, 1393, 1393, 1393,
    0,    0,    0, 1393, 1393,    0, 1393,    0, 1393,    0,
 1393, 1393, 1393,    0, 1393,    0, 1393, 1393, 1393,    0,
 1393, 1393, 1393, 1393, 1393,    0, 1393, 1393,    0,    0,
    0,    0, 1393,    0, 1393, 1393,    0,    0, 1393, 1393,
 1393,    0,    0, 1393,    0, 1393,    0,    0, 1393, 1393,
 1393, 1393,    0, 1393,    0, 1393,    0, 1393, 1393, 1393,
 1393, 1393,    0,    0, 1393, 1393, 1393,    0, 1393, 1393,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1393,
 1393, 1393,    0, 1393, 1393, 1393,    0, 1393,    0,    0,
    0, 1393,    0, 1393, 1393, 1393, 1393,    0, 1393,    0,
 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1393, 1393,    0,
 1393, 1393, 1393,    0,    0,    0,    0, 1393, 1393, 1393,
 1393, 1393,    0, 1393,    0,    0, 1393, 1393,    0,    0,
    0, 1393, 1393,    0,    0, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393, 1393,    0, 1393,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393, 1393, 1393, 1393,    0, 1393, 1393, 1393,
 1393, 1393, 1393,    0, 1393, 1393, 1393, 1393,    0, 1393,
    0, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,    0,
 1393, 1393, 1393, 1393,    0, 1393, 1393, 1393, 1393, 1393,
    0, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,
 1393,    0, 1393, 1393, 1393, 1393, 1393, 1393, 1393, 1393,
 1386, 1393, 1393, 1393, 1393,    0, 1393, 1393, 1393, 1393,
 1393, 1393,    0,    0, 1393, 1393, 1393, 1393, 1393, 1393,
 1393, 1393, 1393,    0,    0,    0,    0,    0, 1393,    0,
 1393, 1393, 1393, 1393, 1393, 1393,    0, 1393,    0,    0,
    0, 1386,    0,    0, 1386,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1386,
 1386, 1386, 1386,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1386,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1386,    0, 1386,
    0,    0, 1386,    0, 1386, 1386,    0,    0, 1386, 1386,
    0, 1386,    0,    0,    0,    0,    0,    0,    0, 1386,
 1386,    0, 1386,    0, 1386,    0,    0, 1386,    0,    0,
 1386,    0,    0,    0,    0,    0,    0, 1386,    0, 1386,
 1386,    0, 1386, 1386, 1386,    0, 1386,    0,    0, 1386,
    0,    0, 1386,    0, 1386, 1386,    0,    0, 1386, 1386,
 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386, 1386,    0,
    0,    0, 1386,    0, 1386, 1386, 1386,    0,    0,    0,
 1386,    0,    0,    0,    0,    0,    0,    0, 1386, 1386,
 1386, 1386, 1386, 1386,    0,    0,    0, 1386, 1386,    0,
 1386,    0, 1386,    0, 1386, 1386, 1386,    0, 1386,    0,
 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386, 1386,    0,
 1386, 1386,    0,    0,    0,    0, 1386,    0, 1386, 1386,
    0,    0, 1386, 1386, 1386,    0,    0, 1386,    0, 1386,
    0,    0, 1386, 1386, 1386, 1386,    0, 1386,    0, 1386,
    0, 1386, 1386, 1386, 1386, 1386,    0,    0, 1386, 1386,
 1386,    0, 1386, 1386,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1386, 1386, 1386,    0, 1386, 1386, 1386,
    0, 1386,    0,    0,    0, 1386,    0, 1386, 1386, 1386,
 1386,    0, 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1386, 1386,    0, 1386, 1386, 1386,    0,    0,    0,
    0, 1386, 1386, 1386, 1386, 1386,    0, 1386,    0,    0,
 1386, 1386,    0,    0,    0, 1386, 1386,    0,    0, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,    0, 1386,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
    0, 1386, 1386, 1386, 1386, 1386, 1386,    0, 1386, 1386,
 1386, 1386,    0, 1386,    0, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386,    0, 1386,
 1386, 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1386,    0, 1386, 1386, 1386, 1386,
 1386, 1386, 1386, 1386, 1388, 1386, 1386, 1386, 1386,    0,
 1386, 1386, 1386, 1386, 1386, 1386,    0,    0, 1386, 1386,
 1386, 1386, 1386, 1386, 1386, 1386, 1386,    0,    0,    0,
    0,    0, 1386,    0, 1386, 1386, 1386, 1386, 1386, 1386,
    0, 1386,    0,    0,    0, 1388,    0,    0, 1388,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1388, 1388, 1388, 1388,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1388,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1388,    0, 1388,    0,    0, 1388,    0, 1388, 1388,
    0,    0, 1388, 1388,    0, 1388,    0,    0,    0,    0,
    0,    0,    0, 1388, 1388,    0, 1388,    0, 1388,    0,
    0, 1388,    0,    0, 1388,    0,    0,    0,    0,    0,
    0, 1388,    0, 1388, 1388,    0, 1388, 1388, 1388,    0,
 1388,    0,    0, 1388,    0,    0, 1388,    0, 1388, 1388,
    0,    0, 1388, 1388, 1388,    0, 1388, 1388, 1388, 1388,
 1388, 1388, 1388,    0,    0,    0, 1388,    0, 1388, 1388,
 1388,    0,    0,    0, 1388,    0,    0,    0,    0,    0,
    0,    0, 1388, 1388, 1388, 1388, 1388, 1388,    0,    0,
    0, 1388, 1388,    0, 1388,    0, 1388,    0, 1388, 1388,
 1388,    0, 1388,    0, 1388, 1388, 1388,    0, 1388, 1388,
 1388, 1388, 1388,    0, 1388, 1388,    0,    0,    0,    0,
 1388,    0, 1388, 1388,    0,    0, 1388, 1388, 1388,    0,
    0, 1388,    0, 1388,    0,    0, 1388, 1388, 1388, 1388,
    0, 1388,    0, 1388,    0, 1388, 1388, 1388, 1388, 1388,
    0,    0, 1388, 1388, 1388,    0, 1388, 1388,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1388, 1388, 1388,
    0, 1388, 1388, 1388,    0, 1388,    0,    0,    0, 1388,
    0, 1388, 1388, 1388, 1388,    0, 1388,    0, 1388, 1388,
 1388, 1388, 1388, 1388, 1388, 1388,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1388, 1388,    0, 1388, 1388,
 1388,    0,    0,    0,    0, 1388, 1388, 1388, 1388, 1388,
    0, 1388,    0,    0, 1388, 1388,    0,    0,    0, 1388,
 1388,    0,    0, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388, 1388,    0, 1388,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388, 1388, 1388, 1388,    0, 1388, 1388, 1388, 1388, 1388,
 1388,    0, 1388, 1388, 1388, 1388,    0, 1388,    0, 1388,
 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388, 1388, 1388, 1388, 1388, 1388, 1388,    0, 1388, 1388,
 1388, 1388,    0, 1388, 1388, 1388, 1388, 1388,    0, 1388,
 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388,    0,
 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1390, 1388,
 1388, 1388, 1388,    0, 1388, 1388, 1388, 1388, 1388, 1388,
    0,    0, 1388, 1388, 1388, 1388, 1388, 1388, 1388, 1388,
 1388,    0,    0,    0,    0,    0, 1388,    0, 1388, 1388,
 1388, 1388, 1388, 1388,    0, 1388,    0,    0,    0, 1390,
    0,    0, 1390,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1390, 1390, 1390,
 1390,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1390,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1390,    0, 1390,    0,    0,
 1390,    0, 1390, 1390,    0,    0, 1390, 1390,    0, 1390,
    0,    0,    0,    0,    0,    0,    0, 1390, 1390,    0,
 1390,    0, 1390,    0,    0, 1390,    0,    0, 1390,    0,
    0,    0,    0,    0,    0, 1390,    0, 1390, 1390,    0,
 1390, 1390, 1390,    0, 1390,    0,    0, 1390,    0,    0,
 1390,    0, 1390, 1390,    0,    0, 1390, 1390, 1390,    0,
 1390, 1390, 1390, 1390, 1390, 1390, 1390,    0,    0,    0,
 1390,    0, 1390, 1390, 1390,    0,    0,    0, 1390,    0,
    0,    0,    0,    0,    0,    0, 1390, 1390, 1390, 1390,
 1390, 1390,    0,    0,    0, 1390, 1390,    0, 1390,    0,
 1390,    0, 1390, 1390, 1390,    0, 1390,    0, 1390, 1390,
 1390,    0, 1390, 1390, 1390, 1390, 1390,    0, 1390, 1390,
    0,    0,    0,    0, 1390,    0, 1390, 1390,    0,    0,
 1390, 1390, 1390,    0,    0, 1390,    0, 1390,    0,    0,
 1390, 1390, 1390, 1390,    0, 1390,    0, 1390,    0, 1390,
 1390, 1390, 1390, 1390,    0,    0, 1390, 1390, 1390,    0,
 1390, 1390,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1390, 1390, 1390,    0, 1390, 1390, 1390,    0, 1390,
    0,    0,    0, 1390,    0, 1390, 1390, 1390, 1390,    0,
 1390,    0, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1390,
 1390,    0, 1390, 1390, 1390,    0,    0,    0,    0, 1390,
 1390, 1390, 1390, 1390,    0, 1390,    0,    0, 1390, 1390,
    0,    0,    0, 1390, 1390,    0,    0, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390, 1390,    0, 1390,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,    0, 1390,
 1390, 1390, 1390, 1390, 1390,    0, 1390, 1390, 1390, 1390,
    0, 1390,    0, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 1390,    0, 1390, 1390, 1390, 1390,    0, 1390, 1390, 1390,
 1390, 1390,    0, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390, 1390,
 1390, 1390, 1390,    0, 1390, 1390, 1390, 1390, 1390, 1390,
 1390, 1390, 1392, 1390, 1390, 1390, 1390,    0, 1390, 1390,
 1390, 1390, 1390, 1390,    0,    0, 1390, 1390, 1390, 1390,
 1390, 1390, 1390, 1390, 1390,    0,    0,    0,    0,    0,
 1390,    0, 1390, 1390, 1390, 1390, 1390, 1390,    0, 1390,
    0,    0,    0, 1392,    0,    0, 1392,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1392, 1392, 1392, 1392,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1392,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1392,
    0, 1392,    0,    0, 1392,    0, 1392, 1392,    0,    0,
 1392, 1392,    0, 1392,    0,    0,    0,    0,    0,    0,
    0, 1392, 1392,    0, 1392,    0, 1392,    0,    0, 1392,
    0,    0, 1392,    0,    0,    0,    0,    0,    0, 1392,
    0, 1392, 1392,    0, 1392, 1392, 1392,    0, 1392,    0,
    0, 1392,    0,    0, 1392,    0, 1392, 1392,    0,    0,
 1392, 1392, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392,
 1392,    0,    0,    0, 1392,    0, 1392, 1392, 1392,    0,
    0,    0, 1392,    0,    0,    0,    0,    0,    0,    0,
 1392, 1392, 1392, 1392, 1392, 1392,    0,    0,    0, 1392,
 1392,    0, 1392,    0, 1392,    0, 1392, 1392, 1392,    0,
 1392,    0, 1392, 1392, 1392,    0, 1392, 1392, 1392, 1392,
 1392,    0, 1392, 1392,    0,    0,    0,    0, 1392,    0,
 1392, 1392,    0,    0, 1392, 1392, 1392,    0,    0, 1392,
    0, 1392,    0,    0, 1392, 1392, 1392, 1392,    0, 1392,
    0, 1392,    0, 1392, 1392, 1392, 1392, 1392,    0,    0,
 1392, 1392, 1392, 1347, 1392, 1392,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1392, 1392, 1392,    0, 1392,
 1392, 1392,    0, 1392,    0,    0,    0, 1392,    0, 1392,
 1392, 1392, 1392,    0, 1392,    0, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1347,    0,    0, 1347,    0,    0,
    0,    0,    0, 1392, 1392,    0, 1392, 1392, 1392,    0,
    0,    0, 1347, 1392, 1392, 1392, 1392, 1392,    0, 1392,
    0,    0, 1392, 1392,    0,    0,    0, 1392, 1392,    0,
    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
    0, 1392,    0,    0,    0,    0, 1347,    0,    0,    0,
    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392,    0,
 1392, 1392, 1392, 1392,    0, 1392,    0, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392, 1392,
    0, 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392,
 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392,    0,    0,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,    0,
    0,    0,    0,    0, 1392,    0, 1392, 1392, 1392, 1392,
 1392, 1392,    0, 1392,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1347,    0, 1347,    0,    0, 1347,    0, 1347, 1347,    0,
    0, 1347, 1347,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1347, 1347,    0, 1347,    0,    0,    0,    0,
 1347,    0,    0, 1347,    0,    0,    0,    0,    0,    0,
 1347,    0, 1347, 1347,    0, 1347, 1347, 1347, 1347, 1347,
    0,    0, 1347,    0,    0, 1347,    0, 1347, 1347,    0,
    0,    0, 1347, 1347,    0, 1347, 1347, 1347,    0, 1347,
 1347, 1347,    0,    0,    0, 1347,    0, 1347, 1347, 1347,
    0,    0,    0, 1347,    0,    0,    0,    0,    0,    0,
    0, 1347, 1347,    0, 1347,    0, 1347,    0,    0,    0,
 1347, 1347,    0, 1347,    0,    0,    0, 1347,    0,    0,
    0, 1347,    0, 1347, 1347, 1347,    0, 1347, 1347, 1347,
 1347, 1347,    0, 1347, 1347,    0,    0,    0,    0, 1347,
    0, 1347, 1347,    0,    0, 1347, 1347, 1347,    0,    0,
 1347,    0, 1347,    0,    0, 1347, 1347, 1347, 1347,    0,
 1347,    0, 1347,    0, 1347,    0, 1347, 1347, 1347,    0,
    0, 1347, 1347, 1347, 1346, 1347, 1347,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1347, 1347, 1347,    0,
 1347, 1347, 1347,    0, 1347,    0,    0,    0, 1347,    0,
 1347, 1347, 1347, 1347,    0, 1347,    0, 1347, 1347, 1347,
 1347, 1347, 1347, 1347, 1347, 1346,    0,    0, 1346,    0,
    0,    0,    0,    0, 1347, 1347,    0, 1347, 1347, 1347,
    0,    0,    0, 1346, 1347, 1347, 1347, 1347, 1347,    0,
 1347,    0,    0, 1347, 1347,    0,    0,    0, 1347, 1347,
    0,    0, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
 1347,    0, 1347,    0,    0,    0,    0, 1346,    0,    0,
    0,    0, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
 1347, 1347, 1347,    0, 1347, 1347, 1347, 1347, 1347, 1347,
    0, 1347, 1347, 1347, 1347,    0, 1347,    0, 1347, 1347,
 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
 1347, 1347, 1347, 1347, 1347, 1347,    0, 1347, 1347, 1347,
 1347,    0, 1347, 1347, 1347, 1347, 1347,    0, 1347, 1347,
 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
 1347,    0, 1347, 1347, 1347, 1347, 1347, 1347,    0, 1347,
 1347, 1347, 1347, 1347, 1347, 1347, 1347,    0, 1347, 1347,
 1347, 1347,    0, 1347, 1347, 1347, 1347, 1347, 1347,    0,
    0, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347, 1347,
    0,    0,    0,    0,    0, 1347,    0, 1347, 1347, 1347,
 1347, 1347, 1347,    0, 1347,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1346,    0, 1346,    0,    0, 1346,    0, 1346, 1346,
    0,    0, 1346, 1346,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1346, 1346,    0, 1346,    0,    0,    0,
    0, 1346,    0,    0, 1346,    0,    0,    0,    0,    0,
    0, 1346,    0, 1346, 1346,    0, 1346, 1346, 1346, 1346,
 1346,    0,    0, 1346,    0,    0, 1346,    0, 1346, 1346,
    0,    0,    0, 1346, 1346,    0, 1346, 1346, 1346,    0,
 1346, 1346, 1346,    0,    0,    0, 1346,    0, 1346, 1346,
 1346,    0,    0,    0, 1346,    0,    0,    0,    0,    0,
    0,    0, 1346, 1346,    0, 1346,    0, 1346,    0,    0,
    0, 1346, 1346,    0, 1346,    0,    0,    0,    0,    0,
    0,    0, 1346,    0, 1346, 1346, 1346,    0, 1346, 1346,
 1346, 1346, 1346,    0, 1346, 1346,    0,    0,    0,    0,
 1346,    0, 1346, 1346,    0,    0, 1346, 1346, 1346,    0,
    0, 1346,    0, 1346,    0,    0, 1346, 1346, 1346, 1346,
    0, 1346,    0, 1346,    0, 1346,    0, 1346, 1346, 1346,
    0,    0, 1346, 1346, 1346, 1345, 1346, 1346,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1346, 1346, 1346,
    0, 1346, 1346, 1346,    0, 1346,    0,    0,    0, 1346,
    0, 1346, 1346, 1346, 1346,    0, 1346,    0, 1346, 1346,
 1346, 1346, 1346, 1346, 1346, 1346, 1345,    0,    0, 1345,
    0,    0,    0,    0,    0, 1346, 1346,    0, 1346, 1346,
 1346,    0,    0,    0, 1345, 1346, 1346, 1346, 1346, 1346,
    0, 1346,    0,    0, 1346, 1346,    0,    0,    0, 1346,
 1346,    0,    0, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346, 1346,    0, 1346,    0,    0,    0,    0, 1345,    0,
    0,    0,    0, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346, 1346, 1346, 1346,    0, 1346, 1346, 1346, 1346, 1346,
 1346,    0, 1346, 1346, 1346, 1346,    0, 1346,    0, 1346,
 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346, 1346, 1346, 1346, 1346, 1346, 1346,    0, 1346, 1346,
 1346, 1346,    0, 1346, 1346, 1346, 1346, 1346,    0, 1346,
 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346, 1346,    0, 1346, 1346, 1346, 1346, 1346, 1346,    0,
 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346,    0, 1346,
 1346, 1346, 1346,    0, 1346, 1346, 1346, 1346, 1346, 1346,
    0,    0, 1346, 1346, 1346, 1346, 1346, 1346, 1346, 1346,
 1346,    0,    0,    0,    0,    0, 1346,    0, 1346, 1346,
 1346, 1346, 1346, 1346,    0, 1346,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1345,    0, 1345,    0,    0,    0,    0, 1345,
 1345,    0,    0, 1345, 1345,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1345, 1345,    0, 1345,    0,    0,
    0,    0, 1345,    0,    0, 1345,    0,    0,    0,    0,
    0,    0, 1345,    0, 1345, 1345,    0, 1345, 1345, 1345,
 1345, 1345,    0,    0, 1345,    0,    0, 1345,    0, 1345,
 1345,    0,    0,    0, 1345, 1345,    0, 1345, 1345, 1345,
    0, 1345, 1345, 1345,    0,    0,    0, 1345,    0, 1345,
 1345, 1345,    0,    0,    0, 1345,    0,    0,    0,    0,
    0,    0,    0, 1345, 1345,    0, 1345,    0, 1345,    0,
    0,    0, 1345, 1345,    0, 1345,    0,    0,    0,    0,
    0,    0,    0, 1345,    0, 1345, 1345, 1345,    0, 1345,
 1345, 1345, 1345, 1345,    0, 1345, 1345,    0,    0,    0,
    0, 1345,    0, 1345, 1345,    0,    0, 1345, 1345, 1345,
    0,    0, 1345,    0, 1345,    0,    0, 1345, 1345, 1345,
 1345,    0, 1345,    0, 1345,    0, 1345,    0, 1345, 1345,
 1345,    0,    0, 1345, 1345, 1345, 1199, 1345, 1345,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1345, 1345,
 1345,    0, 1345, 1345, 1345,    0, 1345,    0,    0,    0,
 1345,    0, 1345, 1345, 1345, 1345,    0, 1345,    0, 1345,
 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1199,    0,    0,
 1199,    0,    0,    0,    0,    0, 1345, 1345,    0, 1345,
 1345, 1345,    0,    0,    0, 1199, 1345, 1345, 1345, 1345,
 1345,    0, 1345,    0,    0, 1345, 1345,    0,    0,    0,
 1345, 1345,    0,    0, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345, 1345,    0, 1345,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345, 1345, 1345, 1345,    0, 1345, 1345, 1345, 1345,
 1345, 1345,    0, 1345, 1345, 1345, 1345,    0, 1345,    0,
 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345,    0, 1345,
 1345, 1345, 1345,    0, 1345, 1345, 1345, 1345, 1345,    0,
 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345, 1345,    0, 1345, 1345, 1345, 1345, 1345, 1345,
    0, 1345, 1345, 1345, 1345, 1345, 1345, 1345, 1345,    0,
 1345, 1345, 1345, 1345,    0, 1345, 1345, 1345, 1345, 1345,
 1345,    0,    0, 1345, 1345, 1345, 1345, 1345, 1345, 1345,
 1345, 1345,    0,    0,    0,    0,    0, 1345,    0, 1345,
 1345, 1345, 1345, 1345, 1345,    0, 1345,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1199,    0, 1199,    0,    0,    0,    0,
 1199, 1199,    0,    0, 1199, 1199,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1199, 1199,    0, 1199,    0,
 1199,    0,    0, 1199,    0,    0, 1199,    0,    0,    0,
    0,    0,    0, 1199,    0, 1199, 1199,    0,    0,    0,
 1199,    0, 1199,    0,    0, 1199,    0,    0, 1199,    0,
    0, 1199,    0,    0,    0, 1199, 1199,    0, 1199, 1199,
 1199,    0, 1199, 1199, 1199,    0,    0,    0, 1199,    0,
 1199, 1199, 1199,    0,    0,    0, 1199,    0,    0,    0,
    0,    0,    0,    0, 1199, 1199,    0, 1199,    0, 1199,
    0,    0,    0, 1199, 1199,    0, 1199,    0,    0,    0,
    0,    0,    0,    0, 1199,    0, 1199,    0, 1199,    0,
 1199, 1199, 1199, 1199, 1199,    0, 1199, 1199,    0,    0,
    0,    0, 1199,    0, 1199, 1199,    0,    0, 1199, 1199,
    0,    0,    0, 1199,    0, 1199,    0,    0, 1199, 1199,
 1199, 1199,    0, 1199,    0, 1199,    0, 1199, 1199, 1199,
 1199, 1199,    0,    0, 1169,    0, 1199,    0, 1199, 1199,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1199,
    0, 1199,    0, 1199, 1199, 1199,    0, 1199,    0,    0,
    0, 1199,    0, 1199, 1199, 1199, 1199,    0, 1199,    0,
    0,    0,    0,    0, 1169, 1169, 1199, 1199, 1169,    0,
    0,    0,    0,    0,    0,    0,    0, 1199, 1199,    0,
 1199, 1199, 1199, 1169,    0,    0,    0, 1199, 1199, 1199,
 1199, 1199,    0, 1199,    0,    0, 1199, 1199,    0,    0,
    0, 1199, 1199,    0,    0, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199, 1199,    0, 1199,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199, 1199, 1199, 1199,    0, 1199, 1199, 1199,
 1199, 1199, 1199,    0, 1199, 1199, 1199, 1199,    0, 1199,
    0, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199,    0,
 1199, 1199, 1199, 1199,    0, 1199, 1199, 1199, 1199, 1199,
    0, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199, 1199,    0, 1199, 1199, 1199, 1199, 1199,
 1199,    0, 1199, 1199, 1199, 1199, 1199, 1199, 1199, 1199,
    0, 1199, 1199, 1199, 1199,    0, 1199, 1199, 1199, 1199,
 1199, 1199,    0,    0, 1199, 1199, 1199, 1199, 1199, 1199,
 1199, 1199, 1199,    0,    0,    0,    0,    0, 1199,    0,
 1199, 1199, 1199, 1199, 1199, 1199,    0, 1199,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169,    0,    0,    0,    0,    0, 1169,
    0,    0, 1169, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1169, 1169,    0, 1169,    0, 1169,    0,
    0, 1169,    0,    0, 1169,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169, 1169,    0,    0,    0, 1169,    0,
 1169,    0,    0, 1169,    0,    0, 1169,    0,    0, 1169,
    0,    0,    0, 1169, 1169,    0, 1169, 1169, 1169,    0,
 1169, 1169, 1169,    0,    0,    0, 1169,    0, 1169, 1169,
 1169,    0,    0,    0, 1169,    0,    0,    0,    0,    0,
    0,    0, 1169, 1169,    0, 1169,    0, 1169,    0,    0,
    0, 1169, 1169,    0, 1169,    0,    0,    0,    0,    0,
    0,    0, 1169,    0, 1169,    0, 1169,    0, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1169,    0,    0,    0,    0,
 1169,    0, 1169, 1169,    0,    0, 1169, 1169,    0,    0,
    0, 1169,    0, 1169,    0,    0, 1169, 1169, 1169, 1169,
    0, 1169,    0, 1169, 1196, 1169, 1169, 1169, 1169, 1169,
    0,    0,    0,    0, 1169,    0, 1169, 1169,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1169,    0, 1169,
    0, 1169, 1169, 1169,    0, 1169,    0,    0,    0, 1169,
    0, 1169, 1169, 1169, 1169, 1196, 1169,    0, 1196,    0,
    0,    0,    0,    0, 1169, 1169,    0,    0,    0,    0,
    0,    0,    0, 1196,    0, 1169, 1169,    0, 1169, 1169,
 1169,    0,    0,    0,    0, 1169, 1169, 1169, 1169, 1169,
    0, 1169,    0,    0, 1169, 1169,    0,    0,    0, 1169,
 1169,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,
 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169,    0,    0,    0,    0,    0, 1169,    0, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1169,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169,    0,    0,    0,    0,    0, 1169,
    0,    0, 1169, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1169, 1169,    0, 1169,    0, 1169,    0,
    0, 1169,    0,    0, 1169,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169, 1169,    0,    0,    0, 1169,    0,
 1169,    0,    0, 1169,    0,    0, 1196,    0,    0, 1196,
    0,    0,    0, 1169, 1169,    0, 1196, 1196, 1169,    0,
 1169, 1196, 1169,    0,    0,    0, 1196,    0, 1169, 1196,
 1169,    0,    0,    0, 1169,    0,    0,    0,    0,    0,
    0,    0, 1169, 1196,    0, 1169,    0, 1169,    0,    0,
    0, 1169, 1169,    0, 1196,    0,    0,    0,    0,    0,
    0,    0, 1196,    0, 1169,    0, 1196,    0, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1196,    0,    0,    0,    0,
 1169,    0, 1169, 1169,    0,    0, 1169, 1169,    0,    0,
    0, 1196,    0, 1169,    0,    0, 1169, 1169, 1169, 1169,
    0, 1169,    0, 1169, 1198, 1169, 1169, 1169, 1169, 1169,
    0,    0,    0,    0, 1169,    0, 1169, 1196,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1169,    0, 1196,
    0, 1196, 1169, 1169,    0, 1169,    0,    0,    0, 1169,
    0, 1169, 1169, 1169, 1169, 1198, 1169,    0, 1198,    0,
    0,    0,    0,    0, 1169, 1169,    0,    0,    0,    0,
    0,    0,    0, 1198,    0, 1169, 1169,    0, 1169, 1169,
 1169,    0,    0,    0,    0, 1169, 1169, 1196, 1169, 1169,
    0, 1169,    0,    0, 1169, 1169,    0,    0,    0, 1169,
 1169,    0,    0, 1196, 1196, 1169, 1169, 1169, 1196, 1169,
 1169, 1169,    0, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,
 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169,    0,    0,    0,    0,    0, 1169,    0, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1196,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169,    0,    0,    0,    0,    0, 1169,
    0,    0, 1169, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1169, 1169,    0, 1169,    0, 1169,    0,
    0, 1169,    0,    0, 1169,    0,    0,    0,    0,    0,
    0, 1169,    0, 1169, 1169,    0,    0,    0, 1169,    0,
 1169,    0,    0, 1169,    0,    0, 1198,    0,    0, 1198,
    0,    0,    0, 1169, 1169,    0, 1198, 1198, 1169,    0,
 1169, 1198, 1169,    0,    0,    0, 1198,    0, 1169, 1198,
 1169,    0,    0,    0, 1169,    0,    0,    0,    0,    0,
    0,    0, 1169, 1198,    0, 1169,    0, 1169,    0,    0,
    0, 1169, 1169,    0, 1198,    0,    0,    0,    0,    0,
    0,    0, 1198,    0, 1169,    0, 1198,    0, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1198,    0,    0,    0,    0,
 1169,    0, 1169, 1169,    0,    0, 1169, 1169,    0, 1203,
    0, 1198,    0, 1169,    0,    0, 1169, 1169, 1169, 1169,
    0, 1169,    0, 1169,    0, 1169, 1169, 1169, 1169, 1169,
    0,    0,    0,    0, 1169,    0, 1169, 1198,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1169,    0, 1198,
    0, 1198, 1169, 1169,    0, 1169,    0,    0,    0, 1169,
    0, 1169, 1169, 1169, 1169,    0, 1169,    0, 1203,    0,
    0,    0,    0,    0, 1169, 1169,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1169, 1169,    0, 1169, 1169,
 1169,    0,    0,    0,    0, 1169, 1169, 1198, 1169, 1169,
    0, 1169,    0,    0, 1169, 1169,    0,    0,    0, 1169,
 1169,    0,    0, 1198, 1198, 1169, 1169, 1169, 1198, 1169,
 1169, 1169,    0, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,
 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169,    0,    0,    0,    0,    0, 1169,    0, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1198, 1169,    0, 1169,    0,
    0,    0,    0,    0, 1169,    0,    0, 1169, 1169,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1169, 1169,
    0, 1169,    0, 1169,    0,    0, 1169,    0,    0, 1169,
    0,    0,    0,    0,    0,    0, 1169,    0, 1169, 1169,
    0,    0,    0, 1169,    0, 1169,    0,    0, 1169,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1169, 1169,
    0,    0,    0, 1169,    0, 1169,    0, 1169,    0,    0,
    0,    0,    0, 1169,    0, 1169,    0,    0,    0, 1169,
    0,    0,    0,    0,    0,    0,    0, 1169,    0,    0,
 1169,    0, 1169,    0,    0,    0, 1169, 1169,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1169,
    0, 1203,    0, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1203,    0,    0,    0,    0, 1169,    0, 1169, 1169,    0,
    0, 1169, 1169,    0,    0, 1167,    0,    0, 1169,    0,
 1203, 1169, 1169, 1169, 1169,    0, 1169,    0, 1169,    0,
 1169, 1169, 1169, 1169, 1169,    0,    0,    0,    0, 1169,
    0, 1169,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1169,    0, 1203,    0,    0, 1169, 1169, 1167,
 1169,    0,    0,    0, 1169,    0, 1169, 1169, 1169, 1169,
    0, 1169,    0,    0, 1167,    0,    0,    0,    0, 1169,
 1169,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1169, 1169,    0, 1169, 1169, 1169,    0,    0,    0,    0,
 1169, 1169, 1203, 1169, 1169,    0, 1169,    0,    0, 1169,
 1169,    0,    0,    0, 1169, 1169,    0,    0,    0, 1203,
 1169, 1169, 1169,    0, 1169, 1169, 1169,    0, 1169,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169,
 1169,    0, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169,    0, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169,
 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169,    0,    0, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169,    0,    0,    0,    0,
    0, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,    0,
    0,    0, 1169,    0, 1169,    0,    0,    0,    0,    0,
 1169,    0,    0, 1169, 1169,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1169, 1169,    0, 1169,    0,    0,
    0,    0, 1169,    0,    0, 1169,    0,    0,    0,    0,
    0,    0, 1169,    0, 1169, 1169,    0,    0,    0, 1169,
    0, 1169,    0,    0, 1169,    0,    0,    0,    0, 1167,
    0,    0,    0,    0, 1169, 1169,    0,    0,    0, 1169,
    0, 1169,    0, 1169,    0,    0,    0, 1167,    0, 1169,
    0, 1169,    0,    0,    0, 1169,    0,    0,    0,    0,
    0,    0,    0, 1169,    0,    0, 1169,    0, 1169,    0,
    0,    0, 1169, 1169,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1169,    0,    0,    0, 1169,
 1169, 1169, 1169, 1169,    0, 1169,    0,    0,    0,    0,
    0, 1169,    0, 1169, 1169,    0,    0, 1169, 1169,    0,
    0,    0,    0,    0, 1169,    0,    0, 1169, 1169, 1169,
 1169,    0, 1169,    0, 1169,    0, 1169,    0, 1169, 1169,
 1169,    0,    0,    0,    0, 1169,    0, 1169,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1169,    0,
    0,    0,    0, 1169, 1169,    0, 1169,    0,    0,    0,
 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,    0,    0,
    0,    0,    0,    0,    0, 1169, 1169,    0,    0,    0,
 1143,    0,    0,  880,    0,  881, 1169, 1169,    0, 1169,
 1169, 1169,    0,    0,    0,    0, 1169, 1169,  883, 1169,
 1169,    0, 1169,  884,    0, 1169, 1169,    0,    0,    0,
 1169, 1169,    0,    0,    0,    0, 1169, 1169, 1169,    0,
 1169, 1169, 1169,    0, 1169,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169,
 1169, 1169,    0, 1169, 1169, 1169, 1169,    0, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169, 1169,
    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169, 1169,    0,
 1169, 1169, 1169, 1169,    0, 1169, 1169, 1169, 1169, 1169,
 1169,    0,    0, 1169, 1169, 1169, 1169, 1169, 1169, 1169,
 1169, 1169,    0,    0,    0,    0,    0, 1169,    0, 1169,
 1169, 1169, 1169, 1169, 1169,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767, 1499, 1500, 1501, 1502, 1503, 1504,
 1532, 1533,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823, 1534,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840, 1535,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227, 1527,  228,
    0,  789,  790,  791, 1528,  792,  793, 1529,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
 1600,    0,    0, 1601,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187, 1602,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1151,    0, 1151, 1151,    0, 1151,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1151,    0,
    0,    0,    0, 1151,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1151,    0, 1151,
 1151,    0,    0,    0,    0, 1151,    0, 1151, 1151, 1151,
    0,    0,    0,    0, 1151,    0,    0,    0,    0, 1151,
 1151,    0, 1151,    0, 1151, 1151,    0, 1151,    0,    0,
 1151, 1151, 1151,    0,    0,    0,    0, 1151, 1151, 1151,
 1151,    0,    0,    0, 1151,    0, 1151,    0, 1151, 1151,
    0,    0,    0,    0,    0,    0,    0, 1151,    0, 1151,
 1151,    0,    0,    0, 1151,    0, 1151,    0, 1151,    0,
    0,    0,    0,    0, 1151,    0, 1151,    0,    0,    0,
 1151,    0,    0,    0, 1151,    0, 1151, 1151, 1151, 1151,
    0, 1151,    0, 1151, 1151,    0, 1151, 1151, 1151,    0,
    0,    0,    0,    0, 1151,    0,    0,    0,    0,    0,
 1151,    0,    0,    0, 1151, 1151, 1151, 1151, 1151,    0,
 1151,    0, 1151,    0,    0,    0, 1151,    0, 1151, 1151,
    0,    0, 1151, 1151,    0,    0,    0, 1151,    0, 1151,
    0,    0, 1151, 1151, 1151, 1151,    0, 1151,    0, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151,    0,    0,    0,
 1151,    0, 1151,    0,    0,    0, 1151,    0,    0,    0,
    0,    0,    0, 1151,    0,    0,    0,    0, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151,    0, 1151, 1151, 1151,
 1151,    0, 1151, 1151,    0,    0,    0,    0,    0,    0,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151,    0, 1151, 1151,    0, 1151, 1151,    0,
 1151, 1151, 1151,    0, 1151, 1151, 1151, 1151,    0,    0,
 1151, 1151, 1151, 1151, 1151, 1151, 1151,    0,    0,    0,
    0, 1151, 1151, 1151,    0, 1151, 1151, 1151,    0, 1151,
    0, 1151, 1151, 1151,    0, 1151, 1151,    0, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
    0, 1151, 1151, 1151, 1151, 1151, 1151,    0, 1151, 1151,
 1151, 1151,    0, 1151,    0, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151,    0, 1151, 1151, 1151, 1151,    0, 1151,
 1151, 1151, 1151, 1151,    0, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,    0, 1151,
 1151, 1151, 1151, 1151, 1151,    0, 1151, 1151, 1151, 1151,
 1151, 1151, 1151, 1151,    0, 1151, 1151, 1151, 1151,    0,
 1151, 1151, 1151, 1151, 1151, 1151,    0,    0, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,    0, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
    0,    0, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151, 1151,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148, 1142,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196, 1174,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,   15,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0, 1327,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143, 1615,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0, 1977,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0, 1599,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143, 2373,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782, 2468,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1149,    0, 1149, 1149,    0, 1149,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1149,    0,
    0,    0,    0, 1149,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1149,    0, 1149,
 1149,    0,    0,    0,    0, 1149,    0, 1149, 1149, 1149,
    0,    0,    0,    0, 1149,    0,    0,    0,    0, 1149,
 1149,    0, 1149,    0, 1149, 1149,    0, 1149,    0,    0,
 1149, 1149, 1149,    0,    0,    0,    0, 1149, 1149, 1149,
 1149,    0,    0,    0, 1149,    0, 1149,    0, 1149, 1149,
    0,    0,    0,    0,    0,    0,    0, 1149,    0, 1149,
 1149,    0,    0,    0, 1149,    0, 1149,    0, 1149,    0,
    0,    0,    0,    0, 1149,    0, 1149,    0,    0,    0,
 1149,    0,    0,    0, 1149,    0, 1149, 1149, 1149, 1149,
    0, 1149,    0, 1149, 1149,    0, 1149, 1149, 1149,    0,
    0,    0,    0,    0, 1149,    0,    0,    0,    0,    0,
 1149,    0,    0,    0, 1149, 1149, 1149, 1149, 1149,    0,
 1149,    0, 1149,    0,    0,    0, 1149,    0, 1149, 1149,
    0,    0, 1149, 1149,    0,    0,    0, 1149,    0, 1149,
    0,    0, 1149, 1149, 1149, 1149,    0, 1149,    0, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149,    0,    0,    0,
 1149,    0, 1149,    0,    0,    0, 1149,    0,    0,    0,
    0,    0,    0, 1149,    0,    0,    0,    0, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149,    0, 1149, 1149, 1149,
 1149,    0, 1149, 1149,    0,    0,    0,    0,    0,    0,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149,    0, 1149,    0,    0, 1149, 1149,    0,
 1149, 1149, 1149,    0, 1149, 1149, 1149, 1149,    0,    0,
 1149, 1149, 1149, 1149, 1149, 1149, 1149,    0,    0,    0,
    0, 1149, 1149, 1149,    0, 1149, 1149, 1149,    0, 1149,
    0, 1149, 1149, 1149,    0, 1149, 1149,    0, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
    0, 1149, 1149, 1149, 1149, 1149, 1149,    0, 1149, 1149,
 1149, 1149,    0, 1149,    0, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149,    0, 1149, 1149, 1149, 1149,    0, 1149,
 1149, 1149, 1149, 1149,    0, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,    0, 1149,
 1149, 1149, 1149, 1149, 1149,    0, 1149, 1149, 1149, 1149,
 1149, 1149, 1149, 1149,    0, 1149, 1149, 1149, 1149,    0,
 1149, 1149, 1149, 1149, 1149, 1149,    0,    0, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,    0, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
    0,    0, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149, 1149,
 1747,    0, 1747, 1747,    0, 1747,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1747,    0,
    0,    0,    0, 1747,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1747,    0, 1747,
    0,    0,    0,    0,    0, 1747,    0, 1747, 1747, 1747,
    0,    0,    0,    0, 1747,    0,    0,    0,    0, 1747,
 1747,    0, 1747,    0, 1747, 1747,    0, 1747,    0,    0,
 1747, 1747, 1747,    0,    0,    0,    0, 1747,    0, 1747,
 1747,    0,    0,    0, 1747,    0, 1747,    0, 1747, 1747,
    0,    0,    0,    0,    0,    0,    0, 1747,    0, 1747,
 1747,    0,    0,    0, 1747,    0, 1747,    0, 1747,    0,
    0,    0,    0,    0, 1747,    0, 1747,    0,    0,    0,
 1747,    0,    0,    0, 1747,    0, 1747, 1747, 1747, 1747,
    0, 1747,    0, 1747, 1747,    0, 1747, 1747, 1747,    0,
    0,    0,    0,    0, 1747,    0,    0,    0,    0,    0,
 1747,    0,    0,    0, 1747, 1747, 1747, 1747, 1747,    0,
 1747,    0, 1747,    0,    0,    0, 1747,    0, 1747, 1747,
    0,    0, 1747, 1747,    0,    0,    0, 1747,    0, 1747,
    0,    0, 1747, 1747, 1747, 1747,    0, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0,    0,    0,
 1747,    0, 1747,    0,    0,    0, 1747,    0,    0,    0,
    0,    0,    0, 1747,    0,    0,    0,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747,
 1747,    0, 1747, 1747,    0,    0,    0,    0,    0,    0,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747, 1747,    0,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0,    0,
 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0,    0,    0,
    0, 1747, 1747, 1747,    0, 1747, 1747, 1747,    0, 1747,
    0, 1747, 1747, 1747,    0, 1747, 1747,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
    0, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747,
 1747, 1747,    0, 1747,    0, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0,
 1747, 1747, 1747, 1747, 1747, 1747,    0,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
    0,    0, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
  882,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 2314,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 2942,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1143,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,  748,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,  757,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  760,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,  784,  785,  786,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303, 3379,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1747,    0,    0, 1747,    0, 1747,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1747,    0,
    0,    0,    0, 1747,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1747,    0, 1747,
    0,    0,    0,    0,    0, 1747,    0, 1747, 1747, 1747,
    0,    0,    0,    0, 1747,    0,    0,    0,    0, 1747,
 1747,    0, 1747,    0, 1747, 1747,    0, 1747,    0,    0,
 1747, 1747, 1747,    0,    0,    0,    0, 1747,    0, 1747,
 1747,    0,    0,    0, 1747,    0, 1747,    0, 1747, 1747,
    0,    0,    0,    0,    0,    0,    0, 1747,    0, 1747,
 1747,    0,    0,    0, 1747,    0, 1747,    0, 1747,    0,
    0,    0,    0,    0, 1747,    0, 1747,    0,    0,    0,
 1747,    0,    0,    0, 1747,    0, 1747, 1747, 1747, 1747,
    0, 1747,    0, 1747, 1747,    0, 1747, 1747, 1747,    0,
    0,    0,    0,    0, 1747,    0,    0,    0,    0,    0,
 1747,    0,    0,    0, 1747, 1747, 1747, 1747, 1747,    0,
 1747,    0, 1747,    0,    0,    0, 1747,    0, 1747, 1747,
    0,    0, 1747, 1747,    0,    0,    0, 1747,    0, 1747,
    0,    0, 1747, 1747, 1747, 1747,    0, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0,    0,    0,
 1747,    0, 1747,    0,    0,    0, 1747,    0,    0,    0,
    0,    0,    0, 1747,    0,    0,    0,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747,
 1747,    0, 1747, 1747,    0,    0,    0,    0,    0,    0,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747, 1747,    0,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0,    0,
 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0,    0,    0,
    0, 1747, 1747, 1747,    0, 1747, 1747, 1747,    0, 1747,
    0, 1747, 1747, 1747,    0, 1747, 1747,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
    0, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747,
 1747, 1747,    0, 1747,    0, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747,    0, 1747, 1747, 1747, 1747,    0,
 1747, 1747, 1747, 1747, 1747, 1747,    0,    0, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,    0, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
    0,    0, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747, 1747,
 1384,    0,    0, 1384,    0, 1384,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1384,    0,
    0,    0,    0, 1384,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1384,    0, 1384,
    0,    0,    0,    0,    0, 1384,    0, 1384, 1384, 1384,
    0,    0,    0,    0, 1384,    0,    0,    0,    0, 1384,
 1384,    0, 1384,    0, 1384, 1384,    0, 1384,    0,    0,
 1384, 1384, 1384,    0,    0,    0,    0, 1384,    0, 1384,
 1384,    0,    0,    0, 1384,    0, 1384,    0, 1384, 1384,
    0,    0,    0,    0,    0,    0,    0, 1384,    0, 1384,
 1384,    0,    0,    0, 1384,    0, 1384,    0, 1384,    0,
    0,    0,    0,    0, 1384,    0, 1384,    0,    0,    0,
 1384,    0,    0,    0, 1384,    0, 1384, 1384, 1384, 1384,
    0, 1384,    0, 1384, 1384,    0, 1384, 1384, 1384,    0,
    0,    0,    0,    0, 1384,    0,    0,    0,    0,    0,
 1384,    0,    0,    0, 1384, 1384, 1384, 1384, 1384,    0,
 1384,    0, 1384,    0,    0,    0, 1384,    0, 1384, 1384,
    0,    0, 1384, 1384,    0,    0,    0, 1384,    0, 1384,
    0,    0, 1384, 1384, 1384, 1384,    0, 1384,    0, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0,    0,    0,
 1384,    0, 1384,    0,    0,    0, 1384,    0,    0,    0,
    0,    0,    0, 1384,    0,    0,    0,    0, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384,    0, 1384, 1384, 1384,
 1384,    0, 1384, 1384,    0,    0,    0,    0,    0,    0,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384, 1384,    0,
 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384,    0,    0,
 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0,    0,    0,
    0, 1384, 1384, 1384,    0, 1384, 1384, 1384,    0, 1384,
    0, 1384, 1384, 1384,    0, 1384, 1384,    0, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
    0, 1384, 1384, 1384, 1384, 1384, 1384,    0, 1384, 1384,
 1384, 1384,    0, 1384,    0, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384,    0, 1384,
 1384, 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0, 1384,
 1384, 1384, 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384,    0, 1384, 1384, 1384, 1384,    0,
 1384, 1384, 1384, 1384, 1384, 1384,    0,    0, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,    0, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
    0,    0, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384, 1384,
 1219,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,   15,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1219,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767,    0,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
 1580,    0,    0,  880,    0,  881,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  883,    0,
    0,    0,    0,  884,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,  743,  142,  143,
    0,    0,    0,    0,  744,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,  745,    0,  148,    0,    0,
  149,  746,  747,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,  749,    0,  156,
  750,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,  751,    0,  752,  753,  164,  754,
    0,  165,    0,  166,  755,    0,  756,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,  758,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,  759,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
  761,  189,  190,  191,  192,  193,  762,    0,    0,    0,
  194,    0,  195,    0,    0,    0,  763,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
  764,  765,  766,  509,  510,  200,    0,  201,  202,  203,
  204,    0,  205,  767, 1230,    0,    0,    0,    0,    0,
  206,  207,  768,  769,  770,  771,  772,  773,  774,  775,
  776,  208,  777,    0,  210,  211,  212,  778,  779,    0,
  780,  781,  782,    0,  215,  216,  783,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  787,  224,    0,  788,  226,  227,    0,  228,
    0,  789,  790,  791,    0,  792,  793,    0,  794,  229,
  230,  231,  232,  233,  234,  795,  236,  796,  238,  797,
  798,  799,  800,  801,  802,  803,  804,  805,  806,  807,
    0,  808,  809,  810,  811,  812,  813,    0,  814,  815,
  816,  259,    0,  817,    0,  818,  819,  820,  821,  822,
  266,  267,  823,  269,  824,  825,  826,  273,  827,  275,
  828,  277,  829,    0,  830,  831,  832,  833,    0,  834,
  835,  836,  286,  837,    0,  838,  839,  290,  840,  292,
  293,  841,  295,  296,  297,  298,  299,  300,    0,  842,
  302,  303,  304,  305,  306,    0,  843,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  844,  845,    0,
  319,  320,  321,  846,  847,  848,    0,    0,  325,  849,
  850,  851,  852,  853,  854,  855,  856,  857,    0,  858,
  859,  860,  334,  861,  335,  336,  337,  338,  339,  340,
    0,    0,  862,  863,  864,  865,  866,  867,  868,  869,
  870,  871,  872,  873,  874,  875,  876,  877,  878,  879,
    0, 1938,    0, 1938,    0,    0,    0,    0,    0, 1938,
    0,    0, 1938, 1938,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1938, 1938,    0, 1938,    0, 1938,    0,
    0, 1938,    0,    0, 1938,    0,    0,    0,    0,    0,
    0, 1938,    0, 1938, 1938,    0,    0,    0, 1938,    0,
 1938,    0,    0, 1938,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1938, 1938,    0,    0,    0, 1938,    0,
 1938,    0, 1938, 1938,    0,    0,    0,    0, 1938,    0,
 1938,    0,    0,    0, 1938,    0,    0,    0,    0,    0,
    0,    0, 1938,    0,    0, 1938,    0, 1938,    0,    0,
    0, 1938, 1938,    0, 1938,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1938,    0, 1938,    0, 1938, 1938,
 1938, 1938, 1938,    0, 1938,    0,    0,    0,    0,    0,
 1938,    0, 1938, 1938,    0,    0, 1938, 1938,    0,    0,
    0,    0,    0, 1938,    0,    0, 1938, 1938, 1938, 1938,
    0, 1938,    0, 1938,    0, 1938, 1938, 1938, 1938, 1938,
    0,    0,    0,    0, 1938,    0, 1938,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1938, 1229,    0,
    0,    0, 1938, 1938,    0, 1938,    0,    0,    0, 1938,
    0, 1938, 1938, 1938, 1938,    0, 1938,    0,    0,    0,
    0,    0,    0,    0, 1938, 1938,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1938, 1938,    0, 1938, 1938,
 1938,    0,    0,    0,    0, 1938, 1938,    0, 1938, 1938,
    0, 1938,    0,    0, 1938, 1938,    0,    0,    0, 1938,
 1938,    0,    0,    0,    0, 1938, 1938, 1938,    0, 1938,
 1938, 1938,    0, 1938,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1938, 1938, 1938, 1938, 1938, 1938, 1938,
 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938,
 1938, 1938, 1938, 1938,    0, 1938, 1938, 1938, 1938, 1938,
 1938,    0, 1938, 1938, 1938, 1938,    0, 1938,    0, 1938,
 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938,
 1938, 1938, 1938, 1938, 1938, 1938, 1938,    0, 1938, 1938,
 1938, 1938,    0, 1938, 1938, 1938, 1938, 1938,    0, 1938,
 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938,
 1938, 1938,    0, 1938, 1938, 1938, 1938, 1938, 1938,    0,
 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938,    0, 1938,
 1938, 1938, 1938,    0, 1938, 1938, 1938, 1938, 1938, 1938,
    0,    0, 1938, 1938, 1938, 1938, 1938, 1938, 1938, 1938,
 1938,    0,    0,    0,    0,    0, 1938,    0, 1938, 1938,
 1938, 1938, 1938, 1938,    0, 1842,    0, 1842,    0,    0,
    0,    0,    0, 1842,    0,    0, 1842, 1842,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1842, 1842,    0,
 1842,    0, 1842,    0,    0, 1842,    0,    0, 1842,    0,
    0,    0,    0,    0,    0, 1842,    0, 1842, 1842,    0,
    0,    0, 1842,    0, 1842,    0,    0, 1842,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1842, 1842,    0,
    0,    0, 1842,    0, 1842,    0, 1842, 1842,    0,    0,
    0,    0, 1842,    0, 1842,    0,    0,    0, 1842,    0,
    0,    0,    0,    0,    0,    0, 1842,    0,    0, 1842,
    0, 1842,    0,    0,    0, 1842, 1842,    0, 1842,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1842,    0,
 1842,    0, 1842, 1842, 1842, 1842, 1842,    0, 1842,    0,
    0,    0,    0,    0, 1842,    0, 1842, 1842,    0,    0,
 1842, 1842,    0,    0,    0,    0,    0, 1842,    0,    0,
 1842, 1842, 1842, 1842,    0, 1842,    0, 1842,    0, 1842,
 1842, 1842, 1842, 1842,    0,    0,    0,    0, 1842,    0,
 1842,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1842,    0, 1573,    0,    0, 1842, 1842,    0, 1842,
    0,    0,    0, 1842,    0, 1842, 1842, 1842, 1842,    0,
 1842,  883,    0,    0,    0,    0,    0,    0, 1842, 1842,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1842,
 1842,    0, 1842, 1842, 1842,    0,    0,    0,    0, 1842,
 1842,    0, 1842, 1842,    0, 1842,    0,    0, 1842, 1842,
    0,    0,    0, 1842, 1842,    0,    0,    0,    0, 1842,
 1842, 1842,    0, 1842, 1842, 1842,    0, 1842,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,    0, 1842,
 1842, 1842, 1842, 1842, 1842,    0, 1842, 1842, 1842, 1842,
    0, 1842,    0, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842,    0, 1842, 1842, 1842, 1842,    0, 1842, 1842, 1842,
 1842, 1842,    0, 1842, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842, 1842,    0, 1842, 1842, 1842,
 1842, 1842, 1842,    0, 1842, 1842, 1842, 1842, 1842, 1842,
 1842, 1842,    0, 1842, 1842, 1842, 1842,    0, 1842, 1842,
 1842, 1842, 1842, 1842,    0,    0, 1842, 1842, 1842, 1842,
 1842, 1842, 1842, 1842, 1842,    0,    0,    0,    0,    0,
 1842,    0, 1842, 1842, 1842, 1842, 1842, 1842,    0,    0,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,    0,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0,    0,    0,    0,  161,    0,  162,
    0,    0,    0,  163,    0,    0,    0,    0,    0,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  169,    0,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179,    0,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186,    0,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196, 1280,    0,    0,
    0,  197,  198,    0,  199,    0,    0,    0,  200,    0,
  201,  202,  203,  204,    0,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0,    0,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  308,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0,    0,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,    0,  139,    0,  140,    0,    0,    0,
    0,    0,  141,    0,    0,  142,  143,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  144,  145,    0,  146,
    0,  147,    0,    0,  148,    0,    0,  149,    0,    0,
    0,    0,    0,    0,  150,    0,  151,  152,    0,    0,
    0,  153,    0,  154,    0,    0,  155,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  156,  157,    0,    0,
    0,  158,    0,  159,    0,  160,    0,    0,    0,    0,
    0,  161,    0,  162,    0,    0,    0,  163,    0,    0,
    0,    0,    0,    0,    0,  164,    0,    0,  165,    0,
  166,    0,    0,    0,  167,  168,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  169,    0,    0,
    0,  171,  172,  173,  174,  175,    0,  176,    0,    0,
    0,    0,    0,  177,    0,  178,  179,    0,    0,  180,
  181,    0,    0,    0,    0,    0,  182,    0,    0,  183,
  184,  185,  186,    0,  187,    0,  188,    0,  189,  190,
  191,  192,  193,    0,    0,    0,    0,  194,    0,  195,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  196, 1280,    0,    0,   15,  197,  198,    0,  199,    0,
    0,    0,  200,    0,  201,  202,  203,  204,    0,  205,
    0,    0,    0,    0,    0,    0,    0,  206,  207,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  208,  209,
    0,  210,  211,  212,    0,    0,    0,    0,  213,  214,
    0,  215,  216,    0,  217,    0,    0,  218,  219,    0,
    0,    0,  220,  221,    0,    0,    0,    0,  222,  223,
  224,    0,  225,  226,  227,    0,  228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,  249,    0,  250,  251,
  252,  253,  254,  255,    0,  256,  257,  258,  259,    0,
  260,    0,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  278,
    0,  279,  280,  281,  282,    0,  283,  284,  285,  286,
  287,    0,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,    0,  301,  302,  303,  304,
  305,  306,    0,  307,  308,  309,  310,  311,  312,  313,
  314,    0,  315,  316,  317,  318,    0,  319,  320,  321,
  322,  323,  324,    0,    0,  325,  326,  327,  328,  329,
  330,  331,  332,  333,    0,    0,    0,    0,    0,  334,
    0,  335,  336,  337,  338,  339,  340,    0,  139,    0,
  140,    0,    0,    0,    0,    0,  141,    0,    0,  142,
  143,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  144,  145,    0,  146,    0,  147,    0,    0,  148,    0,
    0,  149,    0,    0,    0,    0,    0,    0,  150,    0,
  151,  152,    0,    0,    0,  153,    0,  154,    0,    0,
  155,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  156,  157,    0,    0,    0,  158,    0,  159,    0,  160,
    0,    0,    0,    0,    0,  161,    0,  162,    0,    0,
    0,  163,    0,    0,    0,    0,    0,    0,    0,  164,
    0,    0,  165,    0,  166,    0,    0,    0,  167,  168,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  169,    0,    0,    0,  171,  172,  173,  174,  175,
    0,  176,    0,    0,    0,    0,    0,  177,    0,  178,
  179,    0,    0,  180,  181,    0,    0,    0,    0,    0,
  182,    0,    0,  183,  184,  185,  186,    0,  187,    0,
  188,    0,  189,  190,  191,  192,  193,    0,    0,    0,
    0,  194,    0,  195,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  196,  679,    0,    0,    0,  197,
  198,    0,  199,    0,    0,    0,  200,    0,  201,  202,
  203,  204,    0,  205,    0,    0,    0,    0,    0,    0,
    0,  206,  207,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  208,  209,    0,  210,  211,  212,    0,    0,
    0,    0,  213,  214,    0,  215,  216,    0,  217,    0,
    0,  218,  219,    0,    0,    0,  220,  221,    0,    0,
    0,    0,  222,  223,  224,    0,  225,  226,  227,    0,
  228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
  249,    0,  250,  251,  252,  253,  254,  255,    0,  256,
  257,  258,  259,    0,  260,    0,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,  278,    0,  279,  280,  281,  282,    0,
  283,  284,  285,  286,  287,    0,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,  300,    0,
  301,  302,  303,  304,  305,  306,    0,  307,  308,  309,
  310,  311,  312,  313,  314,    0,  315,  316,  317,  318,
    0,  319,  320,  321,  322,  323,  324,    0,    0,  325,
  326,  327,  328,  329,  330,  331,  332,  333,    0,    0,
    0,    0,    0,  334,    0,  335,  336,  337,  338,  339,
  340,    0,  139,    0,  140,    0,    0,    0,    0,    0,
  141,    0,    0,  142,  143,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  144, 2758,    0,  146,    0,  147,
    0,    0,  148,    0,    0,  149,    0,    0,    0,    0,
    0,    0,  150,    0,  151,  152,    0,    0,    0,  153,
    0,  154,    0,    0,  155,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  156,  157,    0,    0,    0,  158,
    0,  159,    0,  160,    0,    0,    0,    0,    0,  161,
    0,  162,    0,    0,    0,  163,    0,    0,    0,    0,
    0,    0,    0,  164,    0,    0,  165,    0,  166,    0,
    0,    0,  167,  168,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  169,    0,    0,    0,  171,
  172,  173,  174,  175,    0,  176,    0,    0,    0,    0,
    0,  177,    0,  178,  179,    0,    0,  180,  181,    0,
    0,    0,    0,    0,  182,    0,    0,  183,  184,  185,
  186,    0,  187,    0,  188,    0,  189,  190,  191,  192,
  193,    0,    0,    0,    0,  194,    0,  195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  196,    0,
 2116,    0,    0,  197,  198,    0,  199,    0,    0,    0,
  200,    0,  201,  202,  203,  204,    0,  205,    0,    0,
    0,    0,    0,    0,    0,  206,  207,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  208,  209,    0,  210,
  211,  212,    0,    0,    0,    0,  213,  214,    0,  215,
  216,    0,  217,    0,    0,  218,  219,    0,    0,    0,
  220,  221,    0,    0,    0,    0,  222,  223,  224,    0,
  225,  226,  227,    0,  228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,  249,    0,  250,  251,  252,  253,
  254,  255,    0,  256,  257,  258,  259,    0,  260,    0,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  278,    0,  279,
  280,  281,  282,    0,  283,  284,  285,  286,  287,    0,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,    0,  301,  302,  303,  304,  305,  306,
    0,  307,  308,  309,  310,  311,  312,  313,  314,    0,
  315,  316,  317,  318,    0,  319,  320,  321,  322,  323,
  324,    0,    0,  325,  326,  327,  328,  329,  330,  331,
  332,  333,    0,    0,    0,    0,    0,  334,    0,  335,
  336,  337,  338,  339,  340,  139,    0,  140,    0,    0,
    0,    0,    0,  141,    0,    0,  142,  143,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  144,  145,    0,
  146,    0,  147,    0,    0,  148,    0,    0,  149,    0,
  747,    0,    0,    0,    0,  150,    0,  151,  152,    0,
    0,    0,  153,    0,  154,    0,    0,  155,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  156,  157,    0,
    0,    0,  158,    0,  159,    0,  160,    0,    0,    0,
    0,    0,  161,    0,  162,    0,    0,    0,  163,    0,
    0,    0,    0,    0,    0,    0,  164,    0,    0,  165,
    0,  166,    0,    0,    0,  167,  168,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  169,    0,
    0,    0,  171,  172,  173,  174,  175,    0,  176,    0,
    0,    0,    0,    0,  177,    0,  178,  179,    0,    0,
  180,  181,    0,    0,    0,    0,    0,  182,    0,    0,
  183,  184,  185,  186,    0,  187,    0,  188,    0,  189,
  190,  191,  192,  193,    0,    0,    0,    0,  194,    0,
  195,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  196,    0,    0,    0,    0,  197,  198, 1136,  199,
    0,    0,    0,  200,    0,  201,  202,  203,  204,    0,
  205,    0,    0,    0,    0,    0,    0,    0,  206,  207,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  208,
  209,    0,  210,  211,  212,    0,    0,    0,    0,  213,
  214,    0,  215,  216,    0,  217,    0,    0,  218,  219,
    0,    0,    0,  220,  221,    0,    0,    0,    0,  222,
  223,  224,    0,  225,  226,  227,    0,  228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,  249,    0,  250,
  251,  252,  253,  254,  255,    0,  256,  257,  258,  259,
    0,  260,    0,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
  278,    0,  279,  280,  281,  282,    0,  283,  284,  285,
  286,  287,    0,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,  300,    0,  301,  302,  303,
  304,  305,  306,    0,  307,  308,  309,  310,  311,  312,
  313,  314,    0,  315,  316,  317,  318,    0,  319,  320,
  321,  322,  323,  324,    0,    0,  325,  326,  327,  328,
  329,  330,  331,  332,  333,    0,    0,    0,    0,    0,
  334,  861,  335,  336,  337,  338,  339,  340,    0,    0,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,    0,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0,    0,    0,    0,  161,    0,  162,
    0,    0,    0,  163,    0,    0,    0,    0,    0,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  169,    0,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179,    0,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186,    0,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196,    0,    0,    0,
    0,  197,  198,    0,  199,  525,    0,    0,  200,    0,
  201,  202,  203,  204,  600,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0,    0,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  308,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0,    0,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,  600,    0,  600,    0,    0,    0,    0,
    0,  600,    0,    0,  600,  600,  600,    0,    0,    0,
    0,    0,    0,    0,    0,  600,  600,    0,  600,    0,
  600,    0,    0,  600,    0,    0,  600,    0,    0,    0,
    0,    0,  600,  600,    0,  600,  600,    0,    0,  600,
  600,    0,  600,  600,    0,  600,    0,    0,  600,    0,
    0,    0,    0,    0,    0,  600,  600,    0,    0,    0,
  600,  600,  600,    0,  600,    0,  600,    0,    0,    0,
  600,    0,  600,    0,    0,    0,  600,    0,    0,    0,
    0,    0,  600,    0,  600,  600,    0,  600,    0,  600,
    0,  600,    0,  600,  600,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  600,    0,    0,    0,
  600,  600,  600,  600,  600,    0,  600,    0,  600,  600,
    0,    0,  600,    0,  600,  600,    0,    0,  600,  600,
    0,    0,    0,  600,    0,  600,  600,    0,  600,  600,
  600,  600,    0,  600,    0,  600,    0,  600,  600,  600,
  600,  600,    0,    0,    0,    0,  600,    0,  600,    0,
    0,  600,    0,    0,    0,    0,    0,    0,    0,  600,
  600,    0,  600,  600,  600,  600,    0,  600,    0,    0,
    0,  600,    0,  600,  600,  600,  600, 1759,  600,  600,
    0,    0,    0,    0,    0,    0,  600,  600,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  600,  600,    0,
  600,  600,  600,    0,    0,    0,    0,  600,  600,    0,
  600,  600,    0,  600,    0,    0,  600,  600,    0,    0,
    0,  600,  600,  600,  600,  600,    0,  600,  600,  600,
    0,  600,  600,  600,    0,  600,    0,  600,  600,  600,
    0,  600,  600,    0,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,    0,  600,  600,  600,
  600,  600,  600,    0,  600,  600,  600,  600,    0,  600,
    0,  600,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,  600,  600,  600,  600,  600,    0,
  600,  600,  600,  600,    0,  600,  600,  600,  600,  600,
    0,  600,  600,  600,  600,  600,  600,  600,  600,  600,
  600,  600,  600,  600,    0,  600,  600,  600,  600,  600,
  600,    0,  600,  600,  600,  600,  600,  600,  600,  600,
    0,  600,  600,  600,  600,    0,  600,  600,  600,  600,
  600,  600,  600,    0,  600,  600,  600,  600,  600,  600,
  600,  600,  600,    0,    0,    0,    0,    0,  600,    0,
  600,  600,  600,  600,  600,  600,  139,    0,  140,    0,
    0,    0,    0,    0,  141,    0,    0,  142,  143, 1375,
    0,    0,    0,    0,    0,    0,    0,    0,  144,  145,
    0,  146,    0,  147,    0,    0,  148,    0,    0,  149,
    0,    0,    0,    0,    0,    5,  150,    0,  151,  152,
    0,    0,    0,  153,    0, 1745, 1746,    0, 1747,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  156,  157,
    0,    0,    0, 1748, 1749,  159,    0,  160,    0,    9,
    0,    0,    0,  161,    0,  162,    0,    0,    0,  163,
    0,    0,    0,    0,    0,  752,    0,  164,  754,    0,
  165,    0,  166,    0,   10,    0,  167,  168,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  169,
    0,    0,    0,  171,  172,  173,  174,  175,    0,  176,
    0,  758, 1750,    0,    0,  177,    0,  178,  179,    0,
    0,  180,  181,    0,    0,    0,  759,    0,  182,    0,
    0,  183,  184,  185,  186,    0,  187,    0,  188,    0,
  189,  190,  191,  192, 1751,    0,    0,    0,    0,  194,
    0,  195,    0,    0,   14,    0,    0,    0,    0,    0,
    0,    0,  196, 2181,    0,    0,   15,  197,  198,    0,
  765,    0,    0,    0,  200,    0,  201,  202,  203,  204,
 1759,  205,  767,    0,    0,    0,    0,    0,    0,  206,
  207,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1752,  777,    0,  210,  211,  212,    0,    0,    0,    0,
  213,  214,    0,  215,  216,    0,  217,    0,    0,  218,
 1753,    0,    0,    0,  220,  221, 1754, 1755, 1756,    0,
  222,  223,  224,    0,  225,  226,  227,    0,  228,    0,
  789,  790,  791,    0,  792,  793,    0,  794,  229,  230,
  231,  232,  233,  234,  795,  236,  796,  238,  797,  798,
  799,  800,  801,  802,  803,  804,  805,  806,  807,    0,
  808,  809,  810,  811,  812,  255,    0,  814,  815,  816,
  259,    0,  817,    0,  261,  819,  820,  821,  822,  266,
  267,  823,  269,  824,  825,  826,  273,  827,  275,  828,
  277,  829,    0,  830,  831,  832,  833,    0,  834,  835,
  836,  286,  837,    0,  838,  839,  290,  840,  292,  293,
  841,  295,  296,  297,  298,  299,  300,    0,  842,  302,
  303,  304,  305,  306,    0,  843,  308, 1757,  310,  311,
  312,  313,  314,    0,  315,  316,  844,  845,    0,  319,
  320,  321,  846,  847,  848, 1758,    0,  325,  326,  327,
  328,  329,  330,  331,  332,  333,    0,    0,    0,    0,
    0,  334,    0,  335,  336,  337,  338,  339,  340,  139,
    0,  140,    0,    0,    0,    0,    0,  141,    0,    0,
  142,  143, 1375,    0,    0,    0,    0,    0,    0,    0,
    0,  144,  145,    0,  146,    0,  147,    0,    0,  148,
    0,    0,  149,    0,    0,    0,    0,    0,    5,  150,
    0,  151,  152,    0,    0,    0,  153,    0, 1745, 1746,
    0, 1747,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  156,  157,    0,    0,    0, 1748, 1749,  159,    0,
  160,    0,    9,    0,    0,    0,  161,    0,  162,    0,
    0,    0,  163,    0,    0,    0,    0,    0,  752,    0,
  164,  754,    0,  165,    0,  166,    0,   10,    0,  167,
  168,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  169,    0,    0,    0,  171,  172,  173,  174,
  175,    0,  176,    0,  758, 1750,    0,    0,  177,    0,
  178,  179,    0,    0,  180,  181,    0,    0,    0,  759,
    0,  182,    0,    0,  183,  184,  185,  186,    0,  187,
    0,  188,    0,  189,  190,  191,  192, 1751,    0,    0,
    0,    0,  194,    0,  195,    0,    0,   14,    0,    0,
    0,    0,    0,    0,    0,  196,    0,    0,    0,   15,
  197,  198,    0,  765,    0,    0,    0,  200,    0,  201,
  202,  203,  204,  883,  205,  767,    0,    0,    0,    0,
    0,    0,  206,  207,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1752,  777,    0,  210,  211,  212,    0,
    0,    0,    0,  213,  214,    0,  215,  216,    0,  217,
    0,    0,  218, 1753,    0,    0,    0,  220,  221, 1754,
 1755, 1756,    0,  222,  223,  224,    0,  225,  226,  227,
    0,  228,    0,  789,  790,  791,    0,  792,  793,    0,
  794,  229,  230,  231,  232,  233,  234,  795,  236,  796,
  238,  797,  798,  799,  800,  801,  802,  803,  804,  805,
  806,  807,    0,  808,  809,  810,  811,  812,  255,    0,
  814,  815,  816,  259,    0,  817,    0,  261,  819,  820,
  821,  822,  266,  267,  823,  269,  824,  825,  826,  273,
  827,  275,  828,  277,  829,    0,  830,  831,  832,  833,
    0,  834,  835,  836,  286,  837,    0,  838,  839,  290,
  840,  292,  293,  841,  295,  296,  297,  298,  299,  300,
    0,  842,  302,  303,  304,  305,  306,    0,  843,  308,
 1757,  310,  311,  312,  313,  314,    0,  315,  316,  844,
  845,    0,  319,  320,  321,  846,  847,  848, 1758,    0,
  325,  326,  327,  328,  329,  330,  331,  332,  333,    0,
    0,    0,    0,    0,  334,    0,  335,  336,  337,  338,
  339,  340,  139,    0,  140,    0,    0,    0,    0,    0,
  141,    0,    0,  142,  143,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  144,  145,    0,  146,    0,  147,
    0,    0,  148,    0,    0,  149,    0,    0,    0,    0,
    0,    0,  150,    0,  151,  152,    0,    0,    0,  153,
    0,  154,    0,    0,  155,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  156,  157,    0,    0,    0,  158,
    0,  159,    0,  160,    0,    0,    0,    0,    0,  161,
    0,  162,    0,    0,    0,  163,    0,    0,    0,    0,
    0,    0,    0,  164,    0,    0,  165,    0,  166,    0,
    0,    0,  167,  168,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  169,    0,    0,    0,  171,
  172,  173,  174,  175,    0,  176,    0,    0,    0,    0,
    0,  177,    0,  178,  179,    0,    0,  180,  181,    0,
    0,    0,    0,    0,  182,    0,    0,  183,  184,  185,
  186,    0,  187,    0,  188,    0,  189,  190,  191,  192,
  193,    0,    0,    0,    0,  194,    0,  195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  196,    0,
    0,    0,    0,  197,  198,    0,  199,    0,    0,    0,
  200,    0,  201,  202,  203,  204,    0,  205,    0,    0,
    0,    0,    0,    0,    0,  206,  207,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  208,  209,    0,  210,
  211,  212,    0,    0,    0,    0,  213,  214,    0,  215,
  216,    0,  217,    0,    0,  218,  219,    0,    0,    0,
  220,  221,    0,    0,    0,    0,  222,  223,  224,    0,
  225,  226,  227,    0,  228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,  249,    0,  250,  251,  252,  253,
  254,  255,    0,  256,  257,  258,  259,    0,  260,    0,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  278,    0,  279,
  280,  281,  282,    0,  283,  284,  285,  286,  287,    0,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,    0,  301,  302,  303,  304,  305,  306,
    0,  307,  308,  309,  310,  311,  312,  313,  314,    0,
  315,  316,  317,  318,    0,  319,  320,  321,  322,  323,
  324,    0,    0,  325,  326,  327,  328,  329,  330,  331,
  332,  333,    0,    0,    0,    0,    0,  334,    0,  335,
  336,  337,  338,  339,  340, 1805, 1805, 1745, 1805, 1805,
 1805,    0,    0,    0,    0,    0, 1806, 1806, 1746, 1806,
 1806, 1806,    0, 1805, 1805, 1805,    0,    0,    0,    0,
    0,    0,    0,    0, 1806, 1806, 1806,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1805,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1806,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1851, 1851, 1743, 1851, 1851,
 1851,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1851, 1851, 1851,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1851,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1805,    0,    0,    0,    0,
    0,    0,    0,    0, 1805,    0, 1806,    0,    0,    0,
 1805,    0,    0,    0, 1805, 1806,    0, 1805,    0,    0,
    0, 1806,    0,    0,    0, 1806,    0,    0, 1806,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1805, 1874, 1874, 1744, 1874, 1874, 1874, 1805,    0,
    0,    0, 1806,    0,    0, 1851, 1805,    0,    0, 1806,
 1874, 1874, 1874,    0, 1851,    0,    0, 1806,    0,    0,
 1851,    0,    0, 1805, 1851, 1805,    0, 1851,    0,    0,
    0,    0,    0,    0, 1806, 1805, 1806, 1805, 1805, 1805,
    0, 1874,    0,    0, 1805,    0, 1806,    0, 1806, 1806,
 1806,    0,    0,    0,    0, 1806,    0,    0,    0,    0,
    0, 1851,    0,    0,    0,    0,    0,    0, 1851,    0,
    0,    0,    0,    0,    0,    0, 1851,    0,    0,    0,
    0,    0,    0,    0,    0, 1805,    0,    0,    0,    0,
    0,    0,    0, 1851,    0, 1851, 1806,    0,    0,    0,
    0,    0,    0,    0,    0, 1851,    0, 1851, 1851, 1851,
    0,    0,    0,    0, 1851,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1805, 1805, 1805,
 1805, 1805, 1805, 1805, 1805,    0,    0,    0, 1806, 1806,
 1806, 1806, 1806, 1806, 1806, 1806, 1886, 1886,    0, 1886,
 1886, 1886,    0,    0,    0, 1851,    0,    0,    0,    0,
    0,    0,    0, 1886, 1886, 1886, 1886,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1886,    0, 1851, 1851, 1851,
 1851, 1851, 1851, 1851, 1851,    0,    0,    0,    0,    0,
    0,    0, 1874,    0,    0,    0,    0,    0,    0,    0,
    0, 1874,    0,    0,    0,    0,    0, 1874,    0,    0,
    0, 1874,    0,    0, 1874,    0, 1805,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1806,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1805,    0,    0,    0,    0,    0, 1874,    0,
    0, 1805,    0, 1806,    0, 1874,    0,    0,    0,    0,
    0,    0, 1806, 1874,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1874,    0, 1874,    0,    0,    0, 1851,    0,    0,    0,
    0,    0, 1874,    0, 1874, 1874, 1874,    0,    0,    0,
    0, 1874,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1851,    0,    0,    0,    0,    0,    0,    0,
    0, 1851,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1874,    0,    0,    0, 1886,    0, 1886,    0,
    0,    0,    0,    0,    0, 1886,    0,    0,    0,    0,
    0, 1886,    0,    0,    0, 1886,    0,    0, 1886,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1874, 1874, 1874, 1874, 1874, 1874,
 1874, 1874,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1886,    0,    0,    0,    0,    0,    0, 1886,
    0,    0,    0,    0,    0,    0, 1886, 1886,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1886,    0, 1886,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1886,    0, 1886, 1886,
 1886,    0, 1886,    0,    0, 1886,    0,    0,    0,    0,
    0,    0,    0,    0, 1886,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1874,    0,    0, 1886,    0,    0,    0,
    0,    0,  139,    0,  140,    0,    0,    0,    0,    0,
  141,    0,    0,  142,  143,    0,    0,    0,    0, 1874,
    0, 1886,    0,    0,  144,  145,    0,  146, 1874,  147,
    0,    0,  148,    0, 1886,  149,    0,    0,    0,    0,
    0,    0,  150,    0,  151,  152,    0,    0,    0,  153,
    0,  154,    0,    0,  155,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  156,  157,    0,    0,    0,  158,
    0,  159,    0,  160,    0,    0,    0,    0,    0,  161,
    0,  162,    0,    0,    0,  163,    0,    0,    0,    0,
    0,    0,    0,  164,    0,    0,  165,    0,  166,    0,
    0,    0,  167,  168,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  169,    0,    0,    0,  171,
  172,  173,  174,  175,    0,  176,    0,    0,    0,    0,
    0,  177,    0,  178,  179,    0,    0,  180,  181,    0,
    0,    0,    0,    0,  182,    0,    0,  183,  184,  185,
  186,    0,  187,    0,  188,    0,  189,  190,  191,  192,
  193,    0,    0,    0,    0,  194,    0,  195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  196,    0,
    0,    0, 1886,  197,  198,    0,  199,    0,    0,    0,
  200,  378,  201,  202,  203,  204,  379,  205,  380,  381,
  382,  383,  384,  385,  386,  206,  207,  387,  388,  389,
  390,  391,    0,    0,  392,  393,  208,  209,  394,  210,
  211,  212,  395,  396,  397,  398,  213,  214,  399,  215,
  216,  400,  217,  401,  402,  218,  219,  403,  404,  405,
  220,  221,  406,  407,  408,  409,  222,  223,  224,  410,
  225,  226,  227,  411,  228,  412,  413,  414,  415,  416,
  417,  418,  419,  420,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,  249,  421,  250,  251,  252,  253,
  254,  255,  422,  256,  257,  258,  259,  423,  260,  424,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  278,  425,  279,
  280,  281,  282,  426,  283,  284,  285,  286,  287,  427,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,  428,  301,  302,  303,  304,  305,  306,
    0,  307,  308,  309,  310,  311,  312,  313,  314,  429,
  315,  316,  317,  318,  430,  319,  320,  321,  322,  323,
  324,  431,  432,  325,  326,  327,  328,  329,  330,  331,
  332,  333,  433,  434,  435,  436,  437,  334,  438,  335,
  336,  337,  338,  339,  340,  439,  440,  441,  442,  443,
  444,  445,  446,  447,  448,  449,  450,  451,  452,  453,
  454,  455,  456,  457,  458,  892,    0,  892,    0,    0,
    0,    0,    0,  892,    0,    0,  892,  892,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  892,  892,    0,
  892,    0,  892,    0,    0,  892,    0,    0,  892,    0,
    0,    0,    0,    0,    0,  892,    0,  892,  892,    0,
    0,    0,  892,    0,  892,    0,    0,  892,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  892,  892,    0,
    0,    0,  892,    0,  892,    0,  892,    0,    0,    0,
    0,    0,  892,    0,  892,    0,    0,    0,  892,    0,
    0,    0,    0,    0,    0,    0,  892,    0,    0,  892,
    0,  892,    0,    0,    0,  892,  892,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  892,    0,
    0,    0,  892,  892,  892,  892,  892,    0,  892,    0,
    0,    0,    0,    0,  892,    0,  892,  892,    0,    0,
  892,  892,    0,    0,    0,    0,    0,  892,    0,    0,
  892,  892,  892,  892,    0,  892,    0,  892,    0,  892,
  892,  892,  892,  892,    0,    0,    0,    0,  892,    0,
  892,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  892,    0,    0,    0,    0,  892,  892,    0,  892,
    0,    0,    0,  892,  892,  892,  892,  892,  892,    0,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,    0,    0,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,    0,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892,  892,  892,
  892,  892,  892,  892,  892,  892,  892,  892, 1758,    0,
 1758,    0,    0,    0,    0,    0, 1758,    0,    0, 1758,
 1758,    0,    0, 1758,    0,    0, 1758,    0,    0,    0,
 1758, 1758,    0, 1758,    0, 1758,    0,    0, 1758,    0,
 1760, 1758, 1758,    0, 1758,    0,    0,    0, 1758,    0,
 1758, 1758,    0,    0,    0, 1758,    0, 1758,    0,    0,
 1758,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1758, 1758,    0,    0,    0, 1758,    0, 1758,    0, 1758,
    0,    0, 1758,    0,    0, 1758,    0, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758,    0, 1758,    0,    0, 1758,
    0,    0, 1758,    0, 1758,    0,    0,    0, 1758, 1758,
 1758,    0, 1758,    0, 1760,    0,    0,    0,    0,    0,
    0, 1758,    0,    0,    0, 1758, 1758, 1758, 1758, 1758,
    0, 1758,    0,    0,    0,    0,    0, 1758,    0, 1758,
 1758, 1758,    0, 1758, 1758,    0,    0,    0,    0,    0,
 1758,    0,    0, 1758, 1758, 1758, 1758, 1758, 1758,    0,
 1758,    0, 1758, 1758, 1758, 1758, 1758,    0,    0,    0,
    0, 1758,    0, 1758,    0,    0,    0,    0,    0, 1758,
    0,    0,    0,    0, 1758,    0,    0,    0,    0, 1758,
 1758,    0, 1758,    0,    0,    0, 1758,    0, 1758, 1758,
 1758, 1758,    0, 1758,    0,    0,    0,    0,    0,    0,
    0, 1758, 1758, 1758, 1758,    0,    0,    0,    0,    0,
    0,    0, 1758, 1758,    0, 1758, 1758, 1758,    0,    0,
 1758,    0, 1758, 1758,    0, 1758, 1758,    0, 1758,    0,
    0, 1758, 1758,    0,    0,    0, 1758, 1758,    0,    0,
    0,    0, 1758, 1758, 1758,    0, 1758, 1758, 1758,    0,
 1758,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758,    0, 1758, 1758, 1758, 1758, 1758, 1758,    0, 1758,
 1758, 1758, 1758,    0, 1758,    0, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758,    0,
 1758, 1758, 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,    0,
 1758, 1758, 1758, 1758, 1758, 1758,    0, 1758, 1758, 1758,
 1758, 1758, 1758, 1758, 1758,    0, 1758, 1758, 1758, 1758,
 1760, 1758, 1758, 1758, 1758, 1758, 1758,    0,    0, 1758,
 1758, 1758, 1758, 1758, 1758, 1758, 1758, 1758,    0, 1758,
    0,    0,    0, 1758,    0, 1758, 1758, 1758, 1758, 1758,
 1758,  139,    0,  140,    0,    0,    0,    0,    0,  141,
    0,    0,  142,  143,    0,    0, 1061,    0,    0, 1062,
    0,    0,    0,  144,  145,    0,  146,    0,  147,    0,
    0,  148,    0,    0,  149, 1063,    0, 1064,    0,    0,
    0,  150,    0,  151,  152,    0,    0,    0,  153,    0,
  154,    0,    0,  155,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  156,  157,    0,    0,    0,  158,    0,
  159,    0,  160,    0,    0, 1065,    0,    0,  161,    0,
  162, 1066, 1067, 1068,  163, 1069, 1070, 1071,    0, 1072,
    0,    0,  164,    0,    0,  165,    0,  166,    0,    0,
    0,  167,  168, 1073,    0, 1074,    0,    0,    0,    0,
    0,    0,    0,    0,  169,    0,    0,    0,  171,  172,
  173,  174,  175,    0,  176,    0,    0,    0,    0,    0,
  177,    0,  178,  179, 1075,    0,  180,  181,    0,    0,
    0,    0,    0,  182,    0,    0,  183,  184,  185,  186,
 1076,  187,    0,  188,    0,  189,  190,  191,  192,  193,
    0,    0,    0,    0,  194,    0,  195,    0,    0,    0,
    0,    0, 1077,    0,    0,    0,    0,  196,    0,    0,
    0,    0,  197,  198,    0,  199,    0,    0,    0,  200,
    0,  201,  202,  203,  204,    0, 2156,    0,    0,    0,
    0,    0,    0,    0,  206,  207, 1078, 1079,    0,    0,
    0,    0,    0,    0,    0,  208,  209,    0,  210,  211,
  212,    0,    0, 1080,    0,  213,  214,    0,  215,  216,
    0,  217,    0,    0,  218,  219,    0,    0,    0,  220,
  221,    0,    0,    0,    0,  222,  223,  224,    0,  225,
  226,  227,    0,  228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,  249,    0,  250,  251,  252,  253,  254,
  255,    0,  256,  257,  258,  259,    0,  260,    0,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,  278,    0,  279,  280,
  281,  282,    0,  283,  284,  285,  286,  287,    0,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,  300,    0,  301,  302,  303,  304,  305,  306,    0,
  307,  308,  309,  310,  311,  312,  313,  314,    0,  315,
  316,  317,  318,    0,  319,  320,  321,  322,  323,  324,
    0,    0,  325,  326,  327,  328,  329,  330,  331,  332,
  333,    0, 1081,    0,    0,    0,  334,    0,  335,  336,
  337,  338,  339,  340,  139,    0,  140,    0,    0,    0,
    0,    0,  141,    0,    0,  142,  143,    0,    0, 1061,
    0,    0, 1062,    0,    0,    0,  144,  145,    0,  146,
    0,  147,    0,    0,  148,    0,    0,  149, 1063,    0,
 1064,    0,    0,    0,  150,    0,  151,  152,    0,    0,
    0,  153,    0,  154,    0,    0,  155,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  156,  157,    0,    0,
    0,  158,    0,  159,    0,  160,    0,    0, 1065,    0,
    0,  161,    0,  162, 1066, 1067, 1068,  163, 1069, 1070,
 1071,    0, 1072,    0,    0,  164,    0,    0,  165,    0,
  166,    0,    0,    0,  167,  168, 1073,    0, 1074,    0,
    0,    0,    0,    0,    0,    0,    0,  169,    0,    0,
    0,  171,  172,  173,  174,  175,    0,  176,    0,    0,
    0,    0,    0,  177,    0,  178,  179, 1075,    0,  180,
  181,    0,    0,    0,    0,    0,  182,    0,    0,  183,
  184,  185,  186, 1076,  187,    0,  188,    0,  189,  190,
  191,  192,  193,    0,    0,    0,    0,  194,    0,  195,
    0,    0,    0,    0,    0, 1077,    0,    0,    0,    0,
  196,    0,    0,    0,    0,  197,  198,    0,  199,    0,
    0,    0,  200,    0,  201,  202,  203,  204,    0, 2303,
    0,    0,    0,    0,    0,    0,    0,  206,  207, 1078,
 1079,    0,    0,    0,    0,    0,    0,    0,  208,  209,
    0,  210,  211,  212,    0,    0, 1080,    0,  213,  214,
    0,  215,  216,    0,  217,    0,    0,  218,  219,    0,
    0,    0,  220,  221,    0,    0,    0,    0,  222,  223,
  224,    0,  225,  226,  227,    0,  228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,  249,    0,  250,  251,
  252,  253,  254,  255,    0,  256,  257,  258,  259,    0,
  260,    0,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  278,
    0,  279,  280,  281,  282,    0,  283,  284,  285,  286,
  287,    0,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,    0,  301,  302,  303,  304,
  305,  306,    0,  307,  308,  309,  310,  311,  312,  313,
  314,    0,  315,  316,  317,  318,    0,  319,  320,  321,
  322,  323,  324,    0,    0,  325,  326,  327,  328,  329,
  330,  331,  332,  333,    0, 1081,    0,    0,    0,  334,
    0,  335,  336,  337,  338,  339,  340,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,    0,  142,  143,
    0,    0, 1061,    0,    0, 1062,    0,    0,    0,  144,
 2758,    0,  146,    0,  147,    0,    0,  148,    0,    0,
  149, 1063,    0, 1064,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  156,
  157,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0, 1065,    0,    0,  161,    0,  162, 1066, 1067, 1068,
  163, 1069, 1070, 1071,    0, 1072,    0,    0,  164,    0,
    0,  165,    0,  166,    0,    0,    0,  167,  168, 1073,
    0, 1074,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,    0,    0,    0,    0,  177,    0,  178,  179,
 1075,    0,  180,  181,    0,    0,    0,    0,    0,  182,
    0,    0,  183,  184,  185,  186, 1076,  187,    0,  188,
    0,  189,  190,  191,  192,  193,    0,    0,    0,    0,
  194,    0,  195,    0,    0,    0,    0,    0, 1077,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
    0,  199,    0,    0,    0,  200,    0,  201,  202,  203,
  204,    0,  205,    0,    0,    0,    0,    0,    0,    0,
  206,  207, 1078, 1079,    0,    0,    0,    0,    0,    0,
    0,  208,  209,    0,  210,  211,  212,    0,    0, 1080,
    0,  213,  214,    0,  215,  216,    0,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  223,  224,    0,  225,  226,  227,    0,  228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
    0,  250,  251,  252,  253,  254,  255,    0,  256,  257,
  258, 2759,    0,  260,    0,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  278,    0,  279,  280,  281,  282,    0,  283,
  284,  285,  286,  287,    0,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,    0,  301,
  302,  303,  304,  305,  306,    0,  307,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  317,  318,    0,
  319,  320,  321,  322,  323,  324,    0,    0,  325,  326,
  327,  328,  329,  330,  331,  332,  333,    0, 1081,    0,
    0,    0,  334,    0,  335,  336,  337,  338,  339,  340,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0, 1061,    0,    0, 1062,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149, 1063,    0, 1064,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0, 1065,    0,    0,  161,    0,  162,
 1066, 1067, 1068,  163, 1069, 1070, 1071,    0, 1072,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168, 1073,    0, 1074,    0,    0,    0,    0,    0,
    0,    0,    0,  169,    0,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179, 1075,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186, 1076,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0, 1077,    0,    0,    0,    0,  196,    0,    0,    0,
    0,  197,  198,    0,  199,    0,    0,    0,  200,    0,
  201,  202,  203,  204,    0,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207, 1078, 1079,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0, 1080,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  308,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0, 1081,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,   44,    0,   44,   32,   32,    0,    0,
    0,   44,    0,    0,   44,   44,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   44,   44,    0,   44,    0,
   44,    0,   32,   44,    0,    0,   44,    0,    0,    0,
    0,    0,   32,   44,    0,   44,   44,   32,    0,    0,
   44,    0,   44,   32,    0,   44,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   44,   44,    0,    0,    0,
   44,    0,   44,    0,   44,    0,   32,    0,    0,    0,
   44,    0,   44,    0,    0,    0,   44,    0,    0,    0,
    0,    0,    0,    0,   44,    0,    0,   44,    0,   44,
    0,    0,    0,   44,   44,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   44,    0,    0,    0,
   44,   44,   44,   44,   44,    0,   44,    0,    0,    0,
    0,    0,   44,    0,   44,   44,    0,   32,   44,   44,
    0,    0,    0,    0,    0,   44,   32,    0,   44,   44,
   44,   44,    0,   44,    0,   44,    0,   44,   44,   44,
   44,   44,    0,    0,    0,    0,   44,    0,   44,    0,
    0,   32,    0,    0,    0,    0,    0,    0,    0,   44,
    0,    0,    0,    0,   44,   44,    0,   44,    0,    0,
    0,   44,    0,   44,   44,   44,   44,    0,   44,    0,
    0,    0,    0,    0,    0,    0,   44,   44,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   44,   44,    0,
   44,   44,   44,    0,    0,    0,    0,   44,   44,    0,
   44,   44,    0,   44,    0,    0,   44,   44,    0,    0,
    0,   44,   44,    0,    0,    0,    0,   44,   44,   44,
    0,   44,   44,   44,    0,   44,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   44,   44,   44,   44,   44,
   44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,   44,   44,   44,    0,   44,   44,   44,
   44,   44,   44,    0,   44,   44,   44,   44,    0,   44,
    0,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,   44,   44,   44,   44,   44,   44,    0,
   44,   44,   44,   44,    0,   44,   44,   44,   44,   44,
    0,   44,   44,   44,   44,   44,   44,   44,   44,   44,
   44,   44,   44,   44,    0,   44,   44,   44,   44,   44,
   44,    0,   44,   44,   44,   44,   44,   44,   44,   44,
    0,   44,   44,   44,   44,    0,   44,   44,   44,   44,
   44,   44,    0,    0,   44,   44,   44,   44,   44,   44,
   44,   44,   44,    0,    0,    0,    0,    0,    0,    0,
   44,   44,   44,   44,   44,   44,  121,    0,  121,    0,
  119,    0,    0,    0,  121,    0,    0,  121,  121,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  121,  121,
    0,  121,    0,  121,    0,  119,  121,    0,    0,  121,
    0,    0,    0,    0,    0,  119,  121,    0,  121,  121,
  119,    0,    0,  121,    0,  121,  119,    0,  121,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  121,  121,
    0,    0,    0,  121,    0,  121,    0,  121,    0,  119,
    0,    0,    0,  121,    0,  121,    0,    0,    0,  121,
    0,    0,    0,    0,    0,    0,    0,  121,    0,    0,
  121,    0,  121,    0,    0,    0,  121,  121,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  121,
    0,    0,    0,  121,  121,  121,  121,  121,    0,  121,
    0,    0,    0,    0,    0,  121,    0,  121,  121,    0,
  119,  121,  121,    0,    0,    0,    0,    0,  121,  119,
    0,  121,  121,  121,  121,    0,  121,    0,  121,    0,
  121,  121,  121,  121,  121,    0,    0,    0,    0,  121,
    0,  121,    0,    0,  119,    0,    0,    0,    0,    0,
    0,    0,  121,    0,    0,    0,    0,  121,  121,    0,
  121,    0,    0,    0,  121,    0,  121,  121,  121,  121,
    0,  121,    0,    0,    0,    0,    0,    0,    0,  121,
  121,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  121,  121,    0,  121,  121,  121,    0,    0,    0,    0,
  121,  121,    0,  121,  121,    0,  121,    0,    0,  121,
  121,    0,    0,    0,  121,  121,    0,    0,    0,    0,
  121,  121,  121,    0,  121,  121,  121,    0,  121,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  121,  121,
  121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,  121,  121,  121,    0,
  121,  121,  121,  121,  121,  121,    0,  121,  121,  121,
  121,    0,  121,    0,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
  121,  121,    0,  121,  121,  121,  121,    0,  121,  121,
  121,  121,  121,    0,  121,  121,  121,  121,  121,  121,
  121,  121,  121,  121,  121,  121,  121,    0,  121,  121,
  121,  121,  121,  121,    0,  121,  121,  121,  121,  121,
  121,  121,  121,    0,  121,  121,  121,  121,    0,  121,
  121,  121,  121,  121,  121,    0,    0,  121,  121,  121,
  121,  121,  121,  121,  121,  121,    0,    0,    0,    0,
    0,    0,    0,  121,  121,  121,  121,  121,  121,  139,
    0,  140,    0,    0,    0,    0,    0,  141,    0,    0,
  142,  143,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  144,  145,    0,  146,    0,  147,    0,    0,  148,
    0,    0,  149,    0,    0,    0,    0,    0,    0,  150,
    0,  151,  152,    0,    0,    0,  153,    0,  154,    0,
    0,  155,    0,    0,    0,    0,    0,    0, 2887,    0,
    0,  156,  157,    0, 2888,    0,  158,    0,  159,    0,
  160,    0,    0,    0,    0,    0,  161,    0,  162,    0,
    0,    0,  163,    0,    0,    0,    0,    0,    0,    0,
  164,    0,    0,  165,    0,  166,    0,    0,    0,  167,
  168,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  169,    0,    0,    0,  171,  172,  173,  174,
  175,    0,  176,    0,    0,    0,    0,    0,  177, 2889,
  178,  179,    0,    0,  180,  181,    0,    0,    0,    0,
    0,  182,    0,    0,  183,  184,  185,  186,    0,  187,
    0,  188,    0,  189,  190,  191,  192,  193,    0,    0,
    0,    0,  194, 2890,  195,    0,    0,    0, 2891,    0,
    0,    0,    0,    0, 2892,  196,    0,    0,    0,    0,
  197,  198,    0,  199,    0,    0,    0,  200,    0,  201,
  202,  203, 2893,    0,  205,    0,    0,    0,    0,    0,
    0,    0,  206,  207,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  208,  209,    0,  210,  211,  212,    0,
    0,    0,    0,  213,  214,    0,  215,  216,    0,  217,
    0,    0,  218,  219,    0,    0,    0,  220,  221,    0,
    0,    0,    0,  222,  223,  224,    0,  225,  226,  227,
    0,  228,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  229,  230,  231,  232,  233,  234,  235,  236,  237,
  238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
  248,  249,    0,  250,  251,  252,  253,  254,  255,    0,
  256,  257,  258,  259,    0,  260,    0,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,  278,    0,  279,  280,  281,  282,
    0,  283,  284,  285,  286,  287,    0,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
    0,  301,  302,  303,  304,  305,  306,    0,  307,  308,
  309,  310,  311,  312,  313,  314,    0, 2894,  316,  317,
  318,    0,  319,  320,  321,  322,  323,  324,    0,    0,
  325,  326,  327,  328,  329,  330,  331,  332,  333,    0,
    0,    0,    0,    0,  334,    0,  335,  336,  337,  338,
  339,  340,  139,    0,  140,    0,    0,    0,    0,    0,
  141,    0,    0,  142,  143,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  144,  145,    0,  146,    0,  147,
    0,    0,  148,    0,    0,  149,    0,    0,    0,    0,
    0,    0,  150,    0,  151,  152,    0,    0,    0,  153,
    0,  154,    0,    0,  155,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  156,  157,    0,    0,    0,  158,
    0,  159,    0,  160, 3013,    0,    0,    0,    0,  161,
    0,  162,    0,    0,    0,  163,    0,    0,    0,    0,
    0,    0,    0,  164,    0,    0,  165,    0,  166,    0,
    0,    0,  167,  168,    0, 3014,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  169,    0, 3015,    0,  171,
  172,  173,  174,  175,    0,  176,    0,    0,    0,    0,
    0,  177,    0,  178,  179,    0,    0,  180,  181,    0,
    0,    0,    0,    0,  182,    0,    0,  183,  184,  185,
  186,    0,  187,    0,  188,    0,  189,  190,  191,  192,
  193,    0,    0,    0,    0,  194,    0,  195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  196,    0,
    0,    0,    0,  197,  198,    0,  199,    0,    0,    0,
  200,    0,  201,  202,  203,  204,    0,  205,    0,    0,
    0,    0,    0,    0,    0,  206,  207,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  208,  209,    0,  210,
  211,  212,    0,    0,    0,    0,  213,  214,    0,  215,
  216,    0,  217,    0,    0,  218,  219,    0,    0,    0,
  220,  221,    0,    0,    0,    0,  222,  223,  224,    0,
  225,  226,  227,    0,  228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,  249,    0,  250,  251,  252,  253,
  254,  255,    0,  256,  257,  258,  259,    0,  260,    0,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  278,    0,  279,
  280,  281,  282,    0,  283,  284,  285,  286,  287,    0,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,    0,  301,  302,  303,  304,  305,  306,
    0,  307,  308,  309,  310,  311,  312,  313,  314,    0,
  315,  316,  317,  318,    0,  319,  320,  321,  322,  323,
  324,    0,    0,  325,  326,  327,  328,  329,  330,  331,
  332,  333,    0,    0,    0,    0,    0,  334,    0,  335,
  336,  337,  338,  339,  340,  139,    0,  140,    0,    0,
    0, 3114,    0,  141,    0,    0,  142,  143,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  144,  145,    0,
  146,    0,  147,    0,    0,  148,    0,    0,  149,    0,
    0,    0,    0,    0,    0,  150,    0,  151,  152,    0,
    0,    0,  153,    0,  154,    0,    0,  155,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  156,  157,    0,
 3115,    0,  158,    0,  159,    0,  160,    0,    0,    0,
    0,    0,  161,    0,  162,    0,    0,    0,  163,    0,
    0,    0,    0,    0,    0,    0,  164,    0,    0,  165,
    0,  166,    0,    0,    0,  167,  168,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  169,    0,
    0,    0,  171,  172,  173,  174,  175,    0,  176,    0,
    0,    0,    0,    0,  177,    0,  178,  179,    0,    0,
  180,  181,    0,    0,    0,    0,    0,  182,    0,    0,
  183,  184,  185,  186,    0,  187,    0,  188,    0,  189,
  190,  191,  192,  193,    0,    0,    0,    0,  194,    0,
  195,    0,    0,    0, 3116,    0,    0,    0,    0,    0,
    0,  196,    0,    0,    0,    0,  197,  198,    0,  199,
    0,    0,    0,  200,    0,  201,  202,  203,  204,    0,
  205,    0,    0,    0,    0,    0,    0,    0,  206,  207,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  208,
  209,    0,  210,  211,  212,    0,    0,    0,    0,  213,
  214,    0,  215,  216,    0,  217,    0,    0,  218,  219,
    0,    0,    0,  220,  221,    0,    0,    0,    0,  222,
  223,  224,    0,  225,  226,  227,    0,  228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,  249,    0,  250,
  251,  252,  253,  254,  255,    0,  256,  257,  258,  259,
    0,  260,    0,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
  278,    0,  279,  280,  281,  282,    0,  283,  284,  285,
  286,  287,    0,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,  300,    0,  301,  302,  303,
  304,  305,  306,    0,  307,  308,  309,  310,  311,  312,
  313,  314,    0,  315,  316,  317,  318,    0,  319,  320,
  321,  322,  323,  324,    0,    0,  325,  326,  327,  328,
  329,  330,  331,  332,  333,    0,    0,    0,    0,    0,
  334,    0,  335,  336,  337,  338,  339,  340,  139,    0,
  140,    0,    0,    0,    0,    0,  141,    0,    0,  142,
  143,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  144,  145,    0,  146,    0,  147,    0,    0,  148,    0,
    0,  149,    0,  747,    0,    0,    0,    0,  150,    0,
  151,  152,    0,    0,    0,  153,    0,  154,    0,    0,
  155,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  156,  157,    0,    0,    0,  158,    0,  159,    0,  160,
    0,    0,    0,    0,    0,  161,    0,  162,    0,    0,
    0,  163,    0,    0,    0,    0,    0,    0,    0,  164,
    0,    0,  165,    0,  166,    0,    0,    0,  167,  168,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  169,    0,    0,    0,  171,  172,  173,  174,  175,
    0,  176,    0,    0,    0,    0,    0,  177,    0,  178,
  179,    0,    0,  180,  181,    0,    0,    0,    0,    0,
  182,    0,    0,  183,  184,  185,  186,    0,  187,    0,
  188,    0,  189,  190,  191,  192,  193,    0,    0,    0,
    0,  194,    0,  195,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  196,    0,    0,    0,    0,  197,
  198,    0,  199,    0,    0,    0,  200,    0,  201,  202,
  203,  204,    0,  205,    0,    0,    0,    0,    0,    0,
    0,  206,  207,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  208,  209,    0,  210,  211,  212,    0,    0,
    0,    0,  213,  214,    0,  215,  216,    0,  217,    0,
    0,  218,  219,    0,    0,    0,  220,  221,    0,    0,
    0,    0,  222,  223,  224,    0,  225,  226,  227,    0,
  228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
  249,    0,  250,  251,  252,  253,  254,  255,    0,  256,
  257,  258,  259,    0,  260,    0,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,  278,    0,  279,  280,  281,  282,    0,
  283,  284,  285,  286,  287,    0,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,  300,    0,
  301,  302,  303,  304,  305,  306,    0,  307,  308,  309,
  310,  311,  312,  313,  314,    0,  315,  316,  317,  318,
    0,  319,  320,  321,  322,  323,  324,    0,    0,  325,
  326,  327,  328,  329,  330,  331,  332,  333,    0,    0,
    0,    0,    0,  334,  861,  335,  336,  337,  338,  339,
  340,  139,    0,  140,    0,    0,    0,    0,    0,  141,
    0,    0,  142,  143,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  144,  145,    0,  146,    0,  147,    0,
    0,  148,    0,    0,  149,    0,    0,    0,    0,    0,
    0,  150,    0,  151,  152,    0,    0,    0,  153,    0,
  154,    0,    0,  155,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  156,  157,    0,    0,    0,  158,    0,
  159,    0,  160,    0,    0,    0,    0,    0,  161,    0,
  162,    0,    0,    0,  163,    0,    0,    0,    0,    0,
    0,    0,  164,    0,    0,  165,    0,  166,    0,    0,
    0,  167,  168,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  169,    0,    0,    0,  171,  172,
  173,  174,  175,    0,  176,    0,    0,    0,    0,    0,
  177,    0,  178,  179,    0,    0,  180,  181,    0,    0,
    0,    0,    0,  182,    0,    0,  183,  184,  185,  186,
    0,  187,    0,  188,    0,  189,  190,  191,  192,  193,
    0,    0,    0,    0,  194,    0,  195,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  196,    0,    0,
    0,    0,  197,  198,    0,  199,    0,  509,  510,  200,
    0,  201,  202,  203,  204,    0,  205,    0,    0,    0,
    0,    0,    0,    0,  206,  207,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  208,  209,    0,  210,  211,
  212,    0,    0,    0,    0,  213,  214,    0,  215,  216,
    0,  217,    0,    0,  218,  219,    0,    0,    0,  220,
  221,    0,    0,    0,    0,  222,  223,  224,    0,  225,
  226,  227,    0,  228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,  249,    0,  250,  251,  252,  253,  254,
  255,    0,  256,  257,  258,  259,    0,  260,    0,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,  278,    0,  279,  280,
  281,  282,    0,  283,  284,  285,  286,  287,    0,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,  300,    0,  301,  302,  303,  304,  305,  306,    0,
  307,  308,  309,  310,  311,  312,  313,  314,    0,  315,
  316,  317,  318,    0,  319,  320,  321,  322,  323,  324,
    0,    0,  325,  326,  327,  328,  329,  330,  331,  332,
  333,    0,    0,    0,    0,    0,  334,    0,  335,  336,
  337,  338,  339,  340,  139,    0,  140,    0,    0,    0,
    0,    0,  141,    0,    0,  142,  143,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  144,  145,    0,  146,
    0,  147,    0,    0,  148,    0,    0,  149,    0,    0,
    0,    0,    0,    0,  150,    0,  151,  152,    0,    0,
    0,  153,    0,  154,    0,    0,  155,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  156,  157,    0,    0,
    0,  158,    0,  159,    0,  160,    0,    0,    0,    0,
    0,  161, 1472,  162,    0,    0,    0,  163,    0,    0,
    0,    0,    0,    0,    0,  164,    0,    0,  165,    0,
  166,    0, 1473,    0,  167,  168,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  169,    0,    0,
    0,  171,  172,  173,  174,  175,    0,  176,    0,    0,
    0,    0,    0,  177,    0,  178,  179,    0,    0,  180,
  181,    0,    0,    0,    0,    0,  182,    0,    0,  183,
  184,  185,  186,    0,  187,    0, 2840,    0,  189,  190,
  191,  192,  193,    0,    0,    0,    0,  194,    0,  195,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  196,    0,    0,    0,    0,  197,  198,    0,  199,    0,
    0,    0,  200,    0,  201,  202,  203,  204,    0,  205,
    0,    0,    0,    0,    0,    0,    0,  206,  207,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  208,  209,
    0,  210,  211,  212,    0,    0,    0,    0,  213,  214,
    0,  215,  216,    0,  217,    0,    0,  218,  219,    0,
    0,    0,  220,  221,    0,    0,    0,    0,  222,  223,
  224,    0,  225,  226,  227,    0,  228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,  249,    0,  250,  251,
  252,  253,  254,  255,    0,  256,  257,  258,  259,    0,
 2841,    0,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  278,
    0,  279,  280,  281,  282,    0,  283,  284,  285,  286,
  287,    0,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,    0,  301,  302,  303,  304,
  305,  306,    0,  307,  308,  309,  310,  311,  312,  313,
  314,    0,  315,  316,  317,  318,    0,  319,  320,  321,
  322,  323,  324,    0,    0,  325,  326,  327,  328,  329,
  330,  331,  332,  333,    0,    0,    0,    0,    0,  334,
    0,  335,  336,  337,  338,  339,  340,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,    0,  142,  143,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,    0,    0,  148,    0,    0,
  149,    0,    0,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  156,
  157,    0, 3115,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,    0,    0,    0,    0,  164,    0,
    0,  165,    0,  166,    0,    0,    0,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,    0,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,    0,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
    0,  189,  190,  191,  192,  193,    0,    0,    0,    0,
  194,    0,  195,    0,    0,    0, 3116,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
    0,  199,    0,    0,    0,  200,    0,  201,  202,  203,
  204,    0,  205,    0,    0,    0,    0,    0,    0,    0,
  206,  207,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  208,  209,    0,  210,  211,  212,    0,    0,    0,
    0,  213,  214,    0,  215,  216,    0,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  223,  224,    0,  225,  226,  227,    0,  228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
    0,  250,  251,  252,  253,  254,  255,    0,  256,  257,
  258,  259,    0,  260,    0,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  278,    0,  279,  280,  281,  282,    0,  283,
  284,  285,  286,  287,    0,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,    0,  301,
  302,  303,  304,  305,  306,    0,  307,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  317,  318,    0,
  319,  320,  321,  322,  323,  324,    0,    0,  325,  326,
  327,  328,  329,  330,  331,  332,  333,    0,    0,    0,
    0,    0,  334,    0,  335,  336,  337,  338,  339,  340,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,    0,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0,    0,    0,    0,  161,    0,  162,
    0,    0,    0,  163,    0,    0,    0,    0,    0,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  169,  170,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179,    0,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186,    0,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196,    0,    0,    0,
    0,  197,  198,    0,  199,    0,    0,    0,  200,    0,
  201,  202,  203,  204,    0,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0,    0,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  308,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0,    0,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,  139,    0,  140,    0,    0,    0,    0,
    0,  141,    0,    0,  142,  143,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  144,  145,    0,  146,    0,
  147,    0,    0,  148,    0,    0,  149,    0,    0,    0,
    0,    0,    0,  150,    0,  151,  152,    0,    0,    0,
  153,    0,  154,    0,    0,  155,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  156,  157,    0,    0,    0,
  158,    0,  159,    0,  160,    0,    0,    0,    0,    0,
  161,    0,  162,    0,    0,    0,  163,    0,    0,    0,
    0,    0,    0,    0,  164,    0,    0,  165,    0,  166,
    0,    0,    0,  167,  168,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  169,    0,    0,    0,
  171,  172,  173,  174,  175,    0,  176,    0,    0,    0,
    0,    0,  177,    0,  178,  179,    0,    0,  180,  181,
    0,    0,    0,    0,    0,  182,    0,    0,  183,  184,
  185,  186,    0,  187,    0,  188,    0,  189,  190,  191,
  192,  193,    0,    0,    0,    0,  194,    0,  195,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  196,
    0,    0,    0,    0,  197,  198,    0,  199,    0,    0,
    0,  200,    0,  201,  202,  203,  204,    0,  205,    0,
    0,    0,    0,    0,    0,    0,  206,  207,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  208,  209,    0,
  210,  211,  212,    0,    0,    0,    0,  213,  214,    0,
  215,  216,    0,  217,    0,    0,  218,  219,    0,    0,
    0,  220,  221,    0,    0,    0,    0,  222,  223,  224,
    0,  225,  226,  227,    0,  228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  229,  230,  231,  232,  233,
  234,  235,  236,  237,  238,  239,  240,  241,  242,  243,
  244,  245,  246,  247,  248,  249,    0,  250,  251,  252,
  253,  254,  255,    0,  256,  257,  258,  259,    0,  260,
    0,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,  278,  346,
  279,  280,  281,  282,    0,  283,  284,  285,  286,  287,
    0,  288,  289,  290,  291,  292,  293,  294,  295,  296,
  297,  298,  299,  300,    0,  301,  302,  303,  304,  305,
  306,    0,  307,  308,  309,  310,  311,  312,  313,  314,
    0,  315,  316,  317,  318,    0,  319,  320,  321,  322,
  323,  324,    0,    0,  325,  326,  327,  328,  329,  330,
  331,  332,  333,    0,    0,    0,    0,    0,  334,    0,
  335,  336,  337,  338,  339,  340,  139,    0,  140,    0,
    0,    0,    0,    0,  141,    0,    0,  142,  143,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  144,  145,
    0,  146, 2199,  147,    0,    0,  148,    0,    0,  149,
    0,    0,    0,    0,    0,    0,  150,    0,  151,  152,
    0,    0,    0,  153,    0,  154,    0,    0,  155,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  156,  157,
    0,    0,    0,  158,    0,  159,    0,  160,    0,    0,
    0,    0,    0,  161,    0,  162,    0,    0,    0,  163,
    0,    0,    0,    0,    0,    0,    0,  164,    0,    0,
  165,    0,  166,    0,    0,    0,  167,  168,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  169,
    0,    0,    0,  171,  172,  173,  174,  175,    0,  176,
    0,    0,    0,    0,    0,  177,    0,  178,  179,    0,
    0,  180,  181,    0,    0,    0,    0,    0,  182,    0,
    0,  183,  184,  185,  186,    0,  187,    0,  188,    0,
  189,  190,  191,  192,  193,    0,    0,    0,    0,  194,
    0,  195,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  196,    0,    0,    0,    0,  197,  198,    0,
  199,    0,    0,    0,  200,    0,  201,  202,  203,  204,
    0,  205,    0,    0,    0,    0,    0,    0,    0,  206,
  207,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  208,  209,    0,  210,  211,  212,    0,    0,    0,    0,
  213,  214,    0,  215,  216,    0,  217,    0,    0,  218,
  219,    0,    0,    0,  220,  221,    0,    0,    0,    0,
  222,  223,  224,    0,  225,  226,  227,    0,  228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
  241,  242,  243,  244,  245,  246,  247,  248,  249,    0,
  250,  251,  252,  253,  254,  255,    0,  256,  257,  258,
  259,    0,  260,    0,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,  278,    0,  279,  280,  281,  282,    0,  283,  284,
  285,  286,  287,    0,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,  300,    0,  301,  302,
  303,  304,  305,  306,    0,  307,  308,  309,  310,  311,
  312,  313,  314,    0,  315,  316,  317,  318,    0,  319,
  320,  321,  322,  323,  324,    0,    0,  325,  326,  327,
  328,  329,  330,  331,  332,  333,    0,    0,    0,    0,
    0,  334,    0,  335,  336,  337,  338,  339,  340,  139,
    0,  140,    0,    0,    0,    0,    0,  141,    0,    0,
  142,  143,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  144,  145,    0,  146, 2493,  147,    0,    0,  148,
    0,    0,  149,    0,    0,    0,    0,    0,    0,  150,
    0,  151,  152,    0,    0,    0,  153,    0,  154,    0,
    0,  155,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  156,  157,    0,    0,    0,  158,    0,  159,    0,
  160,    0,    0,    0,    0,    0,  161,    0,  162,    0,
    0,    0,  163,    0,    0,    0,    0,    0,    0,    0,
  164,    0,    0,  165,    0,  166,    0,    0,    0,  167,
  168,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  169,    0,    0,    0,  171,  172,  173,  174,
  175,    0,  176,    0,    0,    0,    0,    0,  177,    0,
  178,  179,    0,    0,  180,  181,    0,    0,    0,    0,
    0,  182,    0,    0,  183,  184,  185,  186,    0,  187,
    0,  188,    0,  189,  190,  191,  192,  193,    0,    0,
    0,    0,  194,    0,  195,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  196,    0,    0,    0,    0,
  197,  198,    0,  199,    0,    0,    0,  200,    0,  201,
  202,  203,  204,    0,  205,    0,    0,    0,    0,    0,
    0,    0,  206,  207,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  208,  209,    0,  210,  211,  212,    0,
    0,    0,    0,  213,  214,    0,  215,  216,    0,  217,
    0,    0,  218,  219,    0,    0,    0,  220,  221,    0,
    0,    0,    0,  222,  223,  224,    0,  225,  226,  227,
    0,  228,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  229,  230,  231,  232,  233,  234,  235,  236,  237,
  238,  239,  240,  241,  242,  243,  244,  245,  246,  247,
  248,  249,    0,  250,  251,  252,  253,  254,  255,    0,
  256,  257,  258,  259,    0,  260,    0,  261,  262,  263,
  264,  265,  266,  267,  268,  269,  270,  271,  272,  273,
  274,  275,  276,  277,  278,    0,  279,  280,  281,  282,
    0,  283,  284,  285,  286,  287,    0,  288,  289,  290,
  291,  292,  293,  294,  295,  296,  297,  298,  299,  300,
    0,  301,  302,  303,  304,  305,  306,    0,  307,  308,
  309,  310,  311,  312,  313,  314,    0,  315,  316,  317,
  318,    0,  319,  320,  321,  322,  323,  324,    0,    0,
  325,  326,  327,  328,  329,  330,  331,  332,  333,    0,
    0,    0,    0,    0,  334,    0,  335,  336,  337,  338,
  339,  340,  139,    0,  140,    0,    0,    0,    0,    0,
  141,    0,    0,  142,  143,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  144,  145,    0,  146,    0,  147,
    0,    0,  148,    0,    0,  149,    0,    0,    0,    0,
    0,    0,  150,    0,  151,  152,    0,    0,    0,  153,
    0,  154,    0,    0,  155, 2580,    0,    0,    0,    0,
    0,    0,    0,    0,  156,  157,    0,    0,    0,  158,
    0,  159,    0,  160,    0,    0,    0,    0,    0,  161,
    0,  162,    0,    0,    0,  163,    0,    0,    0,    0,
    0,    0,    0,  164,    0,    0,  165,    0,  166,    0,
    0,    0,  167,  168,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  169,    0,    0,    0,  171,
  172,  173,  174,  175,    0,  176,    0,    0,    0,    0,
    0,  177,    0,  178,  179,    0,    0,  180,  181,    0,
    0,    0,    0,    0,  182,    0,    0,  183,  184,  185,
  186,    0,  187,    0,  188,    0,  189,  190,  191,  192,
  193,    0,    0,    0,    0,  194,    0,  195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  196,    0,
    0,    0,    0,  197,  198,    0,  199,    0,    0,    0,
  200,    0,  201,  202,  203,  204,    0,  205,    0,    0,
    0,    0,    0,    0,    0,  206,  207,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  208,  209,    0,  210,
  211,  212,    0,    0,    0,    0,  213,  214,    0,  215,
  216,    0,  217,    0,    0,  218,  219,    0,    0,    0,
  220,  221,    0,    0,    0,    0,  222,  223,  224,    0,
  225,  226,  227,    0,  228,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  229,  230,  231,  232,  233,  234,
  235,  236,  237,  238,  239,  240,  241,  242,  243,  244,
  245,  246,  247,  248,  249,    0,  250,  251,  252,  253,
  254,  255,    0,  256,  257,  258,  259,    0,  260,    0,
  261,  262,  263,  264,  265,  266,  267,  268,  269,  270,
  271,  272,  273,  274,  275,  276,  277,  278,    0,  279,
  280,  281,  282,    0,  283,  284,  285,  286,  287,    0,
  288,  289,  290,  291,  292,  293,  294,  295,  296,  297,
  298,  299,  300,    0,  301,  302,  303,  304,  305,  306,
    0,  307,  308,  309,  310,  311,  312,  313,  314,    0,
  315,  316,  317,  318,    0,  319,  320,  321,  322,  323,
  324,    0,    0,  325,  326,  327,  328,  329,  330,  331,
  332,  333,    0,    0,    0,    0,    0,  334,    0,  335,
  336,  337,  338,  339,  340,  139,    0,  140,    0,    0,
    0,    0,    0,  141,    0,    0,  142,  143,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  144,  145,    0,
  146,    0,  147,    0,    0,  148,    0,    0,  149,    0,
    0,    0,    0,    0,    0,  150,    0,  151,  152,    0,
    0,    0,  153,    0,  154,    0,    0,  155,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  156,  157,    0,
    0,    0,  158,    0,  159,    0,  160,    0,    0,    0,
    0,    0,  161,    0,  162,    0,    0,    0,  163,    0,
    0,    0,    0,    0,    0,    0,  164,    0,    0,  165,
    0,  166,    0,    0,    0,  167,  168,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  169,    0,
    0,    0,  171,  172,  173,  174,  175,    0,  176,    0,
    0,    0,    0,    0,  177,    0,  178,  179,    0,    0,
  180,  181,    0,    0,    0,    0,    0,  182,    0,    0,
  183,  184,  185,  186,    0,  187,    0,  188,    0,  189,
  190,  191,  192,  193,    0,    0,    0,    0,  194,    0,
  195,    0,    0,    0, 2679,    0,    0,    0,    0,    0,
    0,  196,    0,    0,    0,    0,  197,  198,    0,  199,
    0,    0,    0,  200,    0,  201,  202,  203,  204,    0,
  205,    0,    0,    0,    0,    0,    0,    0,  206,  207,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  208,
  209,    0,  210,  211,  212,    0,    0,    0,    0,  213,
  214,    0,  215,  216,    0,  217,    0,    0,  218,  219,
    0,    0,    0,  220,  221,    0,    0,    0,    0,  222,
  223,  224,    0,  225,  226,  227,    0,  228,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  229,  230,  231,
  232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
  242,  243,  244,  245,  246,  247,  248,  249,    0,  250,
  251,  252,  253,  254,  255,    0,  256,  257,  258,  259,
    0,  260,    0,  261,  262,  263,  264,  265,  266,  267,
  268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
  278,    0,  279,  280,  281,  282,    0,  283,  284,  285,
  286,  287,    0,  288,  289,  290,  291,  292,  293,  294,
  295,  296,  297,  298,  299,  300,    0,  301,  302,  303,
  304,  305,  306,    0,  307,  308,  309,  310,  311,  312,
  313,  314,    0,  315,  316,  317,  318,    0,  319,  320,
  321,  322,  323,  324,    0,    0,  325,  326,  327,  328,
  329,  330,  331,  332,  333,    0,    0,    0,    0,    0,
  334,    0,  335,  336,  337,  338,  339,  340,  139,    0,
  140,    0,    0,    0,    0,    0,  141,    0,    0,  142,
  143,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  144,  145,    0,  146,    0,  147,    0,    0,  148,    0,
    0,  149,    0,    0,    0,    0,    0,    0,  150,    0,
  151,  152,    0,    0,    0,  153,    0,  154,    0,    0,
  155,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  156,  157,    0,    0,    0,  158,    0,  159,    0,  160,
    0,    0,    0,    0,    0,  161,    0,  162,    0,    0,
    0,  163,    0,    0,    0,    0,    0,    0,    0,  164,
    0,    0,  165,    0,  166,    0,    0,    0,  167,  168,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  169,    0,    0,    0,  171,  172,  173,  174,  175,
    0,  176,    0,    0,    0,    0,    0,  177,    0,  178,
  179,    0,    0,  180,  181,    0,    0,    0,    0,    0,
  182,    0,    0,  183,  184,  185,  186,    0,  187,    0,
  188,    0,  189,  190,  191,  192,  193,    0,    0,    0,
    0,  194,    0,  195,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  196,    0,    0,    0,    0,  197,
  198,    0,  199,    0,    0,    0,  200,    0,  201,  202,
  203,  204, 2731,  205,    0,    0,    0,    0,    0,    0,
    0,  206,  207,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  208,  209,    0,  210,  211,  212,    0,    0,
    0,    0,  213,  214,    0,  215,  216,    0,  217,    0,
    0,  218,  219,    0,    0,    0,  220,  221,    0,    0,
    0,    0,  222,  223,  224,    0,  225,  226,  227,    0,
  228,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
  249,    0,  250,  251,  252,  253,  254,  255,    0,  256,
  257,  258,  259,    0,  260,    0,  261,  262,  263,  264,
  265,  266,  267,  268,  269,  270,  271,  272,  273,  274,
  275,  276,  277,  278,    0,  279,  280,  281,  282,    0,
  283,  284,  285,  286,  287,    0,  288,  289,  290,  291,
  292,  293,  294,  295,  296,  297,  298,  299,  300,    0,
  301,  302,  303,  304,  305,  306,    0,  307,  308,  309,
  310,  311,  312,  313,  314,    0,  315,  316,  317,  318,
    0,  319,  320,  321,  322,  323,  324,    0,    0,  325,
  326,  327,  328,  329,  330,  331,  332,  333,    0,    0,
    0,    0,    0,  334,    0,  335,  336,  337,  338,  339,
  340,  139,    0,  140,    0,    0,    0,    0,    0,  141,
    0,    0,  142,  143,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  144,  145,    0,  146,    0,  147,    0,
    0,  148,    0,    0,  149,    0,    0,    0,    0,    0,
    0,  150,    0,  151,  152,    0,    0,    0,  153,    0,
  154,    0,    0,  155,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  156,  157,    0,    0,    0,  158,    0,
  159,    0,  160,    0,    0,    0,    0,    0,  161,    0,
  162,    0,    0,    0,  163,    0,    0,    0,    0,    0,
    0,    0,  164,    0,    0,  165,    0,  166,    0,    0,
    0,  167,  168,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  169,    0,    0,    0,  171,  172,
  173,  174,  175,    0,  176,    0,    0,    0,    0,    0,
  177,    0,  178,  179,    0,    0,  180,  181,    0,    0,
    0,    0,    0,  182,    0,    0,  183,  184,  185,  186,
    0,  187,    0,  188,    0,  189,  190,  191,  192,  193,
    0,    0,    0,    0,  194,    0,  195,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  196,    0,    0,
    0,    0,  197,  198,    0,  199,    0,    0,    0,  200,
    0,  201,  202,  203,  204, 2847,  205,    0,    0,    0,
    0,    0,    0,    0,  206,  207,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  208,  209,    0,  210,  211,
  212,    0,    0,    0,    0,  213,  214,    0,  215,  216,
    0,  217,    0,    0,  218,  219,    0,    0,    0,  220,
  221,    0,    0,    0,    0,  222,  223,  224,    0,  225,
  226,  227,    0,  228,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  229,  230,  231,  232,  233,  234,  235,
  236,  237,  238,  239,  240,  241,  242,  243,  244,  245,
  246,  247,  248,  249,    0,  250,  251,  252,  253,  254,
  255,    0,  256,  257,  258,  259,    0,  260,    0,  261,
  262,  263,  264,  265,  266,  267,  268,  269,  270,  271,
  272,  273,  274,  275,  276,  277,  278,    0,  279,  280,
  281,  282,    0,  283,  284,  285,  286,  287,    0,  288,
  289,  290,  291,  292,  293,  294,  295,  296,  297,  298,
  299,  300,    0,  301,  302,  303,  304,  305,  306,    0,
  307,  308,  309,  310,  311,  312,  313,  314,    0,  315,
  316,  317,  318,    0,  319,  320,  321,  322,  323,  324,
    0,    0,  325,  326,  327,  328,  329,  330,  331,  332,
  333,    0,    0,    0,    0,    0,  334,    0,  335,  336,
  337,  338,  339,  340,  139,    0,  140,    0,    0,    0,
    0,    0,  141,    0,    0,  142,  143,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  144,  145,    0,  146,
    0,  147,    0,    0,  148,    0,    0,  149,    0,    0,
    0,    0,    0,    0,  150,    0,  151,  152, 3126,    0,
    0,  153,    0,  154,    0,    0,  155,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  156,  157,    0,    0,
    0,  158,    0,  159,    0,  160,    0,    0,    0,    0,
    0,  161,    0,  162,    0,    0,    0,  163,    0,    0,
    0,    0,    0,    0,    0,  164,    0,    0,  165,    0,
  166,    0,    0,    0,  167,  168,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  169,    0,    0,
    0,  171,  172,  173,  174,  175,    0,  176,    0,    0,
    0,    0,    0,  177,    0,  178,  179,    0,    0,  180,
  181,    0,    0,    0,    0,    0,  182,    0,    0,  183,
  184,  185,  186,    0,  187,    0,  188,    0,  189,  190,
  191,  192,  193,    0,    0,    0,    0,  194,    0,  195,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  196,    0,    0,    0,    0,  197,  198,    0,  199,    0,
    0,    0,  200,    0,  201,  202,  203,  204,    0,  205,
    0,    0,    0,    0,    0,    0,    0,  206,  207,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  208,  209,
    0,  210,  211,  212,    0,    0,    0,    0,  213,  214,
    0,  215,  216,    0,  217,    0,    0,  218,  219,    0,
    0,    0,  220,  221,    0,    0,    0,    0,  222,  223,
  224,    0,  225,  226,  227,    0,  228,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  229,  230,  231,  232,
  233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
  243,  244,  245,  246,  247,  248,  249,    0,  250,  251,
  252,  253,  254,  255,    0,  256,  257,  258,  259,    0,
  260,    0,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  272,  273,  274,  275,  276,  277,  278,
    0,  279,  280,  281,  282,    0,  283,  284,  285,  286,
  287,    0,  288,  289,  290,  291,  292,  293,  294,  295,
  296,  297,  298,  299,  300,    0,  301,  302,  303,  304,
  305,  306,    0,  307,  308,  309,  310,  311,  312,  313,
  314,    0,  315,  316,  317,  318,    0,  319,  320,  321,
  322,  323,  324,    0,    0,  325,  326,  327,  328,  329,
  330,  331,  332,  333,    0,    0,    0,    0,    0,  334,
    0,  335,  336,  337,  338,  339,  340,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,    0,  142,  143,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,    0,    0,  148,    0,    0,
  149,    0,    0,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  156,
  157,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,    0,    0,    0,    0,  164,    0,
    0,  165,    0,  166,    0,    0,    0,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,    0,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,    0,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
    0,  189,  190,  191,  192,  193,    0,    0,    0,    0,
  194,    0,  195,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
    0,  199,    0,    0,    0,  200,    0,  201,  202,  203,
  204,    0,  205,    0,    0,    0,    0,    0,    0,    0,
  206,  207,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  208,  209,    0,  210,  211,  212,    0,    0,    0,
    0,  213,  214,    0,  215,  216,    0,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  223,  224,    0,  225,  226,  227,    0,  228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  229,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
    0,  250,  251,  252,  253,  254,  255,    0,  256,  257,
  258,  259,    0,  260,    0,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  278,    0,  279,  280,  281,  282,    0,  283,
  284,  285,  286,  287,    0,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,    0,  301,
  302,  303,  304,  305,  306,    0,  307,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  317,  318,    0,
  319,  320,  321,  322,  323,  324,    0,    0,  325,  326,
  327,  328,  329,  330,  331,  332,  333,    0,    0,    0,
    0,    0,  334,    0,  335,  336,  337,  338,  339,  340,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,    0,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0,    0,    0,    0,  161,    0,  162,
    0,    0,    0,  163,    0,    0,    0,    0,    0,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  169,    0,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179,    0,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186,    0,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196,    0,    0,    0,
    0,  197,  198,    0,  199,    0,    0,    0,  200,    0,
  201,  202,  203,  204,    0,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0,    0,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  545,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0,    0,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,  139,    0,  140,    0,    0,    0,    0,
    0,  141,    0,    0,  142,  143,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  144,  145,    0,  146,    0,
  147,    0,    0,  148,    0,    0,  149,    0,    0,    0,
    0,    0,    0,  150,    0,  151,  152,    0,    0,    0,
  153,    0,  154,    0,    0,  155,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  156,  157,    0,    0,    0,
  158,    0,  159,    0,  160,    0,    0,    0,    0,    0,
  161,    0,  162,    0,    0,    0,  163,    0,    0,    0,
    0,    0,    0,    0,  164,    0,    0,  165,    0,  166,
    0,    0,    0,  167,  168,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  169,    0,    0,    0,
  171,  172,  173,  174,  175,    0,  176,    0,    0,    0,
    0,    0,  177,    0,  178,  179,    0,    0,  180,  181,
    0,    0,    0,    0,    0,  182,    0,    0,  183,  184,
  185,  186,    0,  187,    0,  188,    0,  189,  190,  191,
  192,  193,    0,    0,    0,    0,  194,    0,  195,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  196,
    0,    0,    0,    0,  197,  198,    0,  199,    0,    0,
    0,  200,    0,  201,  202,  203,  204,    0,  205,    0,
    0,    0,    0,    0,    0,    0,  206,  207,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  208,  209,    0,
  210,  211,  212,    0,    0,    0,    0,  213,  214,    0,
  215,  216,    0,  217,    0,    0,  218,  219,    0,    0,
    0,  220,  221,    0,    0,    0,    0,  222,  223,  224,
    0,  225,  226,  227,    0,  228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  229,  230,  231,  232,  233,
  234,  235,  236,  237,  238,  239,  240,  241,  242,  243,
  244,  245,  246,  247,  248,  249,    0,  250,  251,  252,
  253,  254,  255,    0,  256,  257,  258,  259,    0,  260,
    0,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,  278,    0,
  279,  280,  281,  282,    0,  283,  284,  285,  286,  287,
    0,  288,  289,  290,  291,  292,  293,  294,  295,  296,
  297,  298,  299,  300,    0,  301,  302,  303,  304,  305,
  306,    0,  307,  575,  309,  310,  311,  312,  313,  314,
    0,  315,  316,  317,  318,    0,  319,  320,  321,  322,
  323,  324,    0,    0,  325,  326,  327,  328,  329,  330,
  331,  332,  333,    0,    0,    0,    0,    0,  334,    0,
  335,  336,  337,  338,  339,  340,  139,    0,  140,    0,
    0,    0,    0,    0,  141,    0,    0,  142,  143,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  144,  145,
    0,  146,    0,  147,    0,    0,  148,    0,    0,  149,
    0,    0,    0,    0,    0,    0,  150,    0,  151,  152,
    0,    0,    0,  153,    0,  154,    0,    0,  155,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  156,  157,
    0,    0,    0,  158,    0,  159,    0,  160,    0,    0,
    0,    0,    0,  161,    0,  162,    0,    0,    0,  163,
    0,    0,    0,    0,    0,    0,    0,  164,    0,    0,
  165,    0,  166,    0,    0,    0,  167,  168,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  169,
    0,    0,    0,  171,  172,  173,  174,  175,    0,  176,
    0,    0,    0,    0,    0,  177,    0,  178,  179,    0,
    0,  180,  181,    0,    0,    0,    0,    0,  182,    0,
    0,  183,  184,  185,  186,    0,  187,    0,  188,    0,
  189,  190,  191,  192,  193,    0,    0,    0,    0,  194,
    0,  195,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  196,    0,    0,    0,    0,  197,  198,    0,
  199,    0,    0,    0,  200,    0,  201,  202,  203,  204,
    0,  205,    0,    0,    0,    0,    0,    0,    0,  206,
  207,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  208,  209,    0,  210,  211,  212,    0,    0,    0,    0,
  213,  214,    0,  215,  216,    0,  217,    0,    0,  218,
  219,    0,    0,    0,  220,  221,    0,    0,    0,    0,
  222,  223,  224,    0,  225,  226,  227,    0,  228,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  229,  230,
  231,  232,  233,  234,  235,  236,  237,  238,  239,  240,
  241,  242,  243,  244,  245,  246,  247,  248,  249,    0,
  250,  251,  252,  253,  254,  255,    0,  256,  257,  258,
  259,    0,  260,    0,  261,  262,  263,  264,  265,  266,
  267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
  277,  278,    0,  279,  280,  281,  282,    0,  283,  284,
  285,  286,  287,    0,  288,  289,  290,  291,  292,  293,
  294,  295,  296,  297,  298,  299,  300,    0,  301,  302,
  303,  304,  305,  306,    0,  307,  609,  309,  310,  311,
  312,  313,  314,    0,  315,  316,  317,  318,    0,  319,
  320,  321,  322,  323,  324,    0,    0,  325,  326,  327,
  328,  329,  330,  331,  332,  333,    0,    0,    0,    0,
    0,  334,    0,  335,  336,  337,  338,  339,  340, 1034,
    0, 1034,    0,    0,    0,    0,    0, 1034,    0,    0,
 1034, 1034,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1034, 1034,    0, 1034,    0, 1034,    0,    0, 1034,
    0,    0, 1034,    0,    0,    0,    0,    0,    0, 1034,
    0, 1034, 1034,    0,    0,    0, 1034,    0, 1034,    0,
    0, 1034,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1034, 1034,    0,    0,    0, 1034,    0, 1034,    0,
 1034,    0,    0,    0,    0,    0, 1034,    0, 1034,    0,
    0,    0, 1034,    0,    0,    0,    0,    0,    0,    0,
 1034,    0,    0, 1034,    0, 1034,    0,    0,    0, 1034,
 1034,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1034,    0,    0,    0, 1034, 1034, 1034, 1034,
 1034,    0, 1034,    0,    0,    0,    0,    0, 1034,    0,
 1034, 1034,    0,    0, 1034, 1034,    0,    0,    0,    0,
    0, 1034,    0,    0, 1034, 1034, 1034, 1034,    0, 1034,
    0, 1034,    0, 1034, 1034, 1034, 1034, 1034,    0,    0,
    0,    0, 1034,    0, 1034,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1034,    0,    0,    0,    0,
 1034, 1034,    0, 1034,    0,    0,    0, 1034,    0, 1034,
 1034, 1034, 1034,    0, 1034,    0,    0,    0,    0,    0,
    0,    0, 1034, 1034,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1034, 1034,    0, 1034, 1034, 1034,    0,
    0,    0,    0, 1034, 1034,    0, 1034, 1034,    0, 1034,
    0,    0, 1034, 1034,    0,    0,    0, 1034, 1034,    0,
    0,    0,    0, 1034, 1034, 1034,    0, 1034, 1034, 1034,
    0, 1034,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
 1034, 1034,    0, 1034, 1034, 1034, 1034, 1034, 1034,    0,
 1034, 1034, 1034, 1034,    0, 1034,    0, 1034, 1034, 1034,
 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
 1034, 1034, 1034, 1034, 1034,    0, 1034, 1034, 1034, 1034,
    0, 1034, 1034, 1034, 1034, 1034,    0, 1034, 1034, 1034,
 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,
    0, 1034, 1034, 1034, 1034, 1034, 1034,    0, 1034, 1034,
 1034, 1034, 1034, 1034, 1034, 1034,    0, 1034, 1034, 1034,
 1034,    0, 1034, 1034, 1034, 1034, 1034, 1034,    0,    0,
 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034, 1034,    0,
    0,    0,    0,    0, 1034,    0, 1034, 1034, 1034, 1034,
 1034, 1034, 1121,    0, 1121,    0,    0,    0,    0,    0,
 1121,    0,    0, 1121, 1121,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1121, 1121,    0, 1121,    0, 1121,
    0,    0, 1121,    0,    0, 1121,    0,    0,    0,    0,
    0,    0, 1121,    0, 1121, 1121,    0,    0,    0, 1121,
    0, 1121,    0,    0, 1121,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1121, 1121,    0,    0,    0, 1121,
    0, 1121,    0, 1121,    0,    0,    0,    0,    0, 1121,
    0, 1121,    0,    0,    0, 1121,    0,    0,    0,    0,
    0,    0,    0, 1121,    0,    0, 1121,    0, 1121,    0,
    0,    0, 1121, 1121,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1121,    0,    0,    0, 1121,
 1121, 1121, 1121, 1121,    0, 1121,    0,    0,    0,    0,
    0, 1121,    0, 1121, 1121,    0,    0, 1121, 1121,    0,
    0,    0,    0,    0, 1121,    0,    0, 1121, 1121, 1121,
 1121,    0, 1121,    0, 1121,    0, 1121, 1121, 1121, 1121,
 1121,    0,    0,    0,    0, 1121,    0, 1121,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1121,    0,
    0,    0,    0, 1121, 1121,    0, 1121,    0,    0,    0,
 1121,    0, 1121, 1121, 1121, 1121,    0, 1121,    0,    0,
    0,    0,    0,    0,    0, 1121, 1121,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1121, 1121,    0, 1121,
 1121, 1121,    0,    0,    0,    0, 1121, 1121,    0, 1121,
 1121,    0, 1121,    0,    0, 1121, 1121,    0,    0,    0,
 1121, 1121,    0,    0,    0,    0, 1121, 1121, 1121,    0,
 1121, 1121, 1121,    0, 1121,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1121, 1121, 1121, 1121, 1121, 1121,
 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121,
 1121, 1121, 1121, 1121, 1121,    0, 1121, 1121, 1121, 1121,
 1121, 1121,    0, 1121, 1121, 1121, 1121,    0, 1121,    0,
 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121,
 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121,    0, 1121,
 1121, 1121, 1121,    0, 1121, 1121, 1121, 1121, 1121,    0,
 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121,
 1121, 1121, 1121,    0, 1121, 1121, 1121, 1121, 1121, 1121,
    0, 1121, 1121, 1121, 1121, 1121, 1121, 1121, 1121,    0,
 1121, 1121, 1121, 1121,    0, 1121, 1121, 1121, 1121, 1121,
 1121,    0,    0, 1121, 1121, 1121, 1121, 1121, 1121, 1121,
 1121, 1121,    0,    0,    0,    0,    0, 1121,    0, 1121,
 1121, 1121, 1121, 1121, 1121, 1119,    0, 1119,    0,    0,
    0,    0,    0, 1119,    0,    0, 1119, 1119,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1119, 1119,    0,
 1119,    0, 1119,    0,    0, 1119,    0,    0, 1119,    0,
    0,    0,    0,    0,    0, 1119,    0, 1119, 1119,    0,
    0,    0, 1119,    0, 1119,    0,    0, 1119,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1119, 1119,    0,
    0,    0, 1119,    0, 1119,    0, 1119,    0,    0,    0,
    0,    0, 1119,    0, 1119,    0,    0,    0, 1119,    0,
    0,    0,    0,    0,    0,    0, 1119,    0,    0, 1119,
    0, 1119,    0,    0,    0, 1119, 1119,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1119,    0,
    0,    0, 1119, 1119, 1119, 1119, 1119,    0, 1119,    0,
    0,    0,    0,    0, 1119,    0, 1119, 1119,    0,    0,
 1119, 1119,    0,    0,    0,    0,    0, 1119,    0,    0,
 1119, 1119, 1119, 1119,    0, 1119,    0, 1119,    0, 1119,
 1119, 1119, 1119, 1119,    0,    0,    0,    0, 1119,    0,
 1119,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1119,    0,    0,    0,    0, 1119, 1119,    0, 1119,
    0,    0,    0, 1119,    0, 1119, 1119, 1119, 1119,    0,
 1119,    0,    0,    0,    0,    0,    0,    0, 1119, 1119,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1119,
 1119,    0, 1119, 1119, 1119,    0,    0,    0,    0, 1119,
 1119,    0, 1119, 1119,    0, 1119,    0,    0, 1119, 1119,
    0,    0,    0, 1119, 1119,    0,    0,    0,    0, 1119,
 1119, 1119,    0, 1119, 1119, 1119,    0, 1119,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1119, 1119, 1119,
 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119,
 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119,    0, 1119,
 1119, 1119, 1119, 1119, 1119,    0, 1119, 1119, 1119, 1119,
    0, 1119,    0, 1119, 1119, 1119, 1119, 1119, 1119, 1119,
 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119, 1119,
 1119,    0, 1119, 1119, 1119, 1119,    0, 1119, 1119, 1119,
 1119, 1119,    0, 1119, 1119, 1119, 1119, 1119, 1119, 1119,
 1119, 1119, 1119, 1119, 1119, 1119,    0, 1119, 1119, 1119,
 1119, 1119, 1119,    0, 1119, 1119, 1119, 1119, 1119, 1119,
 1119, 1119,    0, 1119, 1119, 1119, 1119,    0, 1119, 1119,
 1119, 1119, 1119, 1119,    0,    0, 1119, 1119, 1119, 1119,
 1119, 1119, 1119, 1119, 1119,    0,    0,    0,    0,    0,
 1119,    0, 1119, 1119, 1119, 1119, 1119, 1119,  514,    0,
  514,    0,    0,    0,    0,    0,  514,    0,    0,  514,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,    0,  514,    0,  514,    0,    0,  514,    0,
    0,  514,    0,    0,    0,    0,    0,    0,  514,    0,
  514,  514,    0,    0,    0,  514,    0,  514,    0,    0,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,    0,    0,    0,  514,    0,  514,    0,  514,
    0,    0,    0,    0,    0,  514,    0,  514,    0,    0,
    0,  514,    0,    0,    0,    0,    0,    0,    0,  514,
    0,    0,  514,    0,  514,    0,    0,    0,  514,  514,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  514,    0,    0,    0,  514,  514,  514,  514,  514,
    0,  514,    0,    0,    0,    0,    0,  514,    0,  514,
  514,    0,    0,  514,  514,    0,    0,    0,    0,    0,
  514,    0,    0,  514,  514,  514,  514,    0,  514,    0,
  514,    0,  514,  514,  514,  514,  514,    0,    0,    0,
    0,  514,    0,  514,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  514,    0,    0,    0,    0,  514,
  514,    0,  514,    0,    0,    0,  514,    0,  514,  514,
  514,  514,    0,  514,    0,    0,    0,    0,    0,    0,
    0,  514,  514,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  514,  514,    0,  514,  514,  514,    0,    0,
    0,    0,  514,  514,    0,  514,  514,    0,  514,    0,
    0,  514,  514,    0,    0,    0,  514,  514,    0,    0,
    0,    0,  514,  514,  514,    0,  514,  514,  514,    0,
  514,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,    0,  514,  514,  514,  514,  514,  514,    0,  514,
  514,  514,  514,    0,  514,    0,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
  514,  514,  514,  514,    0,  514,  514,  514,  514,    0,
  514,  514,  514,  514,  514,    0,  514,  514,  514,  514,
  514,  514,  514,  514,  514,  514,  514,  514,  514,    0,
  514,  514,  514,  514,  514,  514,    0,  514,  514,  514,
  514,  514,  514,  514,  514,    0,  514,  514,  514,  514,
    0,  514,  514,  514,  514,  514,  514,    0,    0,  514,
  514,  514,  514,  514,  514,  514,  514,  514,    0,    0,
    0,    0,    0,  514,    0,  514,  514,  514,  514,  514,
  514,  157,    0,  157,    0,    0,    0,    0,    0,  157,
    0,    0,  157,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,    0,  157,    0,  157,    0,
    0,  157,    0,    0,  157,    0,    0,    0,    0,    0,
    0,  157,    0,  157,  157,    0,    0,    0,  157,    0,
  157,    0,    0,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,    0,    0,    0,  157,    0,
  157,    0,  157,    0,    0,    0,    0,    0,  157,    0,
  157,    0,    0,    0,  157,    0,    0,    0,    0,    0,
    0,    0,  157,    0,    0,  157,    0,  157,    0,    0,
    0,  157,  157,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  157,    0,    0,    0,  157,  157,
  157,  157,  157,    0,  157,    0,    0,    0,    0,    0,
  157,    0,  157,  157,    0,    0,  157,  157,    0,    0,
    0,    0,    0,  157,    0,    0,  157,  157,  157,  157,
    0,  157,    0,  157,    0,  157,  157,  157,  157,  157,
    0,    0,    0,    0,  157,    0,  157,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  157,    0,    0,
    0,    0,  157,  157,    0,  157,    0,    0,    0,  157,
    0,  157,  157,  157,  157,    0,  157,    0,    0,    0,
    0,    0,    0,    0,  157,  157,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  157,  157,    0,  157,  157,
  157,    0,    0,    0,    0,  157,  157,    0,  157,  157,
    0,  157,    0,    0,  157,  157,    0,    0,    0,  157,
  157,    0,    0,    0,    0,  157,  157,  157,    0,  157,
  157,  157,    0,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,    0,  157,  157,  157,  157,  157,
  157,    0,  157,  157,  157,  157,    0,  157,    0,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,  157,  157,  157,  157,  157,    0,  157,  157,
  157,  157,    0,  157,  157,  157,  157,  157,    0,  157,
  157,  157,  157,  157,  157,  157,  157,  157,  157,  157,
  157,  157,    0,  157,  157,  157,  157,  157,  157,    0,
  157,  157,  157,  157,  157,  157,  157,  157,    0,  157,
  157,  157,  157,    0,  157,  157,  157,  157,  157,  157,
    0,    0,  157,  157,  157,  157,  157,  157,  157,  157,
  157,    0,    0,    0,    0,    0,  157,    0,  157,  157,
  157,  157,  157,  157,   60,    0,   60,    0,    0,    0,
    0,    0,   60,    0,    0,   60,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,    0,   60,
    0,   60,    0,    0,   60,    0,    0,   60,    0,    0,
    0,    0,    0,    0,   60,    0,   60,   60,    0,    0,
    0,   60,    0,   60,    0,    0,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,    0,    0,
    0,   60,    0,   60,    0,   60,    0,    0,    0,    0,
    0,   60,    0,   60,    0,    0,    0,   60,    0,    0,
    0,    0,    0,    0,    0,   60,    0,    0,   60,    0,
   60,    0,    0,    0,   60,   60,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   60,    0,    0,
    0,   60,   60,   60,   60,   60,    0,   60,    0,    0,
    0,    0,    0,   60,    0,   60,   60,    0,    0,   60,
   60,    0,    0,    0,    0,    0,   60,    0,    0,   60,
   60,   60,   60,    0,   60,    0,   60,    0,   60,   60,
   60,   60,   60,    0,    0,    0,    0,   60,    0,   60,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   60,    0,    0,    0,    0,   60,   60,    0,   60,    0,
    0,    0,   60,    0,   60,   60,   60,   60,    0,   60,
    0,    0,    0,    0,    0,    0,    0,   60,   60,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   60,   60,
    0,   60,   60,   60,    0,    0,    0,    0,   60,   60,
    0,   60,   60,    0,   60,    0,    0,   60,   60,    0,
    0,    0,   60,   60,    0,    0,    0,    0,   60,   60,
   60,    0,   60,   60,   60,    0,   60,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,    0,   60,   60,
   60,   60,   60,   60,    0,   60,   60,   60,   60,    0,
   60,    0,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
    0,   60,   60,   60,   60,    0,   60,   60,   60,   60,
   60,    0,   60,   60,   60,   60,   60,   60,   60,   60,
   60,   60,   60,   60,   60,    0,   60,   60,   60,   60,
   60,   60,    0,   60,   60,   60,   60,   60,   60,   60,
   60,    0,   60,   60,   60,   60,    0,   60,   60,   60,
   60,   60,   60,    0,    0,   60,   60,   60,   60,   60,
   60,   60,   60,   60,    0,    0,    0,    0,    0,   60,
    0,   60,   60,   60,   60,   60,   60,  139,    0,  140,
    0,    0,    0,    0,    0,  141,    0,    0,  142,  143,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  144,
  145,    0,  146,    0,  147,    0,    0,  148,    0,    0,
  149,    0,    0,    0,    0,    0,    0,  150,    0,  151,
  152,    0,    0,    0,  153,    0,  154,    0,    0,  155,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  156,
  157,    0,    0,    0,  158,    0,  159,    0,  160,    0,
    0,    0,    0,    0,  161,    0,  162,    0,    0,    0,
  163,    0,    0,    0,    0,    0,    0,    0,  164,    0,
    0,  165,    0,  166,    0,    0,    0,  167,  168,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  169,    0,    0,    0,  171,  172,  173,  174,  175,    0,
  176,    0,    0,    0,    0,    0,  177,    0,  178,  179,
    0,    0,  180,  181,    0,    0,    0,    0,    0,  182,
    0,    0,  183,  184,  185,  186,    0,  187,    0,  188,
    0,  189,  190,  191,  192,  193,    0,    0,    0,    0,
  194,    0,  195,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  196,    0,    0,    0,    0,  197,  198,
    0,  199,    0,    0,    0,  200,    0,  201,  202,  203,
  204,    0,  205,    0,    0,    0,    0,    0,    0,    0,
  206,  207,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  208,  209,    0,  210,  211,  212,    0,    0,    0,
    0,  213,  214,    0,  215,  216,    0,  217,    0,    0,
  218,  219,    0,    0,    0,  220,  221,    0,    0,    0,
    0,  222,  223,  224,    0,  225,  226,  227,    0,  228,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  230,  231,  232,  233,  234,  235,  236,  237,  238,  239,
  240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
    0,  250,  251,  252,  253,  254,  255,    0,  256,  257,
  258,  259,    0,  260,    0,  261,  262,  263,  264,  265,
  266,  267,  268,  269,  270,  271,  272,  273,  274,  275,
  276,  277,  278,    0,  279,  280,  281,  282,    0,  283,
  284,  285,  286,  287,    0,  288,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,    0,  301,
  302,  303,  304,  305,  306,    0,  307,  308,  309,  310,
  311,  312,  313,  314,    0,  315,  316,  317,  318,    0,
  319,  320,  321,  322,  323,  324,    0,    0,  325,  326,
  327,  328,  329,  330,  331,  332,  333,    0,    0,    0,
    0,    0,  334,    0,  335,  336,  337,  338,  339,  340,
  139,    0,  140,    0,    0,    0,    0,    0,  141,    0,
    0,  142,  143,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  144,  145,    0,  146,    0,  147,    0,    0,
  148,    0,    0,  149,    0,    0,    0,    0,    0,    0,
  150,    0,  151,  152,    0,    0,    0,  153,    0,  154,
    0,    0,  155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  156,  157,    0,    0,    0,  158,    0,  159,
    0,  160,    0,    0,    0,    0,    0,  161,    0,  162,
    0,    0,    0,  163,    0,    0,    0,    0,    0,    0,
    0,  164,    0,    0,  165,    0,  166,    0,    0,    0,
  167,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  169,    0,    0,    0,  171,  172,  173,
  174,  175,    0,  176,    0,    0,    0,    0,    0,  177,
    0,  178,  179,    0,    0,  180,  181,    0,    0,    0,
    0,    0,  182,    0,    0,  183,  184,  185,  186,    0,
  187,    0,  188,    0,  189,  190,  191,  192,  193,    0,
    0,    0,    0,  194,    0,  195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  196,    0,    0,    0,
    0,  197,  198,    0,  199,    0,    0,    0,  200,    0,
  201,  202,  203,  204,    0,  205,    0,    0,    0,    0,
    0,    0,    0,  206,  207,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  208,  209,    0,  210,  211,  212,
    0,    0,    0,    0,  213,  214,    0,  215,  216,    0,
  217,    0,    0,  218,  219,    0,    0,    0,  220,  221,
    0,    0,    0,    0,  222,  223,  224,    0,  225,  226,
  227,    0,  228,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  229,  230,  231,  232,  233,  234,  235,  236,
  237,  238,  239,  240,  241,  242,  243,  244,  245,  246,
  247,  248,  249,    0,  250,  251,  252,  253,  254,  255,
    0,  256,  257,  258,  259,    0,  260,    0,  261,  262,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  272,
  273,  274,  275,  276,  277,  278,    0,  279,  280,  281,
  282,    0,  283,  284,  285,  286,  287,    0,  288,  289,
  290,  291,  292,  293,  294,  295,    0,  297,  298,  299,
  300,    0,  301,  302,  303,  304,  305,  306,    0,  307,
  308,  309,  310,  311,  312,  313,  314,    0,  315,  316,
  317,  318,    0,  319,  320,  321,  322,  323,  324,    0,
    0,  325,  326,  327,  328,  329,  330,  331,  332,  333,
    0,    0,    0,    0,    0,  334,    0,  335,  336,  337,
  338,  339,  340,  139,    0,  140,    0,    0,    0,    0,
    0,  141,    0,    0,  142,  143,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  144,  145,    0,  146,    0,
  147,    0,    0,  148,    0,    0,  149,    0,    0,    0,
    0,    0,    0,  150,    0,  151,  152,    0,    0,    0,
  153,    0,  154,    0,    0,  155,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  156,  157,    0,    0,    0,
  158,    0,  159,    0,  160,    0,    0,    0,    0,    0,
  161,    0,  162,    0,    0,    0,  163,    0,    0,    0,
    0,    0,    0,    0,  164,    0,    0,  165,    0,  166,
    0,    0,    0,  167,  168,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  169,    0,    0,    0,
  171,  172,  173,  174,  175,    0,  176,    0,    0,    0,
    0,    0,  177,    0,  178,  179,    0,    0,  180,  181,
    0,    0,    0,    0,    0,  182,    0,    0,  183,  184,
  185,  186,    0,  187,    0,  188,    0,  189,  190,  191,
  192,  193,    0,    0,    0,    0,  194,    0,  195,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  196,
    0,    0,    0,    0,  197,  198,    0,  199,    0,    0,
    0,  200,    0,  201,  202,  203,  204,    0,  205,    0,
    0,    0,    0,    0,    0,    0,  206,  207,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  208,  209,    0,
  210,    0,  212,    0,    0,    0,    0,  213,  214,    0,
  215,    0,    0,  217,    0,    0,  218,  219,    0,    0,
    0,  220,  221,    0,    0,    0,    0,  222,  223,  224,
    0,    0,  226,  227,    0,  228,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  229,  230,  231,  232,  233,
  234,  235,  236,  237,  238,  239,  240,  241,  242,  243,
  244,  245,  246,  247,  248,  249,    0,  250,  251,  252,
  253,  254,  255,    0,  256,  257,  258,  259,    0,  260,
    0,  261,  262,  263,  264,  265,  266,  267,  268,  269,
  270,  271,  272,  273,  274,  275,  276,  277,  278,    0,
  279,  280,  281,  282,    0,  283,  284,  285,  286,  287,
    0,  288,  289,  290,  291,  292,  293,  294,  295,  296,
  297,  298,  299,  300,    0,  301,  302,  303,  304,  305,
  306,    0,  307,  308,  309,  310,  311,  312,  313,  314,
    0,  315,  316,  317,  318,    0,    0,    0,    0,  322,
  323,  324,    0,    0,  325,  326,  327,  328,  329,  330,
  331,  332,  333,    0,    0,    0,    0,    0,  334,    0,
  335,  336,  337,  338,  339,  340,
};
static int yycheck[] = {                                      14,
   15,   68,   17,    0,  593,  122,   64,  111,  640,  641,
 1336,   82,  114,  719,  649,   72,   71,  115,   74,  882,
  671,  882,   14,  995,   15,  127, 1032,  640,  641,  672,
  732,  694, 1375,  694,  694, 1375,   93, 1043, 1470,   95,
  482,  593,   82,  718, 1374,  953,  113, 1729,   63,   64,
  108,   66,   67,   68,   69,   70,   71,   72,   73,   74,
   75,  118,  117,   78,  120, 1015, 1045,   14,   83,   84,
   85,   86, 1763,   88,  657,   90,   91,  729,   93,   94,
   95,   96,   97, 1306, 1015,  100, 1717,   83, 1174,  104,
 1961,  106,  107,  108, 1180,  110,  111,  112,  113,  114,
 1461,  116,  117,  118,  119,  120,  121,  122, 2103,  692,
  125, 1805,  127,   67,  106,  130,  131, 1280, 1015,  134,
 1833,   75,  137,   70,  116, 1802, 2194,  679, 1231, 2061,
 1573, 2063, 1356, 1332, 2223, 2224, 1147, 1422, 2243,  131,
 1318, 1040, 2132,   90, 1463, 1323, 1422,   78, 1422,  880,
  881,  882, 1422, 1354, 1422, 1731,  697, 1125,  112,  106,
  967, 1592,  723, 1583, 1015, 1830, 1018,  121, 2129,  100,
 1385, 2379, 1396, 2297,  492,   88,  633,  634,  100, 1920,
  134,   99,    0,  130,  131,    0,    0, 1818,   85,  532,
   94, 1940, 2587,  364,  125,    0,  127,  543, 1097,    0,
 2795,    0, 1381, 1418,    0, 1264,  124,   42, 1406,   59,
 1425,    0, 1427, 1710,    0,   44,   44,    0,   44,    0,
   45,    0,    0, 1922,   44, 1310,   44,  573,   45,   45,
  260,  965,    0,   45,   44, 1466,   45,    0, 2389,    0,
 1404,   59,   40,    0,   59,   59,   58,  882,  295, 1403,
   44,   63, 2213,    0,   59,  260,  356, 2408,   59,   44,
   59, 2238,  264,   59,   44,   44,    0,    0, 1711,    0,
   59,   40,   44,   59,   44,  268,   59,  307,   59, 2487,
   59,   59, 1143,  278, 2677,   40,  363,   41,    0, 1239,
   44,   59, 1922,  280,   63,  364,   59,    0,   59, 1921,
 1163,  325,   59,   41,   41,   59,   59,   61,   41, 2377,
    0,   44,   59, 1921,    0,  273,   44,   44,  296, 1021,
    0,    0, 1754, 1755, 1756,   59,   59,   59,   59,   61,
 2833,  346,    0,   44, 1231, 2953,  351,  352,  353,  354,
  355,  356,  357,  358,  363,  360,  500,   59,  420,  364,
 1025,   41,   41,  296,   44,  346,   59,  262,    0,  284,
  375,  465,  264,  344,   41,  295,  387,   44,  276,   59,
 1233,  264,  574,   59, 2077,  275, 1051, 3341,  387,   59,
   59,   40, 2590,  372,  265,    0, 2934, 1295,    0,  363,
 1621,   59,  463,  260,  438,  316,  474, 1188, 1189, 1262,
 1263,  389, 1015,  398,   63,  364,  258,  496,  355,  261,
  340,  427, 1143,  314,  264,   41,  297,   59,   44, 1054,
 1763,  437, 2490, 1763,  263,  503,   41,  401,  263,  360,
 1516,  298,   44, 3397,  423,  264,  264,  337,  360,  262,
  433,  354,    0,  995,   59, 2550,  550,   59,  519,  301,
  465,  439, 2323,  357,  558,  352,  364,  258, 2140,  264,
  310,  480,  443,  444, 1663,  264,  387,  306,  540,  270,
 1573,  364, 1422,  447,    0,  547, 3094, 1060,  317,  291,
  501,  490,  425,   41, 2552,  264,   44,  412, 1219, 1352,
  448, 1422, 2885,  395,    0,    0,   40,  651, 3001,  295,
  301,   59,  303,  295, 1235,  290,  295,  526, 1143,  296,
  264, 1689, 1690,  418,  364,   41,   40, 1169, 2231, 1171,
 2233,  588, 1157,  277, 1255, 1256, 1257, 1258, 1259, 1164,
  545,    0, 1695,   59,  295,  550,  738, 3085,   44, 2497,
    0,  295,  619,  558,  340, 2535,  299,  259,  567, 2700,
 2701,  340,  264,   59,   59,  644,  310,  269,  627,  574,
  575,  264,  332,  295,  551, 2960,  496,  304,  625, 1303,
 1801,  410, 1658,  588,  368,   41, 2553,   59,  593,  340,
  595,   41,  597,  598, 1219, 2016,  314,  314,  299,  584,
   59,  593, 2291,  571,  609,  418,  273,  644,  310,   59,
  401,  560,  593,  703,  595, 1307,  597,  310, 1711,  419,
  625, 2031,  642, 1698,  545,  435,  442,  442,  633,  634,
  635,  636,    0,  647, 2121,  442,  442,  304,  440,  427,
  442,  443,  444,  442,  372,  368,  393,  642, 1588, 1314,
 1699,  699,  467,  714,  575, 1280,  393,  704,  434,  264,
  462,  463,  264,  434,  340,  467,  468,  437,  437,  726,
  394, 2291,  419,  394,  679,  437, 1298,  344, 2290, 1680,
  382,  434,  687,  442,  714,  430, 1573, 1312,  609,  382,
    0,   59, 2290,  372,  699,  700,  701,  702,  703,  704,
  705,  706,  372,  372,  709,  363,    0,  312, 2401,  264,
  496,  716,  381,    0,  719,  720,  264,  496,  723, 2833,
 2834,  726, 3107, 3108,  729,  357, 1305,  332,  395, 1580,
 1583,   41,  500,  738,  716, 1923, 2877, 2878, 2879, 2880,
 2881, 2882, 2883,  519,  627,  496,  519,   41,  264,   59,
 3335,  519, 1394, 2186,   41, 1536, 2189,  701, 2497, 1928,
  483,  519,  706, 1305,  312,   59,  519,  372, 1922,  551,
 1710,  596,   59, 1415,  593,  593,  381, 1921, 1114,  395,
  316,  448,  264,  720,  332,  443,  444,  627,  709, 1710,
 1123,  296,  264,  442,  571, 1460,  312,  709,  593,  702,
  708,  962, 1110,  483,  593,    0,    0,   44,  637, 1662,
 2790,  705, 1354,  700,  264, 2763,  332, 2875,  423,  610,
  611,  646,  480, 1710, 1711, 2773,   96, 1469, 2559,    0,
  500,  500,  437, 1375,   61,  437, 1409,  639,  640, 3037,
  648,  500,  333,  648,  648,  340,   41,   41,  304,  519,
  519,  387,  296,    0, 2805, 1397,  302,  949,  347, 1580,
  332,  306,  954,  507,   59,   59,  400,  264,  526, 1710,
 1712, 1592, 1319, 2193,  319, 1322,  372,  316,  883, 2534,
 2069,  340,  332,  627,  307,  381,  400, 3001,   59,  437,
 2532, 1442,  332,  427,  499,  500,  368,   41,   91, 1696,
   44,    0,  883,  437, 2314,  301, 1864, 1438,  380,  567,
  257,   59,   59,  427,  519,   59,  319,   61, 3092, 2012,
  425,  437,  279,  437,  301, 2078,  335,  988, 3069, 3070,
 3071, 3072, 3073, 3074, 3075, 2126,  484, 2558,  434,  435,
  584, 2250,  257, 2509,  949, 2366,  355,  321,  387,  954,
 2571,  499,  500,  312,  264, 1580,  348,  962, 1583,   59,
   59,  966, 1753, 1395,  519,  437, 1757, 1856, 1029,   41,
  264,  519,   44,  306,  979, 1036, 1037,  264,  450,  326,
  280,  425,   42,  499,  500,  474,  319,  437,  434,   61,
  995,  650,  483, 2854,  282,  363,  302,  303,  395, 1029,
  409,  301,  312,  519,  500,  401, 1036, 1037, 2988,  264,
  413,  326,  322,  323,  437,    0, 3190,  420,  312, 1451,
  412, 1686,  332,  519,  401,  312, 1007,  271, 3086,  966,
 1035, 2236, 2033,  954, 2239, 2249, 2241,  519,  332, 1100,
  284, 2474,  979,    0,  259,  332,  651,  450, 3143,  332,
  296,    0,    0,  290,  269,  310,    0, 2738, 1119, 1120,
  298,  506,  372,    0,    0,  422,   59, 2748,  295,  264,
  264,  381,  446,  264,   59,  443,  444,  436,  372,  615,
 1733,  325,  275,  353,   41, 2757,   59,  258,  358, 1119,
 1120, 2167,   41, 2186,  475,   44, 2189,   41,    0,  270,
   44,  401,   59,  651,  485,   41,  344, 1710,  352, 3322,
   59,   59,  480,  423, 1967,   59,  264,  389,  312,  310,
  264, 3396,   59,   59,  505, 2012,  364,  437,  434,  423,
  301,  296,  303,  277, 3308,  651,  298,  332,  332,   41,
   59, 3354, 2784,  437,  553, 2787, 1151, 1254,  312,   93,
  437,  295,  452, 1158, 1850,  443,  444,   59,  526, 3020,
    0, 3436,  310,  316,  264,  330,  310,  439,  412, 2067,
    0, 1265,  330,  506,  488, 1816,  615,  276,  277,  425,
 1759, 1803,  344, 2036, 1817, 3264, 2461, 2462, 1280,  499,
  500, 1833,  316, 1858,    0, 2461, 2462, 2461, 2462,  567,
  260, 2461, 2462, 2461, 2462,  499,  500,  507,  368,  519,
  310,  301,  499,  500, 1158, 2211,  363, 1759, 2407,   59,
  364, 1763, 3280,  295, 3282,  519, 1231, 1868,  268,   59,
  401, 2582,  519,   59,  387,   41,  400, 1870,  298,  620,
  621,  622,    0,  437,    0, 1937,  649,  395,  260, 1254,
 1231,  551, 1917,   59, 2938,  260, 1829, 1318,   59, 1264,
 1265, 2257, 1323,  387, 2945,  364, 2434,  425,    0,  316,
 2937,  264,  436,  258, 1279, 1280,  429, 1371, 1264,    0,
 1372,  302,  303,   41, 2437,   41,  298, 1940, 3149, 1940,
 1940,  264,  382,  298, 3207, 2016,  443,  444,  296, 2186,
 1305,   59, 2189,   59, 1309, 1310,  299,  264, 1369,    0,
  258,  401,  295,  353, 1319,  264,  301, 1322,    0,  264,
  257,  295,  270, 1309, 1305,  519,   59,   59,  264,  419,
  393,  312,  330,  480,  426, 2655, 1341,  310,   59, 1369,
  387,  651, 1430, 1431, 1432,  264,   42,  389,    0, 1354,
  273,   47,    0,  301,  598,  303,  419,  651,  450, 1280,
    0,  344,  264,  312,  651,  407, 1371, 1372,   59, 1374,
 1375,  303,  340, 1354,  260,  332,  312,   59, 2454,  526,
  312, 2474,  400,  332,  321,  265,  322,  323, 1374,  326,
  364,  310, 1397,   41, 1375, 3317,  332, 3100, 1403, 1404,
  257,  639,  640,  641,  276, 2738, 2031,   59, 2738, 2485,
  312,   59,  298,  434, 3095, 2748,  401,  297, 2748,   59,
  567,  344,   59,  368,  264, 3106,  261,  425,  372,  295,
  332, 2751, 3417, 2125,  419,  380,  372, 1442,  264,  610,
  611,  313,  283,  380,   44,  381,  276,  277,  260,  329,
  394,  286,    0,  401,  295,  312,    0, 3442,  264,  396,
 1465, 2314,  401, 2314, 1469, 1470,  301,  452,  400,  326,
  310,    0, 3385, 2824,    0,  443,  444,  639,  640,  641,
  437,  279,  316,  627,  310,  259,  298,  423,  437, 2458,
 2459,  260,  437,   93,   59,  269,  264,   41, 3411,  435,
   44,  437,  264, 3124,  436,  450,  264, 2720,  264, 3431,
 3191,   59,  426,  385, 2136,   59, 1521, 3430, 2371, 3200,
 2418, 2461, 2462,  364,  276,  315,  332, 2949, 1465,  298,
   59,  264, 3445,   59,  364,  437,  264,  327,  587,  277,
 2461, 2462,  310,  281,  276,  277,  483,  596,  310,    0,
  499,  500,  424,  258,  312,   44,  312,   42,   43,  349,
   45,  313,   47,  499,  500,  270,   41, 1572, 1573,   44,
  519,  369, 1664,  264,  332,  257,  332, 1521,  259,    0,
  475,  277,  310,  519, 2126,  281, 1572, 2474,  269, 2231,
    0, 2233, 1573, 2314,  368,    0,  301,  499,  303,  332,
  368,  596, 2267, 1695,   93,  257,  315,  397,   59, 1716,
  505, 2687, 2945,  334,  382, 2945,  264,  519,  327,  310,
   41,    0,  393,   44,  422, 2587,    0,  264, 1689, 1690,
 2252,  437,  364,  385,   44,  368,   41,  303,   59,  321,
  349,  439,  363, 2719,  326, 2366,  312,  380, 2221,   59,
    0,  360,  261,  442,   59,  592,   44,  594,  595, 1664,
 2656,  442,  610,  611,  312,   44,    0,   41,  389,  321,
   44,  392,  424,    0,  326,  323,    0,  368,  467,  437,
   59,  437,  475,  264,  332,   59,  407,  368,  397, 2314,
 1695,  382,  485, 1698, 1699,  332,  401, 1745,  380,  264,
    0,    0,  651,  316,  437,   93, 1711,  264,  645,   59,
    0, 1716,  433, 1699,  396,  651, 1697,  450, 3390,   93,
  264,    0, 1727,  316,  372,   59,    0, 1732,  380,  310,
 1711,  368,   59,  381,  400,   59,  596, 1742,  264, 2380,
 1745, 2433,   41,  380,  396,   44, 1732,  258, 1753, 1754,
 1755, 1756, 1757,  310, 1759, 2451, 1742,  554, 1763,   59,
   59,  519, 3095,  519, 1852, 3095,  487,  332,  312,   59,
  436,    0,  264, 3106, 1695,  423, 3106,  261, 1759,  323,
   59,  578, 1763,  264,  310,   59,  507, 2429,  332,  437,
  301,    0,  277,  296, 1799,  504,  281, 1802,  329,  520,
  437,  483,  286,  368, 1809,  334, 1811,    0,  106,    0,
    0,  368,  475,  450,  450,  380, 1802,  301,  310, 2815,
  330, 2817,  485, 1809, 2256, 1811, 2258,  330,  372,  310,
   59,  483, 3152,  131,  363,    0,    0,  381,   60,   61,
   62,    0,  368,  264, 2497, 1850, 2497, 2497,  401,   59,
   59,  499,  500, 3275,   40, 2287,  382, 2510, 3191,  264,
  389, 3191,    0,  392, 1869,    0,   59, 3200,   59,   59,
 3200,  519,  437,   60,   61,   62,  368,   41,  407,  423,
   44,  264, 2735,   44,   46,  450,    0, 1869,  391,   44,
  401,  312, 3208,  437,   59,   59,   58,  400,    0,   61,
   59,  322,  323,    0,  433,  610,  611,  312,  419,    0,
  592,  332,  594,  595,  335, 2537, 1921, 1922,  323,  475,
  280,   59,  425,  260,   59, 2566,  587,  332, 2569,  485,
    0,    0,   93,  437, 2567, 1940,    0, 2570,    0,  425,
  592,  452,  594,  595, 2052,   59,    0,  315, 2910,  505,
 2044,  372,    0, 2045, 1940,  499,  500,   59,  487,  327,
  381,  298,   59,  645,  264,    0,  427,  372,   59,   59,
  315,  401,  554,  388, 2082,  519,  381,  447,  507,  449,
 2088,  349,  327,  507,   59, 2077, 2078,  276,  403,   59,
   59,  520,  360,  645,  283,   59,  578,   59,  372, 2047,
  368,   40,  423,  651,  349,   59,   41, 2012, 2013,   44,
  310,   59,    0,  264,  435,  360,  437, 1011,  423, 1013,
  394,  407,  382,  368,   59,  443,  590, 2013,  440,  397,
  442, 2012,  437,  264, 2039,  264,  600,  601, 2043, 2044,
 2045, 2046, 2047, 2048, 2049, 2587, 2153,    0,   41,  271,
    0,   44,  397, 2039,  264,  467,  468,   41,   59,  419,
   44, 2043,  284, 2068,  620,  621,  622,  584,  368, 2130,
 2131,   59, 2077, 2078, 2927, 2080,    0,   41,  499,  500,
   44,  310,  382,  261,  271,  263, 3369,  261, 3371,  263,
   41, 2942,  452,   44,  499,  500,  318,  284,  519, 2080,
 2130, 2131,  310,  325, 2048, 2049,   59,  651,  286,   59,
    0,  333,  286,   41,  519,  483,   44,   41,  296,  435,
   44, 2126,  332,  301,  312, 2046,    0,  301,  350,   41,
  352,  318,   44,  310,  311,   59,  504,   61,  325,  368,
  362,  417,  364,  365,  366, 2126,  333,  507, 2153,  443,
  444,  483,  330,  382, 2819,  328, 2077, 2078,  368,  504,
  612,  613,  329,  350, 2225,  352, 2227, 2228,   46,   59,
  380, 2278,  483,   41,  264,  362,   44,    0,  365,  366,
 2227, 2186,  488,   41, 2189,   59,   44,  419, 2193,  264,
  412,  551, 2197,  276, 2199, 2225, 2738, 2227, 2228,   58,
 2187,  332,   61,  264,   46, 2186, 2748, 2193, 2189,  264,
 2271, 2197, 2273, 2274, 2275, 2907,   58,   59,  276,   61,
    0, 2942, 2227, 2228,  369,  412,  401,  437, 2233,  264,
  651,   41,   41,  417,   44,   44,   59, 2298,   46,  316,
  450, 2271,  332, 2273, 2274, 2275,  651,  425,  333,  310,
   58,   59,  367,   61, 3330,    0,   41,  332,  379,   44,
   40,   41,  379,  264,   44,  334,  376,  377, 2298, 2872,
  334,    0, 3268, 2278,  443,  444,  264,  312,  368,   59,
   41,  364,  487,   44, 3360, 2290, 2291,  322,  323,   41,
  380,  273,   44,  368,  363,   41,   41,  332,   44,   44,
  335,   41,  385,  519,   44,  380,  364,  368,  391, 2401,
  371,  264,   41,   40,   59,   44, 2410, 2942,  304, 2411,
  389,  382,  310,  392,    0,  389,    0,  385,  392,  401,
   59,  332,   61,  391,  258,  294,   41,  372,  407,   44,
  264,  424, 3338,  407,  264, 2437,  381,  437,  475,  476,
  437,  275,  276,  277,  264,   41,  280,  310,   44,  283,
  450,  648,  437,  268,  433, 2413,  424,  368, 2910,  433,
  270,  295,  437, 2434,  282,  450,  598,  301,   41,  380,
  368,   44,  596,   59,  334,   59,  310,   41,  423,   41,
   44,  264,   44, 2398,  382, 2400, 2401, 2461, 2462,  340,
  435,    0,  437, 2945, 2409, 2410, 2411, 2412, 2413, 2414,
 2415,  598,  381,  363,   41,  368, 2504,   44,  487, 2400,
  646,  295,   46,  487, 3120,   41,    0, 2409,   44,  382,
   41,  340, 2437,   44,   58,   59,  437,   61,  507,  389,
  364,  264,  392,  507,  334,   41, 2451,   40,   44,  450,
 2538,  520,   41, 2054, 2055,   44,  520,  407, 3100, 2464,
   59,  385, 2151, 2152,  499,  500,  340,  391,   40, 2474,
 2414, 2415,   40,  363,  348,  399,  443,  401, 2464, 2540,
 2401,   40,   40,  433,  519,   59,   41,  310, 2493,   44,
  414, 2412, 2497, 2474,   40,  419,  276,  277,   40,  389,
  424, 2506,  392,  283,  378, 2510,  380,   40,  443,   41,
 2540, 2497,   44,   40,   40,  295, 2437,  407,  443,   40,
 2506,   46,   41, 2528, 2510,   44, 2531,  401,  452,  258,
   40,  276,  277,   58,   59,  264,   61,  487,  283,   41,
   40,   40,   44,  433, 3185,  368,  275,  276,  277,   40,
  295,  280,  426, 3095,  283,   41,  347,  507,   44,  382,
 2565,   40,   46,   40, 3106,   41,  295,   40,   44,    0,
  520,   40,  301,   40,   58,   59,  450,   61,   40, 2565,
 2666,  310, 2587,   40,  364,   41,   42,   43,  264,   45,
  264,   47, 2597, 2598, 3447,   46,   40,  487, 3451, 2913,
 2914, 2915, 2916, 2917, 2918,  385,   40,   58,   59, 3301,
   61,  391, 2598,  348,   40, 2597,  651,  507, 2665,  364,
   41,    0,  496,   44,   40,  394,   41,  551,   59,   44,
  520,   40, 2679,   40,  310,  364,  310,   91,   41,   41,
  385,   44,   44,  378,  424,  380,  391,   40, 2653, 3191,
 2655,   41,   41,   40,   44,   44,  385,   40, 3200,  258,
 2665,   46,  391,   40,   45, 3306,  401, 2653,   40, 2655,
  399,  270,  401,   41, 2679,  306,   44,   58,   40,  424,
   59, 3303,   63, 3305,   40,  316, 2691,  315,  319,   40,
  419,  426,  368,   40,  368,  424,  295, 1656,   40,  327,
 1659,   40,  301,  627,  303, 2710,  382,  335,  382,   40,
 2691, 2716,   40,  261,    0,  450,   40,   40,   40, 2724,
   40,  349,   40,  452,   40,   40, 2731,   40, 2710,   40,
  264,   40,  360, 2738,   40,   40,   44,  614,  286,  261,
   40,  340,   40, 2748,    0, 2731, 2751, 2835,  296,  348,
   46,   40,    0,  301,  368,   41,  387, 2738,   44,   61,
  334, 2822,  370,  370,  286, 2751,   46, 2748,   40,  397,
  333,  551,   46,   59,  296,  499,  310,  333, 2839,  301,
 2785,   40,  330,  295,   40,   41,  417,  357,   44,  363,
  421,   40, 2822, 2887,  382,  270,  257, 2889,  437,  273,
  446,  432,  401,   59,   40,   61,  551,  430,  330, 2839,
  430,   59, 1153,  412, 1155,  389,   40, 3396,  392, 1160,
 1161,  277,  551,  384, 1165,  281,  341,  258,   40,  295,
   91,   40,   40,  407,  368,   91,   40,  371,  270,  270,
 2845, 2888, 2847,  391, 2891, 2890,  374, 2893,  382,    0,
 1191,  368,  400, 2702, 3396,  442,  367, 3436,  372,  433,
  321, 2847,  312, 2845,  295,  326,   41,   41,   41,  391,
  301,   41,  303,   40,   46,  506,  504,  425,  400,  258,
  437,  419, 2887, 2888, 2889, 2890, 2891, 2892, 2893, 2894,
   40,  270,  386,  290, 3436, 2900,  368,  496,  627, 2904,
  368,   40,   46,  425,  368, 2910,  260,  312,   59,  340,
  291,  312,   44,  487,  333, 3003,  295,  348, 2979,  380,
  333,  552,  301,  314,  303, 2658, 2659, 2660, 2661, 2662,
 2663,   44, 2937,  507, 2995,  396,   46,   44,  509,  437,
 2945, 3002,  496,  495, 2949,  495,  520,  612,   41, 2979,
  395, 2937,   44, 2940, 3040, 3041, 3042, 3043, 3044, 3045,
 3046,  340,  596,  371, 2945, 2995,  437,  371,  303,  348,
  401, 2976, 3002, 2894,  483,  371,  401,   40,  437,  348,
  609,  412,   40,  371,  615,   40,   46,  500, 2993,  355,
  276,  277,   41,   41,   44,   41,  730,  283,   41,   41,
  314, 3048,  258,   41,  418,   44, 3011,   44,  264,  295,
   44,  610,  611,  314,  333,  262,   40,  273,  616,  275,
  276,  277,  401,  757,  280,  419,  277,  283,   41, 3011,
   40,  395,   44,  412,  401,  417,   44, 2886,   44,  295,
   41,  419,   41, 3048,  419,  301,  780,  295,  304, 2898,
 3098,  335,  373,  335,  310,  290,  314, 3118,  368,  440,
   41,  442,  443,  444,  368,  496,  484,  340,  275,  368,
 2919, 2920,  435, 3078,  340, 3080,  340,  277,  364,  419,
   59,  462,  463, 3088,   40,  590,  467,  468,  344, 3146,
 3095,   59,  340, 3098, 3099,  332, 3078,  303, 3080,  385,
  348, 3106, 3088,  332,   58,  391,  442,  451,  364, 3114,
  276,   59,  419, 3118, 3095, 3120,   59,  496,   41,  500,
  414, 3126,   58,   41,   41, 3106,   41,   61,  314,  385,
  378,  592,  380,  594,  595,  391,  401,  490,  424,  395,
  303, 3146, 3147,  395,  295,  401,  304, 3152,  645,  607,
   40,  303,  607,  401,   41,  418,   41,  419,  314, 3220,
  262, 3147,  273,  419,   40,  334, 3152,  264,  424,  263,
  335,    0, 3233,  263,  314,  351, 3283,  314,  426,  610,
  611,  524,  523,  417,  521,  333, 3191,   44,  483,  340,
 3220,  322,  448,    0,  363, 3200,  452,  348,  369,  401,
   40,    0,  450, 3233,  276,  275,  344,  367,  344,  619,
 3191,  289,   41, 3218,  332,   44,  434,  420,   40, 3200,
  389,   41,  371,  392,  371,  371,  371,  378,  371,  380,
   59,  610,  611,  358,   41,  399,  371,   44,  407,   46,
  370,   40,   41,   41,   40,   44,   59,  446,  496,  446,
  401,   59,   59,   44,   61,  367,  303,   41,  639,  640,
   59, 3318,   41,   41,  433,  999,  434,   41, 1002,  650,
 3275, 3276,   41, 1007,  431,  426, 1010,  419, 3283,  522,
 1014,  646,  273,  411, 1018,  419,  419,  323,    0,  369,
  419, 3296,  419,  419, 3276,  551,  419,  312,   40,  450,
 3357,  336,   41,  427, 3153, 3154, 3155, 3156, 3157, 3158,
 3159,  344,  299, 3318,  299,  273,   40,  295,  487, 3168,
 3169, 3170, 3171, 3172, 3173, 3174,  425,  528,  490,   41,
  330,  296,   44,  364,  364,  330, 3341,  425,  507,  296,
  314,  325,   41,  646,   41,  496,  405,   59,   41,  450,
  450,  520, 3357,   40,   40,   40,   61,   41,   40,  357,
  446,   60,   61,   62,  314,   44,  431,  314,  314,  314,
  314,  627,  314,  314,  314,  454,  455,  456,  457,  458,
  459,  460,  461,   40,  395,   41,   40, 3392,  314,  418,
   41, 3396, 3397,  344,  627,  344,  280,   41,   42,   43,
   44,   45,  264,   47,  275, 3410,  368,  340,   40, 1143,
  442,  304,  303,  418,   63, 3396,   60,   61,   62,  321,
 1154,  273,   44,  312,   44, 1159,  299,  434, 3410, 1163,
   46, 3436,  370,  336,  273,  264,  336,  401,  344, 1173,
 1174,   41,  278,   41, 1178, 1179, 1180,   91, 1182, 1183,
 1184, 1185, 1186, 1187, 1188, 3436, 1190,  264, 1192,   46,
 1194, 1195, 1196, 1197, 1198,  264,  418, 1201, 1202, 1203,
 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213,
 1214, 1215, 1216,  312,  563,   41,  315,  370,  264,  299,
  302,  264,  299,  322,  323,  483,    0,   61,  327,   41,
 1234,  295,  357,  332,  443,   40,  335, 1241,  560,   40,
  589,  391, 1246,  312,  289,  264,  315,  509, 1252, 1253,
  349,  582,  567,  322,  323,  500, 1260,  500,  327,  448,
  266,  360,  264,  332,  561,  306,  335,   41,  376,  368,
   44,  329,  329,  372,  628,  316,  310,  426,  319,   40,
  349,   40,  381,  283,  420,   59,  386,  420,  330,  368,
  418,  360,  603,  262,  276,  277,  401,  368,  397,  368,
   41,  283,  271,  372, 1308,  368,  418,  605,  296,  425,
  336,   44,  381,  295,  330,  284,  401,   40,   40,  418,
  427,  445,    0,  427,  423,  400,  329,  400,  397,  264,
  264,   40,  264,    0,  270,  434,  435,  333,  437,  270,
  400,  400,  395,  303,   40,  314,  387,   41,  262,  318,
  434,  335,  314,  340,  423,  303,  325,  271,  303,   40,
  264,   41,  290,  277,  333,  335,  435,  281,  437,  368,
  284,  289,   59,   40,   41,  442,   41,   44,  303,   41,
  421,  350,  364,  352,  483,  426,  483,   59,   59,   59,
   59,  432,   59,  362,   61,  364,  365,  366,   59,   41,
  499,  500,  371,  385,  318,  504,  303,   41,  275,  391,
  395,  325,    0,   61,  483,   59,   59,   40,  314,  333,
  519,  303,   41,  614,   91,   41,  418,  314,  264,  314,
  499,  500,  264,  300,  299,  504,  350,  442,  352,  306,
  642,  442,  424,  412,  476,  519,   46,   46,  362,  316,
  364,  365,  366,   41,   41,   41,   44,  371,  305,  305,
  305,   46,  329,   44,  264,  506,  364,  305,  519,  363,
  363,   59,  593,   61,   41,  551, 1480, 1481,  593, 1483,
   44, 1485,  264,   46, 1671, 1489, 1490, 1491, 1492, 1294,
  264, 2390, 2392, 1497, 1498, 1294, 2391, 2904,  412, 3048,
 1294, 1294, 3048,   91, 1294, 2068, 2418, 1295, 2900, 2294,
 1514,  552, 1516, 2834, 3001, 1469,  351, 2811, 3352, 2761,
  387,   75, 2982,  706, 2203, 3132, 2222, 1531, 2790,    0,
 3263,  355,  979, 2280, 2812, 2565, 1540, 1541,  312, 3354,
 3212,  315, 2565,    0, 3441, 3387, 3386, 3402,  322,  323,
  417, 2751,  651,  327,  421,  596, 3152, 2752,  332,  426,
 3184,  335, 1464, 1925, 1923,  432, 2953, 1033, 2187,  551,
   41,  609, 3398,   44,  615,  349, 1580, 2187, 3397, 3309,
 1757, 3105,  651,  450,   41, 2183,  360,   44,   59, 3194,
 1594,  258, 1596,    0,  368, 1599, 1266,  264,  372, 1620,
 2653, 1446,   59, 1914, 1728,  677,  273,  381,  275,  276,
  277,  275, 1126,  280, 2196, 1811,  283, 1357, 1427,  133,
 2089,    0, 2239,  397, 3078, 2420,  290, 2425,  295,  598,
  346, 1096,  636,  992,  301,  643,  300,  304,  597,  506,
 1417, 1697,  306,  310, 1657, 2081, 2683,  311, 1146,  423,
 1280, 3392,  316, 3011, 1658,  319, 3083, 1700,  647,    0,
    0,  435,   41,  437, 2104,   44, 3064, 3064,    0,    0,
  258,    0,  967, 3333, 1593, 2267,  264,  344, 2277, 3218,
   59, 1243,   61, 1440,  598,  273,  721,  275,  276,  277,
  685,  605,  280, 1697, 3114,  283, 1700,  364, 1702, 1710,
  878,  738,  879, 1985,  368, 1262,  275,  295, 1712,  483,
 2799, 1340,   91,  301, 2855, 2233,  304, 2493,  385,  110,
  132,  290,  310,  387,  391,  499,  500, 2083,  395,  596,
  504,  300, 2892, 2417,  401, 3390, 1277,  306, 2587, 3112,
 3281, 3356,  311, 1135, 2496,  519, 1750,  316,  615, 1028,
  319, 1919,  419,  417, 1758,    0,  344,  424, 2728, 1046,
   12, 3238, 2686, 3300,   -1,   -1,   -1,   -1,  432,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,
   -1,  448,   -1,   -1,   -1,  452,  450,   -1,   -1,   -1,
   -1,    0,   -1,   -1,   -1,   -1,   41,  385,   -1,   44,
   -1,   -1,   -1,  391,   -1,  276,  277,  395,   -1,  280,
   -1,   -1,  283,  401,   59,   -1,   61,   -1,  387,  276,
  277,   -1,   -1,  280,  295,   -1,  283,    0,   -1,   -1,
   -1,  419,   41,   -1,   -1,   44,  424,   -1,  295,   -1,
   -1,   -1,  506,   -1,   -1,  509,   91,   -1,  417,   -1,
   59,   -1,   61,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  448,   -1,   -1,  432,  452,    0,   -1,   -1,   41,   -1,
   -1,   44,   -1,   -1,   -1,   -1,   -1,  651,   -1,  258,
   -1,  450,   91,   -1,  551,  264,   59,   -1,   61,   -1,
   -1,   -1,   -1,  364,  273,   -1,   -1,  276,  277,   -1,
   -1,  280,   -1,   -1,  283,   -1,   41,  364,   -1,   44,
   -1,   -1,   -1,   -1,  385,   -1,  295,   -1,   -1,   -1,
  391,   -1,  301,   -1,   59,  304,   61,   -1,  385,   -1,
   -1,  310,   -1,   -1,  391,   -1,   -1,  506,   -1,   -1,
  509, 1945,   -1,   -1,   -1,   -1,   -1, 1951,   -1,   -1,
   -1,  615, 1956,  424,   -1, 1959, 1960, 1961,   -1,   -1,
  627,   -1, 1966,  551, 1968,  344,   -1,  424,   -1,   -1,
   -1, 1975,   -1, 1977,   -1,   -1, 1980, 1981, 1982, 1983,
   -1,   -1, 1986,   -1, 1988,  364, 1990,   -1, 1992,   -1,
   -1,   -1,   -1,   -1, 1998, 1999, 2000, 2001, 2002, 2003,
 2004, 2005, 2006, 2007, 2008, 2009,  385,   -1,   -1,   -1,
   -1,   -1,  391,  258,   -1, 2019,  395,   -1,   -1,  264,
 2024,   -1,  401,   -1, 2028,   -1,   -1,   -1,  273,   -1,
   -1,  276,  277,   -1,   -1,  280,   -1,   -1,  283,  627,
  419,   -1,   45,   -1,   -1,  424,  615,   -1,   -1,  258,
  295,   -1,   -1,   -1,   -1,  264,  301,   -1,   -1,  304,
   -1,   -1,   -1,   -1,  273,  310,   -1,  276,  277,  448,
   -1,  280,   -1,  452,  283,   -1,   -1,   -1,   -1,   -1,
  551,   -1,   -1,   -1,   -1,  258,  295,   -1,   -1,   -1,
   -1,  264,  301,   -1,  551,  304,   -1,   -1,   -1,  344,
   -1,  310,  275,  276,  277,   -1,   -1,  280, 2112,   -1,
  283,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,  295,  258,   -1,   -1,    0,   -1,  301,  264,
   -1,   -1,   -1,   -1,   -1,  344,   -1,  310,  273,   -1,
  385,   -1,  277,   -1,   -1,  280,  391,   -1,   -1,   -1,
  395,   -1,   -1,   -1,   -1,  364,  401,   -1,   -1,   -1,
  295, 2165,   -1, 2167,   -1,   -1,  301,   41,   -1,  304,
   44,   -1,  551,   -1,  419,  310,  385,   -1,   -1,  424,
   -1,   -1,  391,  275,   -1,   59,  395,   61,   -1,   -1,
   -1,  364,  401,   -1,   -1,   -1,   -1,   -1,  290,   -1,
   -1,   41,   -1,  448,   44,   -1,   -1,  452,  300,  344,
  419,   -1,  385,   -1,  306,  424,   -1,   -1,  391,  311,
   60,   61,   62,   -1,  316,   -1,   -1,  319,  401,  364,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  448,
   -1,   -1,   -1,  452,   -1,   -1,  419,   -1,  627,   -1,
   -1,  424,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,
  395,   -1,   -1,   -1,   -1,   -1,  401,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,  368,    0,   -1,  452,
   -1,   -1,   -1,   -1,  419,   -1,   -1,   -1,  291,   -1,
   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  551,   -1,   -1,   -1,
   -1,   -1,   -1,  448,  317,   -1,   -1,  452,   41, 2323,
   -1,   44,   -1,   -1,   -1,  417, 2330, 2331,   -1,   -1,
   -1,   -1,   -1, 2337,   -1,    0,   59,   -1,   -1,   -1,
  432,  344,  551,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,
 2364,   -1,   -1, 2367,   -1, 2369,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   41,   -1,  551,   44,
   -1,   -1,  627,   -1,  258,   -1,   60,   61,   62,   -1,
  264,   -1,   -1,   -1,   59,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  276,  277,   -1,   -1,  280,  410,   -1,  283,
   -1,   -1,   -1,   -1,  506,   -1,  551,  509,  627,   -1,
   -1,  295,  262,  426,   -1,   -1,   -1,  301,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,  310,  440,   -1,  442,
  443,  444,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
 2454,   -1,   -1,   -1,  627,   -1,   -1,   -1,   -1,  462,
  463,  464,  465,  466,  467,  468,  469,  470,   41,   -1,
   -1,   44,   -1,  262,  477,  478,   -1,   -1,  318,   -1,
   -1, 2485,  271,  486,   -1,  325,   -1,   60,   61,   62,
  364,   -1,  627,  333,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,  385,  352,   41,   -1,   -1,   44,  391,   -1,   -1,
   -1,   -1,  362,  615,  364,  365,  366,  401,   -1,  318,
   -1,  371,   60,   61,   62,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,  419,   -1,   -1,   -1,   -1,
  424,   -1,   -1,  276,  277,   -1,   -1,   -1,   -1,   -1,
  283,  350,   -1,  352,   41,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,  362,   -1,  364,  365,  366,  452,   -1,
   -1,   -1,  371,   60,   61,   62,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
 2604,   -1, 2606,   -1, 2608,   -1,   -1,   -1, 2612,   -1,
  284,  276,  277, 2617, 2618, 2619, 2620, 2621,  283,   -1,
   -1,   -1, 2626,  412, 2628,   -1, 2630,   -1,   -1,   -1,
   -1,   -1,   -1,   41,  637,   -1,  639,  640,  641,   -1,
   -1,  364,   -1, 2647,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   60,   61,   62,   -1,   -1,   -1,   -1,  333,
   -1,   -1,  385,   -1,   -1,  668,  669,   -1,  391,    0,
   -1,   -1,   -1,   -1,   -1,   -1,  350,  551,  352,   -1,
   -1,   -1,   -1, 2687,   41,   -1,   -1,   -1,  362,  262,
  364,  365,  366,   -1,   -1,    0,   -1,  371,  271,  364,
   -1,  424,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   41,  284,   -1,   44, 2718, 2719,   -1,   -1,   -1,   -1,
  385,   -1,   -1,    0,   -1,   -1,  391,   -1,   59,   -1,
   -1,   -1, 2736,   -1,  262,   -1,   41,   -1,  412,   44,
 2744, 2745,   -1,  271,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  627,   59,   -1,  284,   -1,  598,  424,
  333,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,
    0,   -1, 2776,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   59,   -1,   -1,  262,   -1,   -1,   -1,  362,
  318,  364,  365,  366,  271,   -1,   -1,  325,  371,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   41,  284,   -1,  598,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,  483,   -1,
   -1,   -1,  350,   -1,  352,   60,   61,   62,   -1,   59,
   -1,   -1,   -1,   -1,  362,  312,  364,  365,  366,  412,
   -1,  318,   -1,  371,   44,   -1,   -1,   -1,  325,   -1,
 2854, 2855,   -1,   -1,  262,   -1,  333,   -1,   -1,   -1,
   60,   61,   62,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,  271,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,  598,  333,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1, 2942,    0,
   -1,   -1,  350,   -1,  352,  276,  277,   -1,   -1,   -1,
   -1,   -1,  283,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,  318,   -1,  371,   -1,   -1,   -1,   -1,  325,   -1,
   -1,  276,  277,   -1,   -1,   -1,  333,   -1,  283,   40,
   41,   -1,   43,   44,   45,   46,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352, 3000,   58,   59,  276,
  277,   -1,   63,   -1,  412,  362,  283,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1, 3020,   -1,   -1,   -1,
   -1,   -1,   -1,   -1, 3028,  598, 3030,  262,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  276,  277,   -1,  284,
   -1,   -1,   -1,  283,  385,  412,   -1,   -1,   -1,  364,
  391,   -1,  262,  368,   -1,   -1,   -1,   -1,   -1,   -1,
  598,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1, 3083,
  385,   -1,   -1,  318,  284,   -1,  391,  364,   -1,   -1,
  325,   -1,   -1,  424,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  385,   -1,
   -1,   -1,   -1,   -1,  391,  350,   -1,  352,  318,  424,
   -1,  598,   -1,   -1,   -1,  325,   -1,  362,   -1,  364,
  365,  366,   -1,  333,  364,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1, 3149,   -1,  424,   -1,   -1,
  350,   -1,  352,   -1,   -1,  385,   -1,   -1,   -1,   -1,
   -1,  391,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,  412,  483,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  598,   -1,   -1,   -1,  424,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,  264,  265,   -1,  267,  268,  269,   -1,
   -1,   -1,  412,  274,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,
  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  598,   -1,  304,   -1,  306,   -1,  308,  309,   -1,
   -1,  312,   -1,  483,  315,   -1,  317,   -1,  319,  320,
   -1,  322,  323,  324,   -1,  326,  327,  328,   -1,   -1,
   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,
  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,  360,
   -1,   -1,   -1,  364,   -1,   -1,   -1,  368, 3312,  370,
 3314,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,  382,   -1,   -1,   -1,  386, 3330,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397, 3341,  399, 3343,
 3344,  402,  403,  404,  405,   -1,  407,   -1,  409,  410,
  411,  412,  413,  414,  415,  416, 3360,   -1,   -1,  420,
   -1,  422,  423,  598,   -1,  426,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,  435,   -1,  437,  438,  439,  440,
  441,  442,  443,  444,  445,   -1,  447,  448,  449,  450,
   -1,  452,  453,   -1, 3398, 3399, 3400,   -1,  598,  460,
  461,  462,  463,  464,  465,  466,  467,  468,  469,  470,
  471,  472,   -1,  474,  475,  476,  477,  478,   -1,  480,
  481,  482,  483,  484,  485,  486,  487,   -1,   -1,  490,
  491,  492,  493,  494,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
  511,  512,  513,   -1,  515,  516,   -1,  518,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,  637,    0,  639,  640,
  641,  642,  643,  644,  645,  646,  647,  648,  649,   -1,
  651,  652,  653,  654,  655,  656,  657,  658,  659,  660,
  661,  662,  663,  664,  665,  666,  667,  668,  669,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
  272,   -1,   -1,  275,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  275,   -1,  287,   -1,   -1,   -1,  291,
   -1,  293,   -1,   -1,   -1,   -1,   -1,   -1,  290,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,
   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,   -1,  311,
   -1,   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,  331,
   -1,   -1,   -1,   -1,   -1,  337,  338,  339,   -1,  341,
  342,  343,   -1,  345,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  359,   -1,  361,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  379,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  390,   -1,
   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  417,  428,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,
  462,  463,   -1,   -1,  257,  258,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,  479,  271,   -1,
   -1,   -1,   -1,  276,  277,   -1,  279,  280,  281,  282,
  283,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,  301,  302,
  303,  304,  305,  306,  506,   -1,  309,  509,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,  385,  386,   -1,  388,  389,   -1,  391,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,  401,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  615,   -1,  418,  419,  420,   -1,  422,
  423,  424,   -1,   -1,   -1,   -1,  638,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,  264,   -1,   -1,
   59,   60,   61,   62,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,  271,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,  350,  325,  352,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,  318,   -1,   -1,  371,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,  258,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,  276,  277,   -1,
  279,  280,  281,  282,  283,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,  301,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,  385,  386,    0,  388,
  389,  598,  391,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,  401,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,  424,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   59,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,  276,  277,   -1,   -1,   -1,   -1,
   -1,  283,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,  364,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,  385,   -1,  318,   -1,   -1,   -1,  391,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,  424,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,  483,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,    0,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   59,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,  276,  277,
   -1,   -1,   -1,   -1,   -1,  283,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,  364,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,  385,   -1,  318,
   -1,   -1,   -1,  391,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,  424,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,    0,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   59,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,  276,  277,   -1,   -1,   -1,   -1,   -1,  283,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
  364,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,  385,   -1,  318,   -1,   -1,   -1,  391,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
  424,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,  261,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  278,   -1,   58,   59,   60,   61,   62,
   -1,  286,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  294,
   -1,  296,   -1,   -1,   -1,   -1,  301,  262,   -1,   -1,
   -1,   -1,  307,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,  321,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,  330,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
  355,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,  396,  333,  398,   -1,   -1,  401,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  425,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,  437,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  473,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  488,  489,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,  510,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   41,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,  598,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   41,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   60,   61,   62,
  495,  496,   41,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   60,   61,   62,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,   -1,  352,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,  598,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,  598,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   41,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   60,   61,   62,  495,  496,   41,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  350,   -1,  352,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  598,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,  598,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   41,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   60,   61,   62,  495,  496,
   41,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   60,
   61,   62,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  598,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,  598,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   41,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   41,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,  272,   -1,   -1,  275,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,  350,
   -1,  352,  291,   -1,  293,   -1,  333,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,  331,   -1,  371,   -1,   -1,   -1,  337,  338,
  339,   -1,  341,  342,  343,   -1,  345,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,   -1,  361,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,  390,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,  406,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,  428,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,  462,  463,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
  479,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,  598,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   41,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   60,   61,   62,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,  638,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,  284,  265,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  297,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,  350,   -1,  352,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,  350,  371,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,  598,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,  598,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,  264,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,  318,  364,  365,  366,   -1,
   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,  412,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,  598,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,  314,   -1,   -1,  362,  318,
  364,  365,  366,   -1,   -1,   -1,  325,  371,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,  412,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,  598,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,  314,
   -1,   -1,  362,  318,  364,  365,  366,   -1,   -1,   -1,
  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,  598,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,  312,   -1,   -1,   -1,   -1,  362,  318,  364,  365,
  366,   -1,   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,  412,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,  598,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,  314,   -1,   -1,
  362,  318,  364,  365,  366,   -1,   -1,   -1,  325,  371,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,  598,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,  318,  364,  365,  366,   -1,
   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,  412,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,  598,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,  318,
  364,  365,  366,   -1,   -1,   -1,  325,  371,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,  412,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,  598,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,  284,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,  318,  364,  365,  366,   -1,   -1,   -1,
  325,  371,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,  412,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,  598,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,  284,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,  318,  364,  365,
  366,   -1,   -1,   -1,  325,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,  598,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,  272,  271,
   -1,  275,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,  287,   -1,   -1,   -1,  291,   -1,  293,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  272,
   -1,   -1,  275,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,  287,   -1,   -1,  331,  291,   -1,
  293,  333,   -1,  337,  338,  339,   -1,  341,  342,  343,
   -1,  345,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,  331,  371,
   -1,   -1,   -1,   -1,  337,  338,  339,   -1,  341,  342,
  343,   -1,  345,   -1,   -1,   -1,  390,   -1,   -1,   -1,
   -1,  395,   -1,   -1,   -1,   -1,  359,   -1,  361,   -1,
   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,  379,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  428,   -1,   -1,  390,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  462,  463,
   -1,   -1,  257,   -1,  259,  428,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,  479,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,  462,
  463,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,  479,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,  638,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,  638,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,  272,  271,   -1,  275,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,  287,   -1,   -1,
   -1,  291,   -1,  293,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,  331,  291,   -1,  293,  333,   -1,  337,  338,  339,
   -1,  341,  342,  343,   -1,  345,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,  359,
   -1,  361,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,  331,  371,   -1,   -1,   -1,   -1,  337,  338,
  339,   -1,  341,  342,  343,   -1,  345,   -1,   -1,   -1,
  390,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,   -1,  361,   -1,   -1,   -1,  406,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  428,   -1,
   -1,  390,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  406,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  462,  463,   -1,   -1,  257,   -1,  259,  428,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,  479,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,  462,  463,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
  479,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,  638,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,  638,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  275,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  300,   -1,   -1,   -1,   -1,   -1,
  306,   -1,   -1,   -1,  318,  311,   -1,   -1,   -1,   -1,
  316,  325,   -1,  319,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  387,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  417,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
  506,   -1,  309,  509,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,  615,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  275,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,
   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,  318,  311,
   -1,   -1,   -1,   -1,  316,  325,   -1,  319,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  417,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,  506,   -1,  309,  509,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  615,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,   -1,
   -1,   -1,   91,  306,   93,   -1,   -1,  310,  311,   -1,
   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,  329,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  402,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  417,   -1,  412,   -1,  421,   -1,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,  432,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,  506,   -1,   -1,  509,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,  552,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,  596,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,  615,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,  316,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,  329,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,
   -1,   -1,   -1,  421,   -1,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  450,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,  506,   -1,
   -1,  509,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,  596,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,  615,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,  300,   -1,   -1,   -1,
   -1,   -1,  306,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,  316,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,  329,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  387,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  417,   -1,   -1,   -1,  421,   -1,   -1,
   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,  432,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  450,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,  506,   -1,   -1,  509,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,  596,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,  615,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   44,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   44,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,
   59,   60,   61,   62,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,  598,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   44,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   58,   59,   60,   61,   62,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,  598,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   44,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   58,   59,   60,
   61,   62,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  598,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   44,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   58,   59,   60,   61,   62,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,  598,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   58,   59,   60,   61,   62,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,  563,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,  589,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,  598,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   60,
   61,   62,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   58,
   59,   60,   61,   62,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,  350,  325,  352,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,  419,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,  569,  388,
  389,  598,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,  598,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   60,   61,
   62,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   58,   59,   60,   61,   62,  271,   -1,
  262,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,  271,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,  288,   -1,
  290,   -1,  284,   -1,   -1,   -1,   91,   -1,   93,   -1,
  300,   -1,  305,   -1,   -1,   -1,  306,   -1,   -1,   -1,
  310,   -1,   -1,   -1,   -1,  318,  316,   -1,   -1,  319,
   -1,   -1,  325,   -1,   -1,   -1,  318,   -1,   -1,  329,
  333,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,  362,
  352,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,   -1,
  412,  421,   -1,   -1,   -1,   -1,  426,  419,   -1,   -1,
   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  450,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,  506,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,  552,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,  598,  596,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,  598,  402,  403,  404,
  405,   -1,  407,   -1,  409,  615,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  275,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,  290,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,   -1,
   -1,  310,  311,   -1,   -1,   -1,   -1,  316,   -1,   -1,
  319,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  329,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  379,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,
   -1,   -1,  421,   -1,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,  432,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  450,  451,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,  506,  309,   -1,
  509,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,  615,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,
   -1,   -1,   -1,   -1,   91,  306,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  402,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,   -1,   -1,
  421,   -1,   -1,  424,   -1,  426,   -1,   -1,   -1,   -1,
   -1,  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  450,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,  506,   -1,   -1,  509,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,  552,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,  596,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,  615,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,    0,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,  454,  455,  456,  457,  458,  459,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,
  501,  502,  503,  504,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,    0,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,    0,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,  454,  455,  456,  457,  458,  459,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,
  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,    0,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  651,   -1,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,  454,  455,  456,  457,  458,
  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
  499,  500,  501,  502,  503,  504,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,    0,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,
   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,  618,    0,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,   42,   43,   44,   45,
   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   42,   43,
   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   42,   43,   44,   45,   -1,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   42,   43,   44,   45,
   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   43,
   44,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   43,   44,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,    0,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
  454,  455,  456,  457,  458,  459,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
    0,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,  499,
  500,  501,  502,  503,  504,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,    0,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
   -1,  651,   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,    0,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   41,
   -1,   -1,   44,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,  454,  455,  456,  457,  458,  459,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,  499,  500,  501,
  502,  503,  504,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,    0,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,  651,
   -1,   -1,   -1,   41,   -1,   -1,   44,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,    0,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,  454,  455,  456,  457,
  458,  459,  460,  461,   41,   -1,   -1,   44,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   59,  481,  482,  483,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,  499,  500,  501,  502,  503,  504,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,   -1,  651,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,   -1,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,  326,
  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,   -1,   -1,  364,   -1,   -1,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,   -1,  413,  414,  415,   -1,
   -1,  418,  419,  420,    0,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   59,  481,  482,  483,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,  499,  500,  501,  502,  503,  504,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  651,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,  415,
   -1,   -1,  418,  419,  420,    0,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   41,   -1,   -1,   44,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   59,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   93,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,
   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,
  415,   -1,   -1,  418,  419,  420,    0,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,  454,
  455,  456,  457,  458,  459,  460,  461,   41,   -1,   -1,
   44,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   59,  481,  482,  483,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,  499,  500,  501,  502,  503,  504,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
   -1,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,    0,   -1,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,  435,   -1,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   40,   41,  460,  461,   44,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   59,   -1,   -1,   -1,  481,  482,  483,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,  499,  500,  501,  502,  503,
  504,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,   -1,  651,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,    0,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   41,  452,   -1,   44,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,    0,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   41,  452,   -1,   44,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,    0,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,
   -1,  437,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   59,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,  483,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,  499,  500,  501,  502,  503,  504,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  651,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,    0,   -1,   -1,  399,   -1,
  401,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,  435,   -1,   -1,  438,  439,   44,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   59,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,  483,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,  500,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,  314,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,  332,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   40,   -1,   -1,   43,   -1,   45,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   58,  484,
  485,   -1,  487,   63,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,  454,  455,  456,  457,  458,  459,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,  508,  509,
   -1,  511,  512,  513,  514,  515,  516,  517,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,   -1,   -1,  263,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,  408,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   42,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,  298,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,   -1,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,  288,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,  437,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   42,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   41,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,  314,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,  419,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   41,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,  483,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   42,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
  260,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,  298,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,   -1,   -1,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   42,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,  492,  493,  494,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,  437,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,
   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,
   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,
  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,
   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
  410,  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
  440,  441,  442,  443,  444,  445,   -1,  447,  448,  449,
  450,   -1,  452,  453,   40,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,  464,  465,  466,  467,  468,  469,
  470,  471,  472,   -1,  474,  475,  476,  477,  478,   -1,
  480,  481,  482,   -1,  484,  485,  486,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,  511,  512,  513,   -1,  515,  516,   -1,  518,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,  637,   -1,  639,
  640,  641,  642,  643,  644,  645,  646,  647,  648,  649,
   -1,   -1,  652,  653,  654,  655,  656,  657,  658,  659,
  660,  661,  662,  663,  664,  665,  666,  667,  668,  669,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,  329,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   40,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,  329,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   40,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   58,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   40,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   40,   -1,   -1,  437,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   40,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   42,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   45,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,  643,  644,  645,  646,  647,  648,  649,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,  442,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   58,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,  270,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,  296,  297,   -1,  299,  300,   -1,   -1,  303,
  304,   -1,  306,  307,   -1,  309,   -1,   -1,  312,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,  325,  326,   -1,  328,   -1,  330,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,  346,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,  355,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,  382,  383,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,  397,   -1,  399,  400,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,  425,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,   -1,  436,  437,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   58,  452,  453,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,  497,  498,  499,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,  511,  512,  513,
   -1,  515,  516,   -1,  518,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,  626,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,  270,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,  296,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,  307,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,  325,  326,   -1,  328,   -1,  330,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,  346,   -1,  348,  349,   -1,
  351,   -1,  353,   -1,  355,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,  382,  383,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,   -1,   -1,  437,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   58,  452,  453,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,  497,  498,  499,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
  511,  512,  513,   -1,  515,  516,   -1,  518,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,  626,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,  307,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,  325,  326,   -1,
  328,   -1,  330,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,  346,   -1,
  348,  349,   -1,  351,   -1,  353,   -1,  355,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,  383,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,  425,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,  437,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   58,  452,  453,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,  497,
  498,  499,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,  511,  512,  513,   -1,  515,  516,   -1,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,  626,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   42,   43,   44,   45,
   46,   47,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,  262,   -1,   -1,   -1,
  277,   -1,   -1,   -1,  281,  271,   -1,  284,   -1,   -1,
   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   42,   43,   44,   45,   46,   47,  325,   -1,
   -1,   -1,  318,   -1,   -1,  262,  333,   -1,   -1,  325,
   60,   61,   62,   -1,  271,   -1,   -1,  333,   -1,   -1,
  277,   -1,   -1,  350,  281,  352,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,  350,  362,  352,  364,  365,  366,
   -1,   91,   -1,   -1,  371,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,  412,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,  454,  455,
  456,  457,  458,  459,  460,  461,   42,   43,   -1,   45,
   46,   47,   -1,   -1,   -1,  412,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,  454,  455,  456,
  457,  458,  459,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,   -1,
   -1,  281,   -1,   -1,  284,   -1,  563,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  563,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  589,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,  598,   -1,  589,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,  598,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,  563,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  589,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  598,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,   -1,  262,   -1,  264,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  454,  455,  456,  457,  458,  459,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,  332,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  380,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  563,   -1,   -1,  412,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,  589,
   -1,  437,   -1,   -1,  279,  280,   -1,  282,  598,  284,
   -1,   -1,  287,   -1,  450,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,  598,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,  446,  447,  448,  449,  450,  451,  452,  453,  454,
  455,  456,  457,  458,  459,  460,  461,  462,  463,  464,
  465,  466,   -1,   -1,  469,  470,  471,  472,  473,  474,
  475,  476,  477,  478,  479,  480,  481,  482,  483,  484,
  485,  486,  487,  488,  489,  490,  491,  492,  493,  494,
  495,  496,  497,  498,  499,  500,  501,  502,  503,  504,
  505,  506,  507,  508,  509,  510,  511,  512,  513,  514,
  515,  516,  517,  518,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,  544,
  545,  546,  547,  548,  549,  550,  551,  552,  553,  554,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,  577,  578,  579,  580,  581,  582,  583,  584,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,  618,  619,  620,  621,  622,  623,  624,
  625,  626,  627,  628,  629,  630,  631,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,  642,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,  654,
  655,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,  446,  447,  448,  449,  450,   -1,
  452,  453,  454,  455,  456,  457,  458,  459,  460,  461,
  462,  463,  464,  465,  466,   -1,   -1,  469,  470,  471,
  472,  473,  474,  475,  476,  477,  478,  479,  480,  481,
  482,  483,  484,  485,  486,  487,  488,  489,  490,  491,
  492,  493,  494,  495,  496,  497,  498,  499,  500,  501,
  502,  503,  504,  505,  506,  507,  508,  509,  510,  511,
  512,  513,  514,  515,  516,  517,  518,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,  544,  545,  546,  547,  548,  549,  550,  551,
  552,  553,  554,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,  577,  578,  579,  580,  581,
  582,  583,  584,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,  618,  619,  620,  621,
  622,  623,  624,  625,  626,  627,  628,  629,  630,  631,
  632,  633,  634,  635,  636,  637,  638,  639,  640,  641,
  642,  643,  644,  645,  646,  647,  648,  649,  650,  651,
  652,  653,  654,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,  668,  669,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
  289,  290,  291,   -1,  293,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,  331,   -1,   -1,  334,   -1,  336,  337,  338,
  339,  340,  341,  342,  343,   -1,  345,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
  359,   -1,  361,   -1,  363,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,  390,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,  406,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,  428,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,  462,  463,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
  479,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
  619,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,  638,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,  272,   -1,   -1,  275,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,  291,   -1,  293,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,  331,   -1,   -1,  334,   -1,
  336,  337,  338,  339,  340,  341,  342,  343,   -1,  345,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,  359,   -1,  361,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,  390,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
  406,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,  428,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,  462,  463,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,  479,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,  638,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,  272,
   -1,   -1,  275,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  291,   -1,
  293,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,  331,   -1,
   -1,  334,   -1,  336,  337,  338,  339,  340,  341,  342,
  343,   -1,  345,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,  359,   -1,  361,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,  390,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,  406,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,  462,
  463,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,  479,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,  638,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,  272,   -1,   -1,  275,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,  291,   -1,  293,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,  331,   -1,   -1,  334,   -1,  336,  337,  338,  339,
  340,  341,  342,  343,   -1,  345,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,  359,
   -1,  361,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
  390,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,  406,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,  428,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,  462,  463,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,  479,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,  638,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,  272,   -1,   -1,  275,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,  291,   -1,  293,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,  331,   -1,   -1,  334,   -1,  336,
  337,  338,  339,  340,  341,  342,  343,   -1,  345,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,  359,   -1,  361,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,  390,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,  406,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,  428,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,  462,  463,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,  479,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,  638,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,  260,  261,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,  286,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,  296,  297,   -1,  299,  300,  301,   -1,   -1,
  304,   -1,  306,  307,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,  330,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,  391,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,  400,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,  425,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
  261,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,  286,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,  296,  297,   -1,  299,  300,
  301,   -1,   -1,  304,   -1,  306,  307,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,  330,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  391,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,  400,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,
   -1,  319,  320,   -1,  322,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,  387,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,  421,  422,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,   -1,  432,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,  329,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,  263,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
  322,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,  643,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,  443,  444,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,  355,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,  322,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,  371,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,  283,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,  283,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,  310,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,  451,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,  451,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,  301,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,  620,  621,  622,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,
   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,
  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,
  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,
  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,
  501,  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,
  521,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,   -1,
  541,  542,  543,  544,  545,  546,   -1,  548,  549,  550,
  551,   -1,  553,   -1,  555,  556,  557,  558,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,   -1,  574,  575,  576,  577,   -1,  579,  580,
  581,  582,  583,   -1,  585,  586,  587,  588,  589,  590,
  591,  592,  593,  594,  595,  596,  597,   -1,  599,  600,
  601,  602,  603,  604,   -1,  606,  607,  608,  609,  610,
  611,  612,  613,   -1,  615,  616,  617,  618,   -1,  620,
  621,  622,  623,  624,  625,   -1,   -1,  628,  629,  630,
  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,
   -1,  642,   -1,  644,  645,  646,  647,  648,  649,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,
  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,
   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,
   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,
   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,   -1,  541,  542,  543,  544,  545,  546,   -1,
  548,  549,  550,  551,   -1,  553,   -1,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,   -1,  574,  575,  576,  577,
   -1,  579,  580,  581,  582,  583,   -1,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
   -1,  599,  600,  601,  602,  603,  604,   -1,  606,  607,
  608,  609,  610,  611,  612,  613,   -1,  615,  616,  617,
  618,   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,
  628,  629,  630,  631,  632,  633,  634,  635,  636,   -1,
   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,
  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,
  475,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,
  485,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,
  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,
  505,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,   -1,  541,  542,  543,  544,
  545,  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,
  555,  556,  557,  558,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,   -1,  574,
  575,  576,  577,   -1,  579,  580,  581,  582,  583,   -1,
  585,  586,  587,  588,  589,  590,  591,  592,  593,  594,
  595,  596,  597,   -1,  599,  600,  601,  602,  603,  604,
   -1,  606,  607,  608,  609,  610,  611,  612,  613,   -1,
  615,  616,  617,  618,   -1,  620,  621,  622,  623,  624,
  625,   -1,   -1,  628,  629,  630,  631,  632,  633,  634,
  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,
  645,  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,
   -1,   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,
  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,
  472,   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,
  482,   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,
   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,
  502,  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,   -1,  541,
  542,  543,  544,  545,  546,   -1,  548,  549,  550,  551,
   -1,  553,   -1,  555,  556,  557,  558,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,   -1,  574,  575,  576,  577,   -1,  579,  580,  581,
  582,  583,   -1,  585,  586,  587,  588,  589,  590,  591,
  592,  593,  594,  595,  596,  597,   -1,  599,  600,  601,
  602,  603,  604,   -1,  606,  607,  608,  609,  610,  611,
  612,  613,   -1,  615,  616,  617,  618,   -1,  620,  621,
  622,  623,  624,  625,   -1,   -1,  628,  629,  630,  631,
  632,  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,
  642,   -1,  644,  645,  646,  647,  648,  649,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,
  449,  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,
   -1,   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,
   -1,  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,
   -1,   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,   -1,  541,  542,  543,  544,  545,  546,   -1,  548,
  549,  550,  551,   -1,  553,   -1,  555,  556,  557,  558,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,   -1,  574,  575,  576,  577,   -1,
  579,  580,  581,  582,  583,   -1,  585,  586,  587,  588,
  589,  590,  591,  592,  593,  594,  595,  596,  597,   -1,
  599,  600,  601,  602,  603,  604,   -1,  606,  607,  608,
  609,  610,  611,  612,  613,   -1,  615,  616,  617,  618,
   -1,  620,  621,  622,  623,  624,  625,   -1,   -1,  628,
  629,  630,  631,  632,  633,  634,  635,  636,   -1,   -1,
   -1,   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,
  649,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,
   -1,  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,
  476,   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,
   -1,  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,
  496,   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,
  506,  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  519,  520,  521,  522,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,   -1,  541,  542,  543,  544,  545,
  546,   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,
  556,  557,  558,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,   -1,  574,  575,
  576,  577,   -1,  579,  580,  581,  582,  583,   -1,  585,
  586,  587,  588,  589,  590,  591,  592,  593,  594,  595,
  596,  597,   -1,  599,  600,  601,  602,  603,  604,   -1,
  606,  607,  608,  609,  610,  611,  612,  613,   -1,  615,
  616,  617,  618,   -1,  620,  621,  622,  623,  624,  625,
   -1,   -1,  628,  629,  630,  631,  632,  633,  634,  635,
  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,
  646,  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,
   -1,   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,
   -1,  474,  475,  476,   -1,   -1,   -1,   -1,  481,  482,
   -1,  484,  485,   -1,  487,   -1,   -1,  490,  491,   -1,
   -1,   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,
  503,   -1,  505,  506,  507,   -1,  509,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,   -1,  541,  542,
  543,  544,  545,  546,   -1,  548,  549,  550,  551,   -1,
  553,   -1,  555,  556,  557,  558,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
   -1,  574,  575,  576,  577,   -1,  579,  580,  581,  582,
  583,   -1,  585,  586,  587,  588,  589,  590,  591,  592,
  593,  594,  595,  596,  597,   -1,  599,  600,  601,  602,
  603,  604,   -1,  606,  607,  608,  609,  610,  611,  612,
  613,   -1,  615,  616,  617,  618,   -1,  620,  621,  622,
  623,  624,  625,   -1,   -1,  628,  629,  630,  631,  632,
  633,  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,
   -1,  644,  645,  646,  647,  648,  649,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,  441,   -1,   -1,   -1,  445,   -1,  447,  448,  449,
  450,   -1,  452,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  460,  461,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  471,  472,   -1,  474,  475,  476,   -1,   -1,   -1,
   -1,  481,  482,   -1,  484,  485,   -1,  487,   -1,   -1,
  490,  491,   -1,   -1,   -1,  495,  496,   -1,   -1,   -1,
   -1,  501,  502,  503,   -1,  505,  506,  507,   -1,  509,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  520,  521,  522,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
   -1,  541,  542,  543,  544,  545,  546,   -1,  548,  549,
  550,  551,   -1,  553,   -1,  555,  556,  557,  558,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,   -1,  574,  575,  576,  577,   -1,  579,
  580,  581,  582,  583,   -1,  585,  586,  587,  588,  589,
  590,  591,  592,  593,  594,  595,  596,  597,   -1,  599,
  600,  601,  602,  603,  604,   -1,  606,  607,  608,  609,
  610,  611,  612,  613,   -1,  615,  616,  617,  618,   -1,
  620,  621,  622,  623,  624,  625,   -1,   -1,  628,  629,
  630,  631,  632,  633,  634,  635,  636,   -1,   -1,   -1,
   -1,   -1,  642,   -1,  644,  645,  646,  647,  648,  649,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,  441,   -1,   -1,   -1,  445,   -1,
  447,  448,  449,  450,   -1,  452,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  460,  461,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  471,  472,   -1,  474,  475,  476,
   -1,   -1,   -1,   -1,  481,  482,   -1,  484,  485,   -1,
  487,   -1,   -1,  490,  491,   -1,   -1,   -1,  495,  496,
   -1,   -1,   -1,   -1,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,   -1,  541,  542,  543,  544,  545,  546,
   -1,  548,  549,  550,  551,   -1,  553,   -1,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,   -1,  574,  575,  576,
  577,   -1,  579,  580,  581,  582,  583,   -1,  585,  586,
  587,  588,  589,  590,  591,  592,   -1,  594,  595,  596,
  597,   -1,  599,  600,  601,  602,  603,  604,   -1,  606,
  607,  608,  609,  610,  611,  612,  613,   -1,  615,  616,
  617,  618,   -1,  620,  621,  622,  623,  624,  625,   -1,
   -1,  628,  629,  630,  631,  632,  633,  634,  635,  636,
   -1,   -1,   -1,   -1,   -1,  642,   -1,  644,  645,  646,
  647,  648,  649,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,  441,   -1,   -1,
   -1,  445,   -1,  447,  448,  449,  450,   -1,  452,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  460,  461,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  471,  472,   -1,
  474,   -1,  476,   -1,   -1,   -1,   -1,  481,  482,   -1,
  484,   -1,   -1,  487,   -1,   -1,  490,  491,   -1,   -1,
   -1,  495,  496,   -1,   -1,   -1,   -1,  501,  502,  503,
   -1,   -1,  506,  507,   -1,  509,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  519,  520,  521,  522,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,   -1,  541,  542,  543,
  544,  545,  546,   -1,  548,  549,  550,  551,   -1,  553,
   -1,  555,  556,  557,  558,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,   -1,
  574,  575,  576,  577,   -1,  579,  580,  581,  582,  583,
   -1,  585,  586,  587,  588,  589,  590,  591,  592,  593,
  594,  595,  596,  597,   -1,  599,  600,  601,  602,  603,
  604,   -1,  606,  607,  608,  609,  610,  611,  612,  613,
   -1,  615,  616,  617,  618,   -1,   -1,   -1,   -1,  623,
  624,  625,   -1,   -1,  628,  629,  630,  631,  632,  633,
  634,  635,  636,   -1,   -1,   -1,   -1,   -1,  642,   -1,
  644,  645,  646,  647,  648,  649,
};
static int yyctable[] = {                                     -1,
 1169, 1203,   -1,  640, 1149,   -1,  641, 1149,   -1,   32,
   44,   -1,  955,  119,   -1,  119,  121,   -1,  641, 1151,
   -1, 1772, 1779,   -1, 1322, 1123,   -1, 1569, 1475,   -1,
 1570, 1474,   -1, 1236, 1169,   -1, 1247, 1169,   -1, 2024,
 1386,   -1,  594, 1196,   -1, 1169, 1196,   -1,  211,  639,
   -1,  216,  639,   -1,  225,  639,   -1,  319,  639,   -1,
  320,  639,   -1,  321,  639,   -1, 2367, 1388,   -1, 2369,
 1390,   -1,   82,   89,   -1,  594, 1169,   -1, 2465,  957,
   -1,  810, 1758,   -1, 2647, 1392,   -1,  229, 1180,   -1,
  594, 1198,   -1, 1169, 1198,   -1, 2706, 1074,   -1, 2361,
 1143,   -1, 2511,  955,   -1,  296, 1786,   -1,  296, 1961,
   -1, 3080, 1085,   -1, 3201,  568,   -1,
};
#define YYFINAL 20
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 671
#if YYDEBUG
static const char *yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'","'*'","'+'","','","'-'","'.'","'/'",0,0,0,0,0,0,0,0,0,0,
"':'","';'","'<'","'='","'>'","'?'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,"'['",0,"']'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"ACTIVE","ADD","AFTER","ALL","ALTER","AND","ANY",
"AS","ASC","AT","AVG","AUTO","BEFORE","BEGIN","BETWEEN","BLOB","BY","CAST",
"CHARACTER","CHECK","COLLATE","COMMIT","COMMITTED","COMPUTED","CONCATENATE",
"CONDITIONAL","CONSTRAINT","CONTAINING","COUNT","CREATE","CSTRING","CURRENT",
"CURSOR","DATABASE","DATE","DB_KEY","DECIMAL","DECLARE","DEFAULT","KW_DELETE",
"DESC","DISTINCT","DO","KW_DOMAIN","DROP","ELSE","END","ENTRY_POINT","ESCAPE",
"EXCEPTION","EXECUTE","EXISTS","EXIT","EXTERNAL","FILTER","FOR","FOREIGN",
"FROM","FULL","FUNCTION","GDSCODE","GEQ","GENERATOR","GEN_ID","GRANT","GROUP",
"HAVING","IF","KW_IN","INACTIVE","INNER","INPUT_TYPE","INDEX","INSERT",
"INTEGER","INTO","IS","ISOLATION","JOIN","KEY","KW_CHAR","KW_DEC","KW_DOUBLE",
"KW_FILE","KW_FLOAT","KW_INT","KW_LONG","KW_NULL","KW_NUMERIC","KW_UPPER",
"KW_VALUE","LENGTH","LEFT","LEQ","LEVEL","LIKE","MANUAL","MAXIMUM","MERGE",
"MINIMUM","MODULE_NAME","NAMES","NATIONAL","NATURAL","NCHAR","NEQ","NO","NOT",
"NOT_GTR","NOT_LSS","OF","ON","ONLY","OPTION","OR","ORDER","OUTER",
"OUTPUT_TYPE","KW_OVERFLOW","PAGE","PAGES","KW_PAGE_SIZE","PARAMETER",
"PASSWORD","PLAN","POSITION","POST_EVENT","PRECISION","PRIMARY","PRIVILEGES",
"PROCEDURE","PROTECTED","READ","REAL","REFERENCES","RESERVING","RETAIN",
"RETURNING_VALUES","RETURNS","REVOKE","RIGHT","ROLLBACK","SEGMENT","SELECT",
"SET","SHADOW","KW_SHARED","SINGULAR","KW_SIZE","SMALLINT","SNAPSHOT","SOME",
"SORT","SQLCODE","STABILITY","STARTING","STATISTICS","SUB_TYPE","SUSPEND","SUM",
"TABLE","THEN","TO","TRANSACTION","TRIGGER","UNCOMMITTED","UNION","UNIQUE",
"UPDATE","USER","VALUES","VARCHAR","VARIABLE","VARYING","VERSION","VIEW","WAIT",
"WHEN","WHERE","WHILE","WITH","WORK","WRITE","FLOAT_NUMBER","SYMBOL","NUMBER",
"STRING","INTRODUCER","ACTION","ADMIN","CASCADE","FREE_IT","RESTRICT","ROLE",
"COLUMN","KW_TYPE","EXTRACT","YEAR","MONTH","DAY","HOUR","MINUTE","SECOND",
"WEEKDAY","YEARDAY","TIME","TIMESTAMP","CURRENT_DATE","CURRENT_TIME",
"CURRENT_TIMESTAMP","NUMBER64BIT","SCALEDINT","CURRENT_USER","CURRENT_ROLE",
"KW_BREAK","SUBSTRING","RECREATE","KW_DESCRIPTOR","FIRST","SKIP",
"CURRENT_CONNECTION","CURRENT_TRANSACTION","BIGINT","CASE","NULLIF","COALESCE",
"USING","NULLS","LAST","ROW_COUNT","LOCK","SAVEPOINT","RELEASE","STATEMENT",
"LEAVE","INSERTING","UPDATING","DELETING","BACKUP","KW_DIFFERENCE","OPEN",
"CLOSE","FETCH","ROWS","BLOCK","IIF","SCALAR_ARRAY","CROSS","NEXT","SEQUENCE",
"RESTART","BOTH","COLLATION","COMMENT","BIT_LENGTH","CHAR_LENGTH",
"CHARACTER_LENGTH","LEADING","KW_LOWER","OCTET_LENGTH","TRAILING","TRIM",
"RETURNING","KW_IGNORE","LIMBO","UNDO","REQUESTS","TIMEOUT","ABS","ACCENT",
"ACOS","ALWAYS","ASCII_CHAR","ASCII_VAL","ASIN","ATAN","ATAN2","BIN_AND",
"BIN_OR","BIN_SHL","BIN_SHR","BIN_XOR","CEIL","CONNECT","COS","COSH","COT",
"DATEADD","DATEDIFF","DECODE","DISCONNECT","EXP","FLOOR","GEN_UUID","GENERATED",
"GLOBAL","HASH","INSENSITIVE","LIST","LN","LOG","LOG10","LPAD","MATCHED",
"MATCHING","MAXVALUE","MILLISECOND","MINVALUE","MOD","OVERLAY","PAD","PI",
"PLACING","POWER","PRESERVE","RAND","RECURSIVE","REPLACE","REVERSE","ROUND",
"RPAD","SENSITIVE","SIGN","SIN","SINH","SPACE","SQRT","START","TAN","TANH",
"TEMPORARY","TRUNC","WEEK","AUTONOMOUS","CHAR_TO_UUID","FIRSTNAME","GRANTED",
"LASTNAME","MIDDLENAME","MAPPING","OS_NAME","SIMILAR","UUID_TO_CHAR","CALLER",
"COMMON","DATA","SOURCE","TWO_PHASE","BIND_PARAM","BIN_NOT","BODY","CONTINUE",
"DDL","DECRYPT","ENCRYPT","ENGINE","NAME","OVER","PACKAGE","PARTITION",
"RDB_GET_CONTEXT","RDB_SET_CONTEXT","SCROLL","PRIOR","KW_ABSOLUTE",
"KW_RELATIVE","ACOSH","ASINH","ATANH","RETURN","DETERMINISTIC","IDENTITY",
"DENSE_RANK","FIRST_VALUE","NTH_VALUE","LAST_VALUE","LAG","LEAD","RANK",
"ROW_NUMBER","SQLSTATE","KW_BOOLEAN","KW_FALSE","KW_TRUE","UNKNOWN","USAGE",
"RDB_RECORD_VERSION","LINGER","TAGS","PLUGIN","SERVERWIDE","INCREMENT",
"TRUSTED","ROW","OFFSET","STDDEV_SAMP","STDDEV_POP","VAR_SAMP","VAR_POP",
"COVAR_SAMP","COVAR_POP","CORR","REGR_AVGX","REGR_AVGY","REGR_COUNT",
"REGR_INTERCEPT","REGR_R2","REGR_SLOPE","REGR_SXX","REGR_SXY","REGR_SYY",
"LOCALTIME","LOCALTIMESTAMP","UMINUS","UPLUS",
};
static const char *yyrule[] = {
"$accept : top",
"top : statement",
"top : statement ';'",
"statement : dml_statement",
"statement : ddl_statement",
"statement : tra_statement",
"dml_statement : delete",
"dml_statement : insert",
"dml_statement : merge",
"dml_statement : exec_procedure",
"dml_statement : exec_block",
"dml_statement : savepoint",
"dml_statement : select",
"dml_statement : update",
"dml_statement : update_or_insert",
"ddl_statement : alter",
"ddl_statement : comment",
"ddl_statement : create",
"ddl_statement : create_or_alter",
"ddl_statement : declare",
"ddl_statement : drop",
"ddl_statement : grant",
"ddl_statement : recreate",
"ddl_statement : revoke",
"ddl_statement : set_statistics",
"tra_statement : set_transaction",
"tra_statement : commit",
"tra_statement : rollback",
"tra_statement : set_role",
"$$1 :",
"$$2 :",
"grant : GRANT $$1 $$2 grant0",
"$$3 :",
"$$4 :",
"grant0 : $$3 privileges ON table_noise symbol_table_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PROCEDURE symbol_procedure_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON FUNCTION symbol_UDF_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PACKAGE symbol_package_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON EXCEPTION symbol_exception_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON GENERATOR symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON SEQUENCE symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"$$5 :",
"grant0 : $$3 ddl_privileges object TO $$5 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 db_ddl_privileges DATABASE TO $$5 non_role_grantee_list grant_option granted_by",
"$$6 :",
"$$7 :",
"grant0 : $$6 role_name_list TO $$7 role_grantee_list role_admin_option granted_by",
"object : TABLE",
"object : VIEW",
"object : PROCEDURE",
"object : FUNCTION",
"object : PACKAGE",
"object : GENERATOR",
"object : SEQUENCE",
"object : KW_DOMAIN",
"object : EXCEPTION",
"object : ROLE",
"object : CHARACTER SET",
"object : COLLATION",
"object : FILTER",
"table_noise :",
"table_noise : TABLE",
"privileges : ALL",
"privileges : ALL PRIVILEGES",
"$$8 :",
"privileges : $$8 privilege_list",
"privilege_list : $$8 privilege",
"$$9 :",
"privilege_list : privilege_list ',' $$9 privilege",
"execute_privilege : EXECUTE",
"usage_privilege : USAGE",
"privilege : SELECT",
"privilege : INSERT",
"privilege : KW_DELETE",
"privilege : UPDATE column_parens_opt",
"privilege : REFERENCES column_parens_opt",
"ddl_privileges : ALL privileges_opt",
"ddl_privileges : $$8 ddl_privilege_list",
"privileges_opt :",
"privileges_opt : PRIVILEGES",
"ddl_privilege_list : $$8 ddl_privilege",
"ddl_privilege_list : ddl_privilege_list ',' $$9 ddl_privilege",
"ddl_privilege : CREATE",
"ddl_privilege : ALTER ANY",
"ddl_privilege : DROP ANY",
"db_ddl_privileges : ALL privileges_opt",
"db_ddl_privileges : $$8 db_ddl_privilege_list",
"db_ddl_privilege_list : $$8 db_ddl_privilege",
"db_ddl_privilege_list : db_ddl_privilege_list ',' $$9 db_ddl_privilege",
"db_ddl_privilege : CREATE",
"db_ddl_privilege : ALTER",
"db_ddl_privilege : DROP",
"grant_option :",
"grant_option : WITH GRANT OPTION",
"role_admin_option :",
"role_admin_option : WITH ADMIN OPTION",
"granted_by :",
"granted_by : granted_by_text grantor",
"granted_by_text : GRANTED BY",
"granted_by_text : AS",
"grantor : symbol_user_name",
"grantor : USER symbol_user_name",
"$$10 :",
"revoke : REVOKE $$10 $$2 revoke0",
"$$11 :",
"$$12 :",
"revoke0 : rev_grant_option $$11 privileges ON table_noise symbol_table_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PROCEDURE symbol_procedure_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON FUNCTION symbol_UDF_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PACKAGE symbol_package_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON EXCEPTION symbol_exception_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON GENERATOR symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON SEQUENCE symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"$$13 :",
"revoke0 : rev_grant_option $$11 ddl_privileges object FROM $$13 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 db_ddl_privileges DATABASE FROM $$13 non_role_grantee_list granted_by",
"$$14 :",
"revoke0 : rev_admin_option $$14 role_name_list FROM $$5 role_grantee_list granted_by",
"revoke0 : ALL ON ALL FROM $$5 non_role_grantee_list",
"rev_grant_option :",
"rev_grant_option : GRANT OPTION FOR",
"rev_admin_option :",
"rev_admin_option : ADMIN OPTION FOR",
"$$15 :",
"non_role_grantee_list : $$15 grantee",
"non_role_grantee_list : $$15 user_grantee",
"$$16 :",
"non_role_grantee_list : non_role_grantee_list ',' $$16 grantee",
"non_role_grantee_list : non_role_grantee_list ',' $$16 user_grantee",
"grantee : PROCEDURE symbol_procedure_name",
"grantee : FUNCTION symbol_UDF_name",
"grantee : PACKAGE symbol_package_name",
"grantee : TRIGGER symbol_trigger_name",
"grantee : VIEW symbol_view_name",
"grantee : ROLE symbol_role_name",
"user_grantee : symbol_user_name",
"user_grantee : USER symbol_user_name",
"user_grantee : GROUP symbol_user_name",
"role_name_list : $$15 role_name",
"role_name_list : role_name_list ',' $$16 role_name",
"role_name : symbol_role_name",
"role_grantee_list : $$15 role_grantee",
"role_grantee_list : role_grantee_list ',' $$16 role_grantee",
"role_grantee : grantor",
"declare : DECLARE declare_clause",
"declare_clause : FILTER filter_decl_clause",
"declare_clause : EXTERNAL FUNCTION udf_decl_clause",
"$$17 :",
"$$18 :",
"$$19 :",
"udf_decl_clause : symbol_UDF_name $$17 $$18 arg_desc_list1 RETURNS $$19 return_value1 ENTRY_POINT utf_string MODULE_NAME utf_string",
"udf_data_type : simple_type",
"udf_data_type : BLOB",
"udf_data_type : CSTRING '(' pos_short_integer ')' charset_clause",
"arg_desc_list1 :",
"$$20 :",
"arg_desc_list1 : $$20 arg_desc_list",
"$$21 :",
"arg_desc_list1 : '(' $$21 arg_desc_list ')'",
"arg_desc_list : $$20 arg_desc",
"$$22 :",
"arg_desc_list : arg_desc_list ',' $$22 arg_desc",
"arg_desc : udf_data_type param_mechanism",
"param_mechanism :",
"param_mechanism : BY KW_DESCRIPTOR",
"param_mechanism : BY SCALAR_ARRAY",
"param_mechanism : KW_NULL",
"$$23 :",
"return_value1 : $$23 return_value",
"$$24 :",
"return_value1 : '(' $$24 return_value ')'",
"return_value : udf_data_type return_mechanism",
"return_value : PARAMETER pos_short_integer",
"return_mechanism :",
"return_mechanism : BY KW_VALUE",
"return_mechanism : BY KW_DESCRIPTOR",
"return_mechanism : FREE_IT",
"return_mechanism : BY KW_DESCRIPTOR FREE_IT",
"filter_decl_clause : symbol_filter_name INPUT_TYPE blob_filter_subtype OUTPUT_TYPE blob_filter_subtype ENTRY_POINT utf_string MODULE_NAME utf_string",
"blob_filter_subtype : symbol_blob_subtype_name",
"blob_filter_subtype : signed_short_integer",
"create : CREATE create_clause",
"create_clause : EXCEPTION exception_clause",
"$$25 :",
"$$26 :",
"create_clause : unique_opt order_direction INDEX symbol_index_name ON simple_table_name $$25 $$26 index_definition",
"create_clause : FUNCTION function_clause",
"create_clause : PROCEDURE procedure_clause",
"create_clause : TABLE table_clause",
"create_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"create_clause : TRIGGER trigger_clause",
"create_clause : VIEW view_clause",
"create_clause : GENERATOR generator_clause",
"create_clause : SEQUENCE generator_clause",
"create_clause : DATABASE db_clause",
"create_clause : KW_DOMAIN domain_clause",
"create_clause : SHADOW shadow_clause",
"create_clause : ROLE role_clause",
"create_clause : COLLATION collation_clause",
"create_clause : USER create_user_clause",
"create_clause : PACKAGE package_clause",
"create_clause : PACKAGE BODY package_body_clause",
"$$27 :",
"create_clause : MAPPING $$27 create_map_clause",
"$$28 :",
"create_clause : GLOBAL MAPPING $$28 create_map_clause",
"recreate : RECREATE recreate_clause",
"recreate_clause : PROCEDURE procedure_clause",
"recreate_clause : FUNCTION function_clause",
"recreate_clause : TABLE table_clause",
"recreate_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"recreate_clause : VIEW view_clause",
"recreate_clause : TRIGGER trigger_clause",
"recreate_clause : PACKAGE package_clause",
"recreate_clause : PACKAGE BODY package_body_clause",
"recreate_clause : EXCEPTION exception_clause",
"recreate_clause : GENERATOR generator_clause",
"recreate_clause : SEQUENCE generator_clause",
"create_or_alter : CREATE OR ALTER replace_clause",
"replace_clause : PROCEDURE replace_procedure_clause",
"replace_clause : FUNCTION replace_function_clause",
"replace_clause : TRIGGER replace_trigger_clause",
"replace_clause : PACKAGE replace_package_clause",
"replace_clause : VIEW replace_view_clause",
"replace_clause : EXCEPTION replace_exception_clause",
"replace_clause : GENERATOR replace_sequence_clause",
"replace_clause : SEQUENCE replace_sequence_clause",
"replace_clause : USER replace_user_clause",
"replace_clause : MAPPING $$27 replace_map_clause",
"replace_clause : GLOBAL MAPPING $$28 replace_map_clause",
"exception_clause : symbol_exception_name sql_string",
"replace_exception_clause : symbol_exception_name sql_string",
"alter_exception_clause : symbol_exception_name sql_string",
"unique_opt :",
"unique_opt : UNIQUE",
"index_definition : column_list",
"index_definition : column_parens",
"index_definition : computed_by '(' value ')'",
"$$29 :",
"$$30 :",
"shadow_clause : pos_short_integer manual_auto conditional utf_string first_file_length $$29 $$30 sec_shadow_files",
"manual_auto :",
"manual_auto : MANUAL",
"manual_auto : AUTO",
"conditional :",
"conditional : CONDITIONAL",
"first_file_length :",
"first_file_length : LENGTH equals long_integer page_noise",
"sec_shadow_files :",
"$$31 :",
"sec_shadow_files : $$31 db_file_list",
"db_file_list : db_file",
"db_file_list : db_file_list db_file",
"$$32 :",
"$$33 :",
"domain_clause : symbol_column_name as_opt data_type domain_default_opt $$32 $$33 domain_constraints_opt collate_clause",
"domain_constraints_opt :",
"domain_constraints_opt : $$33 domain_constraints",
"domain_constraints : $$33 domain_constraint",
"$$34 :",
"domain_constraints : domain_constraints $$34 domain_constraint",
"domain_constraint : null_constraint",
"domain_constraint : check_constraint",
"as_opt :",
"as_opt : AS",
"domain_default : DEFAULT default_value",
"domain_default_opt :",
"domain_default_opt : domain_default",
"null_constraint : NOT KW_NULL",
"check_constraint : CHECK '(' search_condition ')'",
"generator_clause : symbol_generator_name start_with_opt step_option",
"start_with_opt :",
"start_with_opt : start_with",
"start_with : START WITH sequence_value",
"step_option :",
"step_option : INCREMENT by_noise signed_long_integer",
"by_noise :",
"by_noise : BY",
"replace_sequence_clause : symbol_generator_name replace_sequence_options step_option",
"replace_sequence_options : RESTART",
"replace_sequence_options : START WITH sequence_value",
"alter_sequence_clause : symbol_generator_name restart_value_opt2 step_option",
"restart_value_opt : RESTART",
"restart_value_opt : RESTART WITH sequence_value",
"restart_value_opt2 :",
"restart_value_opt2 : restart_value_opt",
"set_generator_clause : SET GENERATOR symbol_generator_name TO sequence_value",
"sequence_value : signed_long_integer",
"sequence_value : NUMBER64BIT",
"sequence_value : '-' NUMBER64BIT",
"role_clause : symbol_role_name",
"$$35 :",
"$$36 :",
"$$37 :",
"$$38 :",
"collation_clause : symbol_collation_name FOR symbol_character_set_name $$35 $$36 collation_sequence_definition $$37 collation_attribute_list_opt $$38 collation_specific_attribute_opt",
"collation_sequence_definition :",
"collation_sequence_definition : FROM symbol_collation_name",
"collation_sequence_definition : FROM EXTERNAL '(' utf_string ')'",
"collation_attribute_list_opt :",
"collation_attribute_list_opt : $$36 collation_attribute_list",
"collation_attribute_list : $$36 collation_attribute",
"$$39 :",
"collation_attribute_list : collation_attribute_list $$39 collation_attribute",
"collation_attribute : $$36 collation_pad_attribute",
"collation_attribute : $$36 collation_case_attribute",
"collation_attribute : $$36 collation_accent_attribute",
"collation_pad_attribute : NO PAD",
"collation_pad_attribute : PAD SPACE",
"collation_case_attribute : CASE SENSITIVE",
"collation_case_attribute : CASE INSENSITIVE",
"collation_accent_attribute : ACCENT SENSITIVE",
"collation_accent_attribute : ACCENT INSENSITIVE",
"collation_specific_attribute_opt :",
"collation_specific_attribute_opt : utf_string",
"alter_charset_clause : symbol_character_set_name SET DEFAULT COLLATION symbol_collation_name",
"$$40 :",
"$$41 :",
"$$42 :",
"db_clause : db_name $$40 $$41 db_initial_desc1 $$42 db_rem_desc1",
"equals :",
"equals : '='",
"db_name : utf_string",
"db_initial_desc1 :",
"db_initial_desc1 : $$41 db_initial_desc",
"db_initial_desc : $$41 db_initial_option",
"$$43 :",
"db_initial_desc : db_initial_desc $$43 db_initial_option",
"db_initial_option : KW_PAGE_SIZE equals pos_short_integer",
"db_initial_option : USER symbol_user_name",
"db_initial_option : USER utf_string",
"db_initial_option : ROLE valid_symbol_name",
"db_initial_option : ROLE utf_string",
"db_initial_option : PASSWORD utf_string",
"db_initial_option : SET NAMES utf_string",
"db_initial_option : LENGTH equals long_integer page_noise",
"db_rem_desc1 :",
"db_rem_desc1 : $$41 db_rem_desc",
"db_rem_desc : $$41 db_rem_option",
"db_rem_desc : db_rem_desc $$43 db_rem_option",
"db_rem_option : db_file",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name COLLATION symbol_collation_name",
"db_rem_option : KW_DIFFERENCE KW_FILE utf_string",
"$$44 :",
"$$45 :",
"db_file : KW_FILE utf_string $$44 $$45 file_desc1",
"file_desc1 :",
"file_desc1 : $$45 file_desc",
"file_desc : $$45 file_clause",
"$$46 :",
"file_desc : file_desc $$46 file_clause",
"file_clause : STARTING file_clause_noise long_integer",
"file_clause : LENGTH equals long_integer page_noise",
"file_clause_noise :",
"file_clause_noise : AT",
"file_clause_noise : AT PAGE",
"page_noise :",
"page_noise : PAGE",
"page_noise : PAGES",
"$$47 :",
"$$48 :",
"table_clause : simple_table_name external_file $$47 '(' $$48 table_elements ')'",
"$$49 :",
"gtt_table_clause : simple_table_name $$49 '(' $$48 table_elements ')' gtt_scope",
"gtt_scope :",
"gtt_scope : ON COMMIT KW_DELETE ROWS",
"gtt_scope : ON COMMIT PRESERVE ROWS",
"external_file :",
"external_file : EXTERNAL KW_FILE utf_string",
"external_file : EXTERNAL utf_string",
"$$50 :",
"table_elements : $$50 table_element",
"$$51 :",
"table_elements : table_elements ',' $$51 table_element",
"$$52 :",
"table_element : $$52 column_def",
"table_element : $$52 table_constraint_definition",
"$$53 :",
"$$54 :",
"column_def : symbol_column_name data_type_or_domain domain_default_opt $$53 $$54 column_constraint_clause collate_clause",
"$$55 :",
"column_def : symbol_column_name data_type_or_domain identity_clause $$55 $$54 column_constraint_clause collate_clause",
"column_def : symbol_column_name non_array_type def_computed",
"column_def : symbol_column_name def_computed",
"identity_clause : GENERATED BY DEFAULT AS IDENTITY identity_clause_options",
"identity_clause_options :",
"identity_clause_options : '(' start_with ')'",
"def_computed : computed_clause '(' value ')'",
"computed_clause : computed_by",
"computed_clause : generated_always_clause",
"generated_always_clause : GENERATED ALWAYS AS",
"computed_by : COMPUTED BY",
"computed_by : COMPUTED",
"data_type_or_domain : data_type",
"data_type_or_domain : symbol_column_name",
"collate_clause :",
"collate_clause : COLLATE symbol_collation_name",
"data_type_descriptor : data_type",
"data_type_descriptor : KW_TYPE OF symbol_column_name",
"data_type_descriptor : KW_TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"data_type_descriptor : symbol_column_name",
"default_value : constant",
"default_value : current_user",
"default_value : current_role",
"default_value : internal_info",
"default_value : null_value",
"default_value : datetime_value_expression",
"column_constraint_clause :",
"$$56 :",
"column_constraint_clause : $$56 column_constraint_list",
"column_constraint_list : $$56 column_constraint_def",
"$$57 :",
"column_constraint_list : column_constraint_list $$57 column_constraint_def",
"column_constraint_def : constraint_name_opt $$57 column_constraint",
"column_constraint : null_constraint",
"column_constraint : check_constraint",
"column_constraint : REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"column_constraint : UNIQUE constraint_index_opt",
"column_constraint : PRIMARY KEY constraint_index_opt",
"$$58 :",
"table_constraint_definition : constraint_name_opt $$58 table_constraint",
"constraint_name_opt :",
"constraint_name_opt : CONSTRAINT symbol_constraint_name",
"table_constraint : UNIQUE column_parens constraint_index_opt",
"table_constraint : PRIMARY KEY column_parens constraint_index_opt",
"table_constraint : FOREIGN KEY column_parens REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"table_constraint : check_constraint",
"constraint_index_opt :",
"constraint_index_opt : USING order_direction INDEX symbol_index_name",
"referential_trigger_action :",
"referential_trigger_action : update_rule",
"referential_trigger_action : delete_rule",
"referential_trigger_action : delete_rule update_rule",
"referential_trigger_action : update_rule delete_rule",
"update_rule : ON UPDATE referential_action",
"delete_rule : ON KW_DELETE referential_action",
"referential_action : CASCADE",
"referential_action : SET DEFAULT",
"referential_action : SET KW_NULL",
"referential_action : NO ACTION",
"procedure_clause : psql_procedure_clause",
"procedure_clause : external_procedure_clause",
"psql_procedure_clause : procedure_clause_start AS local_declaration_list full_proc_block",
"external_procedure_clause : procedure_clause_start external_clause external_body_clause_opt",
"$$59 :",
"$$60 :",
"$$61 :",
"procedure_clause_start : symbol_procedure_name $$59 $$60 input_parameters $$61 output_parameters",
"alter_procedure_clause : procedure_clause",
"replace_procedure_clause : procedure_clause",
"input_parameters :",
"input_parameters : '(' ')'",
"input_parameters : '(' $$21 input_proc_parameters ')'",
"output_parameters :",
"output_parameters : RETURNS '(' $$22 output_proc_parameters ')'",
"input_proc_parameters : $$20 input_proc_parameter",
"input_proc_parameters : input_proc_parameters ',' $$22 input_proc_parameter",
"input_proc_parameter : column_domain_or_non_array_type collate_clause default_par_opt",
"output_proc_parameters : output_proc_parameter",
"output_proc_parameters : output_proc_parameters ',' $$22 output_proc_parameter",
"output_proc_parameter : column_domain_or_non_array_type collate_clause",
"column_domain_or_non_array_type : symbol_column_name domain_or_non_array_type",
"default_par_opt :",
"default_par_opt : DEFAULT default_value",
"default_par_opt : '=' default_value",
"function_clause : psql_function_clause",
"function_clause : external_function_clause",
"psql_function_clause : function_clause_start AS local_declaration_list full_proc_block",
"external_function_clause : function_clause_start external_clause external_body_clause_opt",
"$$62 :",
"function_clause_start : symbol_UDF_name $$62 $$18 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt",
"deterministic_opt :",
"deterministic_opt : NOT DETERMINISTIC",
"deterministic_opt : DETERMINISTIC",
"external_clause : EXTERNAL NAME utf_string ENGINE valid_symbol_name",
"external_clause : EXTERNAL ENGINE valid_symbol_name",
"external_body_clause_opt :",
"external_body_clause_opt : AS utf_string",
"alter_function_clause : function_clause",
"replace_function_clause : function_clause",
"package_clause : symbol_package_name AS BEGIN package_items_opt END",
"package_items_opt : package_items",
"package_items_opt :",
"package_items : package_item",
"package_items : package_items package_item",
"package_item : FUNCTION function_clause_start ';'",
"package_item : PROCEDURE procedure_clause_start ';'",
"alter_package_clause : package_clause",
"replace_package_clause : package_clause",
"package_body_clause : symbol_package_name AS BEGIN package_items package_body_items_opt END",
"package_body_clause : symbol_package_name AS BEGIN package_body_items_opt END",
"package_body_items_opt :",
"package_body_items_opt : package_body_items",
"package_body_items : package_body_item",
"package_body_items : package_body_items package_body_item",
"package_body_item : FUNCTION psql_function_clause",
"package_body_item : FUNCTION external_function_clause ';'",
"package_body_item : PROCEDURE psql_procedure_clause",
"package_body_item : PROCEDURE external_procedure_clause ';'",
"local_declaration_list :",
"local_declaration_list : local_declarations",
"local_declarations : local_declaration",
"local_declarations : local_declarations local_declaration",
"local_declaration : DECLARE var_decl_opt local_declaration_item ';'",
"$$63 :",
"$$64 :",
"$$65 :",
"local_declaration : DECLARE PROCEDURE symbol_procedure_name $$63 $$64 input_parameters $$65 output_parameters AS local_declaration_list full_proc_block",
"$$66 :",
"local_declaration : DECLARE FUNCTION symbol_UDF_name $$66 $$64 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt AS local_declaration_list full_proc_block",
"local_declaration_item : var_declaration_item",
"local_declaration_item : cursor_declaration_item",
"var_declaration_item : column_domain_or_non_array_type collate_clause default_par_opt",
"var_decl_opt :",
"var_decl_opt : VARIABLE",
"cursor_declaration_item : symbol_cursor_name scroll_opt CURSOR FOR '(' select ')'",
"scroll_opt :",
"scroll_opt : NO SCROLL",
"scroll_opt : SCROLL",
"proc_block : proc_statement",
"proc_block : full_proc_block",
"full_proc_block : BEGIN full_proc_block_body END",
"full_proc_block_body :",
"full_proc_block_body : proc_statements",
"full_proc_block_body : proc_statements excp_hndl_statements",
"proc_statements : proc_block",
"proc_statements : proc_statements proc_block",
"proc_statement : simple_proc_statement ';'",
"proc_statement : complex_proc_statement",
"simple_proc_statement : assignment_statement",
"simple_proc_statement : insert",
"simple_proc_statement : merge",
"simple_proc_statement : update",
"simple_proc_statement : update_or_insert",
"simple_proc_statement : delete",
"simple_proc_statement : singleton_select",
"simple_proc_statement : exec_procedure",
"simple_proc_statement : exec_sql",
"simple_proc_statement : exec_into",
"simple_proc_statement : exec_function",
"simple_proc_statement : excp_statement",
"simple_proc_statement : raise_statement",
"simple_proc_statement : post_event",
"simple_proc_statement : cursor_statement",
"simple_proc_statement : breakleave",
"simple_proc_statement : continue",
"simple_proc_statement : SUSPEND",
"simple_proc_statement : EXIT",
"simple_proc_statement : RETURN value",
"assignment_statement : assignment",
"assignment_statement : ':' assignment",
"complex_proc_statement : in_autonomous_transaction",
"complex_proc_statement : if_then_else",
"complex_proc_statement : while",
"complex_proc_statement : for_select",
"complex_proc_statement : for_exec_into",
"in_autonomous_transaction : KW_IN AUTONOMOUS TRANSACTION DO proc_block",
"excp_statement : EXCEPTION symbol_exception_name",
"excp_statement : EXCEPTION symbol_exception_name value",
"excp_statement : EXCEPTION symbol_exception_name USING '(' value_list ')'",
"raise_statement : EXCEPTION",
"$$67 :",
"$$68 :",
"for_select : label_def_opt FOR select $$67 $$68 for_select_into_cursor DO proc_block",
"for_select_into_cursor : into_variable_list cursor_def_opt",
"for_select_into_cursor : into_variable_list_opt cursor_def",
"into_variable_list_opt :",
"into_variable_list_opt : into_variable_list",
"into_variable_list : INTO variable_list",
"$$69 :",
"$$70 :",
"$$71 :",
"exec_sql : EXECUTE STATEMENT $$69 $$70 exec_stmt_inputs $$71 exec_stmt_options",
"exec_into : exec_sql INTO variable_list",
"for_exec_into : label_def_opt FOR exec_into DO proc_block",
"exec_stmt_inputs : value",
"$$72 :",
"exec_stmt_inputs : '(' value ')' '(' $$72 named_params_list ')'",
"exec_stmt_inputs : '(' value ')' '(' $$72 not_named_params_list ')'",
"named_params_list : $$70 named_param",
"named_params_list : named_params_list ',' $$71 named_param",
"named_param : symbol_variable_name BIND_PARAM value",
"not_named_params_list : $$70 not_named_param",
"not_named_params_list : not_named_params_list ',' $$71 not_named_param",
"not_named_param : value",
"exec_stmt_options :",
"exec_stmt_options : $$70 exec_stmt_options_list",
"$$73 :",
"exec_stmt_options_list : exec_stmt_options_list $$73 exec_stmt_option",
"exec_stmt_options_list : $$70 exec_stmt_option",
"exec_stmt_option : ON EXTERNAL DATA SOURCE value",
"exec_stmt_option : ON EXTERNAL value",
"exec_stmt_option : AS USER value",
"exec_stmt_option : PASSWORD value",
"exec_stmt_option : ROLE value",
"exec_stmt_option : WITH AUTONOMOUS TRANSACTION",
"exec_stmt_option : WITH COMMON TRANSACTION",
"exec_stmt_option : WITH CALLER PRIVILEGES",
"if_then_else : IF '(' search_condition ')' THEN proc_block ELSE proc_block",
"if_then_else : IF '(' search_condition ')' THEN proc_block",
"post_event : POST_EVENT value event_argument_opt",
"event_argument_opt :",
"singleton_select : select INTO variable_list",
"variable : ':' symbol_variable_name",
"variable_list : variable",
"variable_list : column_name",
"variable_list : variable_list ',' column_name",
"variable_list : variable_list ',' variable",
"while : label_def_opt WHILE '(' search_condition ')' DO proc_block",
"label_def_opt :",
"label_def_opt : symbol_label_name ':'",
"breakleave : KW_BREAK",
"breakleave : LEAVE label_use_opt",
"continue : CONTINUE label_use_opt",
"label_use_opt :",
"label_use_opt : symbol_label_name",
"cursor_def_opt :",
"cursor_def_opt : cursor_def",
"cursor_def : AS CURSOR symbol_cursor_name",
"excp_hndl_statements : excp_hndl_statement",
"excp_hndl_statements : excp_hndl_statements excp_hndl_statement",
"$$74 :",
"$$75 :",
"excp_hndl_statement : WHEN $$74 $$75 errors DO proc_block",
"$$76 :",
"errors : $$76 err",
"$$77 :",
"errors : errors ',' $$77 err",
"err : SQLCODE signed_short_integer",
"err : SQLSTATE STRING",
"err : GDSCODE symbol_gdscode_name",
"err : EXCEPTION symbol_exception_name",
"err : ANY",
"cursor_statement : open_cursor",
"cursor_statement : fetch_cursor",
"cursor_statement : close_cursor",
"open_cursor : OPEN symbol_cursor_name",
"close_cursor : CLOSE symbol_cursor_name",
"$$78 :",
"$$79 :",
"fetch_cursor : FETCH $$78 $$79 fetch_scroll FROM symbol_cursor_name into_variable_list_opt",
"fetch_cursor : FETCH symbol_cursor_name into_variable_list_opt",
"fetch_scroll : FIRST",
"fetch_scroll : LAST",
"fetch_scroll : PRIOR",
"fetch_scroll : NEXT",
"fetch_scroll : KW_ABSOLUTE value",
"fetch_scroll : KW_RELATIVE value",
"exec_procedure : EXECUTE PROCEDURE symbol_procedure_name proc_inputs proc_outputs_opt",
"exec_procedure : EXECUTE PROCEDURE symbol_package_name '.' symbol_procedure_name proc_inputs proc_outputs_opt",
"proc_inputs :",
"proc_inputs : value_list",
"proc_inputs : '(' value_list ')'",
"proc_outputs_opt :",
"proc_outputs_opt : RETURNING_VALUES variable_list",
"proc_outputs_opt : RETURNING_VALUES '(' variable_list ')'",
"$$80 :",
"exec_block : EXECUTE BLOCK $$80 $$64 block_input_params $$65 output_parameters AS local_declaration_list full_proc_block",
"block_input_params :",
"block_input_params : '(' $$21 block_parameters ')'",
"block_parameters : $$20 block_parameter",
"block_parameters : block_parameters ',' $$22 block_parameter",
"block_parameter : column_domain_or_non_array_type collate_clause '=' parameter",
"view_clause : simple_table_name column_parens_opt AS select_expr check_opt",
"replace_view_clause : view_clause",
"alter_view_clause : view_clause",
"check_opt :",
"check_opt : WITH CHECK OPTION",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position external_clause external_body_clause_opt",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position ON symbol_table_name AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name trigger_active trigger_type trigger_position ON symbol_table_name external_clause external_body_clause_opt",
"trigger_clause : symbol_trigger_name FOR symbol_table_name trigger_active trigger_type trigger_position AS local_declaration_list full_proc_block",
"trigger_clause : symbol_trigger_name FOR symbol_table_name trigger_active trigger_type trigger_position external_clause external_body_clause_opt",
"replace_trigger_clause : trigger_clause",
"trigger_active : ACTIVE",
"trigger_active : INACTIVE",
"trigger_active :",
"trigger_type : trigger_type_prefix trigger_type_suffix",
"trigger_type : ON trigger_db_type",
"trigger_type : trigger_type_prefix trigger_ddl_type",
"trigger_db_type : CONNECT",
"trigger_db_type : DISCONNECT",
"trigger_db_type : TRANSACTION START",
"trigger_db_type : TRANSACTION COMMIT",
"trigger_db_type : TRANSACTION ROLLBACK",
"trigger_ddl_type : trigger_ddl_type_items",
"trigger_ddl_type : ANY DDL STATEMENT",
"trigger_ddl_type_items : CREATE TABLE",
"trigger_ddl_type_items : ALTER TABLE",
"trigger_ddl_type_items : DROP TABLE",
"trigger_ddl_type_items : CREATE PROCEDURE",
"trigger_ddl_type_items : ALTER PROCEDURE",
"trigger_ddl_type_items : DROP PROCEDURE",
"trigger_ddl_type_items : CREATE FUNCTION",
"trigger_ddl_type_items : ALTER FUNCTION",
"trigger_ddl_type_items : DROP FUNCTION",
"trigger_ddl_type_items : CREATE TRIGGER",
"trigger_ddl_type_items : ALTER TRIGGER",
"trigger_ddl_type_items : DROP TRIGGER",
"trigger_ddl_type_items : CREATE EXCEPTION",
"trigger_ddl_type_items : ALTER EXCEPTION",
"trigger_ddl_type_items : DROP EXCEPTION",
"trigger_ddl_type_items : CREATE VIEW",
"trigger_ddl_type_items : ALTER VIEW",
"trigger_ddl_type_items : DROP VIEW",
"trigger_ddl_type_items : CREATE KW_DOMAIN",
"trigger_ddl_type_items : ALTER KW_DOMAIN",
"trigger_ddl_type_items : DROP KW_DOMAIN",
"trigger_ddl_type_items : CREATE ROLE",
"trigger_ddl_type_items : ALTER ROLE",
"trigger_ddl_type_items : DROP ROLE",
"trigger_ddl_type_items : CREATE SEQUENCE",
"trigger_ddl_type_items : ALTER SEQUENCE",
"trigger_ddl_type_items : DROP SEQUENCE",
"trigger_ddl_type_items : CREATE USER",
"trigger_ddl_type_items : ALTER USER",
"trigger_ddl_type_items : DROP USER",
"trigger_ddl_type_items : CREATE INDEX",
"trigger_ddl_type_items : ALTER INDEX",
"trigger_ddl_type_items : DROP INDEX",
"trigger_ddl_type_items : CREATE COLLATION",
"trigger_ddl_type_items : DROP COLLATION",
"trigger_ddl_type_items : ALTER CHARACTER SET",
"trigger_ddl_type_items : CREATE PACKAGE",
"trigger_ddl_type_items : ALTER PACKAGE",
"trigger_ddl_type_items : DROP PACKAGE",
"trigger_ddl_type_items : CREATE PACKAGE BODY",
"trigger_ddl_type_items : DROP PACKAGE BODY",
"trigger_ddl_type_items : CREATE MAPPING",
"trigger_ddl_type_items : ALTER MAPPING",
"trigger_ddl_type_items : DROP MAPPING",
"trigger_ddl_type_items : trigger_ddl_type OR trigger_ddl_type",
"trigger_type_prefix : BEFORE",
"trigger_type_prefix : AFTER",
"trigger_type_suffix : INSERT",
"trigger_type_suffix : UPDATE",
"trigger_type_suffix : KW_DELETE",
"trigger_type_suffix : INSERT OR UPDATE",
"trigger_type_suffix : INSERT OR KW_DELETE",
"trigger_type_suffix : UPDATE OR INSERT",
"trigger_type_suffix : UPDATE OR KW_DELETE",
"trigger_type_suffix : KW_DELETE OR INSERT",
"trigger_type_suffix : KW_DELETE OR UPDATE",
"trigger_type_suffix : INSERT OR UPDATE OR KW_DELETE",
"trigger_type_suffix : INSERT OR KW_DELETE OR UPDATE",
"trigger_type_suffix : UPDATE OR INSERT OR KW_DELETE",
"trigger_type_suffix : UPDATE OR KW_DELETE OR INSERT",
"trigger_type_suffix : KW_DELETE OR INSERT OR UPDATE",
"trigger_type_suffix : KW_DELETE OR UPDATE OR INSERT",
"trigger_position :",
"trigger_position : POSITION nonneg_short_integer",
"alter : ALTER alter_clause",
"alter : set_generator_clause",
"alter_clause : EXCEPTION alter_exception_clause",
"$$81 :",
"$$82 :",
"alter_clause : TABLE simple_table_name $$81 $$82 alter_ops",
"alter_clause : VIEW alter_view_clause",
"alter_clause : TRIGGER alter_trigger_clause",
"alter_clause : PROCEDURE alter_procedure_clause",
"alter_clause : PACKAGE alter_package_clause",
"$$83 :",
"alter_clause : DATABASE $$83 $$41 alter_db",
"alter_clause : KW_DOMAIN alter_domain",
"alter_clause : INDEX alter_index_clause",
"alter_clause : EXTERNAL FUNCTION alter_udf_clause",
"alter_clause : FUNCTION alter_function_clause",
"alter_clause : ROLE alter_role_clause",
"alter_clause : USER alter_user_clause",
"alter_clause : CURRENT USER alter_cur_user_clause",
"alter_clause : CHARACTER SET alter_charset_clause",
"alter_clause : GENERATOR alter_sequence_clause",
"alter_clause : SEQUENCE alter_sequence_clause",
"alter_clause : MAPPING $$27 alter_map_clause",
"alter_clause : GLOBAL MAPPING $$28 alter_map_clause",
"$$84 :",
"$$85 :",
"alter_domain : keyword_or_column $$84 $$85 alter_domain_ops",
"alter_domain_ops : $$85 alter_domain_op",
"$$86 :",
"alter_domain_ops : alter_domain_ops $$86 alter_domain_op",
"alter_domain_op : SET domain_default",
"alter_domain_op : ADD CONSTRAINT check_constraint",
"alter_domain_op : ADD check_constraint",
"alter_domain_op : DROP DEFAULT",
"alter_domain_op : DROP CONSTRAINT",
"alter_domain_op : DROP NOT KW_NULL",
"alter_domain_op : SET NOT KW_NULL",
"alter_domain_op : TO symbol_column_name",
"alter_domain_op : KW_TYPE non_array_type",
"alter_ops : $$82 alter_op",
"$$87 :",
"alter_ops : alter_ops ',' $$87 alter_op",
"alter_op : DROP symbol_column_name drop_behaviour",
"alter_op : DROP CONSTRAINT symbol_constraint_name",
"alter_op : ADD $$58 column_def",
"alter_op : ADD $$58 table_constraint_definition",
"alter_op : col_opt alter_column_name POSITION pos_short_integer",
"alter_op : col_opt alter_column_name TO symbol_column_name",
"alter_op : col_opt alter_column_name DROP NOT KW_NULL",
"alter_op : col_opt alter_column_name SET NOT KW_NULL",
"alter_op : col_opt symbol_column_name KW_TYPE alter_data_type_or_domain",
"alter_op : col_opt symbol_column_name KW_TYPE non_array_type def_computed",
"alter_op : col_opt symbol_column_name def_computed",
"alter_op : col_opt symbol_column_name SET domain_default",
"alter_op : col_opt symbol_column_name DROP DEFAULT",
"alter_op : col_opt symbol_column_name restart_value_opt",
"alter_column_name : keyword_or_column",
"keyword_or_column : valid_symbol_name",
"keyword_or_column : ADMIN",
"keyword_or_column : COLUMN",
"keyword_or_column : EXTRACT",
"keyword_or_column : YEAR",
"keyword_or_column : MONTH",
"keyword_or_column : DAY",
"keyword_or_column : HOUR",
"keyword_or_column : MINUTE",
"keyword_or_column : SECOND",
"keyword_or_column : TIME",
"keyword_or_column : TIMESTAMP",
"keyword_or_column : CURRENT_DATE",
"keyword_or_column : CURRENT_TIME",
"keyword_or_column : CURRENT_TIMESTAMP",
"keyword_or_column : CURRENT_USER",
"keyword_or_column : CURRENT_ROLE",
"keyword_or_column : RECREATE",
"keyword_or_column : CURRENT_CONNECTION",
"keyword_or_column : CURRENT_TRANSACTION",
"keyword_or_column : BIGINT",
"keyword_or_column : CASE",
"keyword_or_column : RELEASE",
"keyword_or_column : ROW_COUNT",
"keyword_or_column : SAVEPOINT",
"keyword_or_column : OPEN",
"keyword_or_column : CLOSE",
"keyword_or_column : FETCH",
"keyword_or_column : ROWS",
"keyword_or_column : USING",
"keyword_or_column : CROSS",
"keyword_or_column : BIT_LENGTH",
"keyword_or_column : BOTH",
"keyword_or_column : CHAR_LENGTH",
"keyword_or_column : CHARACTER_LENGTH",
"keyword_or_column : COMMENT",
"keyword_or_column : LEADING",
"keyword_or_column : KW_LOWER",
"keyword_or_column : OCTET_LENGTH",
"keyword_or_column : TRAILING",
"keyword_or_column : TRIM",
"keyword_or_column : CONNECT",
"keyword_or_column : DISCONNECT",
"keyword_or_column : GLOBAL",
"keyword_or_column : INSENSITIVE",
"keyword_or_column : RECURSIVE",
"keyword_or_column : SENSITIVE",
"keyword_or_column : START",
"keyword_or_column : SIMILAR",
"keyword_or_column : KW_BOOLEAN",
"keyword_or_column : CORR",
"keyword_or_column : COVAR_POP",
"keyword_or_column : COVAR_SAMP",
"keyword_or_column : DELETING",
"keyword_or_column : DETERMINISTIC",
"keyword_or_column : KW_FALSE",
"keyword_or_column : INSERTING",
"keyword_or_column : OFFSET",
"keyword_or_column : OVER",
"keyword_or_column : REGR_AVGX",
"keyword_or_column : REGR_AVGY",
"keyword_or_column : REGR_COUNT",
"keyword_or_column : REGR_INTERCEPT",
"keyword_or_column : REGR_R2",
"keyword_or_column : REGR_SLOPE",
"keyword_or_column : REGR_SXX",
"keyword_or_column : REGR_SXY",
"keyword_or_column : REGR_SYY",
"keyword_or_column : RETURN",
"keyword_or_column : RDB_RECORD_VERSION",
"keyword_or_column : ROW",
"keyword_or_column : SCROLL",
"keyword_or_column : SQLSTATE",
"keyword_or_column : STDDEV_SAMP",
"keyword_or_column : STDDEV_POP",
"keyword_or_column : KW_TRUE",
"keyword_or_column : UNKNOWN",
"keyword_or_column : UPDATING",
"keyword_or_column : VAR_SAMP",
"keyword_or_column : VAR_POP",
"keyword_or_column : LOCALTIME",
"keyword_or_column : LOCALTIMESTAMP",
"col_opt : ALTER",
"col_opt : ALTER COLUMN",
"alter_data_type_or_domain : non_array_type",
"alter_data_type_or_domain : symbol_column_name",
"drop_behaviour :",
"drop_behaviour : RESTRICT",
"drop_behaviour : CASCADE",
"alter_index_clause : symbol_index_name ACTIVE",
"alter_index_clause : symbol_index_name INACTIVE",
"alter_udf_clause : symbol_UDF_name entry_op module_op",
"entry_op :",
"entry_op : ENTRY_POINT utf_string",
"module_op :",
"module_op : MODULE_NAME utf_string",
"alter_role_clause : symbol_role_name alter_role_enable AUTO ADMIN MAPPING",
"alter_role_enable : SET",
"alter_role_enable : DROP",
"alter_db : $$41 db_alter_clause",
"alter_db : alter_db $$43 db_alter_clause",
"$$88 :",
"db_alter_clause : ADD $$88 db_file_list",
"db_alter_clause : ADD KW_DIFFERENCE KW_FILE utf_string",
"db_alter_clause : DROP KW_DIFFERENCE KW_FILE",
"db_alter_clause : BEGIN BACKUP",
"db_alter_clause : END BACKUP",
"db_alter_clause : SET DEFAULT CHARACTER SET symbol_character_set_name",
"$$89 :",
"db_alter_clause : ENCRYPT WITH valid_symbol_name $$89 crypt_key_clause",
"db_alter_clause : DECRYPT",
"db_alter_clause : SET LINGER TO long_integer",
"db_alter_clause : DROP LINGER",
"crypt_key_clause :",
"crypt_key_clause : KEY valid_symbol_name",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position AS local_declaration_list full_proc_block",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position external_clause external_body_clause_opt",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position",
"trigger_type_opt : trigger_type_prefix trigger_type_suffix",
"trigger_type_opt :",
"drop : DROP drop_clause",
"drop_clause : EXCEPTION symbol_exception_name",
"drop_clause : INDEX symbol_index_name",
"drop_clause : PROCEDURE symbol_procedure_name",
"drop_clause : TABLE symbol_table_name",
"drop_clause : TRIGGER symbol_trigger_name",
"drop_clause : VIEW symbol_view_name",
"drop_clause : FILTER symbol_filter_name",
"drop_clause : KW_DOMAIN symbol_domain_name",
"drop_clause : EXTERNAL FUNCTION symbol_UDF_name",
"drop_clause : FUNCTION symbol_UDF_name",
"drop_clause : SHADOW pos_short_integer opt_no_file_delete",
"drop_clause : ROLE symbol_role_name",
"drop_clause : GENERATOR symbol_generator_name",
"drop_clause : SEQUENCE symbol_generator_name",
"drop_clause : COLLATION symbol_collation_name",
"drop_clause : USER symbol_user_name USING PLUGIN valid_symbol_name",
"drop_clause : USER symbol_user_name",
"drop_clause : PACKAGE symbol_package_name",
"drop_clause : PACKAGE BODY symbol_package_name",
"drop_clause : MAPPING $$27 drop_map_clause",
"drop_clause : GLOBAL MAPPING $$28 drop_map_clause",
"opt_no_file_delete :",
"opt_no_file_delete : PRESERVE KW_FILE",
"opt_no_file_delete : KW_DELETE KW_FILE",
"data_type : non_array_type",
"data_type : array_type",
"domain_or_non_array_type : domain_or_non_array_type_name",
"domain_or_non_array_type : domain_or_non_array_type_name NOT KW_NULL",
"domain_or_non_array_type_name : non_array_type",
"domain_or_non_array_type_name : domain_type",
"domain_type : KW_TYPE OF symbol_column_name",
"domain_type : KW_TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"domain_type : symbol_column_name",
"non_array_type : simple_type",
"non_array_type : blob_type",
"array_type : non_charset_simple_type '[' array_spec ']'",
"array_type : character_type '[' array_spec ']' charset_clause",
"array_spec : array_range",
"array_spec : array_spec ',' array_range",
"array_range : signed_long_integer",
"array_range : signed_long_integer ':' signed_long_integer",
"simple_type : non_charset_simple_type",
"simple_type : character_type charset_clause",
"non_charset_simple_type : national_character_type",
"non_charset_simple_type : numeric_type",
"non_charset_simple_type : float_type",
"non_charset_simple_type : BIGINT",
"non_charset_simple_type : integer_keyword",
"non_charset_simple_type : SMALLINT",
"non_charset_simple_type : DATE",
"non_charset_simple_type : TIME",
"non_charset_simple_type : TIMESTAMP",
"non_charset_simple_type : KW_BOOLEAN",
"integer_keyword : INTEGER",
"integer_keyword : KW_INT",
"$$90 :",
"$$91 :",
"blob_type : BLOB $$90 $$91 blob_subtype blob_segsize charset_clause",
"blob_type : BLOB '(' unsigned_short_integer ')'",
"blob_type : BLOB '(' unsigned_short_integer ',' signed_short_integer ')'",
"blob_type : BLOB '(' ',' signed_short_integer ')'",
"blob_segsize :",
"blob_segsize : SEGMENT KW_SIZE unsigned_short_integer",
"blob_subtype :",
"blob_subtype : SUB_TYPE signed_short_integer",
"blob_subtype : SUB_TYPE symbol_blob_subtype_name",
"charset_clause :",
"charset_clause : CHARACTER SET symbol_character_set_name",
"national_character_type : national_character_keyword '(' pos_short_integer ')'",
"national_character_type : national_character_keyword",
"national_character_type : national_character_keyword VARYING '(' pos_short_integer ')'",
"character_type : character_keyword '(' pos_short_integer ')'",
"character_type : character_keyword",
"character_type : varying_keyword '(' pos_short_integer ')'",
"varying_keyword : VARCHAR",
"varying_keyword : CHARACTER VARYING",
"varying_keyword : KW_CHAR VARYING",
"character_keyword : CHARACTER",
"character_keyword : KW_CHAR",
"national_character_keyword : NCHAR",
"national_character_keyword : NATIONAL CHARACTER",
"national_character_keyword : NATIONAL KW_CHAR",
"numeric_type : KW_NUMERIC prec_scale",
"numeric_type : decimal_keyword prec_scale",
"prec_scale :",
"prec_scale : '(' signed_long_integer ')'",
"prec_scale : '(' signed_long_integer ',' signed_long_integer ')'",
"decimal_keyword : DECIMAL",
"decimal_keyword : KW_DEC",
"float_type : KW_FLOAT precision_opt",
"float_type : KW_LONG KW_FLOAT precision_opt",
"float_type : REAL",
"float_type : KW_DOUBLE PRECISION",
"precision_opt :",
"precision_opt : '(' nonneg_short_integer ')'",
"savepoint : set_savepoint",
"savepoint : release_savepoint",
"savepoint : undo_savepoint",
"set_savepoint : SAVEPOINT symbol_savepoint_name",
"release_savepoint : RELEASE SAVEPOINT symbol_savepoint_name release_only_opt",
"release_only_opt :",
"release_only_opt : ONLY",
"undo_savepoint : ROLLBACK optional_work TO optional_savepoint symbol_savepoint_name",
"optional_savepoint :",
"optional_savepoint : SAVEPOINT",
"commit : COMMIT optional_work optional_retain",
"rollback : ROLLBACK optional_work optional_retain",
"optional_work :",
"optional_work : WORK",
"optional_retain :",
"optional_retain : RETAIN opt_snapshot",
"opt_snapshot :",
"opt_snapshot : SNAPSHOT",
"$$92 :",
"$$93 :",
"set_transaction : SET TRANSACTION $$92 $$93 tran_option_list_opt",
"set_role : SET ROLE valid_symbol_name",
"set_role : SET TRUSTED ROLE",
"tran_option_list_opt :",
"tran_option_list_opt : $$93 tran_option_list",
"tran_option_list : $$93 tran_option",
"$$94 :",
"tran_option_list : tran_option_list $$94 tran_option",
"tran_option : READ ONLY",
"tran_option : READ WRITE",
"tran_option : WAIT",
"tran_option : NO WAIT",
"tran_option : isolation_mode",
"tran_option : NO AUTO UNDO",
"tran_option : KW_IGNORE LIMBO",
"tran_option : RESTART REQUESTS",
"tran_option : LOCK TIMEOUT nonneg_short_integer",
"$$95 :",
"$$96 :",
"tran_option : RESERVING $$95 $$96 restr_list",
"isolation_mode : ISOLATION LEVEL iso_mode",
"isolation_mode : iso_mode",
"iso_mode : snap_shot",
"iso_mode : READ UNCOMMITTED version_mode",
"iso_mode : READ COMMITTED version_mode",
"snap_shot : SNAPSHOT",
"snap_shot : SNAPSHOT TABLE",
"snap_shot : SNAPSHOT TABLE STABILITY",
"version_mode :",
"version_mode : VERSION",
"version_mode : NO VERSION",
"lock_type :",
"lock_type : KW_SHARED",
"lock_type : PROTECTED",
"lock_mode : READ",
"lock_mode : WRITE",
"restr_list : restr_option",
"restr_list : restr_list ',' restr_option",
"restr_option : table_list table_lock",
"table_lock :",
"table_lock : FOR lock_type lock_mode",
"table_list : symbol_table_name",
"table_list : table_list ',' symbol_table_name",
"set_statistics : SET STATISTICS INDEX symbol_index_name",
"comment : COMMENT ON ddl_type0 IS ddl_desc",
"comment : COMMENT ON ddl_type1 symbol_ddl_name IS ddl_desc",
"comment : COMMENT ON ddl_type2 symbol_ddl_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type3 ddl_qualified_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type4 ddl_qualified_name IS ddl_desc",
"comment : comment_on_user",
"$$97 :",
"$$98 :",
"comment_on_user : COMMENT ON USER symbol_user_name $$97 $$98 opt_use_plugin IS ddl_desc",
"opt_use_plugin :",
"opt_use_plugin : $$98 use_plugin",
"ddl_type0 : DATABASE",
"ddl_type1 : KW_DOMAIN",
"ddl_type1 : TABLE",
"ddl_type1 : VIEW",
"ddl_type1 : TRIGGER",
"ddl_type1 : FILTER",
"ddl_type1 : EXCEPTION",
"ddl_type1 : GENERATOR",
"ddl_type1 : SEQUENCE",
"ddl_type1 : INDEX",
"ddl_type1 : ROLE",
"ddl_type1 : CHARACTER SET",
"ddl_type1 : COLLATION",
"ddl_type1 : PACKAGE",
"ddl_type2 : COLUMN",
"ddl_type3 : PARAMETER",
"ddl_type3 : PROCEDURE PARAMETER",
"ddl_type3 : FUNCTION PARAMETER",
"ddl_type4 : PROCEDURE",
"ddl_type4 : EXTERNAL FUNCTION",
"ddl_type4 : FUNCTION",
"ddl_subname : '.' symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name '.' symbol_ddl_name",
"ddl_desc : utf_string",
"ddl_desc : KW_NULL",
"select : select_expr for_update_clause lock_clause",
"for_update_clause :",
"for_update_clause : FOR UPDATE for_update_list",
"for_update_list :",
"for_update_list : OF column_list",
"lock_clause :",
"lock_clause : WITH LOCK",
"select_expr : with_clause select_expr_body order_clause rows_clause",
"select_expr : with_clause select_expr_body order_clause result_offset_clause fetch_first_clause",
"with_clause :",
"with_clause : WITH RECURSIVE with_list",
"with_clause : WITH with_list",
"with_list : with_item",
"with_list : with_list ',' with_item",
"with_item : symbol_table_alias_name derived_column_list AS '(' select_expr ')'",
"column_select : select_expr",
"column_singleton : column_select",
"select_expr_body : query_term",
"select_expr_body : select_expr_body UNION distinct_noise query_term",
"select_expr_body : select_expr_body UNION ALL query_term",
"query_term : query_spec",
"query_spec : SELECT limit_clause distinct_clause select_list from_clause where_clause group_clause having_clause plan_clause",
"limit_clause :",
"limit_clause : first_clause skip_clause",
"limit_clause : first_clause",
"limit_clause : skip_clause",
"first_clause : FIRST long_integer",
"first_clause : FIRST '(' value ')'",
"first_clause : FIRST parameter",
"skip_clause : SKIP long_integer",
"skip_clause : SKIP '(' value ')'",
"skip_clause : SKIP parameter",
"distinct_clause : DISTINCT",
"distinct_clause : all_noise",
"select_list : select_items",
"select_list : '*'",
"select_items : select_item",
"select_items : select_items ',' select_item",
"select_item : value_opt_alias",
"select_item : symbol_table_alias_name '.' '*'",
"value_opt_alias : value",
"value_opt_alias : value as_noise symbol_item_alias_name",
"as_noise :",
"as_noise : AS",
"from_clause : FROM from_list",
"from_list : table_reference",
"from_list : from_list ',' table_reference",
"table_reference : joined_table",
"table_reference : table_primary",
"table_primary : table_proc",
"table_primary : derived_table",
"table_primary : '(' joined_table ')'",
"derived_table : '(' select_expr ')' as_noise correlation_name derived_column_list",
"correlation_name :",
"correlation_name : symbol_table_alias_name",
"derived_column_list :",
"derived_column_list : '(' alias_list ')'",
"alias_list : symbol_item_alias_name",
"alias_list : alias_list ',' symbol_item_alias_name",
"joined_table : cross_join",
"joined_table : natural_join",
"joined_table : qualified_join",
"cross_join : table_reference CROSS JOIN table_primary",
"natural_join : table_reference NATURAL join_type JOIN table_primary",
"qualified_join : table_reference join_type JOIN table_reference join_condition",
"qualified_join : table_reference join_type JOIN table_reference named_columns_join",
"join_condition : ON search_condition",
"named_columns_join : USING '(' column_list ')'",
"table_proc : symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_procedure_name table_proc_inputs",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs",
"table_proc_inputs :",
"table_proc_inputs : '(' value_list ')'",
"table_name : simple_table_name",
"table_name : symbol_table_name as_noise symbol_table_alias_name",
"simple_table_name : symbol_table_name",
"join_type :",
"join_type : INNER",
"join_type : LEFT outer_noise",
"join_type : RIGHT outer_noise",
"join_type : FULL outer_noise",
"outer_noise :",
"outer_noise : OUTER",
"group_clause :",
"group_clause : GROUP BY group_by_list",
"group_by_list : group_by_item",
"group_by_list : group_by_list ',' group_by_item",
"group_by_item : value",
"having_clause :",
"having_clause : HAVING search_condition",
"where_clause :",
"where_clause : WHERE search_condition",
"plan_clause :",
"plan_clause : PLAN plan_expression",
"$$99 :",
"$$100 :",
"plan_expression : plan_type $$99 '(' $$100 plan_item_list ')'",
"plan_type :",
"plan_type : JOIN",
"plan_type : SORT MERGE",
"plan_type : MERGE",
"plan_type : HASH",
"plan_type : SORT",
"plan_item_list : plan_item",
"plan_item_list : plan_item_list ',' plan_item",
"plan_item : table_or_alias_list access_type",
"plan_item : plan_expression",
"table_or_alias_list : symbol_table_name",
"table_or_alias_list : table_or_alias_list symbol_table_name",
"access_type : NATURAL",
"$$101 :",
"$$102 :",
"access_type : INDEX $$101 '(' $$102 index_list ')'",
"$$103 :",
"access_type : ORDER $$103 symbol_index_name $$102 extra_indices_opt",
"index_list : symbol_index_name",
"index_list : index_list ',' symbol_index_name",
"extra_indices_opt :",
"$$104 :",
"extra_indices_opt : INDEX '(' $$104 index_list ')'",
"order_clause :",
"order_clause : ORDER BY order_list",
"order_list : order_item",
"order_list : order_list ',' order_item",
"order_item : value order_direction nulls_clause",
"order_direction :",
"order_direction : ASC",
"order_direction : DESC",
"nulls_clause :",
"nulls_clause : NULLS nulls_placement",
"nulls_placement : FIRST",
"nulls_placement : LAST",
"rows_clause : ROWS value",
"rows_clause : ROWS value TO value",
"rows_clause_optional :",
"rows_clause_optional : rows_clause",
"row_noise : ROW",
"row_noise : ROWS",
"result_offset_clause :",
"result_offset_clause : OFFSET simple_value_spec row_noise",
"first_next_noise : FIRST",
"first_next_noise : NEXT",
"fetch_first_clause :",
"fetch_first_clause : FETCH first_next_noise simple_value_spec row_noise ONLY",
"fetch_first_clause : FETCH first_next_noise row_noise ONLY",
"$$105 :",
"insert : insert_start $$105 ins_column_parens_opt VALUES '(' value_list ')' returning_clause",
"insert : insert_start $$105 ins_column_parens_opt select_expr returning_clause",
"insert : insert_start DEFAULT VALUES returning_clause",
"insert_start : INSERT INTO simple_table_name",
"$$106 :",
"$$107 :",
"merge : MERGE INTO table_name USING table_reference ON search_condition $$106 $$107 merge_when_clause returning_clause",
"merge_when_clause : $$107 merge_when_matched_clause",
"merge_when_clause : $$107 merge_when_not_matched_clause",
"$$108 :",
"merge_when_clause : merge_when_clause $$108 merge_when_matched_clause",
"merge_when_clause : merge_when_clause $$108 merge_when_not_matched_clause",
"$$109 :",
"$$110 :",
"merge_when_matched_clause : WHEN MATCHED $$109 $$110 merge_update_specification",
"$$111 :",
"$$112 :",
"merge_when_not_matched_clause : WHEN NOT MATCHED $$111 $$112 merge_insert_specification",
"merge_update_specification : THEN UPDATE SET assignments",
"merge_update_specification : AND search_condition THEN UPDATE SET assignments",
"merge_update_specification : THEN KW_DELETE",
"merge_update_specification : AND search_condition THEN KW_DELETE",
"$$113 :",
"merge_insert_specification : THEN INSERT $$113 ins_column_parens_opt VALUES '(' value_list ')'",
"$$114 :",
"merge_insert_specification : AND search_condition THEN INSERT $$114 ins_column_parens_opt VALUES '(' value_list ')'",
"delete : delete_searched",
"delete : delete_positioned",
"delete_searched : KW_DELETE FROM table_name where_clause plan_clause order_clause rows_clause_optional returning_clause",
"delete_positioned : KW_DELETE FROM table_name cursor_clause returning_clause",
"update : update_searched",
"update : update_positioned",
"update_searched : UPDATE table_name SET assignments where_clause plan_clause order_clause rows_clause_optional returning_clause",
"update_positioned : UPDATE table_name SET assignments cursor_clause returning_clause",
"$$115 :",
"$$116 :",
"$$117 :",
"update_or_insert : UPDATE OR INSERT INTO simple_table_name $$115 $$116 ins_column_parens_opt VALUES '(' value_list ')' $$117 update_or_insert_matching_opt returning_clause",
"update_or_insert_matching_opt :",
"$$118 :",
"update_or_insert_matching_opt : MATCHING $$118 ins_column_parens",
"returning_clause :",
"returning_clause : RETURNING value_opt_alias_list",
"returning_clause : RETURNING value_opt_alias_list INTO variable_list",
"value_opt_alias_list : value_opt_alias",
"value_opt_alias_list : value_opt_alias_list ',' value_opt_alias",
"cursor_clause : WHERE CURRENT OF symbol_cursor_name",
"assignments : assignment",
"assignments : assignments ',' assignment",
"assignment : update_column_name '=' value",
"exec_function : udf",
"exec_function : non_aggregate_function",
"column_parens_opt :",
"column_parens_opt : column_parens",
"column_parens : '(' column_list ')'",
"column_list : simple_column_name",
"column_list : column_list ',' simple_column_name",
"ins_column_parens_opt :",
"$$119 :",
"ins_column_parens_opt : $$119 ins_column_parens",
"ins_column_parens : '(' $$118 ins_column_list ')'",
"ins_column_list : update_column_name",
"ins_column_list : ins_column_list ',' update_column_name",
"column_name : simple_column_name",
"column_name : symbol_table_alias_name '.' symbol_column_name",
"column_name : ':' symbol_table_alias_name '.' symbol_column_name",
"simple_column_name : symbol_column_name",
"update_column_name : simple_column_name",
"update_column_name : symbol_table_alias_name '.' symbol_column_name",
"search_condition : value",
"boolean_value_expression : predicate",
"boolean_value_expression : value OR value",
"boolean_value_expression : value AND value",
"boolean_value_expression : NOT value",
"boolean_value_expression : '(' boolean_value_expression ')'",
"boolean_value_expression : value IS boolean_literal",
"boolean_value_expression : value IS NOT boolean_literal",
"predicate : comparison_predicate",
"predicate : distinct_predicate",
"predicate : between_predicate",
"predicate : binary_pattern_predicate",
"predicate : ternary_pattern_predicate",
"predicate : in_predicate",
"predicate : null_predicate",
"predicate : quantified_predicate",
"predicate : exists_predicate",
"predicate : singular_predicate",
"predicate : trigger_action_predicate",
"comparison_predicate : value comparison_operator value",
"comparison_operator : '='",
"comparison_operator : '<'",
"comparison_operator : '>'",
"comparison_operator : GEQ",
"comparison_operator : LEQ",
"comparison_operator : NOT_GTR",
"comparison_operator : NOT_LSS",
"comparison_operator : NEQ",
"quantified_predicate : value comparison_operator quantified_flag '(' column_select ')'",
"quantified_flag : ALL",
"quantified_flag : SOME",
"quantified_flag : ANY",
"distinct_predicate : value IS DISTINCT FROM value",
"distinct_predicate : value IS NOT DISTINCT FROM value",
"between_predicate : value BETWEEN value_between AND value_between",
"between_predicate : value NOT BETWEEN value_between AND value_between",
"value_between : value_primary",
"value_between : '(' boolean_value_expression ')'",
"binary_pattern_predicate : value binary_pattern_operator value",
"binary_pattern_predicate : value NOT binary_pattern_operator value",
"binary_pattern_operator : CONTAINING",
"binary_pattern_operator : STARTING",
"binary_pattern_operator : STARTING WITH",
"ternary_pattern_predicate : value LIKE value",
"ternary_pattern_predicate : value LIKE value ESCAPE value",
"ternary_pattern_predicate : value NOT LIKE value",
"ternary_pattern_predicate : value NOT LIKE value ESCAPE value",
"ternary_pattern_predicate : value SIMILAR TO value",
"ternary_pattern_predicate : value SIMILAR TO value ESCAPE value",
"ternary_pattern_predicate : value NOT SIMILAR TO value",
"ternary_pattern_predicate : value NOT SIMILAR TO value ESCAPE value",
"in_predicate : value KW_IN in_predicate_value",
"in_predicate : value NOT KW_IN in_predicate_value",
"exists_predicate : EXISTS '(' select_expr ')'",
"singular_predicate : SINGULAR '(' select_expr ')'",
"trigger_action_predicate : INSERTING",
"trigger_action_predicate : UPDATING",
"trigger_action_predicate : DELETING",
"null_predicate : value IS KW_NULL",
"null_predicate : value IS UNKNOWN",
"null_predicate : value IS NOT KW_NULL",
"null_predicate : value IS NOT UNKNOWN",
"in_predicate_value : table_subquery",
"in_predicate_value : '(' value_list ')'",
"table_subquery : '(' column_select ')'",
"$$120 :",
"$$121 :",
"create_user_clause : symbol_user_name $$120 $$98 user_fixed_list_opt $$121 user_var_opts",
"$$122 :",
"alter_user_clause : symbol_user_name set_noise $$122 $$98 user_fixed_list_opt $$121 user_var_opts",
"$$123 :",
"alter_cur_user_clause : set_noise $$123 $$98 user_fixed_list_opt $$121 user_var_opts",
"$$124 :",
"replace_user_clause : symbol_user_name set_noise $$124 $$98 user_fixed_list_opt $$121 user_var_opts",
"set_noise :",
"set_noise : SET",
"user_fixed_list_opt :",
"user_fixed_list_opt : $$98 user_fixed_list",
"user_fixed_list : $$98 user_fixed_option",
"$$125 :",
"user_fixed_list : user_fixed_list $$125 user_fixed_option",
"user_fixed_option : FIRSTNAME utf_string",
"user_fixed_option : MIDDLENAME utf_string",
"user_fixed_option : LASTNAME utf_string",
"user_fixed_option : PASSWORD utf_string",
"user_fixed_option : GRANT ADMIN ROLE",
"user_fixed_option : REVOKE ADMIN ROLE",
"user_fixed_option : ACTIVE",
"user_fixed_option : INACTIVE",
"user_fixed_option : $$98 use_plugin",
"use_plugin : USING PLUGIN valid_symbol_name",
"user_var_opts :",
"user_var_opts : TAGS '(' $$121 user_var_list ')'",
"user_var_list : $$98 user_var_option",
"user_var_list : user_var_list ',' $$121 user_var_option",
"user_var_option : valid_symbol_name '=' utf_string",
"user_var_option : DROP valid_symbol_name",
"$$126 :",
"$$127 :",
"$$128 :",
"create_map_clause : $$126 map_clause $$127 $$128 map_to",
"$$129 :",
"$$130 :",
"alter_map_clause : $$129 map_clause $$130 $$128 map_to",
"$$131 :",
"$$132 :",
"replace_map_clause : $$131 map_clause $$132 $$128 map_to",
"drop_map_clause : map_name",
"$$133 :",
"$$134 :",
"$$135 :",
"map_clause : map_name $$133 USING $$134 map_using FROM $$135 map_from",
"map_name : valid_symbol_name",
"map_from : map_from_symbol_name map_logoninfo",
"map_from : ANY map_from_symbol_name",
"map_from_symbol_name : valid_symbol_name",
"map_from_symbol_name : USER",
"map_from_symbol_name : GROUP",
"map_logoninfo : sql_string",
"map_logoninfo : valid_symbol_name",
"map_using : PLUGIN valid_symbol_name map_in",
"map_using : ANY PLUGIN map_in",
"map_using : ANY PLUGIN SERVERWIDE",
"map_using : MAPPING map_in",
"map_using : '*' map_in",
"map_in :",
"map_in : KW_IN valid_symbol_name",
"map_to : TO map_role valid_symbol_name",
"map_to : TO map_role",
"map_role : ROLE",
"map_role : USER",
"value : value_primary",
"value : boolean_value_expression",
"value_primary : nonparenthesized_value",
"value_primary : '(' value_primary ')'",
"simple_value_spec : constant",
"simple_value_spec : variable",
"simple_value_spec : parameter",
"nonparenthesized_value : column_name",
"nonparenthesized_value : array_element",
"nonparenthesized_value : function",
"nonparenthesized_value : u_constant",
"nonparenthesized_value : boolean_literal",
"nonparenthesized_value : parameter",
"nonparenthesized_value : variable",
"nonparenthesized_value : cast_specification",
"nonparenthesized_value : case_expression",
"nonparenthesized_value : next_value_expression",
"nonparenthesized_value : udf",
"nonparenthesized_value : '-' value_primary",
"nonparenthesized_value : '+' value_primary",
"nonparenthesized_value : value_primary '+' value_primary",
"nonparenthesized_value : value_primary CONCATENATE value_primary",
"nonparenthesized_value : value_primary COLLATE symbol_collation_name",
"nonparenthesized_value : value_primary '-' value_primary",
"nonparenthesized_value : value_primary '*' value_primary",
"nonparenthesized_value : value_primary '/' value_primary",
"nonparenthesized_value : '(' column_singleton ')'",
"nonparenthesized_value : current_user",
"nonparenthesized_value : current_role",
"nonparenthesized_value : internal_info",
"nonparenthesized_value : recordKeyType",
"nonparenthesized_value : symbol_table_alias_name '.' recordKeyType",
"nonparenthesized_value : KW_VALUE",
"nonparenthesized_value : datetime_value_expression",
"nonparenthesized_value : null_value",
"recordKeyType : DB_KEY",
"recordKeyType : RDB_RECORD_VERSION",
"datetime_value_expression : CURRENT_DATE",
"datetime_value_expression : CURRENT_TIME time_precision_opt",
"datetime_value_expression : LOCALTIME time_precision_opt",
"datetime_value_expression : CURRENT_TIMESTAMP timestamp_precision_opt",
"datetime_value_expression : LOCALTIMESTAMP timestamp_precision_opt",
"time_precision_opt :",
"time_precision_opt : '(' nonneg_short_integer ')'",
"timestamp_precision_opt :",
"timestamp_precision_opt : '(' nonneg_short_integer ')'",
"array_element : column_name '[' value_list ']'",
"value_list_opt :",
"value_list_opt : value_list",
"value_list : value",
"value_list : value_list ',' value",
"constant : u_constant",
"constant : '-' u_numeric_constant",
"constant : boolean_literal",
"u_numeric_constant : NUMBER",
"u_numeric_constant : FLOAT_NUMBER",
"u_numeric_constant : NUMBER64BIT",
"u_numeric_constant : SCALEDINT",
"u_constant : u_numeric_constant",
"u_constant : sql_string",
"u_constant : DATE STRING",
"u_constant : TIME STRING",
"u_constant : TIMESTAMP STRING",
"boolean_literal : KW_FALSE",
"boolean_literal : KW_TRUE",
"parameter : '?'",
"current_user : USER",
"current_user : CURRENT_USER",
"current_role : CURRENT_ROLE",
"internal_info : CURRENT_CONNECTION",
"internal_info : CURRENT_TRANSACTION",
"internal_info : GDSCODE",
"internal_info : SQLCODE",
"internal_info : SQLSTATE",
"internal_info : ROW_COUNT",
"sql_string : STRING",
"sql_string : INTRODUCER STRING",
"utf_string : sql_string",
"signed_short_integer : nonneg_short_integer",
"signed_short_integer : '-' neg_short_integer",
"nonneg_short_integer : NUMBER",
"neg_short_integer : NUMBER",
"pos_short_integer : nonneg_short_integer",
"unsigned_short_integer : NUMBER",
"signed_long_integer : long_integer",
"signed_long_integer : '-' long_integer",
"long_integer : NUMBER",
"function : aggregate_function",
"function : non_aggregate_function",
"function : over_clause",
"non_aggregate_function : numeric_value_function",
"non_aggregate_function : string_value_function",
"non_aggregate_function : system_function_expression",
"aggregate_function : COUNT '(' '*' ')'",
"aggregate_function : COUNT '(' all_noise value ')'",
"aggregate_function : COUNT '(' DISTINCT value ')'",
"aggregate_function : SUM '(' all_noise value ')'",
"aggregate_function : SUM '(' DISTINCT value ')'",
"aggregate_function : AVG '(' all_noise value ')'",
"aggregate_function : AVG '(' DISTINCT value ')'",
"aggregate_function : MINIMUM '(' all_noise value ')'",
"aggregate_function : MINIMUM '(' DISTINCT value ')'",
"aggregate_function : MAXIMUM '(' all_noise value ')'",
"aggregate_function : MAXIMUM '(' DISTINCT value ')'",
"aggregate_function : LIST '(' all_noise value delimiter_opt ')'",
"aggregate_function : LIST '(' DISTINCT value delimiter_opt ')'",
"aggregate_function : STDDEV_SAMP '(' value ')'",
"aggregate_function : STDDEV_POP '(' value ')'",
"aggregate_function : VAR_SAMP '(' value ')'",
"aggregate_function : VAR_POP '(' value ')'",
"aggregate_function : COVAR_SAMP '(' value ',' value ')'",
"aggregate_function : COVAR_POP '(' value ',' value ')'",
"aggregate_function : CORR '(' value ',' value ')'",
"aggregate_function : REGR_AVGX '(' value ',' value ')'",
"aggregate_function : REGR_AVGY '(' value ',' value ')'",
"aggregate_function : REGR_COUNT '(' value ',' value ')'",
"aggregate_function : REGR_INTERCEPT '(' value ',' value ')'",
"aggregate_function : REGR_R2 '(' value ',' value ')'",
"aggregate_function : REGR_SLOPE '(' value ',' value ')'",
"aggregate_function : REGR_SXX '(' value ',' value ')'",
"aggregate_function : REGR_SXY '(' value ',' value ')'",
"aggregate_function : REGR_SYY '(' value ',' value ')'",
"window_function : DENSE_RANK '(' ')'",
"window_function : RANK '(' ')'",
"window_function : ROW_NUMBER '(' ')'",
"window_function : FIRST_VALUE '(' value ')'",
"window_function : LAST_VALUE '(' value ')'",
"window_function : NTH_VALUE '(' value ',' value ')' nth_from",
"window_function : LAG '(' value ',' value ',' value ')'",
"window_function : LAG '(' value ',' value ')'",
"window_function : LAG '(' value ')'",
"window_function : LEAD '(' value ',' value ',' value ')'",
"window_function : LEAD '(' value ',' value ')'",
"window_function : LEAD '(' value ')'",
"nth_from :",
"nth_from : FROM FIRST",
"nth_from : FROM LAST",
"aggregate_window_function : aggregate_function",
"aggregate_window_function : window_function",
"over_clause : aggregate_window_function OVER '(' window_partition_opt order_clause ')'",
"window_partition_opt :",
"window_partition_opt : PARTITION BY value_list",
"delimiter_opt :",
"delimiter_opt : ',' value",
"numeric_value_function : extract_expression",
"numeric_value_function : length_expression",
"extract_expression : EXTRACT '(' timestamp_part FROM value ')'",
"length_expression : bit_length_expression",
"length_expression : char_length_expression",
"length_expression : octet_length_expression",
"bit_length_expression : BIT_LENGTH '(' value ')'",
"char_length_expression : CHAR_LENGTH '(' value ')'",
"char_length_expression : CHARACTER_LENGTH '(' value ')'",
"octet_length_expression : OCTET_LENGTH '(' value ')'",
"system_function_expression : system_function_std_syntax '(' value_list_opt ')'",
"system_function_expression : system_function_special_syntax",
"system_function_std_syntax : ABS",
"system_function_std_syntax : ACOS",
"system_function_std_syntax : ACOSH",
"system_function_std_syntax : ASCII_CHAR",
"system_function_std_syntax : ASCII_VAL",
"system_function_std_syntax : ASIN",
"system_function_std_syntax : ASINH",
"system_function_std_syntax : ATAN",
"system_function_std_syntax : ATAN2",
"system_function_std_syntax : ATANH",
"system_function_std_syntax : BIN_AND",
"system_function_std_syntax : BIN_NOT",
"system_function_std_syntax : BIN_OR",
"system_function_std_syntax : BIN_SHL",
"system_function_std_syntax : BIN_SHR",
"system_function_std_syntax : BIN_XOR",
"system_function_std_syntax : CEIL",
"system_function_std_syntax : CHAR_TO_UUID",
"system_function_std_syntax : COS",
"system_function_std_syntax : COSH",
"system_function_std_syntax : COT",
"system_function_std_syntax : EXP",
"system_function_std_syntax : FLOOR",
"system_function_std_syntax : GEN_UUID",
"system_function_std_syntax : HASH",
"system_function_std_syntax : LEFT",
"system_function_std_syntax : LN",
"system_function_std_syntax : LOG",
"system_function_std_syntax : LOG10",
"system_function_std_syntax : LPAD",
"system_function_std_syntax : MAXVALUE",
"system_function_std_syntax : MINVALUE",
"system_function_std_syntax : MOD",
"system_function_std_syntax : PI",
"system_function_std_syntax : POWER",
"system_function_std_syntax : RAND",
"system_function_std_syntax : RDB_GET_CONTEXT",
"system_function_std_syntax : RDB_SET_CONTEXT",
"system_function_std_syntax : REPLACE",
"system_function_std_syntax : REVERSE",
"system_function_std_syntax : RIGHT",
"system_function_std_syntax : ROUND",
"system_function_std_syntax : RPAD",
"system_function_std_syntax : SIGN",
"system_function_std_syntax : SIN",
"system_function_std_syntax : SINH",
"system_function_std_syntax : SQRT",
"system_function_std_syntax : TAN",
"system_function_std_syntax : TANH",
"system_function_std_syntax : TRUNC",
"system_function_std_syntax : UUID_TO_CHAR",
"system_function_special_syntax : DATEADD '(' value timestamp_part TO value ')'",
"system_function_special_syntax : DATEADD '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part FROM value TO value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value FOR value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value ')'",
"system_function_special_syntax : POSITION '(' value KW_IN value ')'",
"system_function_special_syntax : POSITION '(' value_list_opt ')'",
"string_value_function : substring_function",
"string_value_function : trim_function",
"string_value_function : KW_UPPER '(' value ')'",
"string_value_function : KW_LOWER '(' value ')'",
"substring_function : SUBSTRING '(' value FROM value string_length_opt ')'",
"substring_function : SUBSTRING '(' value SIMILAR value ESCAPE value ')'",
"string_length_opt :",
"string_length_opt : FOR value",
"trim_function : TRIM '(' trim_specification value FROM value ')'",
"trim_function : TRIM '(' value FROM value ')'",
"trim_function : TRIM '(' trim_specification FROM value ')'",
"trim_function : TRIM '(' value ')'",
"trim_specification : BOTH",
"trim_specification : TRAILING",
"trim_specification : LEADING",
"udf : symbol_UDF_call_name '(' value_list ')'",
"udf : symbol_UDF_call_name '(' ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' value_list ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' ')'",
"cast_specification : CAST '(' value AS data_type_descriptor ')'",
"case_expression : case_abbreviation",
"case_expression : case_specification",
"case_abbreviation : NULLIF '(' value ',' value ')'",
"case_abbreviation : IIF '(' search_condition ',' value ',' value ')'",
"case_abbreviation : COALESCE '(' value ',' value_list ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ',' value ')'",
"case_specification : simple_case",
"case_specification : searched_case",
"$$136 :",
"$$137 :",
"$$138 :",
"simple_case : CASE case_operand $$136 $$137 $$138 simple_when_clause else_case_result_opt END",
"simple_when_clause : WHEN when_operand THEN case_result",
"simple_when_clause : simple_when_clause WHEN when_operand THEN case_result",
"else_case_result_opt :",
"else_case_result_opt : ELSE case_result",
"searched_case : CASE searched_when_clause END",
"searched_case : CASE searched_when_clause ELSE case_result END",
"searched_when_clause : WHEN search_condition THEN case_result",
"searched_when_clause : searched_when_clause WHEN search_condition THEN case_result",
"when_operand : value",
"case_operand : value",
"case_result : value",
"decode_pairs : value ',' value",
"decode_pairs : decode_pairs ',' value ',' value",
"next_value_expression : NEXT KW_VALUE FOR symbol_generator_name",
"next_value_expression : GEN_ID '(' symbol_generator_name ',' value ')'",
"timestamp_part : YEAR",
"timestamp_part : MONTH",
"timestamp_part : DAY",
"timestamp_part : HOUR",
"timestamp_part : MINUTE",
"timestamp_part : SECOND",
"timestamp_part : MILLISECOND",
"timestamp_part : WEEK",
"timestamp_part : WEEKDAY",
"timestamp_part : YEARDAY",
"all_noise :",
"all_noise : ALL",
"distinct_noise :",
"distinct_noise : DISTINCT",
"null_value : KW_NULL",
"null_value : UNKNOWN",
"symbol_UDF_call_name : SYMBOL",
"symbol_UDF_name : valid_symbol_name",
"symbol_blob_subtype_name : valid_symbol_name",
"symbol_character_set_name : valid_symbol_name",
"symbol_collation_name : valid_symbol_name",
"symbol_column_name : valid_symbol_name",
"symbol_constraint_name : valid_symbol_name",
"symbol_cursor_name : valid_symbol_name",
"symbol_domain_name : valid_symbol_name",
"symbol_exception_name : valid_symbol_name",
"symbol_filter_name : valid_symbol_name",
"symbol_gdscode_name : valid_symbol_name",
"symbol_generator_name : valid_symbol_name",
"symbol_index_name : valid_symbol_name",
"symbol_item_alias_name : valid_symbol_name",
"symbol_label_name : valid_symbol_name",
"symbol_ddl_name : valid_symbol_name",
"symbol_procedure_name : valid_symbol_name",
"symbol_role_name : valid_symbol_name",
"symbol_table_alias_name : valid_symbol_name",
"symbol_table_name : valid_symbol_name",
"symbol_trigger_name : valid_symbol_name",
"symbol_user_name : valid_symbol_name",
"symbol_variable_name : valid_symbol_name",
"symbol_view_name : valid_symbol_name",
"symbol_savepoint_name : valid_symbol_name",
"symbol_package_name : valid_symbol_name",
"valid_symbol_name : SYMBOL",
"valid_symbol_name : non_reserved_word",
"non_reserved_word : ACTION",
"non_reserved_word : CASCADE",
"non_reserved_word : FREE_IT",
"non_reserved_word : RESTRICT",
"non_reserved_word : ROLE",
"non_reserved_word : KW_TYPE",
"non_reserved_word : KW_BREAK",
"non_reserved_word : KW_DESCRIPTOR",
"non_reserved_word : SUBSTRING",
"non_reserved_word : COALESCE",
"non_reserved_word : LAST",
"non_reserved_word : LEAVE",
"non_reserved_word : LOCK",
"non_reserved_word : NULLIF",
"non_reserved_word : NULLS",
"non_reserved_word : STATEMENT",
"non_reserved_word : FIRST",
"non_reserved_word : SKIP",
"non_reserved_word : BLOCK",
"non_reserved_word : BACKUP",
"non_reserved_word : KW_DIFFERENCE",
"non_reserved_word : IIF",
"non_reserved_word : SCALAR_ARRAY",
"non_reserved_word : WEEKDAY",
"non_reserved_word : YEARDAY",
"non_reserved_word : SEQUENCE",
"non_reserved_word : NEXT",
"non_reserved_word : RESTART",
"non_reserved_word : COLLATION",
"non_reserved_word : RETURNING",
"non_reserved_word : KW_IGNORE",
"non_reserved_word : LIMBO",
"non_reserved_word : UNDO",
"non_reserved_word : REQUESTS",
"non_reserved_word : TIMEOUT",
"non_reserved_word : ABS",
"non_reserved_word : ACCENT",
"non_reserved_word : ACOS",
"non_reserved_word : ALWAYS",
"non_reserved_word : ASCII_CHAR",
"non_reserved_word : ASCII_VAL",
"non_reserved_word : ASIN",
"non_reserved_word : ATAN",
"non_reserved_word : ATAN2",
"non_reserved_word : BIN_AND",
"non_reserved_word : BIN_OR",
"non_reserved_word : BIN_SHL",
"non_reserved_word : BIN_SHR",
"non_reserved_word : BIN_XOR",
"non_reserved_word : CEIL",
"non_reserved_word : COS",
"non_reserved_word : COSH",
"non_reserved_word : COT",
"non_reserved_word : DATEADD",
"non_reserved_word : DATEDIFF",
"non_reserved_word : DECODE",
"non_reserved_word : EXP",
"non_reserved_word : FLOOR",
"non_reserved_word : GEN_UUID",
"non_reserved_word : GENERATED",
"non_reserved_word : HASH",
"non_reserved_word : LIST",
"non_reserved_word : LN",
"non_reserved_word : LOG",
"non_reserved_word : LOG10",
"non_reserved_word : LPAD",
"non_reserved_word : MATCHED",
"non_reserved_word : MATCHING",
"non_reserved_word : MAXVALUE",
"non_reserved_word : MILLISECOND",
"non_reserved_word : MINVALUE",
"non_reserved_word : MOD",
"non_reserved_word : OVERLAY",
"non_reserved_word : PAD",
"non_reserved_word : PI",
"non_reserved_word : PLACING",
"non_reserved_word : POWER",
"non_reserved_word : PRESERVE",
"non_reserved_word : RAND",
"non_reserved_word : REPLACE",
"non_reserved_word : REVERSE",
"non_reserved_word : ROUND",
"non_reserved_word : RPAD",
"non_reserved_word : SIGN",
"non_reserved_word : SIN",
"non_reserved_word : SINH",
"non_reserved_word : SPACE",
"non_reserved_word : SQRT",
"non_reserved_word : TAN",
"non_reserved_word : TANH",
"non_reserved_word : TEMPORARY",
"non_reserved_word : TRUNC",
"non_reserved_word : WEEK",
"non_reserved_word : AUTONOMOUS",
"non_reserved_word : CHAR_TO_UUID",
"non_reserved_word : FIRSTNAME",
"non_reserved_word : MIDDLENAME",
"non_reserved_word : LASTNAME",
"non_reserved_word : MAPPING",
"non_reserved_word : OS_NAME",
"non_reserved_word : UUID_TO_CHAR",
"non_reserved_word : GRANTED",
"non_reserved_word : CALLER",
"non_reserved_word : COMMON",
"non_reserved_word : DATA",
"non_reserved_word : SOURCE",
"non_reserved_word : TWO_PHASE",
"non_reserved_word : BIN_NOT",
"non_reserved_word : ACTIVE",
"non_reserved_word : AFTER",
"non_reserved_word : ASC",
"non_reserved_word : AUTO",
"non_reserved_word : BEFORE",
"non_reserved_word : COMMITTED",
"non_reserved_word : COMPUTED",
"non_reserved_word : CONDITIONAL",
"non_reserved_word : CONTAINING",
"non_reserved_word : CSTRING",
"non_reserved_word : DATABASE",
"non_reserved_word : DESC",
"non_reserved_word : DO",
"non_reserved_word : KW_DOMAIN",
"non_reserved_word : ENTRY_POINT",
"non_reserved_word : EXCEPTION",
"non_reserved_word : EXIT",
"non_reserved_word : KW_FILE",
"non_reserved_word : GENERATOR",
"non_reserved_word : GEN_ID",
"non_reserved_word : IF",
"non_reserved_word : INACTIVE",
"non_reserved_word : INPUT_TYPE",
"non_reserved_word : ISOLATION",
"non_reserved_word : KEY",
"non_reserved_word : LENGTH",
"non_reserved_word : LEVEL",
"non_reserved_word : MANUAL",
"non_reserved_word : MODULE_NAME",
"non_reserved_word : NAMES",
"non_reserved_word : OPTION",
"non_reserved_word : OUTPUT_TYPE",
"non_reserved_word : KW_OVERFLOW",
"non_reserved_word : PAGE",
"non_reserved_word : PAGES",
"non_reserved_word : KW_PAGE_SIZE",
"non_reserved_word : PASSWORD",
"non_reserved_word : PRIVILEGES",
"non_reserved_word : PROTECTED",
"non_reserved_word : READ",
"non_reserved_word : RESERVING",
"non_reserved_word : RETAIN",
"non_reserved_word : SEGMENT",
"non_reserved_word : SHADOW",
"non_reserved_word : KW_SHARED",
"non_reserved_word : SINGULAR",
"non_reserved_word : KW_SIZE",
"non_reserved_word : SNAPSHOT",
"non_reserved_word : SORT",
"non_reserved_word : STABILITY",
"non_reserved_word : STARTING",
"non_reserved_word : STATISTICS",
"non_reserved_word : SUB_TYPE",
"non_reserved_word : SUSPEND",
"non_reserved_word : TRANSACTION",
"non_reserved_word : UNCOMMITTED",
"non_reserved_word : WAIT",
"non_reserved_word : WORK",
"non_reserved_word : WRITE",
"non_reserved_word : KW_ABSOLUTE",
"non_reserved_word : ACOSH",
"non_reserved_word : ASINH",
"non_reserved_word : ATANH",
"non_reserved_word : BODY",
"non_reserved_word : CONTINUE",
"non_reserved_word : DDL",
"non_reserved_word : DECRYPT",
"non_reserved_word : ENCRYPT",
"non_reserved_word : ENGINE",
"non_reserved_word : IDENTITY",
"non_reserved_word : NAME",
"non_reserved_word : PACKAGE",
"non_reserved_word : PARTITION",
"non_reserved_word : PRIOR",
"non_reserved_word : RDB_GET_CONTEXT",
"non_reserved_word : RDB_SET_CONTEXT",
"non_reserved_word : KW_RELATIVE",
"non_reserved_word : DENSE_RANK",
"non_reserved_word : FIRST_VALUE",
"non_reserved_word : NTH_VALUE",
"non_reserved_word : LAST_VALUE",
"non_reserved_word : LAG",
"non_reserved_word : LEAD",
"non_reserved_word : RANK",
"non_reserved_word : ROW_NUMBER",
"non_reserved_word : USAGE",
"non_reserved_word : LINGER",
"non_reserved_word : TAGS",
"non_reserved_word : PLUGIN",
"non_reserved_word : SERVERWIDE",
"non_reserved_word : INCREMENT",
"non_reserved_word : TRUSTED",
};
#endif

#ifdef YYREDUCEPOSNFUNC
#define YYCALLREDUCEPOSN(e)   \
	if (reduce_posn) {     \
	  YYREDUCEPOSNFUNC(yyps->pos, &(yyps->psp)[1 - yym], &(yyps->vsp)[1 - yym], \
			   yym, yyps->psp - yyps->ps, yychar, yyposn, e);       \
	  reduce_posn = 0;    \
	}

#ifndef YYCALLREDUCEPOSNARG
#define YYCALLREDUCEPOSNARG yyps->val
#endif


#define YYPOSNARG(n) ((yyps->psp)[1 - yym + (n) - 1])
#define YYPOSNOUT    (yyps->pos)
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEVAL
#define YYDELETEVAL(v, n)
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEPOSN
#define YYDELETEPOSN(v, n)
#endif

#define yyclearin (yychar = (-1))

#define yyerrok (yyps->errflag = 0)

#ifndef YYSTACKGROWTH
#define YYSTACKGROWTH 128
#endif

#ifndef YYDEFSTACKSIZE
#define YYDEFSTACKSIZE 12
#endif

#ifdef YYDEBUG
int yydebug;
#endif


#define YYABORT  goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab
#define YYVALID         do { if (yyps->save)          goto yyvalid; } while(0)
#define YYVALID_NESTED  do { if (yyps->save && \
                                 yyps->save->save == 0) goto yyvalid; } while(0)
//
// For use in generated program
//
#define yytrial (yyps->save)
#define yyvsp   (yyps->vsp)
#define yyval   (yyps->val)
#define yydepth (yyps->ssp - yyps->ss)





void Parser::yySCopy(YYSTYPE* to, YYSTYPE* from, int size)
{
  int i;
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyPCopy(YYPOSN* to, YYPOSN* from, int size)
{
  int i;
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyMoreStack(yyparsestate* yyps)
{
  int p = yyps->ssp - yyps->ss;
  Yshort  *tss = yyps->ss;
  YYSTYPE *tvs = yyps->vs;
  YYPOSN  *tps = yyps->ps;
  yyps->ss = FB_NEW_POOL(getPool()) Yshort [yyps->stacksize + YYSTACKGROWTH];
  yyps->vs = FB_NEW_POOL(getPool()) YYSTYPE[yyps->stacksize + YYSTACKGROWTH];
  yyps->ps = FB_NEW_POOL(getPool()) YYPOSN [yyps->stacksize + YYSTACKGROWTH];
  memcpy(yyps->ss, tss, yyps->stacksize * sizeof(Yshort));
  yySCopy(yyps->vs, tvs, yyps->stacksize);
  yyPCopy(yyps->ps, tps, yyps->stacksize);
  yyps->stacksize += YYSTACKGROWTH;
  delete[] tss;
  delete[] tvs;
  delete[] tps;
  yyps->ssp = yyps->ss + p;
  yyps->vsp = yyps->vs + p;
  yyps->psp = yyps->ps + p;
}


Parser::yyparsestate* Parser::yyNewState(int size)
{
  yyparsestate *p = FB_NEW_POOL(getPool()) yyparsestate;
  p->stacksize = size + 4;
  p->ss = FB_NEW_POOL(getPool()) Yshort [size + 4];
  p->vs = FB_NEW_POOL(getPool()) YYSTYPE[size + 4];
  p->ps = FB_NEW_POOL(getPool()) YYPOSN [size + 4];
  memset(&p->vs[0], 0, (size + 4) * sizeof(YYSTYPE));
  memset(&p->ps[0], 0, (size + 4) * sizeof(YYPOSN));
  return p;
}


void Parser::yyFreeState(Parser::yyparsestate* p)
{
  delete[] p->ss;
  delete[] p->vs;
  delete[] p->ps;
  delete p;
}


void Parser::setNodeLineColumn(Node* node)
{
	// Check if we are not accessing the position stack below its base.
	if (&YYPOSNARG(1) >= yyps->ps)
	{
		node->line = YYPOSNARG(1).firstLine;
		node->column = YYPOSNARG(1).firstColumn;
	}
}


int Parser::parseAux()
{
  // ASF: yym moved to Parser.h
  int /*yym, */yyn, yystate, yychar, yynewerrflag;
  yyparsestate *yyerrctx = NULL;
  int reduce_posn;

#if YYDEBUG
  const char *yys;

  if ((yys = getenv("YYDEBUG"))) {
    yyn = *yys;
    if (yyn >= '0' && yyn <= '9')
      yydebug = yyn - '0';
  }
#endif

  yyps = yyNewState(YYDEFSTACKSIZE);
  yyps->save = 0;
  yynerrs = 0;
  yyps->errflag = 0;
  yychar = (-1);

  yyps->ssp = yyps->ss;
  yyps->vsp = yyps->vs;
  yyps->psp = yyps->ps;
  *(yyps->ssp) = yystate = 0;


  //
  // Main parsing loop
  //
 yyloop:
  if ((yyn = yydefred[yystate])) {
    goto yyreduce;
  }

  //
  // Read one token
  //
  if (yychar < 0) {
    if ((yychar = yylex1()) < 0) yychar = 0;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, reading %d (%s)",
	     int(yydepth), yytrial, yystate, yychar, yys);
#ifdef YYDBPR
      printf("<");
      YYDBPR(yylval);
      printf(">");
#endif
      printf("\n");
    }
#endif
  }

  //
  // Do we have a conflict?
  //
  if ((yyn = yycindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    int ctry;

    if (yypath) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d: following successful trial parse\n",
	       int(yydepth), yytrial, yystate);
      }
#endif
      // Switch to the next conflict context
      yyparsestate *save = yypath;
      yypath = save->save;
      ctry = save->ctry;
      if (save->state != yystate)
        goto yyabort;
      yyFreeState(save);

    } else {

#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d. ",
	       int(yydepth), yytrial, yystate);
        if (yyps->save) {
          printf("ALREADY in conflict. Continue trial parse.");
        } else {
          printf("Start trial parse.");
        }
        printf("\n");
      }
#endif
      yyparsestate *save = yyNewState(yyps->ssp - yyps->ss);
      save->save    = yyps->save;
      save->state   = yystate;
      save->errflag = yyps->errflag;
      save->ssp     = save->ss + (yyps->ssp - yyps->ss);
      save->vsp     = save->vs + (yyps->vsp - yyps->vs);
      save->psp     = save->ps + (yyps->psp - yyps->ps);
      memcpy (save->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(save->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(save->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      ctry = yytable[yyn];
      if (yyctable[ctry] == -1) {
#if YYDEBUG
        if (yydebug && yychar >= 0)
          printf("yydebug[%p]: backtracking 1 token\n", yytrial);
#endif
        ctry++;
      }
      save->ctry = ctry;
      if (!yyps->save) {
        // If this is a first conflict in the stack, start saving lexemes
        if (!yylexemes) {
          yylexemes = FB_NEW_POOL(getPool()) Yshort[YYSTACKGROWTH];
          yylvals = FB_NEW_POOL(getPool()) YYSTYPE[YYSTACKGROWTH];
          yylvlim = yylvals + YYSTACKGROWTH;
          yylpsns = FB_NEW_POOL(getPool()) YYPOSN[YYSTACKGROWTH];
          yylplim = yylpsns + YYSTACKGROWTH;
        }
        if (yylvp == yylve) {
          yylvp = yylve = yylvals;
	  yylpp = yylpe = yylpsns;
          yylexp = yylexemes;
          if (yychar >= 0) {
            *yylve++ = yylval;
            *yylpe++ = yyposn;
            *yylexp = yychar;
            yychar = -1;
          }
        }
      }
      if (yychar >= 0) {
        yylvp--, yylpp--, yylexp--;
        yychar = -1;
      }
      save->lexeme = yylvp - yylvals;
      yyps->save = save;
    }
    if (yytable[yyn] == ctry) {
#if YYDEBUG
      if (yydebug)
        printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
               int(yydepth), yytrial, yystate, yyctable[ctry]);
#endif
      if (yychar < 0)
        yylvp++, yylpp++, yylexp++;
      yychar = -1;
      if (yyps->errflag > 0) --yyps->errflag;
      yystate = yyctable[ctry];
      goto yyshift;
    } else {
      yyn = yyctable[ctry];
      goto yyreduce;
    }
  }

  //
  // Is action a shift?
  //
  if ((yyn = yysindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
             int(yydepth), yytrial, yystate, yytable[yyn]);
#endif
    yychar = (-1);
    if (yyps->errflag > 0)  --yyps->errflag;
    yystate = yytable[yyn];
  yyshift:
    if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
      yyMoreStack(yyps);
    }
    *++(yyps->ssp) = yystate;
    *++(yyps->vsp) = yylval;
    *++(yyps->psp) = yyposn;
    goto yyloop;
  }
  if ((yyn = yyrindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    yyn = yytable[yyn];
    goto yyreduce;
  }

  //
  // Action: error
  //
  if (yyps->errflag) goto yyinrecovery;
  yynewerrflag = 1;
  goto yyerrhandler;
yyerrlab:
  yynewerrflag = 0;
yyerrhandler:
  while (yyps->save) {
    int ctry;
    yyparsestate *save = yyps->save;
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: ERROR in state %d, CONFLICT BACKTRACKING to state %d, %d tokens\n",
             int(yydepth), yytrial, yystate, yyps->save->state, int(yylvp - yylvals - yyps->save->lexeme));
#endif
    // Memorize most forward-looking error state in case
    // it's really an error.
    if (yyerrctx == NULL || yyerrctx->lexeme < yylvp-yylvals) {
      // Free old saved error context state
      if (yyerrctx) yyFreeState(yyerrctx);
      // Create and fill out new saved error context state
      yyerrctx = yyNewState(yyps->ssp - yyps->ss);
      yyerrctx->save = yyps->save;
      yyerrctx->state = yystate;
      yyerrctx->errflag = yyps->errflag;
      yyerrctx->ssp = yyerrctx->ss + (yyps->ssp - yyps->ss);
      yyerrctx->vsp = yyerrctx->vs + (yyps->vsp - yyps->vs);
      yyerrctx->psp = yyerrctx->ps + (yyps->psp - yyps->ps);
      memcpy (yyerrctx->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyerrctx->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(yyerrctx->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      yyerrctx->lexeme = yylvp - yylvals;
    }
    yylvp  = yylvals   + save->lexeme;
    yylpp  = yylpsns   + save->lexeme;
    yylexp = yylexemes + save->lexeme;
    yychar = -1;
    yyps->ssp = yyps->ss + (save->ssp - save->ss);
    yyps->vsp = yyps->vs + (save->vsp - save->vs);
    yyps->psp = yyps->ps + (save->psp - save->ps);
    memcpy (yyps->ss, save->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
    yySCopy(yyps->vs, save->vs,  yyps->vsp - yyps->vs + 1);
    yyPCopy(yyps->ps, save->ps,  yyps->psp - yyps->ps + 1);
    ctry = ++save->ctry;
    yystate = save->state;
    // We tried shift, try reduce now
    if ((yyn = yyctable[ctry]) >= 0) {
      goto yyreduce;
    }
    yyps->save = save->save;
    yyFreeState(save);
    //
    // Nothing left on the stack -- error
    //
    if (!yyps->save) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%p]: trial parse FAILED, entering ERROR mode\n",
	       yytrial);
      }
#endif
      // Restore state as it was in the most forward-advanced error
      yylvp  = yylvals   + yyerrctx->lexeme;
      yylpp  = yylpsns   + yyerrctx->lexeme;
      yylexp = yylexemes + yyerrctx->lexeme;
      yychar = yylexp[-1];
      yylval = yylvp[-1];
      yyposn = yylpp[-1];
      yyps->ssp = yyps->ss + (yyerrctx->ssp - yyerrctx->ss);
      yyps->vsp = yyps->vs + (yyerrctx->vsp - yyerrctx->vs);
      yyps->psp = yyps->ps + (yyerrctx->psp - yyerrctx->ps);
      memcpy (yyps->ss, yyerrctx->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyps->vs, yyerrctx->vs,  yyps->vsp - yyps->vs + 1);
      yyPCopy(yyps->ps, yyerrctx->ps,  yyps->psp - yyps->ps + 1);
      yystate = yyerrctx->state;
      yyFreeState(yyerrctx);
      yyerrctx = NULL;
    }
    yynewerrflag = 1;
  }
  if (yynewerrflag) {
#ifdef YYERROR_DETAILED
    yyerror_detailed("syntax error", yychar, yylval, yyposn);
#else
    yyerror("syntax error");
#endif
  }
  ++yynerrs;
 yyinrecovery:
  if (yyps->errflag < 3) {
    yyps->errflag = 3;
    for (;;) {
      if ((yyn = yysindex[*(yyps->ssp)]) &&
	  (yyn += YYERRCODE) >= 0 &&
          yyn <= YYTABLESIZE &&
	  yycheck[yyn] == YYERRCODE) {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: state %d, ERROR recovery shifts to state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp), yytable[yyn]);
#endif
        /* Use label yyerrlab, so that compiler does not warn */
        if (yyps->errflag != yyps->errflag) goto yyerrlab;
        yystate = yytable[yyn];
        goto yyshift;
      } else {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: ERROR recovery discards state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp));
#endif
        if (yyps->ssp <= yyps->ss) {
	  goto yyabort;
	}
	if (!yytrial) {
	  YYDELETEVAL(yyps->vsp[0], 1);
	  YYDELETEPOSN(yyps->psp[0], 1);
	}
        --(yyps->ssp);
        --(yyps->vsp);
        --(yyps->psp);
      }
    }
  } else {
    if (yychar == 0) goto yyabort;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, ERROR recovery discards token %d (%s)\n",
             int(yydepth), yytrial, yystate, yychar, yys);
    }
#endif
    if (!yytrial) {
      YYDELETEVAL(yylval, 0);
      YYDELETEPOSN(yyposn, 0);
    }
    yychar = (-1);
    goto yyloop;
  }

  //
  // Reduce the rule
  //
yyreduce:
  yym = yylen[yyn];
#if YYDEBUG
  if (yydebug) {
    printf("yydebug[%d,%p]: state %d, reducing by rule %d (%s)",
           int(yydepth), yytrial, yystate, yyn, yyrule[yyn]);
#ifdef YYDBPR
    if (yym) {
      int i;
      printf("<");
      for (i = yym; i > 0; i--) {
        if (i != yym) printf(", ");
        YYDBPR((yyps->vsp)[1 - i]);
      }
      printf(">");
    }
#endif
    printf("\n");
  }
#endif
  if (yyps->ssp + 1 - yym >= yyps->ss + yyps->stacksize) {
    yyMoreStack(yyps);
  }

  /* default action - assign last argument as in standard yacc */
  yyps->val = yyvsp[1 - yym];

  /* default reduced position is NULL -- no position at all.
     no position will be assigned at trial time and if no position handling is present */
  memset(&yyps->pos, 0, sizeof(yyps->pos));

  reduce_posn = TRUE;

  switch (yyn) {

case 1:
  if (!yytrial)
{ DSQL_parse = yyvsp[0].dsqlReq; }
break;
case 2:
  if (!yytrial)
{ DSQL_parse = yyvsp[-1].dsqlReq; }
break;
case 3:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlDmlRequest(getStatementPool(), yyvsp[0].stmtNode); }
break;
case 4:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlDdlRequest(getStatementPool(), yyvsp[0].ddlNode); }
break;
case 5:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlTransactionRequest(getStatementPool(), yyvsp[0].traNode); }
break;
case 6:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 7:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 8:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 9:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 10:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execBlockNode; }
break;
case 11:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 12:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].selectNode; }
break;
case 13:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 14:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 15:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 16:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 17:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 18:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 19:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 20:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 21:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 22:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 23:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 24:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 25:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].setTransactionNode; }
break;
case 26:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 27:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 28:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].setRoleNode; }
break;
case 29:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(true); }
break;
case 30:
yyval.grantRevokeNode = yyvsp[0].grantRevokeNode;
break;
case 31:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 32:
yyval.privilegeArray = NOTRIAL(&yyvsp[0].grantRevokeNode->privileges);
break;
case 33:
yyval.granteeArray = NOTRIAL(&yyvsp[-6].grantRevokeNode->users);
break;
case 34:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 35:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 36:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 37:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 38:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 39:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 40:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 41:
yyval.granteeArray = NOTRIAL(&yyvsp[-4].grantRevokeNode->users);
break;
case 42:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = yyvsp[-5].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 43:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 44:
yyval.granteeArray = NOTRIAL(&yyvsp[0].grantRevokeNode->roles);
break;
case 45:
yyval.granteeArray = NOTRIAL(&yyvsp[-3].grantRevokeNode->users);
break;
case 46:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 47:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_relations, get_object_name(obj_relations)); }
break;
case 48:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_views, get_object_name(obj_views)); }
break;
case 49:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_procedures, get_object_name(obj_procedures)); }
break;
case 50:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_functions, get_object_name(obj_functions)); }
break;
case 51:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_packages, get_object_name(obj_packages)); }
break;
case 52:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 53:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 54:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_domains, get_object_name(obj_domains)); }
break;
case 55:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_exceptions, get_object_name(obj_exceptions)); }
break;
case 56:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_roles, get_object_name(obj_roles)); }
break;
case 57:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_charsets, get_object_name(obj_charsets)); }
break;
case 58:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_collations, get_object_name(obj_collations)); }
break;
case 59:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_filters, get_object_name(obj_filters)); }
break;
case 62:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 63:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 64:
yyval.privilegeArray = yyvsp[0].privilegeArray;
break;
case 67:
yyval.privilegeArray = yyvsp[-2].privilegeArray;
break;
case 69:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('X', NULL)); }
break;
case 70:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('G', NULL)); }
break;
case 71:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('S', NULL)); }
break;
case 72:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('I', NULL)); }
break;
case 73:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('D', NULL)); }
break;
case 74:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('U', yyvsp[0].valueListNode)); }
break;
case 75:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('R', yyvsp[0].valueListNode)); }
break;
case 76:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('C', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 82:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 83:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 84:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 85:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 89:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 90:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 91:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 92:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 93:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 94:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 95:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 96:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 97:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 101:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 102:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(false); }
break;
case 103:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 104:
yyval.privilegeArray = NOTRIAL(&yyvsp[-1].grantRevokeNode->privileges);
break;
case 105:
yyval.granteeArray = NOTRIAL(&yyvsp[-7].grantRevokeNode->users);
break;
case 106:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 107:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 108:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 109:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 110:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 111:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 112:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 113:
yyval.granteeArray = NOTRIAL(&yyvsp[-5].grantRevokeNode->users);
break;
case 114:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = yyvsp[-4].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 115:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 116:
yyval.granteeArray = NOTRIAL(&yyvsp[-1].grantRevokeNode->roles);
break;
case 117:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-6].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 119:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 120:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 121:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 122:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 123:
yyval.granteeArray = yyvsp[0].granteeArray;
break;
case 126:
yyval.granteeArray = yyvsp[-2].granteeArray;
break;
case 129:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_procedure, *yyvsp[0].metaNamePtr)); }
break;
case 130:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_udf, *yyvsp[0].metaNamePtr)); }
break;
case 131:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_package_header, *yyvsp[0].metaNamePtr)); }
break;
case 132:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_trigger, *yyvsp[0].metaNamePtr)); }
break;
case 133:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_view, *yyvsp[0].metaNamePtr)); }
break;
case 134:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 135:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user_or_role, *yyvsp[0].metaNamePtr)); }
break;
case 136:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 137:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user_group, *yyvsp[0].metaNamePtr)); }
break;
case 140:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 143:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 144:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode;}
break;
case 145:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 146:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 147:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 148:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterFunctionNode->parameters);
break;
case 149:
yyval.createAlterFunctionNode = yyvsp[-3].createAlterFunctionNode;
break;
case 150:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-9].createAlterFunctionNode;
				yyval.createAlterFunctionNode->external = newNode<ExternalClause>();
				yyval.createAlterFunctionNode->external->name = *yyvsp[-2].stringPtr;
				yyval.createAlterFunctionNode->external->udfModule = *yyvsp[0].stringPtr;
			}
break;
case 152:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(bid);
		}
break;
case 153:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_cstring;
			yyval.legacyField->charLength = (USHORT) yyvsp[-2].int32Val;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 155:
yyval.parametersClause = yyvsp[0].parametersClause;
break;
case 157:
yyval.parametersClause = yyvsp[-1].parametersClause;
break;
case 160:
yyval.parametersClause = yyvsp[-2].parametersClause;
break;
case 162:
  if (!yytrial)
{
			yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName()));
			yyvsp[-2].parametersClause->back()->udfMechanism = yyvsp[0].nullableIntVal;
		}
break;
case 163:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 164:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_descriptor); }
break;
case 165:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_scalar_array); }
break;
case 166:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_ref_with_null); }
break;
case 167:
yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
break;
case 169:
yyval.createAlterFunctionNode = yyvsp[-1].createAlterFunctionNode;
break;
case 171:
  if (!yytrial)
{
			yyvsp[-2].createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName());
			yyvsp[-2].createAlterFunctionNode->returnType->udfMechanism = yyvsp[0].int32Val;
		}
break;
case 172:
  if (!yytrial)
{ yyvsp[-2].createAlterFunctionNode->udfReturnPos = yyvsp[0].int32Val; }
break;
case 173:
  if (!yytrial)
{ yyval.int32Val = FUN_reference; }
break;
case 174:
  if (!yytrial)
{ yyval.int32Val = FUN_value; }
break;
case 175:
  if (!yytrial)
{ yyval.int32Val = FUN_descriptor; }
break;
case 176:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_reference; }
break;
case 177:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_descriptor; }
break;
case 178:
  if (!yytrial)
{
				CreateFilterNode* node = newNode<CreateFilterNode>(*yyvsp[-8].metaNamePtr);
				node->inputFilter = yyvsp[-6].filterNameNumber;
				node->outputFilter = yyvsp[-4].filterNameNumber;
				node->entryPoint = *yyvsp[-2].stringPtr;
				node->moduleName = *yyvsp[0].stringPtr;
				yyval.ddlNode = node;
			}
break;
case 179:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(*yyvsp[0].metaNamePtr); }
break;
case 180:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(yyvsp[0].int32Val); }
break;
case 181:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 182:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 183:
  if (!yytrial)
{
				CreateIndexNode* node = newNode<CreateIndexNode>(*yyvsp[-2].metaNamePtr);
				node->unique = yyvsp[-5].boolVal;
				node->descending = yyvsp[-4].boolVal;
				node->relation = yyvsp[0].relSourceNode;
				yyval.ddlNode = node;
			}
break;
case 184:
yyval.createIndexNode = static_cast<CreateIndexNode*>(yyvsp[0].ddlNode);
break;
case 185:
  if (!yytrial)
{
				yyval.ddlNode = yyvsp[-2].ddlNode;
			}
break;
case 186:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 187:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 188:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 189:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 190:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 191:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterViewNode; }
break;
case 192:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 193:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 194:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDatabaseNode; }
break;
case 195:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createDomainNode; }
break;
case 196:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createShadowNode; }
break;
case 197:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 198:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createCollationNode; }
break;
case 199:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 200:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 201:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createPackageBodyNode; }
break;
case 202:
yyval.boolVal = false;
break;
case 203:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 204:
yyval.boolVal = true;
break;
case 205:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 206:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 207:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateProcedureNode>(yyvsp[0].createAlterProcedureNode); }
break;
case 208:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateFunctionNode>(yyvsp[0].createAlterFunctionNode); }
break;
case 209:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 210:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 211:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateViewNode>(yyvsp[0].createAlterViewNode); }
break;
case 212:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTriggerNode>(yyvsp[0].createAlterTriggerNode); }
break;
case 213:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageNode>(yyvsp[0].createAlterPackageNode); }
break;
case 214:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageBodyNode>(yyvsp[0].createPackageBodyNode); }
break;
case 215:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateExceptionNode>(yyvsp[0].createAlterExceptionNode); }
break;
case 216:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 217:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 218:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 219:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 220:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 221:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 222:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 223:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 224:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 225:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 226:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 227:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 228:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 229:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 230:
  if (!yytrial)
{ yyval.createAlterExceptionNode = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString()); }
break;
case 231:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 232:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->create = false;
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 233:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 234:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 235:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 236:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 237:
  if (!yytrial)
{
 			yyvsp[-4].createIndexNode->computed = newNode<ValueSourceClause>();
			yyvsp[-4].createIndexNode->computed->value = yyvsp[-1].valueExprNode;
			yyvsp[-4].createIndexNode->computed->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
		}
break;
case 238:
  if (!yytrial)
{
	 			yyval.createShadowNode = newNode<CreateShadowNode>(yyvsp[-4].int32Val);
		 		yyval.createShadowNode->manual = yyvsp[-3].boolVal;
		 		yyval.createShadowNode->conditional = yyvsp[-2].boolVal;
		 		yyval.createShadowNode->files.add(newNode<DbFileClause>(*yyvsp[-1].stringPtr));
		 		yyval.createShadowNode->files.front()->length = yyvsp[0].int32Val;
	 		}
break;
case 239:
yyval.dbFilesClause = NOTRIAL(&yyvsp[0].createShadowNode->files);
break;
case 240:
  if (!yytrial)
{ yyval.createShadowNode = yyvsp[-2].createShadowNode; }
break;
case 241:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 242:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 243:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 244:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 245:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 246:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 247:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 249:
yyval.dbFilesClause = yyvsp[0].dbFilesClause;
break;
case 251:
  if (!yytrial)
{ yyvsp[-1].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 252:
  if (!yytrial)
{ yyvsp[-2].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 253:
  if (!yytrial)
{
				yyvsp[-1].legacyField->fld_name = *yyvsp[-3].metaNamePtr;
				yyval.createDomainNode = newNode<CreateDomainNode>(
					newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName(), yyvsp[0].valueSourceClause));
			}
break;
case 254:
yyval.createDomainNode = yyvsp[0].createDomainNode;
break;
case 255:
  if (!yytrial)
{
				yyval.createDomainNode = yyvsp[-3].createDomainNode;
				if (yyvsp[0].metaNamePtr)
					yyval.createDomainNode->nameType->type->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 259:
yyval.createDomainNode = yyvsp[-1].createDomainNode;
break;
case 261:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->notNull, "NOT NULL"); }
break;
case 262:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->check, "DOMAIN CHECK CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 265:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 266:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 269:
  if (!yytrial)
{
			BoolSourceClause* clause = newNode<BoolSourceClause>();
			clause->value = yyvsp[-1].boolExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(4));
			yyval.boolSourceClause = clause;
		}
break;
case 270:
  if (!yytrial)
{ yyval.createAlterSequenceNode = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableInt64Val, yyvsp[0].nullableInt32Val); }
break;
case 271:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 272:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 273:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int64Val; }
break;
case 274:
  if (!yytrial)
{ yyval.nullableInt32Val = Nullable<SLONG>::empty(); }
break;
case 275:
  if (!yytrial)
{ yyval.nullableInt32Val = Nullable<SLONG>::val(yyvsp[0].int32Val); }
break;
case 278:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableInt64Val, yyvsp[0].nullableInt32Val);
			node->alter = true;
			node->restartSpecified = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 279:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 280:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 281:
  if (!yytrial)
{
			if (!yyvsp[-1].nullableNullableInt64Val.specified && !yyvsp[0].nullableInt32Val.specified)
				yyerrorIncompleteCmd(YYPOSNARG(3));
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr, yyvsp[-1].nullableNullableInt64Val.value, yyvsp[0].nullableInt32Val);
			node->create = false;
			node->alter = true;
			node->restartSpecified = yyvsp[-1].nullableNullableInt64Val.specified;
			yyval.createAlterSequenceNode = node;
		}
break;
case 282:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::empty(); }
break;
case 283:
  if (!yytrial)
{ yyval.nullableInt64Val = Nullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 284:
  if (!yytrial)
{ yyval.nullableNullableInt64Val = Nullable<BaseNullable<SINT64> >::empty(); }
break;
case 285:
  if (!yytrial)
{ yyval.nullableNullableInt64Val = Nullable<BaseNullable<SINT64> > ::val(yyvsp[0].nullableInt64Val); }
break;
case 286:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr,
				Nullable<SINT64>::val(yyvsp[0].int64Val), Nullable<SLONG>::empty());
			node->create = false;
			node->alter = true;
			node->legacy = true;
			node->restartSpecified = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 287:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int32Val; }
break;
case 288:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (!yyvsp[0].scaledNumber.hex && yyvsp[0].scaledNumber.number > MAX_SINT64)
			{
				ERRD_post(
					Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_arith_except) <<
					Arg::Gds(isc_numeric_out_of_range));
			}

			yyval.int64Val = signedNumber;
		}
break;
case 289:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber == MIN_SINT64)
				ERRD_post(Arg::Gds(isc_exception_integer_overflow));

			yyval.int64Val = -signedNumber;
		}
break;
case 290:
  if (!yytrial)
{ yyval.ddlNode = newNode<CreateRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 291:
  if (!yytrial)
{ yyval.createCollationNode = newNode<CreateCollationNode>(*yyvsp[-2].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 292:
yyval.createCollationNode = yyvsp[0].createCollationNode;
break;
case 293:
yyval.createCollationNode = yyvsp[-2].createCollationNode;
break;
case 294:
yyval.createCollationNode = yyvsp[-4].createCollationNode;
break;
case 295:
  if (!yytrial)
{ yyval.createCollationNode = yyvsp[-6].createCollationNode; }
break;
case 297:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->fromName = *yyvsp[0].metaNamePtr; }
break;
case 298:
  if (!yytrial)
{ yyvsp[-5].createCollationNode->fromExternal = *yyvsp[-1].stringPtr; }
break;
case 302:
yyval.createCollationNode = yyvsp[-1].createCollationNode;
break;
case 307:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 308:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 309:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 310:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 311:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 312:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 314:
  if (!yytrial)
{
			const string& s = *yyvsp[0].stringPtr;
			yyvsp[-1].createCollationNode->specificAttributes.clear();
			yyvsp[-1].createCollationNode->specificAttributes.add((const UCHAR*) s.begin(), s.length());
		}
break;
case 315:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterCharSetNode>(*yyvsp[-4].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 316:
  if (!yytrial)
{
				yyval.alterDatabaseNode = newNode<AlterDatabaseNode>();
				yyval.alterDatabaseNode->create = true;
			}
break;
case 317:
yyval.alterDatabaseNode = yyvsp[0].alterDatabaseNode;
break;
case 318:
yyval.alterDatabaseNode = yyvsp[-2].alterDatabaseNode;
break;
case 319:
  if (!yytrial)
{ yyval.alterDatabaseNode = yyvsp[-4].alterDatabaseNode; }
break;
case 326:
yyval.alterDatabaseNode = yyvsp[-1].alterDatabaseNode;
break;
case 335:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->createLength = yyvsp[-1].int32Val; }
break;
case 340:
  if (!yytrial)
{ yyvsp[-1].alterDatabaseNode->files.add(yyvsp[0].dbFileClause); }
break;
case 341:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 342:
  if (!yytrial)
{
			yyvsp[-6].alterDatabaseNode->setDefaultCharSet = *yyvsp[-2].metaNamePtr;
			yyvsp[-6].alterDatabaseNode->setDefaultCollation = *yyvsp[0].metaNamePtr;
		}
break;
case 343:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 344:
  if (!yytrial)
{
				DbFileClause* clause = newNode<DbFileClause>(*yyvsp[0].stringPtr);
				yyval.dbFileClause = clause;
			}
break;
case 345:
yyval.dbFileClause = yyvsp[0].dbFileClause;
break;
case 346:
  if (!yytrial)
{ yyval.dbFileClause = yyvsp[-2].dbFileClause; }
break;
case 350:
yyval.dbFileClause = yyvsp[-1].dbFileClause;
break;
case 352:
  if (!yytrial)
{ yyvsp[-3].dbFileClause->start = yyvsp[0].int32Val; }
break;
case 353:
  if (!yytrial)
{ yyvsp[-4].dbFileClause->length = yyvsp[-1].int32Val; }
break;
case 360:
  if (!yytrial)
{ yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[-1].relSourceNode, yyvsp[0].stringPtr); }
break;
case 361:
yyval.createRelationNode = yyvsp[-1].createRelationNode;
break;
case 362:
  if (!yytrial)
{ yyval.createRelationNode = yyvsp[-4].createRelationNode; }
break;
case 363:
  if (!yytrial)
{ yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[0].relSourceNode); }
break;
case 364:
  if (!yytrial)
{
				yyval.createRelationNode = yyvsp[-5].createRelationNode;
				yyval.createRelationNode->relationType = static_cast<rel_t>(yyvsp[0].intVal);
			}
break;
case 365:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_delete; }
break;
case 366:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_delete; }
break;
case 367:
  if (!yytrial)
{ yyval.intVal = rel_global_temp_preserve; }
break;
case 368:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 369:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 370:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 371:
yyval.createRelationNode = yyvsp[0].createRelationNode;
break;
case 373:
yyval.createRelationNode = yyvsp[-2].createRelationNode;
break;
case 375:
yyval.relationNode = yyvsp[0].createRelationNode;
break;
case 378:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->defaultValue = yyvsp[0].valueSourceClause;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 379:
yyval.addColumnClause = NOTRIAL(yyvsp[0].addColumnClause);
break;
case 380:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 381:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->identity = true;
				clause->identityStart = yyvsp[0].int64Val;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 382:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 383:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 384:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-2].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 385:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int64Val; }
break;
case 386:
  if (!yytrial)
{ yyval.int64Val = 0; }
break;
case 387:
  if (!yytrial)
{ yyval.int64Val = yyvsp[-1].int64Val; }
break;
case 388:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[-1].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
			yyval.valueSourceClause = clause;
		}
break;
case 395:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 396:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 397:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 399:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 400:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 401:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 402:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 403:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 404:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 405:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 406:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 407:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 409:
yyval.addColumnClause = yyvsp[0].addColumnClause;
break;
case 412:
yyval.addColumnClause = yyvsp[-1].addColumnClause;
break;
case 414:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
				yyvsp[-3].addColumnClause->constraints.back()->name = *yyvsp[-2].metaNamePtr;
		}
break;
case 415:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_NOT_NULL;
		}
break;
case 416:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint.check = yyvsp[0].boolSourceClause;
		}
break;
case 417:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-5].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			constraint.columns.add(yyvsp[-5].addColumnClause->field->fld_name);
			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add((*ptr)->as<FieldNode>()->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 418:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-2].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 419:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-3].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 420:
yyval.relationNode = yyvsp[-1].relationNode;
break;
case 421:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
			{
				static_cast<RelationNode::AddConstraintClause*>(
					yyvsp[-3].relationNode->clauses.back().getObject())->name = *yyvsp[-2].metaNamePtr;
			}
		}
break;
case 422:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 423:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 424:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-3].relationNode->clauses.add(&constraint);
		}
break;
case 425:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-4].relationNode->clauses.add(&constraint);
		}
break;
case 426:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			const ValueListNode* columns = yyvsp[-5].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add((*ptr)->as<FieldNode>()->dsqlName);

			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add((*ptr)->as<FieldNode>()->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-8].relationNode->clauses.add(&constraint);
		}
break;
case 427:
  if (!yytrial)
{
			RelationNode::AddConstraintClause* constraint = newNode<RelationNode::AddConstraintClause>();
			constraint->constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint->check = yyvsp[0].boolSourceClause;
			yyvsp[-1].relationNode->clauses.add(constraint);
		}
break;
case 428:
  if (!yytrial)
{ yyval.indexConstraintClause = newNode<RelationNode::IndexConstraintClause>(); }
break;
case 429:
  if (!yytrial)
{
			RelationNode::IndexConstraintClause* clause = yyval.indexConstraintClause =
				newNode<RelationNode::IndexConstraintClause>();
			clause->descending = yyvsp[-2].boolVal;
			clause->name = *yyvsp[0].metaNamePtr;
		}
break;
case 430:
  if (!yytrial)
{ yyval.refActionClause = NULL; }
break;
case 431:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, 0); }
break;
case 432:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(0, yyvsp[0].uintVal); }
break;
case 433:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, yyvsp[-1].uintVal); }
break;
case 434:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[-1].uintVal, yyvsp[0].uintVal); }
break;
case 435:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 436:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 437:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_CASCADE; }
break;
case 438:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_DEFAULT; }
break;
case 439:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_NULL; }
break;
case 440:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_NONE; }
break;
case 443:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-3].createAlterProcedureNode;
			yyval.createAlterProcedureNode->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(4));
			yyval.createAlterProcedureNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterProcedureNode->body = yyvsp[0].stmtNode;
		}
break;
case 444:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-2].createAlterProcedureNode;
			yyval.createAlterProcedureNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterProcedureNode->source = *yyvsp[0].stringPtr;
		}
break;
case 445:
  if (!yytrial)
{ yyval.createAlterProcedureNode = newNode<CreateAlterProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 446:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterProcedureNode->parameters);
break;
case 447:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].createAlterProcedureNode->returns);
break;
case 448:
  if (!yytrial)
{ yyval.createAlterProcedureNode = yyvsp[-4].createAlterProcedureNode; }
break;
case 449:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
			yyval.createAlterProcedureNode->create = false;
		}
break;
case 450:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
		}
break;
case 458:
  if (!yytrial)
{ yyvsp[-3].parametersClause->add(newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause)); }
break;
case 461:
  if (!yytrial)
{ yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, optName(yyvsp[0].metaNamePtr))); }
break;
case 462:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->fld_name = *yyvsp[-1].metaNamePtr;
		}
break;
case 463:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 464:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 465:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 468:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-3].createAlterFunctionNode;
			yyval.createAlterFunctionNode->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(4));
			yyval.createAlterFunctionNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterFunctionNode->body = yyvsp[0].stmtNode;
		}
break;
case 469:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-2].createAlterFunctionNode;
			yyval.createAlterFunctionNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterFunctionNode->source = *yyvsp[0].stringPtr;
		}
break;
case 470:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 471:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-6].createAlterFunctionNode;
				yyval.createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr));
				yyval.createAlterFunctionNode->deterministic = yyvsp[0].boolVal;
			}
break;
case 472:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 473:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 474:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 475:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->name = *yyvsp[-2].stringPtr;
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 476:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 477:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 478:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 479:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
			yyval.createAlterFunctionNode->create = false;
		}
break;
case 480:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
		}
break;
case 481:
  if (!yytrial)
{
			CreateAlterPackageNode* node = newNode<CreateAlterPackageNode>(*yyvsp[-4].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			node->items = yyvsp[-1].packageItems;
			yyval.createAlterPackageNode = node;
		}
break;
case 483:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 484:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 485:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 486:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 487:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 488:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
			yyval.createAlterPackageNode->create = false;
		}
break;
case 489:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
		}
break;
case 490:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-5].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(6));
			node->declaredItems = yyvsp[-2].packageItems;
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 491:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-4].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 492:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 494:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 495:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 496:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterFunctionNode); }
break;
case 497:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 498:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterProcedureNode); }
break;
case 499:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 500:
  if (!yytrial)
{ yyval.compoundStmtNode = NULL; }
break;
case 502:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 503:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 504:
  if (!yytrial)
{
			yyval.stmtNode = yyvsp[-1].stmtNode;
			yyval.stmtNode->line = YYPOSNARG(1).firstLine;
			yyval.stmtNode->column = YYPOSNARG(1).firstColumn;
		}
break;
case 505:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 506:
yyval.parametersClause = NOTRIAL(&yyvsp[0].execBlockNode->parameters);
break;
case 507:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].execBlockNode->returns);
break;
case 508:
  if (!yytrial)
{
			DeclareSubProcNode* node = newNode<DeclareSubProcNode>(*yyvsp[-8].metaNamePtr);
			node->dsqlBlock = yyvsp[-7].execBlockNode;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			yyval.stmtNode = node;
		}
break;
case 509:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 510:
  if (!yytrial)
{
			DeclareSubFuncNode* node = newNode<DeclareSubFuncNode>(*yyvsp[-10].metaNamePtr);
			node->dsqlDeterministic = yyvsp[-3].boolVal;
			node->dsqlBlock = yyvsp[-9].execBlockNode;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			node->dsqlBlock->returns.add(newNode<ParameterClause>(yyvsp[-5].legacyField, optName(yyvsp[-4].metaNamePtr)));

			yyval.stmtNode = node;
		}
break;
case 513:
  if (!yytrial)
{
			DeclareVariableNode* node = newNode<DeclareVariableNode>();
			node->dsqlDef = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause);
			yyval.stmtNode = node;
		}
break;
case 516:
  if (!yytrial)
{
			DeclareCursorNode* node = newNode<DeclareCursorNode>(*yyvsp[-6].metaNamePtr,
				DeclareCursorNode::CUR_TYPE_EXPLICIT);
			node->dsqlScroll = yyvsp[-5].boolVal;
			node->dsqlSelect = yyvsp[-1].selectNode;
			yyval.stmtNode = node;
		}
break;
case 517:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 518:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 519:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 522:
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 523:
  if (!yytrial)
{ yyval.stmtNode = newNode<CompoundStmtNode>(); }
break;
case 524:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 525:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[-1].compoundStmtNode;
			node->handlers = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 526:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 527:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 528:
{YYVALID;}
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 529:
{YYVALID;}
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[0].stmtNode); }
break;
case 531:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 532:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 534:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 538:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 539:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 541:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 547:
  if (!yytrial)
{ yyval.stmtNode = newNode<SuspendNode>(); }
break;
case 548:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExitNode>(); }
break;
case 549:
  if (!yytrial)
{ yyval.stmtNode = newNode<ReturnNode>(yyvsp[0].valueExprNode); }
break;
case 551:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 555:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].forNode; }
break;
case 556:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 557:
  if (!yytrial)
{
			InAutonomousTransactionNode* node = newNode<InAutonomousTransactionNode>();
			node->action = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 558:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 559:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].valueExprNode); }
break;
case 560:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-4].metaNamePtr, (ValueExprNode*) NULL, yyvsp[-1].valueListNode); }
break;
case 561:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(); }
break;
case 562:
  if (!yytrial)
{
				ForNode* node = newNode<ForNode>();
				node->dsqlLabelName = yyvsp[-2].metaNamePtr;
				node->dsqlSelect = yyvsp[0].selectNode;
				yyval.forNode = node;
			}
break;
case 563:
yyval.forNode = yyvsp[0].forNode;
break;
case 564:
  if (!yytrial)
{
				ForNode* node = yyvsp[-4].forNode;
				node->statement = yyvsp[0].stmtNode;
				yyval.forNode = node;
			}
break;
case 565:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 566:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 567:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 569:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 570:
  if (!yytrial)
{ yyval.execStatementNode = newNode<ExecStatementNode>(); }
break;
case 571:
yyval.execStatementNode = yyvsp[0].execStatementNode;
break;
case 572:
yyval.execStatementNode = yyvsp[-2].execStatementNode;
break;
case 573:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-4].execStatementNode;
		}
break;
case 574:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->outputs = yyvsp[0].valueListNode;
		}
break;
case 575:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->dsqlLabelName = yyvsp[-4].metaNamePtr;
			yyval.execStatementNode->innerStmt = yyvsp[0].stmtNode;
		}
break;
case 576:
  if (!yytrial)
{ yyvsp[-1].execStatementNode->sql = yyvsp[0].valueExprNode; }
break;
case 577:
yyval.execStatementNode = yyvsp[-4].execStatementNode;
break;
case 578:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 579:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 582:
  if (!yytrial)
{
			if (!yyvsp[-3].execStatementNode->inputNames)
				yyvsp[-3].execStatementNode->inputNames = FB_NEW_POOL(getPool()) EDS::ParamNames(getPool());

			yyvsp[-3].execStatementNode->inputNames->add(yyvsp[-2].metaNamePtr);

			if (!yyvsp[-3].execStatementNode->inputs)
				yyvsp[-3].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-3].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 585:
  if (!yytrial)
{
			if (!yyvsp[-1].execStatementNode->inputs)
				yyvsp[-1].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-1].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 588:
yyval.execStatementNode = yyvsp[-1].execStatementNode;
break;
case 591:
  if (!yytrial)
{ setClause(yyvsp[-5].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 592:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 593:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->userName, "USER", yyvsp[0].valueExprNode); }
break;
case 594:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->password, "PASSWORD", yyvsp[0].valueExprNode); }
break;
case 595:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->role, "ROLE", yyvsp[0].valueExprNode); }
break;
case 596:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traAutonomous); }
break;
case 597:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traCommon); }
break;
case 598:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->useCallerPrivs, "CALLER PRIVILEGES"); }
break;
case 599:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-5].boolExprNode;
			node->trueAction = yyvsp[-2].stmtNode;
			node->falseAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 600:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-3].boolExprNode;
			node->trueAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 601:
  if (!yytrial)
{
			PostEventNode* node = newNode<PostEventNode>();
			node->event = yyvsp[-1].valueExprNode;
			node->argument = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 602:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 603:
  if (!yytrial)
{
			ForNode* node = newNode<ForNode>();
			node->dsqlSelect = yyvsp[-2].selectNode;
			node->dsqlInto = yyvsp[0].valueListNode;
			yyval.stmtNode = node;
		}
break;
case 604:
  if (!yytrial)
{
			VariableNode* node = newNode<VariableNode>();
			node->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.valueExprNode = node;
		}
break;
case 605:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 606:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 607:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 608:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 609:
  if (!yytrial)
{
			LoopNode* node = newNode<LoopNode>();
			node->dsqlLabelName = yyvsp[-6].metaNamePtr;
			node->dsqlExpr = yyvsp[-3].boolExprNode;
			node->statement = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 610:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 611:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[-1].metaNamePtr; }
break;
case 612:
  if (!yytrial)
{ yyval.stmtNode = newNode<ContinueLeaveNode>(blr_leave); }
break;
case 613:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_leave);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 614:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_continue_loop);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 615:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 617:
  if (!yytrial)
{ yyval.declCursorNode = NULL; }
break;
case 619:
  if (!yytrial)
{ yyval.declCursorNode = newNode<DeclareCursorNode>(*yyvsp[0].metaNamePtr, DeclareCursorNode::CUR_TYPE_FOR); }
break;
case 620:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 621:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 622:
  if (!yytrial)
{ yyval.errorHandlerNode = newNode<ErrorHandlerNode>(); }
break;
case 623:
yyval.exceptionArray = NOTRIAL(&yyvsp[0].errorHandlerNode->conditions);
break;
case 624:
  if (!yytrial)
{
				ErrorHandlerNode* node = yyvsp[-4].errorHandlerNode;
				node->action = yyvsp[0].stmtNode;
				yyval.stmtNode = node;
			}
break;
case 625:
yyval.exceptionArray = yyvsp[0].exceptionArray;
break;
case 627:
yyval.exceptionArray = yyvsp[-2].exceptionArray;
break;
case 629:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_CODE;
			item.code = yyvsp[0].int32Val;
		}
break;
case 630:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_STATE;
			item.name = yyvsp[0].intlStringPtr->getString();
		}
break;
case 631:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::GDS_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 632:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::XCP_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 633:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-1].exceptionArray->add();
			item.type = ExceptionItem::XCP_DEFAULT;
		}
break;
case 637:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_open, *yyvsp[0].metaNamePtr); }
break;
case 638:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_close, *yyvsp[0].metaNamePtr); }
break;
case 639:
  if (!yytrial)
{ yyval.cursorStmtNode = newNode<CursorStmtNode>(blr_cursor_fetch_scroll); }
break;
case 640:
yyval.cursorStmtNode = yyvsp[0].cursorStmtNode;
break;
case 641:
  if (!yytrial)
{
			CursorStmtNode* cursorStmt = yyvsp[-5].cursorStmtNode;
			cursorStmt->dsqlName = *yyvsp[-1].metaNamePtr;
			cursorStmt->dsqlIntoStmt = yyvsp[0].valueListNode;
			yyval.stmtNode = cursorStmt;
		}
break;
case 642:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_fetch, *yyvsp[-1].metaNamePtr, yyvsp[0].valueListNode); }
break;
case 643:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_bof; }
break;
case 644:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_eof; }
break;
case 645:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_backward; }
break;
case 646:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_forward; }
break;
case 647:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_absolute;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 648:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_relative;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 649:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 650:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 651:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 652:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 653:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 654:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 655:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 656:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 657:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 658:
  if (!yytrial)
{
			ExecBlockNode* node = yyvsp[-7].execBlockNode;
			node->localDeclList = yyvsp[-1].compoundStmtNode;
			node->body = yyvsp[0].stmtNode;
			yyval.execBlockNode = node;
		}
break;
case 663:
  if (!yytrial)
{ yyvsp[-4].parametersClause->add(newNode<ParameterClause>(yyvsp[-3].legacyField, optName(yyvsp[-2].metaNamePtr), (ValueSourceClause*) NULL, yyvsp[0].valueExprNode)); }
break;
case 664:
  if (!yytrial)
{
			CreateAlterViewNode* node = newNode<CreateAlterViewNode>(yyvsp[-4].relSourceNode, yyvsp[-3].valueListNode, yyvsp[-1].selectExprNode);
			node->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(5));
			node->withCheckOption = yyvsp[0].boolVal;
			yyval.createAlterViewNode = node;
		}
break;
case 665:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 666:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyvsp[0].createAlterViewNode->create = false;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 667:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 668:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 669:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-6].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(5), YYPOSNARG(7));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 670:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-5].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 671:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-8].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-7].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-6].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-5].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-3].metaNamePtr;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(7), YYPOSNARG(9));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 672:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-7].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-6].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-5].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-4].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-2].metaNamePtr;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 673:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-8].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-6].metaNamePtr;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(7), YYPOSNARG(9));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 674:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-7].metaNamePtr);
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].uint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->relationName = *yyvsp[-5].metaNamePtr;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 675:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = yyvsp[0].createAlterTriggerNode;
			yyval.createAlterTriggerNode->alter = true;
		}
break;
case 676:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(true); }
break;
case 677:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(false); }
break;
case 678:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::empty(); }
break;
case 679:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1; }
break;
case 680:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[0].uint64Val; }
break;
case 681:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val; }
break;
case 682:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_CONNECT; }
break;
case 683:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_DISCONNECT; }
break;
case 684:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_START; }
break;
case 685:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_COMMIT; }
break;
case 686:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_ROLLBACK; }
break;
case 688:
  if (!yytrial)
{
			yyval.uint64Val = TRIGGER_TYPE_DDL | DDL_TRIGGER_ANY;
		}
break;
case 689:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TABLE); }
break;
case 690:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TABLE); }
break;
case 691:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TABLE); }
break;
case 692:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PROCEDURE); }
break;
case 693:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PROCEDURE); }
break;
case 694:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PROCEDURE); }
break;
case 695:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_FUNCTION); }
break;
case 696:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_FUNCTION); }
break;
case 697:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_FUNCTION); }
break;
case 698:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TRIGGER); }
break;
case 699:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TRIGGER); }
break;
case 700:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TRIGGER); }
break;
case 701:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_EXCEPTION); }
break;
case 702:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_EXCEPTION); }
break;
case 703:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_EXCEPTION); }
break;
case 704:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_VIEW); }
break;
case 705:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_VIEW); }
break;
case 706:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_VIEW); }
break;
case 707:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_DOMAIN); }
break;
case 708:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_DOMAIN); }
break;
case 709:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_DOMAIN); }
break;
case 710:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_ROLE); }
break;
case 711:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_ROLE); }
break;
case 712:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_ROLE); }
break;
case 713:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_SEQUENCE); }
break;
case 714:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_SEQUENCE); }
break;
case 715:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_SEQUENCE); }
break;
case 716:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_USER); }
break;
case 717:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_USER); }
break;
case 718:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_USER); }
break;
case 719:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_INDEX); }
break;
case 720:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_INDEX); }
break;
case 721:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_INDEX); }
break;
case 722:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_COLLATION); }
break;
case 723:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_COLLATION); }
break;
case 724:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_CHARACTER_SET); }
break;
case 725:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE); }
break;
case 726:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PACKAGE); }
break;
case 727:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE); }
break;
case 728:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE_BODY); }
break;
case 729:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE_BODY); }
break;
case 730:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_MAPPING); }
break;
case 731:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_MAPPING); }
break;
case 732:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_MAPPING); }
break;
case 733:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-2].uint64Val | yyvsp[0].uint64Val; }
break;
case 734:
  if (!yytrial)
{ yyval.uint64Val = 0; }
break;
case 735:
  if (!yytrial)
{ yyval.uint64Val = 1; }
break;
case 736:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 0, 0); }
break;
case 737:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 0, 0); }
break;
case 738:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 0, 0); }
break;
case 739:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 0); }
break;
case 740:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 0); }
break;
case 741:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 0); }
break;
case 742:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 0); }
break;
case 743:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 0); }
break;
case 744:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 0); }
break;
case 745:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 3); }
break;
case 746:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 2); }
break;
case 747:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 3); }
break;
case 748:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 1); }
break;
case 749:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 2); }
break;
case 750:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 1); }
break;
case 751:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 752:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(yyvsp[0].int32Val); }
break;
case 753:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 754:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 755:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 756:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterRelationNode>(yyvsp[0].relSourceNode); }
break;
case 757:
yyval.relationNode = yyvsp[0].relationNode;
break;
case 758:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].relationNode; }
break;
case 759:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 760:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 761:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 762:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 763:
  if (!yytrial)
{ yyval.alterDatabaseNode = newNode<AlterDatabaseNode>(); }
break;
case 764:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].alterDatabaseNode; }
break;
case 765:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDomainNode; }
break;
case 766:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 767:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 768:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 769:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 770:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 771:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 772:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 773:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 774:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 775:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 776:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 777:
  if (!yytrial)
{ yyval.alterDomainNode = newNode<AlterDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 778:
yyval.alterDomainNode = yyvsp[0].alterDomainNode;
break;
case 779:
  if (!yytrial)
{ yyval.alterDomainNode = yyvsp[-2].alterDomainNode; }
break;
case 781:
yyval.alterDomainNode = yyvsp[-1].alterDomainNode;
break;
case 783:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setDefault, "DOMAIN DEFAULT", yyvsp[0].valueSourceClause); }
break;
case 784:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 785:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 786:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropDefault, "DOMAIN DROP DEFAULT"); }
break;
case 787:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropConstraint, "DOMAIN DROP CONSTRAINT"); }
break;
case 788:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", false); }
break;
case 789:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", true); }
break;
case 790:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->renameTo, "DOMAIN NAME", *yyvsp[0].metaNamePtr); }
break;
case 791:
  if (!yytrial)
{
			/*// FIXME: ALTER DOMAIN doesn't support collations, and altered domain's*/
			/*// collation is always lost.*/
			dsql_fld* type = yyvsp[0].legacyField;
			type->collate = "";
			setClause(yyvsp[-2].alterDomainNode->type, "DOMAIN TYPE", type);
		}
break;
case 793:
yyval.relationNode = yyvsp[-2].relationNode;
break;
case 795:
  if (!yytrial)
{
			RelationNode::DropColumnClause* clause = newNode<RelationNode::DropColumnClause>();
			clause->name = *yyvsp[-1].metaNamePtr;
			clause->cascade = yyvsp[0].boolVal;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 796:
  if (!yytrial)
{
			RelationNode::DropConstraintClause* clause = newNode<RelationNode::DropConstraintClause>();
			clause->name = *yyvsp[0].metaNamePtr;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 799:
  if (!yytrial)
{
			RelationNode::AlterColPosClause* clause = newNode<RelationNode::AlterColPosClause>();
			clause->name = *yyvsp[-2].metaNamePtr;
			clause->newPos = yyvsp[0].int32Val;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 800:
  if (!yytrial)
{
			RelationNode::AlterColNameClause* clause = newNode<RelationNode::AlterColNameClause>();
			clause->fromName = *yyvsp[-2].metaNamePtr;
			clause->toName = *yyvsp[0].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 801:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = false;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 802:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = true;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 803:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[0].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 804:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-3].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-5].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 805:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 806:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->defaultValue = yyvsp[0].valueSourceClause;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 807:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->dropDefault = true;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 808:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->identityRestart = true;
			clause->identityRestartValue = yyvsp[0].nullableInt64Val;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 895:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 896:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 897:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 898:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 899:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, true); }
break;
case 900:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, false); }
break;
case 901:
  if (!yytrial)
{
			AlterExternalFunctionNode* node = newNode<AlterExternalFunctionNode>(*yyvsp[-2].metaNamePtr);
			if (yyvsp[-1].stringPtr)
				node->clauses.name = *yyvsp[-1].stringPtr;
			if (yyvsp[0].stringPtr)
				node->clauses.udfModule = *yyvsp[0].stringPtr;
			yyval.ddlNode = node;
		}
break;
case 902:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 903:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 904:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 905:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 906:
  if (!yytrial)
{
			yyval.mappingNode = newNode<MappingNode>(MappingNode::MAP_RPL, "AutoAdminImplementationMapping");
			yyval.mappingNode->op = yyvsp[-3].boolVal ? MappingNode::MAP_RPL : MappingNode::MAP_DROP;
			yyval.mappingNode->from = newNode<IntlString>(FB_DOMAIN_ANY_RID_ADMINS);
			yyval.mappingNode->fromType = newNode<MetaName>(FB_PREDEFINED_GROUP);
			yyval.mappingNode->mode = 'P';
			yyval.mappingNode->plugin = newNode<MetaName>("Win_Sspi");
			yyval.mappingNode->role = true;
			yyval.mappingNode->to = yyvsp[-4].metaNamePtr;
			yyval.mappingNode->validateAdmin();
		}
break;
case 907:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 908:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 911:
yyval.dbFilesClause = NOTRIAL(&yyvsp[-1].alterDatabaseNode->files);
break;
case 913:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 914:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_DROP_DIFFERENCE; }
break;
case 915:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_BEGIN_BACKUP; }
break;
case 916:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_END_BACKUP; }
break;
case 917:
  if (!yytrial)
{ yyvsp[-5].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 918:
yyval.alterDatabaseNode = yyvsp[-3].alterDatabaseNode;
break;
case 919:
  if (!yytrial)
{
			setClauseFlag(yyvsp[-5].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT");
			yyvsp[-5].alterDatabaseNode->cryptPlugin = *yyvsp[-2].metaNamePtr;
		}
break;
case 920:
  if (!yytrial)
{ setClauseFlag(yyvsp[-1].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT"); }
break;
case 921:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->linger = yyvsp[0].int32Val; }
break;
case 922:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->linger = 0; }
break;
case 924:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->keyName = *yyvsp[0].metaNamePtr; }
break;
case 925:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-6].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-5].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-4].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-3].nullableIntVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(5), YYPOSNARG(7));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 926:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-5].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 927:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-3].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-2].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-1].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[0].nullableIntVal;
		}
break;
case 928:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::val(yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1); }
break;
case 929:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::empty(); }
break;
case 930:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 931:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 932:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropIndexNode>(*yyvsp[0].metaNamePtr); }
break;
case 933:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 934:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, false); }
break;
case 935:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropTriggerNode>(*yyvsp[0].metaNamePtr); }
break;
case 936:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, true); }
break;
case 937:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFilterNode>(*yyvsp[0].metaNamePtr); }
break;
case 938:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 939:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 940:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 941:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropShadowNode>(yyvsp[-1].int32Val, yyvsp[0].boolVal); }
break;
case 942:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 943:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 944:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 945:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropCollationNode>(*yyvsp[0].metaNamePtr); }
break;
case 946:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[-3].metaNamePtr, yyvsp[0].metaNamePtr); }
break;
case 947:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[0].metaNamePtr); }
break;
case 948:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageNode>(*yyvsp[0].metaNamePtr); }
break;
case 949:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageBodyNode>(*yyvsp[0].metaNamePtr); }
break;
case 950:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 951:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 952:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 953:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 954:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 958:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-2].legacyField;
			yyval.legacyField->notNull = true;
		}
break;
case 961:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 962:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
		}
break;
case 963:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 966:
  if (!yytrial)
{
			yyvsp[-3].legacyField->ranges = yyvsp[-1].valueListNode;
			yyvsp[-3].legacyField->dimensions = yyvsp[-3].legacyField->ranges->items.getCount() / 2;
			yyvsp[-3].legacyField->elementDtype = yyvsp[-3].legacyField->dtype;
			yyval.legacyField = yyvsp[-3].legacyField;
		}
break;
case 967:
  if (!yytrial)
{
			yyvsp[-4].legacyField->ranges = yyvsp[-2].valueListNode;
			yyvsp[-4].legacyField->dimensions = yyvsp[-4].legacyField->ranges->items.getCount() / 2;
			yyvsp[-4].legacyField->elementDtype = yyvsp[-4].legacyField->dtype;
			if (yyvsp[0].metaNamePtr)
				yyvsp[-4].legacyField->charSet = *yyvsp[0].metaNamePtr;
			yyval.legacyField = yyvsp[-4].legacyField;
		}
break;
case 969:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueListNode->items[0])->add(yyvsp[0].valueListNode->items[1]); }
break;
case 970:
  if (!yytrial)
{
			if (yyvsp[0].int32Val < 1)
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[0].int32Val))->add(MAKE_const_slong(1));
			else
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(1))->add(MAKE_const_slong(yyvsp[0].int32Val));
		}
break;
case 971:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[-2].int32Val))->add(MAKE_const_slong(yyvsp[0].int32Val)); }
break;
case 973:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-1].legacyField;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 977:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
																	Arg::Str("BIGINT"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
																Arg::Str("BIGINT"));
			}

			yyval.legacyField->dtype = dtype_int64;
			yyval.legacyField->length = sizeof(SINT64);
		}
break;
case 978:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
		}
break;
case 979:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_short;
			yyval.legacyField->length = sizeof(SSHORT);
		}
break;
case 980:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			stmt_ambiguous = true;

			if (client_dialect <= SQL_DIALECT_V5)
			{
				/* Post warning saying that DATE is equivalent to TIMESTAMP*/
				ERRD_post_warning(Arg::Warning(isc_sqlwarn) << Arg::Num(301) <<
								  Arg::Warning(isc_dtype_renamed));
				yyval.legacyField->dtype = dtype_timestamp;
				yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
			}
			else if (client_dialect == SQL_DIALECT_V6_TRANSITION)
				yyabandon(-104, isc_transitional_date);
			else
			{
				yyval.legacyField->dtype = dtype_sql_date;
				yyval.legacyField->length = sizeof(ULONG);
			}
		}
break;
case 981:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
																		  Arg::Str("TIME"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
																		  Arg::Str("TIME"));
			}
			yyval.legacyField->dtype = dtype_sql_time;
			yyval.legacyField->length = sizeof(SLONG);
		}
break;
case 982:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_timestamp;
			yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
		}
break;
case 983:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_boolean;
			yyval.legacyField->length = sizeof(UCHAR);
		}
break;
case 986:
  if (!yytrial)
{ yyval.legacyField = newNode<dsql_fld>(); }
break;
case 987:
yyval.legacyField = NOTRIAL(yyvsp[0].legacyField);
break;
case 988:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-4].legacyField;
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = yyvsp[-1].uintVal;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 989:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->subType = 0;
		}
break;
case 990:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 991:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = 80;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 992:
  if (!yytrial)
{ yyval.uintVal = (USHORT) 80; }
break;
case 993:
  if (!yytrial)
{ yyval.uintVal = (USHORT) yyvsp[0].int32Val; }
break;
case 994:
  if (!yytrial)
{ yyvsp[0].legacyField->subType = (USHORT) 0; }
break;
case 995:
  if (!yytrial)
{ yyvsp[-2].legacyField->subType = (USHORT) yyvsp[0].int32Val; }
break;
case 996:
  if (!yytrial)
{ yyvsp[-2].legacyField->subTypeName = *yyvsp[0].metaNamePtr; }
break;
case 997:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 998:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 999:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 1000:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 1001:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 1002:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1003:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
		}
break;
case 1004:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1013:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_numeric;
		}
break;
case 1014:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_decimal;

			if (yyval.legacyField->dtype == dtype_short)
			{
				yyval.legacyField->dtype = dtype_long;
				yyval.legacyField->length = sizeof(SLONG);
			}
		}
break;
case 1015:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
			yyval.legacyField->precision = 9;
		}
break;
case 1016:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[-1].int32Val < 1 || yyvsp[-1].int32Val > 18)
				yyabandon(-842, isc_precision_err);	/* Precision must be between 1 and 18.*/

			if (yyvsp[-1].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}

					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-1].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1017:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[-3].int32Val < 1 || yyvsp[-3].int32Val > 18)
				yyabandon (-842, isc_precision_err);	/* Precision should be between 1 and 18*/

			if (yyvsp[-1].int32Val > yyvsp[-3].int32Val || yyvsp[-1].int32Val < 0)
				yyabandon (-842, isc_scale_nogt);	/* Scale must be between 0 and precision*/

			if (yyvsp[-3].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}
					/* client_dialect >= SQL_DIALECT_V6*/
					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-3].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->scale = - (SSHORT) yyvsp[-1].int32Val;
		}
break;
case 1020:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (yyvsp[0].int32Val > 7)
			{
				yyval.legacyField->dtype = dtype_double;
				yyval.legacyField->length = sizeof(double);
			}
			else
			{
				yyval.legacyField->dtype = dtype_real;
				yyval.legacyField->length = sizeof(float);
			}
		}
break;
case 1021:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1022:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_real;
			yyval.legacyField->length = sizeof(float);
		}
break;
case 1023:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1024:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 1025:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 1029:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_SET;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1030:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = (yyvsp[0].boolVal ? UserSavepointNode::CMD_RELEASE_ONLY : UserSavepointNode::CMD_RELEASE);
			node->name = *yyvsp[-1].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1031:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1032:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1033:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_ROLLBACK;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1036:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_COMMIT, yyvsp[0].boolVal); }
break;
case 1037:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_ROLLBACK, yyvsp[0].boolVal); }
break;
case 1040:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1041:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1044:
  if (!yytrial)
{ yyval.setTransactionNode = newNode<SetTransactionNode>(); }
break;
case 1045:
yyval.setTransactionNode = yyvsp[0].setTransactionNode;
break;
case 1046:
  if (!yytrial)
{ yyval.setTransactionNode = yyvsp[-2].setTransactionNode; }
break;
case 1047:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(yyvsp[0].metaNamePtr); }
break;
case 1048:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(); }
break;
case 1052:
yyval.setTransactionNode = yyvsp[-1].setTransactionNode;
break;
case 1054:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", true); }
break;
case 1055:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", false); }
break;
case 1056:
  if (!yytrial)
{ setClause(yyvsp[-1].setTransactionNode->wait, "[NO] WAIT", true); }
break;
case 1057:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->wait, "[NO] WAIT", false); }
break;
case 1058:
  if (!yytrial)
{ setClause(yyvsp[-1].setTransactionNode->isoLevel, "ISOLATION LEVEL", yyvsp[0].uintVal); }
break;
case 1059:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->noAutoUndo, "NO AUTO UNDO", true); }
break;
case 1060:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->ignoreLimbo, "IGNORE LIMBO", true); }
break;
case 1061:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->restartRequests, "RESTART REQUESTS", true); }
break;
case 1062:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->lockTimeout, "LOCK TIMEOUT", (USHORT) yyvsp[0].int32Val); }
break;
case 1063:
  if (!yytrial)
{ checkDuplicateClause(yyvsp[-1].setTransactionNode->reserveList, "RESERVING"); }
break;
case 1064:
yyval.setTransactionNode = yyvsp[-2].setTransactionNode;
break;
case 1066:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 1069:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1070:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1071:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONCURRENCY; }
break;
case 1072:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1073:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1074:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1075:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_REC_VERSION; }
break;
case 1076:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1077:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1078:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_SHARED; }
break;
case 1079:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_PROTECTED; }
break;
case 1080:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_READ; }
break;
case 1081:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_WRITE; }
break;
case 1082:
  if (!yytrial)
{ yyvsp[-1].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1083:
  if (!yytrial)
{ yyvsp[-3].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1084:
  if (!yytrial)
{ yyval.setTransactionRestrictionClause = newNode<SetTransactionNode::RestrictionOption>(yyvsp[-1].metaNameArray, yyvsp[0].uintVal); }
break;
case 1085:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1086:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].uintVal | yyvsp[0].uintVal; }
break;
case 1087:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1088:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1089:
  if (!yytrial)
{ yyval.ddlNode = newNode<SetStatisticsNode>(*yyvsp[0].metaNamePtr); }
break;
case 1090:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-2].intVal, QualifiedName(""), "", *yyvsp[0].stringPtr); }
break;
case 1091:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, QualifiedName(*yyvsp[-2].metaNamePtr), "", *yyvsp[0].stringPtr); }
break;
case 1092:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, QualifiedName(*yyvsp[-3].metaNamePtr), *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1093:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, *yyvsp[-3].qualifiedNamePtr, *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1094:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, *yyvsp[-2].qualifiedNamePtr, "", *yyvsp[0].stringPtr); }
break;
case 1095:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 1096:
  if (!yytrial)
{
				yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[0].metaNamePtr);
			}
break;
case 1097:
yyval.createAlterUserNode = yyvsp[0].createAlterUserNode;
break;
case 1098:
  if (!yytrial)
{
				CreateAlterUserNode* node = yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
				node->comment = yyvsp[0].stringPtr;
			}
break;
case 1101:
  if (!yytrial)
{ yyval.intVal = obj_database; }
break;
case 1102:
  if (!yytrial)
{ yyval.intVal = obj_field; }
break;
case 1103:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1104:
  if (!yytrial)
{ yyval.intVal = obj_view; }
break;
case 1105:
  if (!yytrial)
{ yyval.intVal = obj_trigger; }
break;
case 1106:
  if (!yytrial)
{ yyval.intVal = obj_blob_filter; }
break;
case 1107:
  if (!yytrial)
{ yyval.intVal = obj_exception; }
break;
case 1108:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1109:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1110:
  if (!yytrial)
{ yyval.intVal = obj_index; }
break;
case 1111:
  if (!yytrial)
{ yyval.intVal = obj_sql_role; }
break;
case 1112:
  if (!yytrial)
{ yyval.intVal = obj_charset; }
break;
case 1113:
  if (!yytrial)
{ yyval.intVal = obj_collation; }
break;
case 1114:
  if (!yytrial)
{ yyval.intVal = obj_package_header; }
break;
case 1115:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1116:
  if (!yytrial)
{ yyval.intVal = obj_parameter; }
break;
case 1117:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1118:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1119:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1120:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1121:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1122:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1123:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr); }
break;
case 1124:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr, *yyvsp[-2].metaNamePtr); }
break;
case 1125:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 1126:
  if (!yytrial)
{ yyval.stringPtr = newString(""); }
break;
case 1127:
  if (!yytrial)
{
			SelectNode* node = newNode<SelectNode>();
			node->dsqlExpr = yyvsp[-2].selectExprNode;
			node->dsqlForUpdate = yyvsp[-1].boolVal;
			node->dsqlWithLock = yyvsp[0].boolVal;
			yyval.selectNode = node;
		}
break;
case 1128:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1129:
  if (!yytrial)
{ yyval.boolVal = true; /* for_update_list is ignored */ }
break;
case 1130:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1131:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1132:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1133:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1134:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-2].recSourceNode;
			node->orderClause = yyvsp[-1].valueListNode;
			node->rowsClause = yyvsp[0].rowsClause;
			node->withClause = yyvsp[-3].withClause;
		}
break;
case 1135:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-3].recSourceNode;
			node->orderClause = yyvsp[-2].valueListNode;

			if (yyvsp[-1].valueExprNode || yyvsp[0].valueExprNode)
			{
				RowsClause* rowsNode = newNode<RowsClause>();
				rowsNode->skip = yyvsp[-1].valueExprNode;
				rowsNode->length = yyvsp[0].valueExprNode;
				node->rowsClause = rowsNode;
			}

			node->withClause = yyvsp[-4].withClause;
		}
break;
case 1136:
  if (!yytrial)
{ yyval.withClause = NULL; }
break;
case 1137:
  if (!yytrial)
{
			yyval.withClause = yyvsp[0].withClause;
			yyval.withClause->recursive = true;
		}
break;
case 1138:
  if (!yytrial)
{ yyval.withClause = yyvsp[0].withClause; }
break;
case 1139:
  if (!yytrial)
{
			yyval.withClause = newNode<WithClause>();
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1140:
  if (!yytrial)
{
			yyval.withClause = yyvsp[-2].withClause;
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1141:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-1].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			yyval.selectExprNode->alias = yyvsp[-5].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[-4].metaNameArray;
		}
break;
case 1142:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[0].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_VALUE;
		}
break;
case 1143:
  if (!yytrial)
{
			yyvsp[0].selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_SINGLETON;
			yyval.valueExprNode = newNode<SubQueryNode>(blr_via, yyvsp[0].selectExprNode);
		}
break;
case 1144:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].rseNode; }
break;
case 1145:
  if (!yytrial)
{
			UnionSourceNode* node = yyvsp[-3].recSourceNode->as<UnionSourceNode>();
			if (node && !node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1146:
  if (!yytrial)
{
			UnionSourceNode* node = yyvsp[-3].recSourceNode->as<UnionSourceNode>();
			if (node && node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlAll = true;
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1148:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlFirst = yyvsp[-7].valueListNode ? yyvsp[-7].valueListNode->items[1] : NULL;
			rse->dsqlSkip = yyvsp[-7].valueListNode ? yyvsp[-7].valueListNode->items[0] : NULL;
			rse->dsqlDistinct = yyvsp[-6].valueListNode;
			rse->dsqlSelectList = yyvsp[-5].valueListNode;
			rse->dsqlFrom = yyvsp[-4].recSourceListNode;
			rse->dsqlWhere = yyvsp[-3].boolExprNode;
			rse->dsqlGroup = yyvsp[-2].valueListNode;
			rse->dsqlHaving = yyvsp[-1].boolExprNode;
			rse->rse_plan = yyvsp[0].planNode;
			yyval.rseNode = rse;
		}
break;
case 1149:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1150:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(yyvsp[-1].valueExprNode); }
break;
case 1151:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(1u)->add(yyvsp[0].valueExprNode); }
break;
case 1152:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(NULL); }
break;
case 1153:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1154:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1155:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1156:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1157:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1158:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1159:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1160:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1161:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1162:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1163:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1164:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1166:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			yyval.valueExprNode = fieldNode;
		}
break;
case 1168:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DsqlAliasNode>(*yyvsp[0].metaNamePtr, yyvsp[-2].valueExprNode); }
break;
case 1171:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[0].recSourceListNode; }
break;
case 1172:
  if (!yytrial)
{ yyval.recSourceListNode = newNode<RecSourceListNode>(yyvsp[0].recSourceNode); }
break;
case 1173:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[-2].recSourceListNode->add(yyvsp[0].recSourceNode); }
break;
case 1177:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].selectExprNode; }
break;
case 1178:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[-1].recSourceNode; }
break;
case 1179:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-4].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			if (yyvsp[-1].metaNamePtr)
				yyval.selectExprNode->alias = yyvsp[-1].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[0].metaNameArray;
		}
break;
case 1180:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1182:
  if (!yytrial)
{ yyval.metaNameArray = NULL; }
break;
case 1183:
  if (!yytrial)
{ yyval.metaNameArray = yyvsp[-1].metaNameArray; }
break;
case 1184:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1185:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1189:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = blr_inner;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].recSourceNode);
			yyval.recSourceNode = rse;
		}
break;
case 1190:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-2].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode)->add(yyvsp[0].recSourceNode);
			rse->dsqlJoinUsing = newNode<ValueListNode>(0u);	/* using list with size 0 -> natural*/
			yyval.recSourceNode = rse;
		}
break;
case 1191:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlWhere = yyvsp[0].boolExprNode;
			yyval.recSourceNode = rse;
		}
break;
case 1192:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlJoinUsing = yyvsp[0].valueListNode;
			yyval.recSourceNode = rse;
		}
break;
case 1193:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1194:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1195:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1196:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-1].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1197:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1198:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-1].metaNamePtr, *yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1199:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1200:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1202:
  if (!yytrial)
{
			RelationSourceNode* node = newNode<RelationSourceNode>(*yyvsp[-2].metaNamePtr);
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.relSourceNode = node;
		}
break;
case 1203:
  if (!yytrial)
{ yyval.relSourceNode = newNode<RelationSourceNode>(*yyvsp[0].metaNamePtr); }
break;
case 1204:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1205:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1206:
  if (!yytrial)
{ yyval.blrOp = blr_left; }
break;
case 1207:
  if (!yytrial)
{ yyval.blrOp = blr_right; }
break;
case 1208:
  if (!yytrial)
{ yyval.blrOp = blr_full; }
break;
case 1211:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1212:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1213:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1214:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1216:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1217:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1218:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1219:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1220:
  if (!yytrial)
{ yyval.planNode = NULL; }
break;
case 1221:
  if (!yytrial)
{ yyval.planNode = yyvsp[0].planNode; }
break;
case 1222:
  if (!yytrial)
{ yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE); }
break;
case 1223:
yyval.planNode = yyvsp[-1].planNode;
break;
case 1224:
  if (!yytrial)
{ yyval.planNode = yyvsp[-4].planNode; }
break;
case 1231:
  if (!yytrial)
{ yyvsp[-1].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1232:
  if (!yytrial)
{ yyvsp[-3].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1233:
  if (!yytrial)
{
			yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE);
			yyval.planNode->dsqlNames = yyvsp[-1].metaNameArray;
			yyval.planNode->accessType = yyvsp[0].accessType;
		}
break;
case 1235:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1236:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-1].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1237:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_SEQUENTIAL); }
break;
case 1238:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_INDICES); }
break;
case 1239:
yyval.accessType = yyvsp[-1].accessType;
break;
case 1240:
  if (!yytrial)
{ yyval.accessType = yyvsp[-4].accessType; }
break;
case 1241:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_NAVIGATIONAL); }
break;
case 1242:
  if (!yytrial)
{
			yyval.accessType = yyvsp[-3].accessType;
			yyval.accessType->items.insert(0).indexName = *yyvsp[-2].metaNamePtr;
		}
break;
case 1243:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-1].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1244:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-3].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1246:
yyval.accessType = yyvsp[-2].accessType;
break;
case 1248:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1249:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1250:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1251:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1252:
  if (!yytrial)
{
			OrderNode* node = newNode<OrderNode>(yyvsp[-2].valueExprNode);
			node->descending = yyvsp[-1].boolVal;
			node->nullsPlacement = yyvsp[0].nullsPlacement;
			yyval.valueExprNode = node;
		}
break;
case 1253:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1254:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1255:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1256:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_DEFAULT; }
break;
case 1257:
  if (!yytrial)
{ yyval.nullsPlacement = yyvsp[0].nullsPlacement; }
break;
case 1258:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_FIRST; }
break;
case 1259:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_LAST; }
break;
case 1260:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->length = yyvsp[0].valueExprNode;
		}
break;
case 1261:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->skip = newNode<ArithmeticNode>(blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));
			yyval.rowsClause->length = newNode<ArithmeticNode>(blr_add, true,
				newNode<ArithmeticNode>(blr_subtract, true, yyvsp[0].valueExprNode, yyvsp[-2].valueExprNode), MAKE_const_slong(1));
		}
break;
case 1262:
  if (!yytrial)
{ yyval.rowsClause = NULL; }
break;
case 1266:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1267:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1270:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1271:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-2].valueExprNode; }
break;
case 1272:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(1); }
break;
case 1273:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].storeNode->dsqlFields);
break;
case 1274:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-7].storeNode;
			node->dsqlValues = yyvsp[-2].valueListNode;
			node->dsqlReturning = yyvsp[0].returningClause;
		}
break;
case 1275:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-4].storeNode;
			node->dsqlRse = yyvsp[-1].selectExprNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1276:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-3].storeNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1277:
  if (!yytrial)
{
			StoreNode* node = newNode<StoreNode>();
			node->dsqlRelation = yyvsp[0].relSourceNode;
			yyval.storeNode = node;
		}
break;
case 1278:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = newNode<MergeNode>();
				node->relation = yyvsp[-4].relSourceNode;
				node->usingClause = yyvsp[-2].recSourceNode;
				node->condition = yyvsp[0].boolExprNode;
			}
break;
case 1279:
yyval.mergeNode = yyvsp[0].mergeNode;
break;
case 1280:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = yyvsp[-3].mergeNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1283:
yyval.mergeNode = yyvsp[-1].mergeNode;
break;
case 1286:
  if (!yytrial)
{ yyval.mergeMatchedClause = &yyvsp[-2].mergeNode->whenMatched.add(); }
break;
case 1287:
yyval.mergeMatchedClause = NOTRIAL(yyvsp[0].mergeMatchedClause);
break;
case 1289:
  if (!yytrial)
{ yyval.mergeNotMatchedClause = &yyvsp[-3].mergeNode->whenNotMatched.add(); }
break;
case 1290:
yyval.mergeNotMatchedClause = NOTRIAL(yyvsp[0].mergeNotMatchedClause);
break;
case 1292:
  if (!yytrial)
{ yyvsp[-4].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode; }
break;
case 1293:
  if (!yytrial)
{
			yyvsp[-6].mergeMatchedClause->condition = yyvsp[-4].boolExprNode;
			yyvsp[-6].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode;
		}
break;
case 1295:
  if (!yytrial)
{ yyvsp[-4].mergeMatchedClause->condition = yyvsp[-2].boolExprNode; }
break;
case 1296:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-2].mergeNotMatchedClause->fields);
break;
case 1297:
  if (!yytrial)
{ yyvsp[-8].mergeNotMatchedClause->values = yyvsp[-1].valueListNode; }
break;
case 1298:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-4].mergeNotMatchedClause->fields);
break;
case 1299:
  if (!yytrial)
{
			yyvsp[-10].mergeNotMatchedClause->values = yyvsp[-1].valueListNode;
			yyvsp[-10].mergeNotMatchedClause->condition = yyvsp[-8].boolExprNode;
		}
break;
case 1302:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-5].relSourceNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1303:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-2].relSourceNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1306:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-7].relSourceNode;
			node->statement = yyvsp[-5].compoundStmtNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1307:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-4].relSourceNode;
			node->statement = yyvsp[-2].compoundStmtNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1308:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = newNode<UpdateOrInsertNode>();
				node->relation = yyvsp[0].relSourceNode;
			}
break;
case 1309:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].updInsNode->fields);
break;
case 1310:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-6].updInsNode->matching);
break;
case 1311:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = yyvsp[-9].updInsNode;
				node->values = yyvsp[-4].valueListNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1313:
yyval.nestFieldArray = yyvsp[-1].nestFieldArray;
break;
case 1315:
  if (!yytrial)
{ yyval.returningClause = NULL; }
break;
case 1316:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[0].valueListNode;
		}
break;
case 1317:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[-2].valueListNode;
			yyval.returningClause->second = yyvsp[0].valueListNode;
		}
break;
case 1318:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1319:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1320:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(*yyvsp[0].metaNamePtr); }
break;
case 1321:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 1322:
  if (!yytrial)
{
			yyvsp[-2].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-2].compoundStmtNode;
		}
break;
case 1323:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = yyvsp[-2].fieldNode;
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1324:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = newNode<NullNode>();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1325:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = newNode<NullNode>();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1326:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1328:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1329:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 1330:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 1332:
yyval.nestFieldArray = yyvsp[0].nestFieldArray;
break;
case 1335:
  if (!yytrial)
{ yyvsp[-1].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1336:
  if (!yytrial)
{ yyvsp[-3].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1338:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1339:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			fieldNode->dsqlCursorField = true;
			yyval.fieldNode = fieldNode;
		}
break;
case 1340:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1342:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1343:
  if (!yytrial)
{ yyval.boolExprNode = valueToBool(yyvsp[0].valueExprNode); }
break;
case 1345:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_or, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1346:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_and, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1347:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1348:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[-1].boolExprNode; }
break;
case 1349:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = node;
		}
break;
case 1350:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1362:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1363:
  if (!yytrial)
{ yyval.blrOp = blr_eql; }
break;
case 1364:
  if (!yytrial)
{ yyval.blrOp = blr_lss; }
break;
case 1365:
  if (!yytrial)
{ yyval.blrOp = blr_gtr; }
break;
case 1366:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1367:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1368:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1369:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1370:
  if (!yytrial)
{ yyval.blrOp = blr_neq; }
break;
case 1371:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(yyvsp[-4].blrOp, yyvsp[-5].valueExprNode);
			node->dsqlFlag = yyvsp[-3].cmpBoolFlag;
			node->dsqlSpecialArg = yyvsp[-1].selectExprNode;
			yyval.boolExprNode = node;
		}
break;
case 1372:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ALL; }
break;
case 1373:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1374:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1375:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1376:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-5].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1377:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_between, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1378:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_between, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1380:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[-1].boolExprNode); }
break;
case 1381:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1382:
  if (!yytrial)
{
			ComparativeBoolNode* cmpNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(cmpNode);
		}
break;
case 1383:
  if (!yytrial)
{ yyval.blrOp = blr_containing; }
break;
case 1384:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1385:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1386:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1387:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1388:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1389:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1390:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1391:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1392:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1393:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-6].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1394:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-2].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = node;
		}
break;
case 1395:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1396:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_any, yyvsp[-1].selectExprNode); }
break;
case 1397:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_unique, yyvsp[-1].selectExprNode); }
break;
case 1398:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(1));
		}
break;
case 1399:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(2));
		}
break;
case 1400:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(3));
		}
break;
case 1401:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode); }
break;
case 1402:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode, true); }
break;
case 1403:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode)); }
break;
case 1404:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode, true)); }
break;
case 1405:
  if (!yytrial)
{ yyval.exprNode = yyvsp[0].selectExprNode; }
break;
case 1406:
  if (!yytrial)
{ yyval.exprNode = yyvsp[-1].valueListNode; }
break;
case 1407:
  if (!yytrial)
{ yyval.selectExprNode = yyvsp[-1].selectExprNode; }
break;
case 1408:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_ADD, *yyvsp[0].metaNamePtr);
		}
break;
case 1409:
yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
break;
case 1410:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1411:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[-1].metaNamePtr);
		}
break;
case 1412:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1413:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, "");
		}
break;
case 1414:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1415:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_RPL, *yyvsp[-1].metaNamePtr);
		}
break;
case 1416:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
		}
break;
case 1422:
yyval.createAlterUserNode = yyvsp[-1].createAlterUserNode;
break;
case 1424:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->firstName, "FIRSTNAME", yyvsp[0].stringPtr); }
break;
case 1425:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->middleName, "MIDDLENAME", yyvsp[0].stringPtr); }
break;
case 1426:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->lastName, "LASTNAME", yyvsp[0].stringPtr); }
break;
case 1427:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->password, "PASSWORD", yyvsp[0].stringPtr); }
break;
case 1428:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", Nullable<bool>(true)); }
break;
case 1429:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", Nullable<bool>(false)); }
break;
case 1430:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", Nullable<bool>(true)); }
break;
case 1431:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", Nullable<bool>(false)); }
break;
case 1433:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->plugin, "USING PLUGIN", yyvsp[0].metaNamePtr); }
break;
case 1438:
  if (!yytrial)
{
			yyvsp[-3].createAlterUserNode->addProperty(yyvsp[-2].metaNamePtr, yyvsp[0].stringPtr);
		}
break;
case 1439:
  if (!yytrial)
{
			yyvsp[-2].createAlterUserNode->addProperty(yyvsp[0].metaNamePtr);
		}
break;
case 1440:
yyval.mappingOp = MappingNode::MAP_ADD;
break;
case 1441:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1442:
yyval.mappingNode = yyvsp[0].mappingNode;
break;
case 1443:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1444:
yyval.mappingOp = MappingNode::MAP_MOD;
break;
case 1445:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1446:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1447:
yyval.mappingOp = MappingNode::MAP_RPL;
break;
case 1448:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1449:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1450:
  if (!yytrial)
{
 			MappingNode* node = newNode<MappingNode>(MappingNode::MAP_DROP, *yyvsp[0].metaNamePtr);
			node->global = yyvsp[-1].boolVal;
			yyval.mappingNode = node;
		}
break;
case 1451:
  if (!yytrial)
{
				yyval.mappingNode = newNode<MappingNode>(yyvsp[-1].mappingOp, *yyvsp[0].metaNamePtr);
			}
break;
case 1452:
yyval.mappingNode = yyvsp[-1].mappingNode;
break;
case 1453:
yyval.mappingNode = yyvsp[-4].mappingNode;
break;
case 1454:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-6].mappingNode;
			}
break;
case 1455:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1456:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[-1].metaNamePtr;
			yyvsp[-2].mappingNode->from = yyvsp[0].intlStringPtr;
		}
break;
case 1457:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[0].metaNamePtr;
			yyvsp[-2].mappingNode->from = newNode<IntlString>("*");
		}
break;
case 1459:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("USER"); }
break;
case 1460:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("GROUP"); }
break;
case 1462:
  if (!yytrial)
{ yyval.intlStringPtr = newNode<IntlString>(yyvsp[0].metaNamePtr->c_str()); }
break;
case 1463:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->plugin = yyvsp[-1].metaNamePtr;
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1464:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1465:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'S';
		}
break;
case 1466:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = 'M';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1467:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = '*';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1468:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1469:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1470:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->role = yyvsp[-1].boolVal;
			yyvsp[-3].mappingNode->to = yyvsp[0].metaNamePtr;
		}
break;
case 1471:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->role = yyvsp[0].boolVal;
		}
break;
case 1472:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1473:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1475:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[0].boolExprNode); }
break;
case 1477:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1481:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].fieldNode; }
break;
case 1483:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1490:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1491:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1492:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1493:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1494:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_add, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1495:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ConcatenateNode>(yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1496:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CollateNode>(yyvsp[-2].valueExprNode, *yyvsp[0].metaNamePtr); }
break;
case 1497:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_subtract, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1498:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_multiply, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1499:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_divide, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1500:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1501:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1502:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1503:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1504:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp); }
break;
case 1505:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp, *yyvsp[-2].metaNamePtr); }
break;
case 1506:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DomainValidationNode>(); }
break;
case 1507:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1508:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1509:
  if (!yytrial)
{ yyval.blrOp = blr_dbkey; }
break;
case 1510:
  if (!yytrial)
{ yyval.blrOp = blr_record_version2; }
break;
case 1511:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}

			yyval.valueExprNode = newNode<CurrentDateNode>();
		}
break;
case 1512:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}

			yyval.valueExprNode = newNode<CurrentTimeNode>(yyvsp[0].uintVal);
		}
break;
case 1513:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}

			CurrentTimeNode* node = newNode<CurrentTimeNode>(yyvsp[0].uintVal);
			node->dsqlLocal = true;
			yyval.valueExprNode = node;
		}
break;
case 1514:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentTimeStampNode>(yyvsp[0].uintVal); }
break;
case 1515:
  if (!yytrial)
{
			CurrentTimeStampNode* node = newNode<CurrentTimeStampNode>(yyvsp[0].uintVal);
			node->dsqlLocal = true;
			yyval.valueExprNode = node;
		}
break;
case 1516:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIME_PRECISION; }
break;
case 1517:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1518:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIMESTAMP_PRECISION; }
break;
case 1519:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1520:
  if (!yytrial)
{
			ArrayNode* node = newNode<ArrayNode>(yyvsp[-3].fieldNode);
			node->field->dsqlIndices = yyvsp[-1].valueListNode;
			yyval.valueExprNode = node;
		}
break;
case 1521:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1522:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1523:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1524:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1526:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1528:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1529:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].stringPtr->c_str(), CONSTANT_DOUBLE); }
break;
case 1530:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber < 0)
				yyval.valueExprNode = newNode<NegateNode>(MAKE_const_sint64(-signedNumber, yyvsp[0].scaledNumber.scale));
			else
				yyval.valueExprNode = MAKE_const_sint64(signedNumber, yyvsp[0].scaledNumber.scale);
		}
break;
case 1531:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_sint64((SINT64) yyvsp[0].scaledNumber.number, yyvsp[0].scaledNumber.scale); }
break;
case 1533:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(yyvsp[0].intlStringPtr, lex.att_charset); }
break;
case 1534:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_DATE);
		}
break;
case 1535:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIME);
		}
break;
case 1536:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIMESTAMP); }
break;
case 1537:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("", CONSTANT_BOOLEAN); }
break;
case 1538:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("1", CONSTANT_BOOLEAN); }
break;
case 1539:
  if (!yytrial)
{ yyval.valueExprNode = make_parameter(); }
break;
case 1540:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1541:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1542:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentRoleNode>(); }
break;
case 1543:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_CONNECTION_ID)); }
break;
case 1544:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRANSACTION_ID)); }
break;
case 1545:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_GDSCODE)); }
break;
case 1546:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLCODE)); }
break;
case 1547:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLSTATE)); }
break;
case 1548:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_ROWS_AFFECTED)); }
break;
case 1550:
  if (!yytrial)
{
			yyval.intlStringPtr = yyvsp[0].intlStringPtr;
			yyval.intlStringPtr->setCharSet(*yyvsp[-1].metaNamePtr);

			StrMark* mark = strMarks.get(yyvsp[0].intlStringPtr);

			if (mark)	/* hex string is not in strMarks*/
				mark->introduced = true;
		}
break;
case 1551:
  if (!yytrial)
{ yyval.stringPtr = newString(yyvsp[0].intlStringPtr->toUtf8(scratch)); }
break;
case 1553:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1554:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_POS_MAX)
				yyabandon(-842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1555:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_NEG_MAX)
				yyabandon(-842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1556:
  if (!yytrial)
{
			if (yyvsp[0].int32Val == 0)
				yyabandon(-842, isc_expec_positive);	/* Positive number expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1557:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_UNSIGNED_MAX)
				yyabandon(-842, isc_expec_ushort);	/* Unsigned short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1559:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1560:
  if (!yytrial)
{ yyval.int32Val = yyvsp[0].int32Val;}
break;
case 1561:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].aggNode; }
break;
case 1567:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION)); }
break;
case 1568:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1569:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(true, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1570:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1571:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1572:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1573:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1574:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1575:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1576:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1577:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1578:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(false, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1579:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(true, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1580:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1581:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_POP, yyvsp[-1].valueExprNode); }
break;
case 1582:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1583:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_POP, yyvsp[-1].valueExprNode); }
break;
case 1584:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_SAMP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1585:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_POP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1586:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_CORR, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1587:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1588:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1589:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrCountAggNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1590:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_INTERCEPT, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1591:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_R2, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1592:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SLOPE, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1593:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1594:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1595:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SYY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1596:
  if (!yytrial)
{ yyval.aggNode = newNode<DenseRankWinNode>(); }
break;
case 1597:
  if (!yytrial)
{ yyval.aggNode = newNode<RankWinNode>(); }
break;
case 1598:
  if (!yytrial)
{ yyval.aggNode = newNode<RowNumberWinNode>(); }
break;
case 1599:
  if (!yytrial)
{ yyval.aggNode = newNode<FirstValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1600:
  if (!yytrial)
{ yyval.aggNode = newNode<LastValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1601:
  if (!yytrial)
{ yyval.aggNode = newNode<NthValueWinNode>(yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1602:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1603:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, newNode<NullNode>()); }
break;
case 1604:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), newNode<NullNode>()); }
break;
case 1605:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1606:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, newNode<NullNode>()); }
break;
case 1607:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), newNode<NullNode>()); }
break;
case 1608:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1609:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1610:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_LAST); }
break;
case 1613:
  if (!yytrial)
{ yyval.valueExprNode = newNode<OverNode>(yyvsp[-5].aggNode, yyvsp[-2].valueListNode, yyvsp[-1].valueListNode); }
break;
case 1614:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1615:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1616:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(","), lex.att_charset); }
break;
case 1617:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1620:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ExtractNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 1624:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_bit, yyvsp[-1].valueExprNode); }
break;
case 1625:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1626:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1627:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_octet, yyvsp[-1].valueExprNode); }
break;
case 1628:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1629:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].sysFuncCallNode; }
break;
case 1681:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-6].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-4].valueExprNode)->add(MAKE_const_slong(yyvsp[-3].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1682:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1683:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1684:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1685:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-9].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-7].valueExprNode)->add(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1686:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1687:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr, newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1688:
  if (!yytrial)
{ yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1691:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_upcase, yyvsp[-1].valueExprNode); }
break;
case 1692:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_lowcase, yyvsp[-1].valueExprNode); }
break;
case 1693:
  if (!yytrial)
{
			/* SQL spec requires numbering to start with 1,*/
			/* hence we decrement the first parameter to make it*/
			/* compatible with the engine's implementation*/
			ArithmeticNode* subtractNode = newNode<ArithmeticNode>(
				blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));

			yyval.valueExprNode = newNode<SubstringNode>(yyvsp[-4].valueExprNode, subtractNode, yyvsp[-1].valueExprNode);
		}
break;
case 1694:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SubstringSimilarNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1695:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1696:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1697:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-4].blrOp, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 1698:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 1699:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 1700:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode); }
break;
case 1701:
  if (!yytrial)
{ yyval.blrOp = blr_trim_both; }
break;
case 1702:
  if (!yytrial)
{ yyval.blrOp = blr_trim_trailing; }
break;
case 1703:
  if (!yytrial)
{ yyval.blrOp = blr_trim_leading; }
break;
case 1704:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, ""), yyvsp[-1].valueListNode); }
break;
case 1705:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, ""), newNode<ValueListNode>(0)); }
break;
case 1706:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr), yyvsp[-1].valueListNode); }
break;
case 1707:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), newNode<ValueListNode>(0)); }
break;
case 1708:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CastNode>(yyvsp[-3].valueExprNode, yyvsp[-1].legacyField); }
break;
case 1711:
  if (!yytrial)
{
			ComparativeBoolNode* condition = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode);
			yyval.valueExprNode = newNode<ValueIfNode>(condition, newNode<NullNode>(), yyvsp[-3].valueExprNode);
		}
break;
case 1712:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ValueIfNode>(yyvsp[-5].boolExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1713:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CoalesceNode>(yyvsp[-1].valueListNode->addFront(yyvsp[-3].valueExprNode)); }
break;
case 1714:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-1].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-3].valueExprNode, conditions, values);
		}
break;
case 1715:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-3].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2 + 1);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			values->items[list->items.getCount() / 2] = yyvsp[-1].valueExprNode;

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-5].valueExprNode, conditions, values);
		}
break;
case 1716:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].decodeNode; }
break;
case 1717:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1718:
  if (!yytrial)
{ yyval.decodeNode = newNode<DecodeNode>(yyvsp[0].valueExprNode, newNode<ValueListNode>(0u), newNode<ValueListNode>(0u)); }
break;
case 1719:
yyval.valueListNode = NOTRIAL(yyvsp[0].decodeNode->conditions);
break;
case 1720:
yyval.valueListNode =  NOTRIAL(yyvsp[-1].decodeNode->values);
break;
case 1721:
  if (!yytrial)
{
				DecodeNode* node = yyval.decodeNode = yyvsp[-5].decodeNode;
				node->label = "CASE";
				if (yyvsp[-1].valueExprNode)
					node->values->add(yyvsp[-1].valueExprNode);
			}
break;
case 1722:
  if (!yytrial)
{
			yyvsp[-5].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-4].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 1723:
  if (!yytrial)
{
			yyvsp[-6].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-5].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 1724:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1725:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1726:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueIfNode; }
break;
case 1727:
  if (!yytrial)
{
			ValueIfNode* last = yyvsp[-3].valueIfNode;
			ValueIfNode* next;

			while ((next = last->falseValue->as<ValueIfNode>()))
				last = next;

			fb_assert(last->falseValue->is<NullNode>());

			last->falseValue = yyvsp[-1].valueExprNode;
			yyval.valueExprNode = yyvsp[-3].valueIfNode;
		}
break;
case 1728:
  if (!yytrial)
{ yyval.valueIfNode = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, newNode<NullNode>()); }
break;
case 1729:
  if (!yytrial)
{
			ValueIfNode* cond = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, newNode<NullNode>());
			ValueIfNode* last = yyvsp[-4].valueIfNode;
			ValueIfNode* next;

			while ((next = last->falseValue->as<ValueIfNode>()))
				last = next;

			fb_assert(last->falseValue->is<NullNode>());

			last->falseValue = cond;
			yyval.valueIfNode = yyvsp[-4].valueIfNode;
		}
break;
case 1733:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0u)->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 1734:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-4].valueListNode->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 1735:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[0].metaNamePtr, ((Jrd::ValueExprNode*) NULL), true, false);
		}
break;
case 1736:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[-3].metaNamePtr, yyvsp[-1].valueExprNode, false, false);
		}
break;
case 1737:
  if (!yytrial)
{ yyval.blrOp = blr_extract_year; }
break;
case 1738:
  if (!yytrial)
{ yyval.blrOp = blr_extract_month; }
break;
case 1739:
  if (!yytrial)
{ yyval.blrOp = blr_extract_day; }
break;
case 1740:
  if (!yytrial)
{ yyval.blrOp = blr_extract_hour; }
break;
case 1741:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 1742:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 1743:
  if (!yytrial)
{ yyval.blrOp = blr_extract_millisecond; }
break;
case 1744:
  if (!yytrial)
{ yyval.blrOp = blr_extract_week; }
break;
case 1745:
  if (!yytrial)
{ yyval.blrOp = blr_extract_weekday; }
break;
case 1746:
  if (!yytrial)
{ yyval.blrOp = blr_extract_yearday; }
break;
case 1751:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NullNode>(); }
break;
case 1752:
  if (!yytrial)
{
			dsql_fld* field = newNode<dsql_fld>();
			field->dtype = dtype_boolean;
			field->length = sizeof(UCHAR);

			CastNode* castNode = newNode<CastNode>(newNode<NullNode>(), field);
			castNode->dsqlAlias = "CONSTANT";
			yyval.valueExprNode = castNode;
		}
break;

  default:
    break;
  }

#if YYDEBUG && defined(YYDBPR)
  if (yydebug) {
    printf("yydebug[%d]: after reduction, result is ", yytrial);
    YYDBPR(yyps->val);
    printf("\n");
  }
#endif

  // Perform user-defined position reduction
#ifdef YYREDUCEPOSNFUNC
  if (!yytrial) {
    YYCALLREDUCEPOSN(YYREDUCEPOSNFUNCARG);
  }
#endif

  yyps->ssp -= yym;
  yystate = *(yyps->ssp);
  yyps->vsp -= yym;
  yyps->psp -= yym;

  yym = yylhs[yyn];
  if (yystate == 0 && yym == 0) {
#if YYDEBUG
    if (yydebug) {
      printf("yydebug[%d,%p]: after reduction, shifting from state 0 to state %d\n",
	     int(yydepth), yytrial, YYFINAL);
    }
#endif
    yystate = YYFINAL;
    *++(yyps->ssp) = YYFINAL;
    *++(yyps->vsp) = yyps->val;
    yyretlval = yyps->val;	// return value of root non-terminal to yylval
    *++(yyps->psp) = yyps->pos;
    yyretposn = yyps->pos;	// return value of root position to yyposn
    if (yychar < 0) {
      if ((yychar = yylex1()) < 0) {
        yychar = 0;
      }
#if YYDEBUG
      if (yydebug) {
        yys = 0;
        if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
        if (!yys) yys = "illegal-symbol";
        printf("yydebug[%d,%p]: state %d, reading %d (%s)\n",
	       int(yydepth), yytrial, YYFINAL, yychar, yys);
      }
#endif
    }
    if (yychar == 0) goto yyaccept;
    goto yyloop;
  }

  if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
      yyn <= YYTABLESIZE && yycheck[yyn] == yystate) {
    yystate = yytable[yyn];
  } else {
    yystate = yydgoto[yym];
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: after reduction, shifting from state %d to state %d\n",
           int(yydepth), yytrial, *(yyps->ssp), yystate);
#endif
  if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
    yyMoreStack(yyps);
  }
  *++(yyps->ssp) = yystate;
  *++(yyps->vsp) = yyps->val;
  *++(yyps->psp) = yyps->pos;
  goto yyloop;


  //
  // Reduction declares that this path is valid.
  // Set yypath and do a full parse
  //
yyvalid:
  if (yypath) {
    goto yyabort;
  }
  while (yyps->save) {
    yyparsestate *save = yyps->save;
    yyps->save = save->save;
    save->save = yypath;
    yypath = save;
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: CONFLICT trial successful, backtracking to state %d, %d tokens\n",
           int(yydepth), yytrial, yypath->state, int(yylvp - yylvals - yypath->lexeme));
#endif
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  yychar = -1;
  yyps->ssp = yyps->ss + (yypath->ssp - yypath->ss);
  yyps->vsp = yyps->vs + (yypath->vsp - yypath->vs);
  yyps->psp = yyps->ps + (yypath->psp - yypath->ps);
  memcpy (yyps->ss, yypath->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
  yySCopy(yyps->vs, yypath->vs,  yyps->vsp - yyps->vs + 1);
  yyPCopy(yyps->ps, yypath->ps,  yyps->psp - yyps->ps + 1);
  yylvp = yylvals + yypath->lexeme;
  yylpp = yylpsns + yypath->lexeme;
  yylexp = yylexemes + yypath->lexeme;
  yystate = yypath->state;
  goto yyloop;


yyabort:
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }

  YYSTYPE *pv;
  for(pv = yyps->vs; pv < yyps->vsp; pv++) {
    YYDELETEVAL(*pv, 2);
  }

  YYPOSN *pp;
  for(pp = yyps->ps; pp < yyps->psp; pp++) {
    YYDELETEPOSN(*pp, 2);
  }

  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save);
  }
  return (1);


yyaccept:
  if (yyps->save) goto yyvalid;
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save);
  }
  return (0);
}


int Parser::yylex1()
{
  if (yylvp < yylve) {
    yylval = *yylvp++;
    yyposn = *yylpp++;
    return *yylexp++;
  } else {
    if (yyps->save) {
      if (yylvp == yylvlim) {
	yyexpand();
      }
      *yylexp = yylex();
      *yylvp++ = yylval;
      yylve++;
      *yylpp++ = yyposn;
      yylpe++;
      return *yylexp++;
    } else {
      return yylex();
    }
  }
}


int Parser::yyexpand()
{
  int p = yylvp - yylvals;
  int s = yylvlim - yylvals;
  s += YYSTACKGROWTH;
  { Yshort  *tl = yylexemes;
    YYSTYPE *tv = yylvals;
    YYPOSN  *tp = yylpsns;
    yylvals = FB_NEW_POOL(getPool()) YYSTYPE[s];
    yylpsns = FB_NEW_POOL(getPool()) YYPOSN[s];
    yylexemes = FB_NEW_POOL(getPool()) Yshort[s];
    memcpy(yylexemes, tl, (s - YYSTACKGROWTH) * sizeof(Yshort));
    yySCopy(yylvals, tv, s - YYSTACKGROWTH);
    yyPCopy(yylpsns, tp, s - YYSTACKGROWTH);
    delete[] tl;
    delete[] tv;
    delete[] tp;
  }
  yylvp = yylve = yylvals + p;
  yylvlim = yylvals + s;
  yylpp = yylpe = yylpsns + p;
  yylplim = yylpsns + s;
  yylexp = yylexemes + p;
  return 0;
}

